/*
 * Drag_and_Drop methods tests
 * Testing Drag_and_Drop methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
GtkTargetEntry target_table[] = {
    {"text/plain", GTK_TARGET_SAME_APP, 0},
    {"text/html", GTK_TARGET_SAME_APP, 1},
    {"image/x-pixmap", GTK_TARGET_SAME_APP, 2},
    {"application/x-rootwin-drop", GTK_TARGET_SAME_APP, 3}
    };
gint n_targets = 3; /*no rootwin*/


/*
 * Name: gtk_drag_dest_set
 * Params: GtkWidget *widget, GtkDestDefaults flags, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets a widget as a potential drop destination.
 * Params Values: newly created GtkWidget*, GTK_DEST_DEFAULT_MOTION , target_table, n_targets, GDK_ACTION_DEFAULT
 * Expected: void  
 */
static void test_purpose_1()
{
    #define FLAGS GTK_DEST_DEFAULT_MOTION 
    #define ACTIONS GDK_ACTION_DEFAULT
    #define WIDGET gtk_label_new ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set
 * Params: GtkWidget *widget, GtkDestDefaults flags, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets a widget as a potential drop destination.
 * Params Values: newly created GtkWidget*, GTK_DEST_DEFAULT_MOTION , target_table, n_targets, GDK_ACTION_COPY  
 * Expected: void  
 */
static void test_purpose_2()
{
    #define FLAGS GTK_DEST_DEFAULT_MOTION 
    #define ACTIONS GDK_ACTION_COPY  
    #define WIDGET gtk_button_new_with_label ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set
 * Params: GtkWidget *widget, GtkDestDefaults flags, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets a widget as a potential drop destination.
 * Params Values: newly created GtkWidget*, GTK_DEST_DEFAULT_MOTION , target_table, n_targets, GDK_ACTION_MOVE  
 * Expected: void  
 */
static void test_purpose_3()
{
    #define FLAGS GTK_DEST_DEFAULT_MOTION 
    #define ACTIONS GDK_ACTION_MOVE  
    #define WIDGET gtk_label_new ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set
 * Params: GtkWidget *widget, GtkDestDefaults flags, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets a widget as a potential drop destination.
 * Params Values: newly created GtkWidget*, GTK_DEST_DEFAULT_MOTION , target_table, n_targets, GDK_ACTION_LINK  
 * Expected: void  
 */
static void test_purpose_4()
{
    #define FLAGS GTK_DEST_DEFAULT_MOTION 
    #define ACTIONS GDK_ACTION_LINK  
    #define WIDGET gtk_button_new_with_label ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set
 * Params: GtkWidget *widget, GtkDestDefaults flags, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets a widget as a potential drop destination.
 * Params Values: newly created GtkWidget*, GTK_DEST_DEFAULT_MOTION , target_table, n_targets, GDK_ACTION_PRIVATE
 * Expected: void  
 */
static void test_purpose_5()
{
    #define FLAGS GTK_DEST_DEFAULT_MOTION 
    #define ACTIONS GDK_ACTION_PRIVATE
    #define WIDGET gtk_label_new ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set
 * Params: GtkWidget *widget, GtkDestDefaults flags, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets a widget as a potential drop destination.
 * Params Values: newly created GtkWidget*, GTK_DEST_DEFAULT_MOTION , target_table, n_targets, GDK_ACTION_ASK    
 * Expected: void  
 */
static void test_purpose_6()
{
    #define FLAGS GTK_DEST_DEFAULT_MOTION 
    #define ACTIONS GDK_ACTION_ASK    
    #define WIDGET gtk_button_new_with_label ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set
 * Params: GtkWidget *widget, GtkDestDefaults flags, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets a widget as a potential drop destination.
 * Params Values: newly created GtkWidget*, GTK_DEST_DEFAULT_DROP, target_table, n_targets, GDK_ACTION_DEFAULT
 * Expected: void  
 */
static void test_purpose_7()
{
    #define FLAGS GTK_DEST_DEFAULT_DROP
    #define ACTIONS GDK_ACTION_DEFAULT
    #define WIDGET gtk_label_new ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set
 * Params: GtkWidget *widget, GtkDestDefaults flags, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets a widget as a potential drop destination.
 * Params Values: newly created GtkWidget*, GTK_DEST_DEFAULT_DROP   , target_table, n_targets, GDK_ACTION_COPY  
 * Expected: void  
 */
static void test_purpose_8()
{
    #define FLAGS GTK_DEST_DEFAULT_DROP   
    #define ACTIONS GDK_ACTION_COPY  
    #define WIDGET gtk_button_new_with_label ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set
 * Params: GtkWidget *widget, GtkDestDefaults flags, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets a widget as a potential drop destination.
 * Params Values: newly created GtkWidget*, GTK_DEST_DEFAULT_DROP, target_table, n_targets, GDK_ACTION_MOVE  
 * Expected: void  
 */
static void test_purpose_9()
{
    #define FLAGS GTK_DEST_DEFAULT_DROP
    #define ACTIONS GDK_ACTION_MOVE  
    #define WIDGET gtk_label_new ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set
 * Params: GtkWidget *widget, GtkDestDefaults flags, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets a widget as a potential drop destination.
 * Params Values: newly created GtkWidget*, GTK_DEST_DEFAULT_DROP, target_table, n_targets, GDK_ACTION_LINK  
 * Expected: void  
 */
static void test_purpose_10()
{
    #define FLAGS GTK_DEST_DEFAULT_DROP
    #define ACTIONS GDK_ACTION_LINK  
    #define WIDGET gtk_button_new_with_label ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set
 * Params: GtkWidget *widget, GtkDestDefaults flags, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets a widget as a potential drop destination.
 * Params Values: newly created GtkWidget*, GTK_DEST_DEFAULT_DROP, target_table, n_targets, GDK_ACTION_PRIVATE
 * Expected: void  
 */
static void test_purpose_11()
{
    #define FLAGS GTK_DEST_DEFAULT_DROP
    #define ACTIONS GDK_ACTION_PRIVATE
    #define WIDGET gtk_label_new ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set
 * Params: GtkWidget *widget, GtkDestDefaults flags, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets a widget as a potential drop destination.
 * Params Values: newly created GtkWidget*, GTK_DEST_DEFAULT_DROP, target_table, n_targets, GDK_ACTION_ASK    
 * Expected: void  
 */
static void test_purpose_12()
{
    #define FLAGS GTK_DEST_DEFAULT_DROP
    #define ACTIONS GDK_ACTION_ASK    
    #define WIDGET gtk_button_new_with_label ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set
 * Params: GtkWidget *widget, GtkDestDefaults flags, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets a widget as a potential drop destination.
 * Params Values: newly created GtkWidget*, GTK_DEST_DEFAULT_HIGHLIGHT , target_table, n_targets, GDK_ACTION_PRIVATE
 * Expected: void  
 */
static void test_purpose_13()
{
    #define FLAGS GTK_DEST_DEFAULT_HIGHLIGHT 
    #define ACTIONS GDK_ACTION_PRIVATE
    #define WIDGET gtk_button_new_with_label ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set
 * Params: GtkWidget *widget, GtkDestDefaults flags, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets a widget as a potential drop destination.
 * Params Values: newly created GtkWidget*, GTK_DEST_DEFAULT_ALL       , target_table, n_targets, GDK_ACTION_MOVE  
 * Expected: void  
 */
static void test_purpose_14()
{
    #define FLAGS GTK_DEST_DEFAULT_ALL       
    #define ACTIONS GDK_ACTION_MOVE  
    #define WIDGET gtk_label_new ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set_proxy
 * Params: GtkWidget *widget, GdkWindow *proxy_window, GdkDragProtocol protocol, gboolean use_coordinates
 * Returns: void
 * Assertion: Sets this widget as a proxy for drops to another window.
 * Params Values: newly created GtkWidget*, NULL, GDK_DRAG_PROTO_ROOTWIN, FALSE 
 * Expected: void  
 */
static void test_purpose_15()
{
    #define WIDGET gtk_button_new_with_label ("Drop Here\n")
    #define PROXY_WINDOW NULL
    #define PROTOCOL GDK_DRAG_PROTO_ROOTWIN
    #define USE_COORDINATES FALSE 
    
    GtkWidget* widget;
    GdkWindowAttr attributes;
    GdkWindow* proxy_window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.title = "";
    attributes.cursor = 0;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual(widget);
    attributes.colormap = gtk_widget_get_colormap(widget);
    attributes.event_mask = gtk_widget_get_events(widget);
    proxy_window = PROXY_WINDOW;
    gtk_drag_dest_set_proxy (widget, proxy_window, PROTOCOL, USE_COORDINATES);
    
    #undef WIDGET
    #undef PROXY_WINDOW
    #undef PROTOCOL
    #undef USE_COORDINATES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set_proxy
 * Params: GtkWidget *widget, GdkWindow *proxy_window, GdkDragProtocol protocol, gboolean use_coordinates
 * Returns: void
 * Assertion: Sets this widget as a proxy for drops to another window.
 * Params Values: newly created GtkWidget*, gdk_window_new (NULL, &attributes, GDK_WA_TITLE), GDK_DRAG_PROTO_MOTIF, TRUE 
 * Expected: void  
 */
static void test_purpose_16()
{
    #define WIDGET gtk_label_new ("Drop Here\n")
    #define PROXY_WINDOW gdk_window_new (NULL, &attributes, GDK_WA_TITLE)
    #define PROTOCOL GDK_DRAG_PROTO_MOTIF
    #define USE_COORDINATES TRUE 
    
    GtkWidget* widget;
    GdkWindowAttr attributes;
    GdkWindow* proxy_window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.title = "";
    attributes.cursor = 0;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual(widget);
    attributes.colormap = gtk_widget_get_colormap(widget);
    attributes.event_mask = gtk_widget_get_events(widget);
    proxy_window = PROXY_WINDOW;
    gtk_drag_dest_set_proxy (widget, proxy_window, PROTOCOL, USE_COORDINATES);
    
    #undef WIDGET
    #undef PROXY_WINDOW
    #undef PROTOCOL
    #undef USE_COORDINATES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set_proxy
 * Params: GtkWidget *widget, GdkWindow *proxy_window, GdkDragProtocol protocol, gboolean use_coordinates
 * Returns: void
 * Assertion: Sets this widget as a proxy for drops to another window.
 * Params Values: newly created GtkWidget*, gdk_window_new (NULL, &attributes, GDK_WA_X | GDK_WA_Y), GDK_DRAG_PROTO_XDND, FALSE 
 * Expected: void  
 */
static void test_purpose_17()
{
    #define WIDGET gtk_button_new_with_label ("Drop Here\n")
    #define PROXY_WINDOW gdk_window_new (NULL, &attributes, GDK_WA_X | GDK_WA_Y)
    #define PROTOCOL GDK_DRAG_PROTO_XDND
    #define USE_COORDINATES FALSE 
    
    GtkWidget* widget;
    GdkWindowAttr attributes;
    GdkWindow* proxy_window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.title = "";
    attributes.cursor = 0;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual(widget);
    attributes.colormap = gtk_widget_get_colormap(widget);
    attributes.event_mask = gtk_widget_get_events(widget);
    proxy_window = PROXY_WINDOW;
    gtk_drag_dest_set_proxy (widget, proxy_window, PROTOCOL, USE_COORDINATES);
    
    #undef WIDGET
    #undef PROXY_WINDOW
    #undef PROTOCOL
    #undef USE_COORDINATES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set_proxy
 * Params: GtkWidget *widget, GdkWindow *proxy_window, GdkDragProtocol protocol, gboolean use_coordinates
 * Returns: void
 * Assertion: Sets this widget as a proxy for drops to another window.
 * Params Values: newly created GtkWidget*, gdk_window_new (NULL, &attributes, GDK_WA_CURSOR), GDK_DRAG_PROTO_OLE2, FALSE 
 * Expected: void  
 */
static void test_purpose_18()
{
    #define WIDGET gtk_button_new_with_label ("Drop Here\n")
    #define PROXY_WINDOW gdk_window_new (NULL, &attributes, GDK_WA_CURSOR)
    #define PROTOCOL GDK_DRAG_PROTO_OLE2
    #define USE_COORDINATES FALSE 
    
    GtkWidget* widget;
    GdkWindowAttr attributes;
    GdkWindow* proxy_window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.title = "";
    attributes.cursor = 0;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual(widget);
    attributes.colormap = gtk_widget_get_colormap(widget);
    attributes.event_mask = gtk_widget_get_events(widget);
    proxy_window = PROXY_WINDOW;
    gtk_drag_dest_set_proxy (widget, proxy_window, PROTOCOL, USE_COORDINATES);
    
    #undef WIDGET
    #undef PROXY_WINDOW
    #undef PROTOCOL
    #undef USE_COORDINATES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set_proxy
 * Params: GtkWidget *widget, GdkWindow *proxy_window, GdkDragProtocol protocol, gboolean use_coordinates
 * Returns: void
 * Assertion: Sets this widget as a proxy for drops to another window.
 * Params Values: newly created GtkWidget*, gdk_window_new (NULL, &attributes, GDK_WA_NOREDIR), GDK_DRAG_PROTO_WIN32_DROPFILES, TRUE 
 * Expected: void  
 */
static void test_purpose_19()
{
    #define WIDGET gtk_button_new_with_label ("Drop Here\n")
    #define PROXY_WINDOW gdk_window_new (NULL, &attributes, GDK_WA_NOREDIR)
    #define PROTOCOL GDK_DRAG_PROTO_WIN32_DROPFILES
    #define USE_COORDINATES TRUE 
    
    GtkWidget* widget;
    GdkWindowAttr attributes;
    GdkWindow* proxy_window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.title = "";
    attributes.cursor = 0;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual(widget);
    attributes.colormap = gtk_widget_get_colormap(widget);
    attributes.event_mask = gtk_widget_get_events(widget);
    proxy_window = PROXY_WINDOW;
    gtk_drag_dest_set_proxy (widget, proxy_window, PROTOCOL, USE_COORDINATES);
    
    #undef WIDGET
    #undef PROXY_WINDOW
    #undef PROTOCOL
    #undef USE_COORDINATES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set_proxy
 * Params: GtkWidget *widget, GdkWindow *proxy_window, GdkDragProtocol protocol, gboolean use_coordinates
 * Returns: void
 * Assertion: Sets this widget as a proxy for drops to another window.
 * Params Values: newly created GtkWidget*, gdk_window_new (NULL, &attributes, GDK_WA_TITLE), GDK_DRAG_PROTO_LOCAL, TRUE 
 * Expected: void  
 */
static void test_purpose_20()
{
    #define WIDGET gtk_label_new ("Drop Here\n")
    #define PROXY_WINDOW gdk_window_new (NULL, &attributes, GDK_WA_TITLE)
    #define PROTOCOL GDK_DRAG_PROTO_LOCAL
    #define USE_COORDINATES TRUE 
    
    GtkWidget* widget;
    GdkWindowAttr attributes;
    GdkWindow* proxy_window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    attributes.window_type = GDK_WINDOW_TOPLEVEL;
    attributes.title = "";
    attributes.cursor = 0;
    attributes.x = widget->allocation.x;
    attributes.y = widget->allocation.y;
    attributes.width = widget->allocation.width;
    attributes.height = widget->allocation.height;
    attributes.wclass = GDK_INPUT_OUTPUT;
    attributes.visual = gtk_widget_get_visual(widget);
    attributes.colormap = gtk_widget_get_colormap(widget);
    attributes.event_mask = gtk_widget_get_events(widget);
    proxy_window = PROXY_WINDOW;
    gtk_drag_dest_set_proxy (widget, proxy_window, PROTOCOL, USE_COORDINATES);
    
    #undef WIDGET
    #undef PROXY_WINDOW
    #undef PROTOCOL
    #undef USE_COORDINATES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Clears information about a drop destination set with gtk_drag_dest_set().
 * Params Values: newly created GtkWidget*
 * Expected: void
 * 
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: The widget will no longer receive notification of drags.
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_21()
{
    #define FLAGS GTK_DEST_DEFAULT_MOTION 
    #define ACTIONS GDK_ACTION_DEFAULT
    #define WIDGET gtk_label_new ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    gtk_drag_dest_unset (widget);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Clears information about a drop destination set with gtk_drag_dest_set().
 * Params Values: newly created GtkWidget*
 * Expected: void
 * 
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: The widget will no longer receive notification of drags.
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_22()
{
    #define FLAGS GTK_DEST_DEFAULT_MOTION 
    #define ACTIONS GDK_ACTION_COPY  
    #define WIDGET gtk_button_new_with_label ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    gtk_drag_dest_unset (widget);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Clears information about a drop destination set with gtk_drag_dest_set().
 * Params Values: newly created GtkWidget*
 * Expected: void
 * 
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: The widget will no longer receive notification of drags.
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_23()
{
    #define FLAGS GTK_DEST_DEFAULT_MOTION 
    #define ACTIONS GDK_ACTION_MOVE  
    #define WIDGET gtk_label_new ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    gtk_drag_dest_unset (widget);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Clears information about a drop destination set with gtk_drag_dest_set().
 * Params Values: newly created GtkWidget*
 * Expected: void
 * 
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: The widget will no longer receive notification of drags.
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_24()
{
    #define FLAGS GTK_DEST_DEFAULT_MOTION 
    #define ACTIONS GDK_ACTION_LINK  
    #define WIDGET gtk_button_new_with_label ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    gtk_drag_dest_unset (widget);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Clears information about a drop destination set with gtk_drag_dest_set().
 * Params Values: newly created GtkWidget*
 * Expected: void
 * 
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: The widget will no longer receive notification of drags.
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_25()
{
    #define FLAGS GTK_DEST_DEFAULT_MOTION 
    #define ACTIONS GDK_ACTION_PRIVATE
    #define WIDGET gtk_label_new ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    gtk_drag_dest_unset (widget);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Clears information about a drop destination set with gtk_drag_dest_set().
 * Params Values: newly created GtkWidget*
 * Expected: void
 * 
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: The widget will no longer receive notification of drags.
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_26()
{
    #define FLAGS GTK_DEST_DEFAULT_MOTION 
    #define ACTIONS GDK_ACTION_ASK    
    #define WIDGET gtk_button_new_with_label ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    gtk_drag_dest_unset (widget);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Clears information about a drop destination set with gtk_drag_dest_set().
 * Params Values: newly created GtkWidget*
 * Expected: void
 * 
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: The widget will no longer receive notification of drags.
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_27()
{
    #define FLAGS GTK_DEST_DEFAULT_DROP
    #define ACTIONS GDK_ACTION_DEFAULT
    #define WIDGET gtk_label_new ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    gtk_drag_dest_unset (widget);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Clears information about a drop destination set with gtk_drag_dest_set().
 * Params Values: newly created GtkWidget*
 * Expected: void
 * 
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: The widget will no longer receive notification of drags.
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_28()
{
    #define FLAGS GTK_DEST_DEFAULT_DROP   
    #define ACTIONS GDK_ACTION_COPY  
    #define WIDGET gtk_button_new_with_label ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    gtk_drag_dest_unset (widget);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Clears information about a drop destination set with gtk_drag_dest_set().
 * Params Values: newly created GtkWidget*
 * Expected: void
 * 
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: The widget will no longer receive notification of drags.
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_29()
{
    #define FLAGS GTK_DEST_DEFAULT_DROP
    #define ACTIONS GDK_ACTION_MOVE  
    #define WIDGET gtk_label_new ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    gtk_drag_dest_unset (widget);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Clears information about a drop destination set with gtk_drag_dest_set().
 * Params Values: newly created GtkWidget*
 * Expected: void
 * 
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: The widget will no longer receive notification of drags.
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_30()
{
    #define FLAGS GTK_DEST_DEFAULT_DROP
    #define ACTIONS GDK_ACTION_LINK  
    #define WIDGET gtk_button_new_with_label ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    gtk_drag_dest_unset (widget);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Clears information about a drop destination set with gtk_drag_dest_set().
 * Params Values: newly created GtkWidget*
 * Expected: void
 * 
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: The widget will no longer receive notification of drags.
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_31()
{
    #define FLAGS GTK_DEST_DEFAULT_DROP
    #define ACTIONS GDK_ACTION_PRIVATE
    #define WIDGET gtk_label_new ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    gtk_drag_dest_unset (widget);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Clears information about a drop destination set with gtk_drag_dest_set().
 * Params Values: newly created GtkWidget*
 * Expected: void
 * 
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: The widget will no longer receive notification of drags.
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_32()
{
    #define FLAGS GTK_DEST_DEFAULT_DROP
    #define ACTIONS GDK_ACTION_ASK    
    #define WIDGET gtk_button_new_with_label ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    gtk_drag_dest_unset (widget);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Clears information about a drop destination set with gtk_drag_dest_set().
 * Params Values: newly created GtkWidget*
 * Expected: void
 * 
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: The widget will no longer receive notification of drags.
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_33()
{
    #define FLAGS GTK_DEST_DEFAULT_HIGHLIGHT 
    #define ACTIONS GDK_ACTION_PRIVATE
    #define WIDGET gtk_button_new_with_label ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    gtk_drag_dest_unset (widget);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Clears information about a drop destination set with gtk_drag_dest_set().
 * Params Values: newly created GtkWidget*
 * Expected: void
 * 
 * Name: gtk_drag_dest_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: The widget will no longer receive notification of drags.
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_34()
{
    #define FLAGS GTK_DEST_DEFAULT_ALL       
    #define ACTIONS GDK_ACTION_MOVE  
    #define WIDGET gtk_label_new ("Drop Here\n")
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    gtk_drag_dest_unset (widget);
    
    #undef FLAGS 
    #undef ACTIONS
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_find_target
 * Params: GtkWidget *widget, GdkDragContext *context, GtkTargetList *target_list
 * Returns: GdkAtom
 * Assertion: Looks for a match between context->targets and the dest_target_list, returning the first matching target, otherwise returning GDK_NONE.
 * Params Values: gtk_label_new ("Drop Here\n"), newly created GdkDragContext, GtkTargetList*
 * Expected:    
 */
static void test_purpose_35()
{
    #define FLAGS GTK_DEST_DEFAULT_MOTION 
    #define ACTIONS GDK_ACTION_DEFAULT
    #define WIDGET gtk_label_new ("Drop Here\n")
    
    GtkWidget* widget;
    GtkWidget* source_widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GdkAtom atom;
    gchar* atom_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    drag_context = gdk_drag_context_new ();
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    target_list = gtk_drag_dest_get_target_list (widget);
    atom = gtk_drag_dest_find_target (widget, drag_context, target_list);
    atom_str = gdk_atom_name (atom);
    
    /* LSB bug 2700 - newer GTK does not return "NONE" for gdk_atom_name(GDK_NONE)
    if (strcmp(atom_str, "NONE"))
    {
        TEST_FAIL ("gtk_drag_dest_find_target () returns %s, but it should be GDK_NONE.", atom_str); 
    }
    */
    
    if (atom != GDK_NONE)
    {
        TEST_FAIL ("gtk_drag_dest_find_target () returns %d, but it should be GDK_NONE (NULL).", atom); 
    }
    
    #undef FLAGS
    #undef ACTIONS
    #undef WIDGET 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_find_target
 * Params: GtkWidget *widget, GdkDragContext *context, GtkTargetList *target_list
 * Returns: GdkAtom
 * Assertion: Looks for a match between context->targets and the dest_target_list, returning the first matching target, otherwise returning GDK_NONE.
 * Params Values: gtk_label_new ("Drop Here\n"), newly created GdkDragContext, GtkTargetList*
 * Expected:    
 */
static void test_purpose_36()
{
    #define FLAGS GTK_DEST_DEFAULT_MOTION 
    #define ACTIONS GDK_ACTION_DEFAULT
    #define WIDGET gtk_label_new ("Drop Here\n")
    
    GtkWidget* source_widget;
    GtkWidget* widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    GdkAtom atom;
    gchar* atom_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, 0, event);
    drag_context->is_source = FALSE;
    drag_context->protocol = GDK_DRAG_PROTO_XDND;
    
    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, target_table, n_targets, ACTIONS);
    target_list = gtk_drag_dest_get_target_list (widget);
    atom = gtk_drag_dest_find_target (widget, drag_context, target_list);
    atom_str = gdk_atom_name (atom);
    
    if (!strcmp(atom_str, "NONE"))
    {
        TEST_FAIL ("gtk_drag_dest_find_target () return GDK_NONE, but it shouldn't.", NULL); 
    }
    
    #undef FLAGS
    #undef ACTIONS
    #undef WIDGET 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set_target_list
 * Params: GtkWidget *widget, GtkTargetList *target_list
 * Returns: void
 * Assertion: Sets the target types that this widget can accept from drag-and-drop. 
 * Params Values: gtk_label_new ("Drop Here\n") result, gtk_target_list_new (target_table, n_targets)
 * Expected: void
 * 
 * Name: gtk_drag_dest_get_target_list
 * Params: GtkWidget *widget
 * Returns: GtkTargetList*
 * Assertion: Returns the list of targets this widget can accept from drag-and-drop.
 * Params Values: gtk_label_new ("Drop Here\n") result
 * Expected: gtk_target_list_new (target_table, n_targets)  
 */
static void test_purpose_37()
{
    #define FLAGS GTK_DEST_DEFAULT_MOTION 
    #define ACTIONS GDK_ACTION_DEFAULT
    #define WIDGET gtk_label_new ("Drop Here\n")
    #define TARGET_LIST gtk_target_list_new (target_table, n_targets)
    
    GtkWidget* widget;
    GtkTargetList* target_list;
    GtkTargetList* real_target_list;
    GdkAtom atom;
    int i;
    gint info;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, NULL, 0, ACTIONS);
    target_list = TARGET_LIST;
    gtk_drag_dest_set_target_list (widget, target_list);
    real_target_list = gtk_drag_dest_get_target_list (widget);
    if (target_list != NULL)
    {
      for (i =0; i < n_targets; i++)
      {
        atom = gdk_atom_intern (target_table[i].target, FALSE);
        if (!gtk_target_list_find (real_target_list, atom, &info))
        {
            TEST_FAIL ("target_table[%i]='%s' not found in target list that was set by gtk_drag_dest_set_target_list ()", 
                       i, target_table[i].target);         
        }
      }
    } else {
        if (real_target_list != NULL)
        {
            TEST_FAIL ("gtk_drag_dest_get_target_list () result is not NULL !", NULL); 
        }
    }
    #undef FLAGS
    #undef ACTIONS
    #undef WIDGET 
    #undef TARGET_LIST
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_dest_set_target_list
 * Params: GtkWidget *widget, GtkTargetList *target_list
 * Returns: void
 * Assertion: Sets the target types that this widget can accept from drag-and-drop. 
 * Params Values: gtk_button_new_with_label ("Drop Here\n") result, NULL
 * Expected: void
 * 
 * Name: gtk_drag_dest_get_target_list
 * Params: GtkWidget *widget
 * Returns: GtkTargetList*
 * Assertion: Returns the list of targets this widget can accept from drag-and-drop.
 * Params Values: gtk_button_new_with_label ("Drop Here\n") result
 * Expected: NULL  
 */
static void test_purpose_38()
{
    #define FLAGS GTK_DEST_DEFAULT_HIGHLIGHT 
    #define ACTIONS GDK_ACTION_PRIVATE
    #define WIDGET gtk_button_new_with_label ("Drop Here\n")
    #define TARGET_LIST NULL
    
    GtkWidget* widget;
    GtkTargetList* target_list;
    GtkTargetList* real_target_list;
    GdkAtom atom;
    int i;
    gint info;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_drag_dest_set (widget, FLAGS, NULL, 0, ACTIONS);
    target_list = TARGET_LIST;
    gtk_drag_dest_set_target_list (widget, target_list);
    real_target_list = gtk_drag_dest_get_target_list (widget);
    if (target_list != NULL)
    {
      for (i =0; i < n_targets; i++)
      {
        atom = gdk_atom_intern (target_table[i].target, FALSE);
        if (!gtk_target_list_find (real_target_list, atom, &info))
        {
            TEST_FAIL ("target_table[%i]='%s' not found in target list that was set by gtk_drag_dest_set_target_list ()", 
                       i, target_table[i].target);         
        }
      }
    } else {
        if (real_target_list != NULL)
        {
            TEST_FAIL ("gtk_drag_dest_get_target_list () result is not NULL !", NULL); 
        }
    }
    #undef FLAGS
    #undef ACTIONS
    #undef WIDGET 
    #undef TARGET_LIST
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_finish
 * Params: GdkDragContext *context, gboolean success, gboolean del, guint32 time
 * Returns: void
 * Assertion: Informs the drag source that the drop is finished, and that the data of the drag will no longer be required.
 * Params Values: newly created GdkDragContext*, 
 * Expected: void  
 */
static void test_purpose_39()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define WIDGET gtk_window_new (GTK_WINDOW_TOPLEVEL)
    #define TARGET_LIST gtk_target_list_new (target_table, n_targets)
    #define SUCCESS TRUE
    #define DEL TRUE
    #define TIME 0
    
    
    GtkWidget* widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    gtk_widget_realize (widget);
    target_list = TARGET_LIST;
    drag_context = gtk_drag_begin (widget, target_list, ACTIONS, 0, NULL);
    drag_context->is_source = FALSE;
    drag_context->protocol = GDK_DRAG_PROTO_XDND;
    gtk_drag_finish (drag_context, SUCCESS, DEL, TIME);
    
    #undef ACTIONS
    #undef WIDGET 
    #undef TARGET_LIST
    #undef SUCCESS
    #undef DEL 
    #undef TIME
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_get_data
 * Params: GtkWidget *widget, GdkDragContext *context, GdkAtom target, guint32 time
 * Returns: void
 * Assertion: Gets the data associated with a drag.
 * Params Values: newly created GtkWidget, newly created GdkDragContext, 
 * Expected:    
 */
static void test_purpose_40()
{
    #define FLAGS GTK_DEST_DEFAULT_MOTION 
    #define ACTIONS GDK_ACTION_DEFAULT
    #define WIDGET gtk_label_new ("Drop Here\n")
    
    GtkWidget* source_widget;
    GtkWidget* widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    GdkAtom atom;
    gchar* atom_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    /* LSB bug 2700 - was GdkAtom atom = 0 (in DEFINE), which make tests 
       after this one crash with a 'BadAtom' X error */ 
    atom = gdk_atom_intern ("GDK_NONE", FALSE);
    
    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, 0, event);
    drag_context->is_source = FALSE;
    drag_context->protocol = GDK_DRAG_PROTO_XDND;
    
    gtk_drag_get_data (source_widget, drag_context, atom, 0);
    
    #undef FLAGS
    #undef ACTIONS
    #undef WIDGET 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_get_source_widget
 * Params: GdkDragContext *context
 * Returns: GtkWidget*
 * Assertion: Determines the source widget for a drag.
 * Params Values: newly created GdkDragContext* 
 * Expected: GtkWidget*   
 */
static void test_purpose_41()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    
    GtkWidget* source_widget;
    GtkWidget* widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, 0, event);
    drag_context->is_source = FALSE;
    drag_context->protocol = GDK_DRAG_PROTO_XDND;
    
    widget = gtk_drag_get_source_widget (drag_context);
    
    if (widget != source_widget)
    {
        TEST_FAIL ("gtk_drag_get_source_widget () return %p, instead of %p", widget, source_widget);     
    }
    
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_get_source_widget
 * Params: GdkDragContext *context
 * Returns: GtkWidget*
 * Assertion: Determines the source widget for a drag.
 * Params Values: newly created GdkDragContext* 
 * Expected: GtkWidget*   
 */
static void test_purpose_42()
{
    #define ACTIONS GDK_ACTION_COPY  
    
    GtkWidget* source_widget;
    GtkWidget* widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, 0, event);
    drag_context->is_source = FALSE;
    drag_context->protocol = GDK_DRAG_PROTO_XDND;
    
    widget = gtk_drag_get_source_widget (drag_context);
    
    if (widget != source_widget)
    {
        TEST_FAIL ("gtk_drag_get_source_widget () return %p, instead of %p", widget, source_widget);     
    }
    
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_get_source_widget
 * Params: GdkDragContext *context
 * Returns: GtkWidget*
 * Assertion: Determines the source widget for a drag.
 * Params Values: newly created GdkDragContext* 
 * Expected: GtkWidget*   
 */
static void test_purpose_43()
{
    #define ACTIONS GDK_ACTION_MOVE  
    
    GtkWidget* source_widget;
    GtkWidget* widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, 0, event);
    drag_context->is_source = FALSE;
    drag_context->protocol = GDK_DRAG_PROTO_XDND;
    
    widget = gtk_drag_get_source_widget (drag_context);
    
    if (widget != source_widget)
    {
        TEST_FAIL ("gtk_drag_get_source_widget () return %p, instead of %p", widget, source_widget);     
    }
    
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_get_source_widget
 * Params: GdkDragContext *context
 * Returns: GtkWidget*
 * Assertion: Determines the source widget for a drag.
 * Params Values: newly created GdkDragContext* 
 * Expected: GtkWidget*   
 */
static void test_purpose_44()
{
    #define ACTIONS GDK_ACTION_LINK  
    
    GtkWidget* source_widget;
    GtkWidget* widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, 0, event);
    drag_context->is_source = FALSE;
    drag_context->protocol = GDK_DRAG_PROTO_XDND;
    
    widget = gtk_drag_get_source_widget (drag_context);
    
    if (widget != source_widget)
    {
        TEST_FAIL ("gtk_drag_get_source_widget () return %p, instead of %p", widget, source_widget);     
    }
    
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_get_source_widget
 * Params: GdkDragContext *context
 * Returns: GtkWidget*
 * Assertion: Determines the source widget for a drag.
 * Params Values: newly created GdkDragContext* 
 * Expected: GtkWidget*   
 */
static void test_purpose_45()
{
    #define ACTIONS GDK_ACTION_PRIVATE
    
    GtkWidget* source_widget;
    GtkWidget* widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, 0, event);
    drag_context->is_source = FALSE;
    drag_context->protocol = GDK_DRAG_PROTO_XDND;
    
    widget = gtk_drag_get_source_widget (drag_context);
    
    if (widget != source_widget)
    {
        TEST_FAIL ("gtk_drag_get_source_widget () return %p, instead of %p", widget, source_widget);     
    }
    
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_get_source_widget
 * Params: GdkDragContext *context
 * Returns: GtkWidget*
 * Assertion: Determines the source widget for a drag.
 * Params Values: newly created GdkDragContext* 
 * Expected: GtkWidget*   
 */
static void test_purpose_46()
{
    #define ACTIONS GDK_ACTION_ASK    
    
    GtkWidget* source_widget;
    GtkWidget* widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, 0, event);
    drag_context->is_source = FALSE;
    drag_context->protocol = GDK_DRAG_PROTO_XDND;
    
    widget = gtk_drag_get_source_widget (drag_context);
    
    if (widget != source_widget)
    {
        TEST_FAIL ("gtk_drag_get_source_widget () return %p, instead of %p", widget, source_widget);     
    }
    
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_highlight
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Draws a highlight around a widget. 
 * Params Values: newly created GtkWidget* 
 * Expected: void  
 */
static void test_purpose_47()
{
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("Drop Here\n");
    gtk_drag_highlight (widget);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_unhighlight
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Removes a highlight set by gtk_drag_highlight() from a widget.
 * Params Values: newly created GtkWidget* 
 * Expected: void  
 */
static void test_purpose_48()
{
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_label_new ("Drop Here\n");
    gtk_drag_highlight (widget);
    gtk_drag_unhighlight (widget);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_begin
 * Params: GtkWidget *widget, GtkTargetList *targets, GdkDragAction actions, guint button, GdkEvent *event
 * Returns: GdkDragContext *context
 * Assertion: Initiates a drag on the source side.
 * Params Values: newly created GtkWidget*, newly created GtkTargetList*, GDK_ACTION_DEFAULT, 0, event  
 * Expected: GdkDragContext* that source widget is *widget.   
 */
static void test_purpose_49()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define BUTTON 0
    
    GtkWidget* source_widget;
    GtkWidget* widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    drag_context->is_source = FALSE;
    drag_context->protocol = GDK_DRAG_PROTO_XDND;
    
    widget = gtk_drag_get_source_widget (drag_context);
    
    if (widget != source_widget)
    {
        TEST_FAIL ("gtk_drag_begin () set source widget in %p, instead of %p", widget, source_widget);     
    }
    
    #undef ACTIONS
    #undef BUTTON
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_begin
 * Params: GtkWidget *widget, GtkTargetList *targets, GdkDragAction actions, guint button, GdkEvent *event
 * Returns: GdkDragContext *context
 * Assertion: Initiates a drag on the source side.
 * Params Values: newly created GtkWidget*, newly created GtkTargetList*, GDK_ACTION_COPY  , 1, event  
 * Expected: GdkDragContext* that source widget is *widget.   
 */
static void test_purpose_50()
{
    #define ACTIONS GDK_ACTION_COPY  
    #define BUTTON 1
    
    GtkWidget* source_widget;
    GtkWidget* widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    drag_context->is_source = FALSE;
    drag_context->protocol = GDK_DRAG_PROTO_XDND;
    
    widget = gtk_drag_get_source_widget (drag_context);
    
    if (widget != source_widget)
    {
        TEST_FAIL ("gtk_drag_begin () set source widget in %p, instead of %p", widget, source_widget);     
    }
    
    #undef ACTIONS
    #undef BUTTON
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_begin
 * Params: GtkWidget *widget, GtkTargetList *targets, GdkDragAction actions, guint button, GdkEvent *event
 * Returns: GdkDragContext *context
 * Assertion: Initiates a drag on the source side.
 * Params Values: newly created GtkWidget*, newly created GtkTargetList*, GDK_ACTION_MOVE  , -1, event  
 * Expected: GdkDragContext* that source widget is *widget.   
 */
static void test_purpose_51()
{
    #define ACTIONS GDK_ACTION_MOVE  
    #define BUTTON -1
    
    GtkWidget* source_widget;
    GtkWidget* widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    drag_context->is_source = FALSE;
    drag_context->protocol = GDK_DRAG_PROTO_XDND;
    
    widget = gtk_drag_get_source_widget (drag_context);
    
    if (widget != source_widget)
    {
        TEST_FAIL ("gtk_drag_begin () set source widget in %p, instead of %p", widget, source_widget);     
    }
    
    #undef ACTIONS
    #undef BUTTON
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_begin
 * Params: GtkWidget *widget, GtkTargetList *targets, GdkDragAction actions, guint button, GdkEvent *event
 * Returns: GdkDragContext *context
 * Assertion: Initiates a drag on the source side.
 * Params Values: newly created GtkWidget*, newly created GtkTargetList*, GDK_ACTION_LINK  , G_MAXINT , event  
 * Expected: GdkDragContext* that source widget is *widget.   
 */
static void test_purpose_52()
{
    #define ACTIONS GDK_ACTION_LINK  
    #define BUTTON G_MAXINT 
    
    GtkWidget* source_widget;
    GtkWidget* widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    drag_context->is_source = FALSE;
    drag_context->protocol = GDK_DRAG_PROTO_XDND;
    
    widget = gtk_drag_get_source_widget (drag_context);
    
    if (widget != source_widget)
    {
        TEST_FAIL ("gtk_drag_begin () set source widget in %p, instead of %p", widget, source_widget);     
    }
    
    #undef ACTIONS
    #undef BUTTON
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_begin
 * Params: GtkWidget *widget, GtkTargetList *targets, GdkDragAction actions, guint button, GdkEvent *event
 * Returns: GdkDragContext *context
 * Assertion: Initiates a drag on the source side.
 * Params Values: newly created GtkWidget*, newly created GtkTargetList*, GDK_ACTION_PRIVATE, G_MININT, event  
 * Expected: GdkDragContext* that source widget is *widget.   
 */
static void test_purpose_53()
{
    #define ACTIONS GDK_ACTION_PRIVATE
    #define BUTTON G_MININT
    
    GtkWidget* source_widget;
    GtkWidget* widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    drag_context->is_source = FALSE;
    drag_context->protocol = GDK_DRAG_PROTO_XDND;
    
    widget = gtk_drag_get_source_widget (drag_context);
    
    if (widget != source_widget)
    {
        TEST_FAIL ("gtk_drag_begin () set source widget in %p, instead of %p", widget, source_widget);     
    }
    
    #undef ACTIONS
    #undef BUTTON
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_begin
 * Params: GtkWidget *widget, GtkTargetList *targets, GdkDragAction actions, guint button, GdkEvent *event
 * Returns: GdkDragContext *context
 * Assertion: Initiates a drag on the source side.
 * Params Values: newly created GtkWidget*, newly created GtkTargetList*, GDK_ACTION_ASK    , 0, event  
 * Expected: GdkDragContext* that source widget is *widget.   
 */
static void test_purpose_54()
{
    #define ACTIONS GDK_ACTION_ASK    
    #define BUTTON 0
    
    GtkWidget* source_widget;
    GtkWidget* widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    drag_context->is_source = FALSE;
    drag_context->protocol = GDK_DRAG_PROTO_XDND;
    
    widget = gtk_drag_get_source_widget (drag_context);
    
    if (widget != source_widget)
    {
        TEST_FAIL ("gtk_drag_begin () set source widget in %p, instead of %p", widget, source_widget);     
    }
    
    #undef ACTIONS
    #undef BUTTON
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_set_icon_widget
 * Params: GdkDragContext *context, GtkWidget *widget, gint hot_x, gint hot_y
 * Returns: void
 * Assertion: Changes the icon for a widget to a given widget.  
 * Params Values: newly created GdkDragContext*, newly created GtkWidget*, 0, 0  
 * Expected: void  
 */
static void test_purpose_55()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define BUTTON 0
    #define HOT_X 0
    #define HOT_Y 0
    
    GtkWidget* source_widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    
    gtk_drag_set_icon_widget (drag_context, source_widget, HOT_X, HOT_Y);
    
    #undef ACTIONS
    #undef BUTTON
    #undef HOT_X 
    #undef HOT_Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_set_icon_widget
 * Params: GdkDragContext *context, GtkWidget *widget, gint hot_x, gint hot_y
 * Returns: void
 * Assertion: Changes the icon for a widget to a given widget.  
 * Params Values: newly created GdkDragContext*, newly created GtkWidget*, 1, 1  
 * Expected: void  
 */
static void test_purpose_56()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define BUTTON 0
    #define HOT_X 1
    #define HOT_Y 1
    
    GtkWidget* source_widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    
    gtk_drag_set_icon_widget (drag_context, source_widget, HOT_X, HOT_Y);
    
    #undef ACTIONS
    #undef BUTTON
    #undef HOT_X 
    #undef HOT_Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_set_icon_widget
 * Params: GdkDragContext *context, GtkWidget *widget, gint hot_x, gint hot_y
 * Returns: void
 * Assertion: Changes the icon for a widget to a given widget.  
 * Params Values: newly created GdkDragContext*, newly created GtkWidget*, G_MAXINT, G_MAXINT  
 * Expected: void  
 */
static void test_purpose_57()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define BUTTON 0
    #define HOT_X G_MAXINT
    #define HOT_Y G_MAXINT
    
    GtkWidget* source_widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    
    gtk_drag_set_icon_widget (drag_context, source_widget, HOT_X, HOT_Y);
    
    #undef ACTIONS
    #undef BUTTON
    #undef HOT_X 
    #undef HOT_Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_set_icon_widget
 * Params: GdkDragContext *context, GtkWidget *widget, gint hot_x, gint hot_y
 * Returns: void
 * Assertion: Changes the icon for a widget to a given widget.  
 * Params Values: newly created GdkDragContext*, newly created GtkWidget*, G_MININT, G_MININT  
 * Expected: void  
 */
static void test_purpose_58()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define BUTTON 0
    #define HOT_X G_MININT
    #define HOT_Y G_MININT
    
    GtkWidget* source_widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    
    gtk_drag_set_icon_widget (drag_context, source_widget, HOT_X, HOT_Y);
    
    #undef ACTIONS
    #undef BUTTON
    #undef HOT_X 
    #undef HOT_Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_set_icon_pixmap
 * Params: GdkDragContext *context, GdkColormap *colormap, GdkPixmap *pixmap, GdkBitmap *mask, gint hot_x, gint hot_y
 * Returns: void
 * Assertion: Sets pixmap as the icon for a given drag.
 * Params Values: newly created GdkDragContext*, newly created GdkColormap*, newly created GdkPixmap*, NULL, 0, 0  
 * Expected: void  
 */
static void test_purpose_59()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define BUTTON 0
    #define COLORMAP gdk_colormap_get_system ()
    #define PIXMAP gdk_pixmap_new (NULL, 1, 1, gdk_colormap_get_visual (colormap)->depth)
    #define MASK NULL
    #define HOT_X 0
    #define HOT_Y 0
    
    GtkWidget* source_widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    GdkColormap *colormap;
    GdkPixmap *pixmap;
    GdkBitmap *mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    
    colormap = COLORMAP;
    pixmap = PIXMAP;
    mask = MASK;
    gtk_drag_set_icon_pixmap (drag_context, colormap, pixmap, mask, HOT_X, HOT_Y);
    
    #undef ACTIONS
    #undef BUTTON
    #undef COLORMAP 
    #undef PIXMAP
    #undef MASK 
    #undef HOT_X 
    #undef HOT_Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_set_icon_pixmap
 * Params: GdkDragContext *context, GdkColormap *colormap, GdkPixmap *pixmap, GdkBitmap *mask, gint hot_x, gint hot_y
 * Returns: void
 * Assertion: Sets pixmap as the icon for a given drag.
 * Params Values: newly created GdkDragContext*, newly created GdkColormap*, newly created GdkPixmap*, NULL, 1, 1  
 * Expected: void  
 */
static void test_purpose_60()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define BUTTON 0
    #define COLORMAP gdk_colormap_get_system ()
    #define PIXMAP gdk_pixmap_new (NULL, 1, 1, gdk_colormap_get_visual (colormap)->depth)
    #define MASK NULL
    #define HOT_X 1
    #define HOT_Y 1
    
    GtkWidget* source_widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    GdkColormap *colormap;
    GdkPixmap *pixmap;
    GdkBitmap *mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    
    colormap = COLORMAP;
    pixmap = PIXMAP;
    mask = MASK;
    gtk_drag_set_icon_pixmap (drag_context, colormap, pixmap, mask, HOT_X, HOT_Y);
    
    #undef ACTIONS
    #undef BUTTON
    #undef COLORMAP 
    #undef PIXMAP
    #undef MASK 
    #undef HOT_X 
    #undef HOT_Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_set_icon_pixmap
 * Params: GdkDragContext *context, GdkColormap *colormap, GdkPixmap *pixmap, GdkBitmap *mask, gint hot_x, gint hot_y
 * Returns: void
 * Assertion: Sets pixmap as the icon for a given drag.
 * Params Values: newly created GdkDragContext*, newly created GdkColormap*, newly created GdkPixmap*, NULL, G_MAXINT, G_MAXINT  
 * Expected: void  
 */
static void test_purpose_61()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define BUTTON 0
    #define COLORMAP gdk_colormap_get_system ()
    #define PIXMAP gdk_pixmap_new (NULL, 1, 1, gdk_colormap_get_visual (colormap)->depth)
    #define MASK NULL
    #define HOT_X G_MAXINT
    #define HOT_Y G_MAXINT
    
    GtkWidget* source_widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    GdkColormap *colormap;
    GdkPixmap *pixmap;
    GdkBitmap *mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    
    colormap = COLORMAP;
    pixmap = PIXMAP;
    mask = MASK;
    gtk_drag_set_icon_pixmap (drag_context, colormap, pixmap, mask, HOT_X, HOT_Y);
    
    #undef ACTIONS
    #undef BUTTON
    #undef COLORMAP 
    #undef PIXMAP
    #undef MASK 
    #undef HOT_X 
    #undef HOT_Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_set_icon_pixmap
 * Params: GdkDragContext *context, GdkColormap *colormap, GdkPixmap *pixmap, GdkBitmap *mask, gint hot_x, gint hot_y
 * Returns: void
 * Assertion: Sets pixmap as the icon for a given drag.
 * Params Values: newly created GdkDragContext*, newly created GdkColormap*, newly created GdkPixmap*, NULL, G_MININT, G_MININT  
 * Expected: void  
 */
static void test_purpose_62()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define BUTTON 0
    #define COLORMAP gdk_colormap_get_system ()
    #define PIXMAP gdk_pixmap_new (NULL, 1, 1, gdk_colormap_get_visual (colormap)->depth)
    #define MASK NULL
    #define HOT_X G_MININT
    #define HOT_Y G_MININT
    
    GtkWidget* source_widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    GdkColormap *colormap;
    GdkPixmap *pixmap;
    GdkBitmap *mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    
    colormap = COLORMAP;
    pixmap = PIXMAP;
    mask = MASK;
    gtk_drag_set_icon_pixmap (drag_context, colormap, pixmap, mask, HOT_X, HOT_Y);
    
    #undef ACTIONS
    #undef BUTTON
    #undef COLORMAP 
    #undef PIXMAP
    #undef MASK 
    #undef HOT_X 
    #undef HOT_Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_set_icon_pixbuf
 * Params: GdkDragContext *context, GdkPixbuf *pixbuf, gint hot_x, gint hot_y
 * Returns: void
 * Assertion: Sets pixbuf as the icon for a given drag.
 * Params Values: newly created GdkDragContext*, 0, 0  
 * Expected: void  
 */
static void test_purpose_63()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define BUTTON 0
    #define PIXBUF gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 1, 1)
    #define HOT_X 0
    #define HOT_Y 0
    
    GtkWidget* source_widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    GdkPixbuf *pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    
    pixbuf = PIXBUF;
    gtk_drag_set_icon_pixbuf (drag_context, pixbuf, HOT_X, HOT_Y);
    
    #undef ACTIONS
    #undef BUTTON
    #undef PIXBUF
    #undef HOT_X 
    #undef HOT_Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_set_icon_pixbuf
 * Params: GdkDragContext *context, GdkPixbuf *pixbuf, gint hot_x, gint hot_y
 * Returns: void
 * Assertion: Sets pixbuf as the icon for a given drag.
 * Params Values: newly created GdkDragContext*, 1, 1  
 * Expected: void  
 */
static void test_purpose_64()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define BUTTON 0
    #define PIXBUF gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 1, 1)
    #define HOT_X 1
    #define HOT_Y 1
    
    GtkWidget* source_widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    GdkPixbuf *pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    
    pixbuf = PIXBUF;
    gtk_drag_set_icon_pixbuf (drag_context, pixbuf, HOT_X, HOT_Y);
    
    #undef ACTIONS
    #undef BUTTON
    #undef PIXBUF
    #undef HOT_X 
    #undef HOT_Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_set_icon_pixbuf
 * Params: GdkDragContext *context, GdkPixbuf *pixbuf, gint hot_x, gint hot_y
 * Returns: void
 * Assertion: Sets pixbuf as the icon for a given drag.
 * Params Values: newly created GdkDragContext*, G_MAXINT, G_MAXINT  
 * Expected: void  
 */
static void test_purpose_65()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define BUTTON 0
    #define PIXBUF gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 1, 1)
    #define HOT_X G_MAXINT
    #define HOT_Y G_MAXINT
    
    GtkWidget* source_widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    GdkPixbuf *pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    
    pixbuf = PIXBUF;
    gtk_drag_set_icon_pixbuf (drag_context, pixbuf, HOT_X, HOT_Y);
    
    #undef ACTIONS
    #undef BUTTON
    #undef PIXBUF
    #undef HOT_X 
    #undef HOT_Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_set_icon_pixbuf
 * Params: GdkDragContext *context, GdkPixbuf *pixbuf, gint hot_x, gint hot_y
 * Returns: void
 * Assertion: Sets pixbuf as the icon for a given drag.
 * Params Values: newly created GdkDragContext*, G_MININT, G_MININT  
 * Expected: void  
 */
static void test_purpose_66()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define BUTTON 0
    #define PIXBUF gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 1, 1)
    #define HOT_X G_MININT
    #define HOT_Y G_MININT
    
    GtkWidget* source_widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    GdkPixbuf *pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    
    pixbuf = PIXBUF;
    gtk_drag_set_icon_pixbuf (drag_context, pixbuf, HOT_X, HOT_Y);
    
    #undef ACTIONS
    #undef BUTTON
    #undef PIXBUF
    #undef HOT_X 
    #undef HOT_Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_set_icon_stock
 * Params: GdkDragContext *context, const gchar *stock_id, gint hot_x, gint hot_y
 * Returns: void
 * Assertion: Sets the the icon for a given drag from a stock ID.
 * Params Values: newly created GdkDragContext*, 0, 0  
 * Expected: void  
 */
static void test_purpose_67()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define BUTTON 0
    #define STOCK_ID GTK_STOCK_STOP
    #define HOT_X 0
    #define HOT_Y 0
    
    GtkWidget* source_widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    
    gtk_drag_set_icon_stock (drag_context, STOCK_ID, HOT_X, HOT_Y);
    
    #undef ACTIONS
    #undef BUTTON
    #undef STOCK_ID
    #undef HOT_X 
    #undef HOT_Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_set_icon_stock
 * Params: GdkDragContext *context, const gchar *stock_id, gint hot_x, gint hot_y
 * Returns: void
 * Assertion: Sets the the icon for a given drag from a stock ID.
 * Params Values: newly created GdkDragContext*, 1, 1  
 * Expected: void  
 */
static void test_purpose_68()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define BUTTON 0
    #define STOCK_ID GTK_STOCK_SORT_DESCENDING
    #define HOT_X 1
    #define HOT_Y 1
    
    GtkWidget* source_widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    
    gtk_drag_set_icon_stock (drag_context, STOCK_ID, HOT_X, HOT_Y);
    
    #undef ACTIONS
    #undef BUTTON
    #undef STOCK_ID
    #undef HOT_X 
    #undef HOT_Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_set_icon_stock
 * Params: GdkDragContext *context, const gchar *stock_id, gint hot_x, gint hot_y
 * Returns: void
 * Assertion: Sets the the icon for a given drag from a stock ID.
 * Params Values: newly created GdkDragContext*, G_MAXINT, G_MAXINT  
 * Expected: void  
 */
static void test_purpose_69()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define BUTTON 0
    #define STOCK_ID GTK_STOCK_STRIKETHROUGH
    #define HOT_X G_MAXINT
    #define HOT_Y G_MAXINT
    
    GtkWidget* source_widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    
    gtk_drag_set_icon_stock (drag_context, STOCK_ID, HOT_X, HOT_Y);
    
    #undef ACTIONS
    #undef BUTTON
    #undef STOCK_ID
    #undef HOT_X 
    #undef HOT_Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_set_icon_stock
 * Params: GdkDragContext *context, const gchar *stock_id, gint hot_x, gint hot_y
 * Returns: void
 * Assertion: Sets the the icon for a given drag from a stock ID.
 * Params Values: newly created GdkDragContext*, G_MININT, G_MININT  
 * Expected: void  
 */
static void test_purpose_70()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define BUTTON 0
    #define STOCK_ID GTK_STOCK_ZOOM_FIT
    #define HOT_X G_MININT
    #define HOT_Y G_MININT
    
    GtkWidget* source_widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    
    gtk_drag_set_icon_stock (drag_context, STOCK_ID, HOT_X, HOT_Y);
    
    #undef ACTIONS
    #undef BUTTON
    #undef STOCK_ID
    #undef HOT_X 
    #undef HOT_Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_set_icon_default
 * Params: GdkDragContext *context
 * Returns: void
 * Assertion: Sets the icon for a particular drag to the default icon.
 * Params Values: newly created GdkDragContext*
 * Expected: void  
 */
static void test_purpose_71()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define BUTTON 0
    
    GtkWidget* source_widget;
    GdkDragContext* drag_context;
    GtkTargetList* target_list;
    GtkTargetList* source_target_list;
    GdkEvent* event = gdk_event_new(GDK_NOTHING);
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    source_widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_widget_realize (source_widget);
    source_target_list =  gtk_target_list_new (target_table, n_targets);
    drag_context = gtk_drag_begin (source_widget, source_target_list,  ACTIONS, BUTTON, event);
    
    gtk_drag_set_icon_default (drag_context);
    
    #undef ACTIONS
    #undef BUTTON
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_check_threshold
 * Params: GtkWidget *widget, gint start_x, gint start_y, gint current_x, gint current_y
 * Returns: void
 * Assertion: Checks to see if a mouse drag starting at (start_x, start_y) and ending at (current_x, current_y) has passed the GTK+ drag threshhold, and thus should trigger the beginning of a drag-and-drop operation.
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_72()
{
    #define START_X 0
    #define START_Y 0
    #define CURRENT_X 0
    #define CURRENT_Y 0
    
    GtkWidget* widget;
    gboolean threshold_passed;
    gint drag_threshold;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    g_object_get (gtk_widget_get_settings (widget),
                    "gtk-dnd-drag-threshold", &drag_threshold,
                    NULL);
    
    tet_printf ("drag = %d",drag_threshold);
    
    threshold_passed = gtk_drag_check_threshold (widget, START_X, START_Y, CURRENT_X, CURRENT_Y);
    if ((ABS (CURRENT_X - START_X) <= drag_threshold || 
         ABS (CURRENT_Y - START_Y) <= drag_threshold) && threshold_passed)
    {
        TEST_FAIL ("gtk_drag_check_threshold () return TRUE instead of FALSE", NULL); 
    }
    
    if ((ABS (CURRENT_X - START_X) > drag_threshold || 
         ABS (CURRENT_Y - START_Y) > drag_threshold) && !threshold_passed)
    {
        TEST_FAIL ("gtk_drag_check_threshold () return FALSE instead of TRUE", NULL); 
    }
    
    #undef START_X 
    #undef START_Y 
    #undef CURRENT_X
    #undef CURRENT_Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_check_threshold
 * Params: GtkWidget *widget, gint start_x, gint start_y, gint current_x, gint current_y
 * Returns: void
 * Assertion: Checks to see if a mouse drag starting at (start_x, start_y) and ending at (current_x, current_y) has passed the GTK+ drag threshhold, and thus should trigger the beginning of a drag-and-drop operation.
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_73()
{
    #define START_X 2
    #define START_Y 7
    #define CURRENT_X 10
    #define CURRENT_Y 5
    
    GtkWidget* widget;
    gboolean threshold_passed;
    gint drag_threshold;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    g_object_get (gtk_widget_get_settings (widget),
                    "gtk-dnd-drag-threshold", &drag_threshold,
                    NULL);
    
    tet_printf ("drag = %d",drag_threshold);
    
    threshold_passed = gtk_drag_check_threshold (widget, START_X, START_Y, CURRENT_X, CURRENT_Y);
    if ((ABS (CURRENT_X - START_X) <= drag_threshold || 
         ABS (CURRENT_Y - START_Y) <= drag_threshold) && threshold_passed)
    {
        TEST_FAIL ("gtk_drag_check_threshold () return TRUE instead of FALSE", NULL); 
    }
    
    if ((ABS (CURRENT_X - START_X) > drag_threshold || 
         ABS (CURRENT_Y - START_Y) > drag_threshold) && !threshold_passed)
    {
        TEST_FAIL ("gtk_drag_check_threshold () return FALSE instead of TRUE", NULL); 
    }
    
    #undef START_X 
    #undef START_Y 
    #undef CURRENT_X
    #undef CURRENT_Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set
 * Params: GtkWidget *widget, GdkModifierType start_button_mask, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets up a widget so that GTK+ will start a drag operation when the user clicks and drags on the widget. 
 * Params Values: GDK_SHIFT_MASK, GDK_ACTION_DEFAULT
 * Expected: void  
 */
static void test_purpose_74()
{
    #define MOD_TYPE GDK_SHIFT_MASK
    #define ACTIONS GDK_ACTION_DEFAULT
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set
 * Params: GtkWidget *widget, GdkModifierType start_button_mask, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets up a widget so that GTK+ will start a drag operation when the user clicks and drags on the widget. 
 * Params Values: GDK_LOCK_MASK, GDK_ACTION_COPY
 * Expected: void  
 */
static void test_purpose_75()
{
    #define MOD_TYPE GDK_LOCK_MASK
    #define ACTIONS GDK_ACTION_COPY
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set
 * Params: GtkWidget *widget, GdkModifierType start_button_mask, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets up a widget so that GTK+ will start a drag operation when the user clicks and drags on the widget. 
 * Params Values: GDK_CONTROL_MASK, GDK_ACTION_MOVE
 * Expected: void  
 */
static void test_purpose_76()
{
    #define MOD_TYPE GDK_CONTROL_MASK
    #define ACTIONS GDK_ACTION_MOVE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set
 * Params: GtkWidget *widget, GdkModifierType start_button_mask, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets up a widget so that GTK+ will start a drag operation when the user clicks and drags on the widget. 
 * Params Values: GDK_MOD1_MASK, GDK_ACTION_LINK
 * Expected: void  
 */
static void test_purpose_77()
{
    #define MOD_TYPE GDK_MOD1_MASK
    #define ACTIONS GDK_ACTION_LINK
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set
 * Params: GtkWidget *widget, GdkModifierType start_button_mask, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets up a widget so that GTK+ will start a drag operation when the user clicks and drags on the widget. 
 * Params Values: GDK_MOD2_MASK, GDK_ACTION_PRIVATE
 * Expected: void  
 */
static void test_purpose_78()
{
    #define MOD_TYPE GDK_MOD2_MASK
    #define ACTIONS GDK_ACTION_PRIVATE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set
 * Params: GtkWidget *widget, GdkModifierType start_button_mask, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets up a widget so that GTK+ will start a drag operation when the user clicks and drags on the widget. 
 * Params Values: GDK_MOD3_MASK, GDK_ACTION_ASK
 * Expected: void  
 */
static void test_purpose_79()
{
    #define MOD_TYPE GDK_MOD3_MASK
    #define ACTIONS GDK_ACTION_ASK
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set
 * Params: GtkWidget *widget, GdkModifierType start_button_mask, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets up a widget so that GTK+ will start a drag operation when the user clicks and drags on the widget. 
 * Params Values: GDK_MOD4_MASK, GDK_ACTION_DEFAULT
 * Expected: void  
 */
static void test_purpose_80()
{
    #define MOD_TYPE GDK_MOD4_MASK
    #define ACTIONS GDK_ACTION_DEFAULT
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set
 * Params: GtkWidget *widget, GdkModifierType start_button_mask, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets up a widget so that GTK+ will start a drag operation when the user clicks and drags on the widget. 
 * Params Values: GDK_MOD5_MASK, GDK_ACTION_COPY
 * Expected: void  
 */
static void test_purpose_81()
{
    #define MOD_TYPE GDK_MOD5_MASK
    #define ACTIONS GDK_ACTION_COPY
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set
 * Params: GtkWidget *widget, GdkModifierType start_button_mask, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets up a widget so that GTK+ will start a drag operation when the user clicks and drags on the widget. 
 * Params Values: GDK_BUTTON1_MASK, GDK_ACTION_MOVE
 * Expected: void  
 */
static void test_purpose_82()
{
    #define MOD_TYPE GDK_BUTTON1_MASK
    #define ACTIONS GDK_ACTION_MOVE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set
 * Params: GtkWidget *widget, GdkModifierType start_button_mask, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets up a widget so that GTK+ will start a drag operation when the user clicks and drags on the widget. 
 * Params Values: GDK_BUTTON2_MASK, GDK_ACTION_LINK
 * Expected: void  
 */
static void test_purpose_83()
{
    #define MOD_TYPE GDK_BUTTON2_MASK
    #define ACTIONS GDK_ACTION_LINK
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set
 * Params: GtkWidget *widget, GdkModifierType start_button_mask, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets up a widget so that GTK+ will start a drag operation when the user clicks and drags on the widget. 
 * Params Values: GDK_BUTTON3_MASK, GDK_ACTION_PRIVATE
 * Expected: void  
 */
static void test_purpose_84()
{
    #define MOD_TYPE GDK_BUTTON3_MASK
    #define ACTIONS GDK_ACTION_PRIVATE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set
 * Params: GtkWidget *widget, GdkModifierType start_button_mask, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets up a widget so that GTK+ will start a drag operation when the user clicks and drags on the widget. 
 * Params Values: GDK_BUTTON4_MASK, GDK_ACTION_ASK
 * Expected: void  
 */
static void test_purpose_85()
{
    #define MOD_TYPE GDK_BUTTON4_MASK
    #define ACTIONS GDK_ACTION_ASK
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set
 * Params: GtkWidget *widget, GdkModifierType start_button_mask, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets up a widget so that GTK+ will start a drag operation when the user clicks and drags on the widget. 
 * Params Values: GDK_BUTTON5_MASK, GDK_ACTION_DEFAULT
 * Expected: void  
 */
static void test_purpose_86()
{
    #define MOD_TYPE GDK_BUTTON5_MASK
    #define ACTIONS GDK_ACTION_DEFAULT
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set
 * Params: GtkWidget *widget, GdkModifierType start_button_mask, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets up a widget so that GTK+ will start a drag operation when the user clicks and drags on the widget. 
 * Params Values: GDK_RELEASE_MASK, GDK_ACTION_COPY
 * Expected: void  
 */
static void test_purpose_87()
{
    #define MOD_TYPE GDK_RELEASE_MASK
    #define ACTIONS GDK_ACTION_COPY
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set
 * Params: GtkWidget *widget, GdkModifierType start_button_mask, const GtkTargetEntry *targets, gint n_targets, GdkDragAction actions
 * Returns: void
 * Assertion: Sets up a widget so that GTK+ will start a drag operation when the user clicks and drags on the widget. 
 * Params Values: GDK_MODIFIER_MASK, GDK_ACTION_MOVE
 * Expected: void  
 */
static void test_purpose_88()
{
    #define MOD_TYPE GDK_MODIFIER_MASK
    #define ACTIONS GDK_ACTION_MOVE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set_icon
 * Params: GtkWidget *widget, GdkColormap *colormap, GdkPixmap *pixmap, GdkBitmap *mask
 * Returns: void
 * Assertion: Sets the icon that will be used for drags from a particular widget from a pixmap/mask. 
 * Params Values: newly created GtkWidget*, newly created GdkColormap*, newly created GdkPixmap*, NULL, <%5%>, <%6%>  
 * Expected: void  
 */
static void test_purpose_89()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define MOD_TYPE GDK_SHIFT_MASK
    #define COLORMAP gdk_colormap_get_system ()
    #define PIXMAP gdk_pixmap_new (NULL, 1, 1, 1)
    #define MASK NULL
    
    GtkWidget* widget;
    GdkColormap *colormap;
    GdkPixmap *pixmap;
    GdkBitmap *mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    colormap = COLORMAP;
    pixmap = PIXMAP;
    mask = MASK;
    gtk_drag_source_set_icon (widget, colormap, pixmap, mask);
    
    #undef ACTIONS
    #undef MOD_TYPE
    #undef COLORMAP 
    #undef PIXMAP
    #undef MASK 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set_icon
 * Params: GtkWidget *widget, GdkColormap *colormap, GdkPixmap *pixmap, GdkBitmap *mask
 * Returns: void
 * Assertion: Sets the icon that will be used for drags from a particular widget from a pixmap/mask. 
 * Params Values: newly created GtkWidget*, newly created GdkColormap*, newly created GdkPixmap*, NULL, <%5%>, <%6%>  
 * Expected: void  
 */
static void test_purpose_90()
{
    #define ACTIONS GDK_ACTION_COPY
    #define MOD_TYPE GDK_LOCK_MASK
    #define COLORMAP gdk_colormap_get_system ()
    #define PIXMAP gdk_pixmap_new (NULL, 1, 1, 1)
    #define MASK NULL
    
    GtkWidget* widget;
    GdkColormap *colormap;
    GdkPixmap *pixmap;
    GdkBitmap *mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    colormap = COLORMAP;
    pixmap = PIXMAP;
    mask = MASK;
    gtk_drag_source_set_icon (widget, colormap, pixmap, mask);
    
    #undef ACTIONS
    #undef MOD_TYPE
    #undef COLORMAP 
    #undef PIXMAP
    #undef MASK 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set_icon
 * Params: GtkWidget *widget, GdkColormap *colormap, GdkPixmap *pixmap, GdkBitmap *mask
 * Returns: void
 * Assertion: Sets the icon that will be used for drags from a particular widget from a pixmap/mask. 
 * Params Values: newly created GtkWidget*, newly created GdkColormap*, newly created GdkPixmap*, NULL, <%5%>, <%6%>  
 * Expected: void  
 */
static void test_purpose_91()
{
    #define ACTIONS GDK_ACTION_MOVE
    #define MOD_TYPE GDK_CONTROL_MASK
    #define COLORMAP gdk_colormap_get_system ()
    #define PIXMAP gdk_pixmap_new (NULL, 1, 1, 1)
    #define MASK NULL
    
    GtkWidget* widget;
    GdkColormap *colormap;
    GdkPixmap *pixmap;
    GdkBitmap *mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    colormap = COLORMAP;
    pixmap = PIXMAP;
    mask = MASK;
    gtk_drag_source_set_icon (widget, colormap, pixmap, mask);
    
    #undef ACTIONS
    #undef MOD_TYPE
    #undef COLORMAP 
    #undef PIXMAP
    #undef MASK 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set_icon
 * Params: GtkWidget *widget, GdkColormap *colormap, GdkPixmap *pixmap, GdkBitmap *mask
 * Returns: void
 * Assertion: Sets the icon that will be used for drags from a particular widget from a pixmap/mask. 
 * Params Values: newly created GtkWidget*, newly created GdkColormap*, newly created GdkPixmap*, NULL, <%5%>, <%6%>  
 * Expected: void  
 */
static void test_purpose_92()
{
    #define ACTIONS GDK_ACTION_LINK
    #define MOD_TYPE GDK_MOD1_MASK
    #define COLORMAP gdk_colormap_get_system ()
    #define PIXMAP gdk_pixmap_new (NULL, 1, 1, 1)
    #define MASK NULL
    
    GtkWidget* widget;
    GdkColormap *colormap;
    GdkPixmap *pixmap;
    GdkBitmap *mask;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    colormap = COLORMAP;
    pixmap = PIXMAP;
    mask = MASK;
    gtk_drag_source_set_icon (widget, colormap, pixmap, mask);
    
    #undef ACTIONS
    #undef MOD_TYPE
    #undef COLORMAP 
    #undef PIXMAP
    #undef MASK 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set_icon_pixbuf
 * Params: GtkWidget *widget, GdkPixbuf *pixbuf
 * Returns: void
 * Assertion: Sets the icon that will be used for drags from a particular widget from a GdkPixbuf. 
 * Params Values: newly created GtkWidget*, newly created GdkPixbuf*
 * Expected: void  
 */
static void test_purpose_93()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define MOD_TYPE GDK_SHIFT_MASK
    #define PIXBUF gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 1, 1)
    
    GtkWidget* widget;
    GdkPixbuf *pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    pixbuf = PIXBUF;
    gtk_drag_source_set_icon_pixbuf (widget, pixbuf);
    
    #undef ACTIONS
    #undef MOD_TYPE
    #undef PIXBUF 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set_icon_pixbuf
 * Params: GtkWidget *widget, GdkPixbuf *pixbuf
 * Returns: void
 * Assertion: Sets the icon that will be used for drags from a particular widget from a GdkPixbuf. 
 * Params Values: newly created GtkWidget*, newly created GdkPixbuf*
 * Expected: void  
 */
static void test_purpose_94()
{
    #define ACTIONS GDK_ACTION_COPY
    #define MOD_TYPE GDK_LOCK_MASK
    #define PIXBUF gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 1, 1)
    
    GtkWidget* widget;
    GdkPixbuf *pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    pixbuf = PIXBUF;
    gtk_drag_source_set_icon_pixbuf (widget, pixbuf);
    
    #undef ACTIONS
    #undef MOD_TYPE
    #undef PIXBUF 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set_icon_pixbuf
 * Params: GtkWidget *widget, GdkPixbuf *pixbuf
 * Returns: void
 * Assertion: Sets the icon that will be used for drags from a particular widget from a GdkPixbuf. 
 * Params Values: newly created GtkWidget*, newly created GdkPixbuf*
 * Expected: void  
 */
static void test_purpose_95()
{
    #define ACTIONS GDK_ACTION_MOVE
    #define MOD_TYPE GDK_CONTROL_MASK
    #define PIXBUF gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 1, 1)
    
    GtkWidget* widget;
    GdkPixbuf *pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    pixbuf = PIXBUF;
    gtk_drag_source_set_icon_pixbuf (widget, pixbuf);
    
    #undef ACTIONS
    #undef MOD_TYPE
    #undef PIXBUF 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set_icon_pixbuf
 * Params: GtkWidget *widget, GdkPixbuf *pixbuf
 * Returns: void
 * Assertion: Sets the icon that will be used for drags from a particular widget from a GdkPixbuf. 
 * Params Values: newly created GtkWidget*, newly created GdkPixbuf*
 * Expected: void  
 */
static void test_purpose_96()
{
    #define ACTIONS GDK_ACTION_LINK
    #define MOD_TYPE GDK_MOD1_MASK
    #define PIXBUF gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 1, 1)
    
    GtkWidget* widget;
    GdkPixbuf *pixbuf;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    pixbuf = PIXBUF;
    gtk_drag_source_set_icon_pixbuf (widget, pixbuf);
    
    #undef ACTIONS
    #undef MOD_TYPE
    #undef PIXBUF 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set_icon_stock
 * Params: GtkWidget *widget, const gchar *stock_id
 * Returns: void
 * Assertion: Sets the icon that will be used for drags from a particular source to a stock icon.
 * Params Values: newly created GtkWidget*, GTK_STOCK_STOP
 * Expected: void  
 */
static void test_purpose_97()
{
    #define ACTIONS GDK_ACTION_DEFAULT
    #define MOD_TYPE GDK_SHIFT_MASK
    #define STOCK_ID GTK_STOCK_STOP
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    gtk_drag_source_set_icon_stock (widget, STOCK_ID);
    
    #undef ACTIONS
    #undef MOD_TYPE
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set_icon_stock
 * Params: GtkWidget *widget, const gchar *stock_id
 * Returns: void
 * Assertion: Sets the icon that will be used for drags from a particular source to a stock icon.
 * Params Values: newly created GtkWidget*, GTK_STOCK_SORT_DESCENDING
 * Expected: void  
 */
static void test_purpose_98()
{
    #define ACTIONS GDK_ACTION_COPY
    #define MOD_TYPE GDK_LOCK_MASK
    #define STOCK_ID GTK_STOCK_SORT_DESCENDING
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    gtk_drag_source_set_icon_stock (widget, STOCK_ID);
    
    #undef ACTIONS
    #undef MOD_TYPE
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set_icon_stock
 * Params: GtkWidget *widget, const gchar *stock_id
 * Returns: void
 * Assertion: Sets the icon that will be used for drags from a particular source to a stock icon.
 * Params Values: newly created GtkWidget*, GTK_STOCK_STRIKETHROUGH
 * Expected: void  
 */
static void test_purpose_99()
{
    #define ACTIONS GDK_ACTION_MOVE
    #define MOD_TYPE GDK_CONTROL_MASK
    #define STOCK_ID GTK_STOCK_STRIKETHROUGH
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    gtk_drag_source_set_icon_stock (widget, STOCK_ID);
    
    #undef ACTIONS
    #undef MOD_TYPE
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_set_icon_stock
 * Params: GtkWidget *widget, const gchar *stock_id
 * Returns: void
 * Assertion: Sets the icon that will be used for drags from a particular source to a stock icon.
 * Params Values: newly created GtkWidget*, GTK_STOCK_ZOOM_FIT
 * Expected: void  
 */
static void test_purpose_100()
{
    #define ACTIONS GDK_ACTION_LINK
    #define MOD_TYPE GDK_MOD1_MASK
    #define STOCK_ID GTK_STOCK_ZOOM_FIT
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    
    gtk_drag_source_set_icon_stock (widget, STOCK_ID);
    
    #undef ACTIONS
    #undef MOD_TYPE
    #undef STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Undoes the effects of gtk_drag_source_set().
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_101()
{
    #define MOD_TYPE GDK_SHIFT_MASK
    #define ACTIONS GDK_ACTION_DEFAULT
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    gtk_drag_source_unset (widget);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Undoes the effects of gtk_drag_source_set().
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_102()
{
    #define MOD_TYPE GDK_LOCK_MASK
    #define ACTIONS GDK_ACTION_COPY
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    gtk_drag_source_unset (widget);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Undoes the effects of gtk_drag_source_set().
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_103()
{
    #define MOD_TYPE GDK_CONTROL_MASK
    #define ACTIONS GDK_ACTION_MOVE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    gtk_drag_source_unset (widget);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Undoes the effects of gtk_drag_source_set().
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_104()
{
    #define MOD_TYPE GDK_MOD1_MASK
    #define ACTIONS GDK_ACTION_LINK
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    gtk_drag_source_unset (widget);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Undoes the effects of gtk_drag_source_set().
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_105()
{
    #define MOD_TYPE GDK_MOD2_MASK
    #define ACTIONS GDK_ACTION_PRIVATE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    gtk_drag_source_unset (widget);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Undoes the effects of gtk_drag_source_set().
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_106()
{
    #define MOD_TYPE GDK_MOD3_MASK
    #define ACTIONS GDK_ACTION_ASK
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    gtk_drag_source_unset (widget);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Undoes the effects of gtk_drag_source_set().
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_107()
{
    #define MOD_TYPE GDK_MOD4_MASK
    #define ACTIONS GDK_ACTION_DEFAULT
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    gtk_drag_source_unset (widget);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Undoes the effects of gtk_drag_source_set().
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_108()
{
    #define MOD_TYPE GDK_MOD5_MASK
    #define ACTIONS GDK_ACTION_COPY
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    gtk_drag_source_unset (widget);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Undoes the effects of gtk_drag_source_set().
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_109()
{
    #define MOD_TYPE GDK_BUTTON1_MASK
    #define ACTIONS GDK_ACTION_MOVE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    gtk_drag_source_unset (widget);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Undoes the effects of gtk_drag_source_set().
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_110()
{
    #define MOD_TYPE GDK_BUTTON2_MASK
    #define ACTIONS GDK_ACTION_LINK
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    gtk_drag_source_unset (widget);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Undoes the effects of gtk_drag_source_set().
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_111()
{
    #define MOD_TYPE GDK_BUTTON3_MASK
    #define ACTIONS GDK_ACTION_PRIVATE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    gtk_drag_source_unset (widget);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Undoes the effects of gtk_drag_source_set().
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_112()
{
    #define MOD_TYPE GDK_BUTTON4_MASK
    #define ACTIONS GDK_ACTION_ASK
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    gtk_drag_source_unset (widget);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Undoes the effects of gtk_drag_source_set().
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_113()
{
    #define MOD_TYPE GDK_BUTTON5_MASK
    #define ACTIONS GDK_ACTION_DEFAULT
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    gtk_drag_source_unset (widget);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Undoes the effects of gtk_drag_source_set().
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_114()
{
    #define MOD_TYPE GDK_RELEASE_MASK
    #define ACTIONS GDK_ACTION_COPY
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    gtk_drag_source_unset (widget);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_drag_source_unset
 * Params: GtkWidget *widget
 * Returns: void
 * Assertion: Undoes the effects of gtk_drag_source_set().
 * Params Values: newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_115()
{
    #define MOD_TYPE GDK_MODIFIER_MASK
    #define ACTIONS GDK_ACTION_MOVE
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    gtk_drag_source_set (widget, MOD_TYPE, target_table, n_targets, ACTIONS);
    gtk_drag_source_unset (widget);
    
    #undef MOD_TYPE 
    #undef ACTIONS
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for Drag_and_Drop ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {test_purpose_79, 1},
    {test_purpose_80, 1},
    {test_purpose_81, 1},
    {test_purpose_82, 1},
    {test_purpose_83, 1},
    {test_purpose_84, 1},
    {test_purpose_85, 1},
    {test_purpose_86, 1},
    {test_purpose_87, 1},
    {test_purpose_88, 1},
    {test_purpose_89, 1},
    {test_purpose_90, 1},
    {test_purpose_91, 1},
    {test_purpose_92, 1},
    {test_purpose_93, 1},
    {test_purpose_94, 1},
    {test_purpose_95, 1},
    {test_purpose_96, 1},
    {test_purpose_97, 1},
    {test_purpose_98, 1},
    {test_purpose_99, 1},
    {test_purpose_100, 1},
    {test_purpose_101, 1},
    {test_purpose_102, 1},
    {test_purpose_103, 1},
    {test_purpose_104, 1},
    {test_purpose_105, 1},
    {test_purpose_106, 1},
    {test_purpose_107, 1},
    {test_purpose_108, 1},
    {test_purpose_109, 1},
    {test_purpose_110, 1},
    {test_purpose_111, 1},
    {test_purpose_112, 1},
    {test_purpose_113, 1},
    {test_purpose_114, 1},
    {test_purpose_115, 1},
    {NULL,0}
};
