/*
 * GArray methods tests
 * Testing GArray methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: g_array_new
 * Params: gboolean zero_terminated, gboolean clear_, guint element_size
 * Returns: GArray*
 * Assertion: Creates a new GArray.
 *            zero_terminated : TRUE if the array should have an extra element at the end which is set to 0.  
 * 	       clear_ : TRUE if GArray elements should be automatically cleared to 0 when they are allocated.  
 * 	       element_size : the size of each element in bytes 
 * Params Values: TRUE, TRUE, sizeof(gchar)
 * Expected: "have one '\0', and the new elements are 0"  
 */
static void test_purpose_1()
{
    #define ZERO TRUE
    #define CLR  TRUE
    #define SIZE sizeof(gchar)
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GArray *ga = NULL;
    ga = g_array_new(ZERO, CLR, SIZE);
    
    if (ga == NULL){
        TEST_FAIL("g_array_new: error in alloc", NULL);
    }
    
    if (ZERO){
        if (*(ga->data) != '\0'){
            TEST_FAIL("g_array_new: error in ZERO = TRUE", NULL);
        }
    }
    
    if (CLR){
        gint i = 0;
        ga = g_array_set_size(ga, 10);
        for (i = 0; i < 10; i++){
            if (((gchar *)(ga->data))[i] != 0){
                TEST_FAIL("g_array_sized_new: if clear_ = TRUE, the new data should be 0", NULL);
            }
        }
    }
    
    g_array_free(ga, TRUE);
    
    #undef ZERO
    #undef CLR
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_array_new
 * Params: gboolean zero_terminated, gboolean clear_, guint element_size
 * Returns: GArray*
 * Assertion: Creates a new GArray.
 *            zero_terminated : TRUE if the array should have an extra element at the end which is set to 0.  
 * 	       clear_ : TRUE if GArray elements should be automatically cleared to 0 when they are allocated.  
 * 	       element_size : the size of each element in bytes 
 * Params Values: FALSE, TRUE, sizeof(gchar)
 * Expected: "the new elements are 0"  
 */
static void test_purpose_2()
{
    #define ZERO FALSE
    #define CLR  TRUE
    #define SIZE sizeof(gchar)
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GArray *ga = NULL;
    ga = g_array_new(ZERO, CLR, SIZE);
    
    if (ga == NULL){
        TEST_FAIL("g_array_new: error in alloc", NULL);
    }
    
    if (ZERO){
        if (*(ga->data) != '\0'){
            TEST_FAIL("g_array_new: error in ZERO = TRUE", NULL);
        }
    }
    
    if (CLR){
        gint i = 0;
        ga = g_array_set_size(ga, 10);
        for (i = 0; i < 10; i++){
            if (((gchar *)(ga->data))[i] != 0){
                TEST_FAIL("g_array_sized_new: if clear_ = TRUE, the new data should be 0", NULL);
            }
        }
    }
    
    g_array_free(ga, TRUE);
    
    #undef ZERO
    #undef CLR
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_array_new
 * Params: gboolean zero_terminated, gboolean clear_, guint element_size
 * Returns: GArray*
 * Assertion: Creates a new GArray.
 *            zero_terminated : TRUE if the array should have an extra element at the end which is set to 0.  
 * 	       clear_ : TRUE if GArray elements should be automatically cleared to 0 when they are allocated.  
 * 	       element_size : the size of each element in bytes 
 * Params Values: TRUE, FALSE, sizeof(gchar)
 * Expected: "have one '\0'"  
 */
static void test_purpose_3()
{
    #define ZERO TRUE
    #define CLR  FALSE
    #define SIZE sizeof(gchar)
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GArray *ga = NULL;
    ga = g_array_new(ZERO, CLR, SIZE);
    
    if (ga == NULL){
        TEST_FAIL("g_array_new: error in alloc", NULL);
    }
    
    if (ZERO){
        if (*(ga->data) != '\0'){
            TEST_FAIL("g_array_new: error in ZERO = TRUE", NULL);
        }
    }
    
    if (CLR){
        gint i = 0;
        ga = g_array_set_size(ga, 10);
        for (i = 0; i < 10; i++){
            if (((gchar *)(ga->data))[i] != 0){
                TEST_FAIL("g_array_sized_new: if clear_ = TRUE, the new data should be 0", NULL);
            }
        }
    }
    
    g_array_free(ga, TRUE);
    
    #undef ZERO
    #undef CLR
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_array_new
 * Params: gboolean zero_terminated, gboolean clear_, guint element_size
 * Returns: GArray*
 * Assertion: Creates a new GArray.
 *            zero_terminated : TRUE if the array should have an extra element at the end which is set to 0.  
 * 	       clear_ : TRUE if GArray elements should be automatically cleared to 0 when they are allocated.  
 * 	       element_size : the size of each element in bytes 
 * Params Values: FALSE, FALSE, sizeof(gchar)
 * Expected: ""  
 */
static void test_purpose_4()
{
    #define ZERO FALSE
    #define CLR  FALSE
    #define SIZE sizeof(gchar)
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GArray *ga = NULL;
    ga = g_array_new(ZERO, CLR, SIZE);
    
    if (ga == NULL){
        TEST_FAIL("g_array_new: error in alloc", NULL);
    }
    
    if (ZERO){
        if (*(ga->data) != '\0'){
            TEST_FAIL("g_array_new: error in ZERO = TRUE", NULL);
        }
    }
    
    if (CLR){
        gint i = 0;
        ga = g_array_set_size(ga, 10);
        for (i = 0; i < 10; i++){
            if (((gchar *)(ga->data))[i] != 0){
                TEST_FAIL("g_array_sized_new: if clear_ = TRUE, the new data should be 0", NULL);
            }
        }
    }
    
    g_array_free(ga, TRUE);
    
    #undef ZERO
    #undef CLR
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_array_append_vals
 * Params: GArray *array, gconstpointer data, guint len
 * Returns: GArray*
 * Assertion: Adds len elements onto the end of the array.
 *            array : a GArray.  
 *            data : a pointer to the elements to append to the end of the array.  
 *            len : the number of elements to append.  
 * Params Values: ga, data
 * Expected: Add the data into ga  
 */
static void test_purpose_5()
{
    #define GA   ga
    #define DATA data
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    gint data[] = {0, 1, 2, 3};
    GArray* ga = NULL;
    
    ga = g_array_new(FALSE, TRUE, sizeof(gint));
    if (ga){
        ga = g_array_append_vals(GA, DATA, sizeof(data)/sizeof(gint));
    }
    for (i = 0; i < ga->len; i++){
        if (((gint *)(ga->data))[i] != i){
            TEST_FAIL("g_array_append_vals: should be %d, now is %d", i, *(ga+i)->data);
        }
    }
    g_array_free(ga, TRUE);
    #undef GA
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_array_free
 * Params: GArray *array, gboolean free_segment
 * Returns: gchar*
 * Assertion: Frees the memory allocated for the GArray. If free_segment is TRUE it frees the actual element data as well
 *            array : a GArray.  
 *            free_segment : if TRUE the actual element data is freed as well.  
 *            Returns : the element data if free_segment is FALSE, otherwise NULL  
 * Params Values: ga, TRUE
 * Expected: NULL  
 */
static void test_purpose_6()
{
    #define GA  ga
    #define SEG TRUE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GArray *ga = NULL;
    char *ret_data = NULL;
    gint i = 0;
    gint data[] = {0, 1};
    
    ga = g_array_new(FALSE, TRUE, sizeof(gint));
    if (!ga){
        TEST_FAIL("g_array_free: error when allocing the array", NULL);
    }
    else{
        ga = g_array_append_vals(ga, &data, sizeof(data)/sizeof(gint));
        ret_data = g_array_free(GA, SEG);
        if (SEG){
            if (ret_data != NULL){
                TEST_FAIL("g_array_free: free error", NULL);
            }
        }
        else{
            for (i = 0; i < ga->len; i++){
                if (((gint *)ret_data)[i] != i){
                    TEST_FAIL("g_array_free: should be %d, now is %d", i, ((gint *)ret_data)[i]);
                }
            }
        }
    }
    
    #undef GA
    #undef SEG
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_array_free
 * Params: GArray *array, gboolean free_segment
 * Returns: gchar*
 * Assertion: Frees the memory allocated for the GArray. If free_segment is TRUE it frees the actual element data as well
 *            array : a GArray.  
 *            free_segment : if TRUE the actual element data is freed as well.  
 *            Returns : the element data if free_segment is FALSE, otherwise NULL  
 * Params Values: ga, FALSE
 * Expected: ga->data  
 */
static void test_purpose_7()
{
    #define GA  ga
    #define SEG FALSE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GArray *ga = NULL;
    char *ret_data = NULL;
    gint i = 0;
    gint data[] = {0, 1};
    
    ga = g_array_new(FALSE, TRUE, sizeof(gint));
    if (!ga){
        TEST_FAIL("g_array_free: error when allocing the array", NULL);
    }
    else{
        ga = g_array_append_vals(ga, &data, sizeof(data)/sizeof(gint));
        ret_data = g_array_free(GA, SEG);
        if (SEG){
            if (ret_data != NULL){
                TEST_FAIL("g_array_free: free error", NULL);
            }
        }
        else{
            for (i = 0; i < ga->len; i++){
                if (((gint *)ret_data)[i] != i){
                    TEST_FAIL("g_array_free: should be %d, now is %d", i, ((gint *)ret_data)[i]);
                }
            }
        }
    }
    
    #undef GA
    #undef SEG
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_array_set_size
 * Params: GArray *array, guint length
 * Returns: GArray*
 * Assertion: Sets the size of the array, expanding it if necessary. If the array was created with clear_ set to TRUE, the new elements are set to 0.
 *            array : a GArray.  
 *            length : the new size of the GArray.  
 *            Returns : the GArray.  
 * Params Values: ga, 10
 * Expected: 10  
 */
static void test_purpose_8()
{
    #define GA  ga
    #define LEN 10
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GArray *ga = NULL;
    gint data = 1;
    
    ga = g_array_new(FALSE, TRUE, sizeof(gint));
    ga = g_array_append_vals(ga, &data, sizeof(data)/sizeof(gint));
    ga = g_array_set_size(GA, LEN);
    if (ga->len != LEN){
        TEST_FAIL("g_array_set_size: the length should be %d, now is %d", LEN, ga->len);
    }
    else{
        gint i = 0;
        for (i = 1; i < (ga->len); i++){
            if (((gint *)(ga->data))[i] != 0){
                TEST_FAIL("when the clear_ is TRUE, the new data should be 0", NULL);
                break;
            }
        }
    }
    g_array_free(ga, TRUE);
    
    #undef GA
    #undef LEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_array_sized_new
 * Params: gboolean zero_terminated, gboolean clear_, guint element_size, guint reserved_size
 * Returns: GArray*
 * Assertion: Creates a new GArray with reserved_size elements preallocated. This avoids frequent reallocation, if you are going to add many elements to the array. Note however that the size of the array is still 0. 
 * 	       zero_terminated : TRUE if the array should have an extra element at the end with all bits cleared.  
 * 	       clear_ : TRUE if all bits in the array should be cleared to 0 on allocation.  
 * 	       element_size : size of each element in the array.  
 * 	       reserved_size : number of elements preallocated.  
 * 	       Returns : the new GArray 
 * Params Values: TRUE, TRUE, sizeof(gint), 10
 * Expected: the new array with '\0'  
 */
static void test_purpose_9()
{
    #define ZERO  TRUE
    #define CLR   TRUE
    #define SIZE  sizeof(gint)
    #define REV   10
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GArray *ga = NULL;
    
    ga = g_array_sized_new(ZERO, CLR, SIZE, REV);
    if (ga->len != 0){
        TEST_FAIL("g_array_sized_new: should be 0, now is %d\n", ga->len);
    }
    else{
        if (ZERO){
            if (*(ga->data) != '\0'){
                TEST_FAIL("g_array_sized_new: when zero_terminated = TRUE, data should be '\0'", NULL);
            }
        }
        if (CLR){
            gint i = 0;
            ga = g_array_set_size(ga, REV);
            for (i = 0; i < REV; i++){
                if (((gint *)(ga->data))[i] != 0){
                    TEST_FAIL("g_array_sized_new: if clear_ = TRUE, the new data should be 0", NULL);
                }
            }
        }
    }
    
    g_array_free(ga, TRUE);
    
    #undef ZERO
    #undef CLR
    #undef SIZE
    #undef REV
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_array_sized_new
 * Params: gboolean zero_terminated, gboolean clear_, guint element_size, guint reserved_size
 * Returns: GArray*
 * Assertion: Creates a new GArray with reserved_size elements preallocated. This avoids frequent reallocation, if you are going to add many elements to the array. Note however that the size of the array is still 0. 
 * 	       zero_terminated : TRUE if the array should have an extra element at the end with all bits cleared.  
 * 	       clear_ : TRUE if all bits in the array should be cleared to 0 on allocation.  
 * 	       element_size : size of each element in the array.  
 * 	       reserved_size : number of elements preallocated.  
 * 	       Returns : the new GArray 
 * Params Values: FALSE, TRUE, sizeof(gint), 10
 * Expected: the new array without '\0'  
 */
static void test_purpose_10()
{
    #define ZERO  FALSE
    #define CLR   TRUE
    #define SIZE  sizeof(gint)
    #define REV   10
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GArray *ga = NULL;
    
    ga = g_array_sized_new(ZERO, CLR, SIZE, REV);
    if (ga->len != 0){
        TEST_FAIL("g_array_sized_new: should be 0, now is %d\n", ga->len);
    }
    else{
        if (ZERO){
            if (*(ga->data) != '\0'){
                TEST_FAIL("g_array_sized_new: when zero_terminated = TRUE, data should be '\0'", NULL);
            }
        }
        if (CLR){
            gint i = 0;
            ga = g_array_set_size(ga, REV);
            for (i = 0; i < REV; i++){
                if (((gint *)(ga->data))[i] != 0){
                    TEST_FAIL("g_array_sized_new: if clear_ = TRUE, the new data should be 0", NULL);
                }
            }
        }
    }
    
    g_array_free(ga, TRUE);
    
    #undef ZERO
    #undef CLR
    #undef SIZE
    #undef REV
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_array_remove_index
 * Params: GArray *array, guint index_
 * Returns: GArray*
 * Assertion: Removes the element at the given index from a GArray. The following elements are moved down one place. 
 *     	   array : a GArray.  
 *     	   index_ : the index of the element to remove 
 * Params Values: ga, 2
 * Expected: Remove the data and move down the following elements  
 */
static void test_purpose_11()
{
    #define GA  ga
    #define INX 2
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GArray *ga = NULL;
    gint i = 0;
    
    ga = g_array_new(FALSE, TRUE, sizeof(gint));
    for (i = 0; i < 10; i++)
        g_array_append_val (ga, i);
    ga = g_array_remove_index(GA, INX);
    for (i = INX; i < 9; i++){
        if (((gint *)(ga->data))[i] != (i + 1)){
            TEST_FAIL("g_array_remove_index: should be %d, now is %d", (i + 1), ((gint *)(ga->data))[i]);
        }
    }
    
    g_array_free(ga, TRUE);
    
    #undef GA
    #undef INX
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GArray ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {NULL,0}
};
