/*
 * GPtrArray methods tests
 * Testing GPtrArray methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: g_ptr_array_new
 * Params: void 
 * Returns: GPtrArray*
 * Assertion: Creates a new GPtrArray.
 * Params Values:
 * Expected: GPtrArray*  
 */
static void test_purpose_1()
{
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GPtrArray *gpa = NULL;
    
    gpa = g_ptr_array_new();
    /* check if the ptr_array has been alloced */
    if (gpa == NULL){
        TEST_FAIL("g_ptr_array_new: new failed", NULL);
    }
    g_ptr_array_free(gpa, TRUE);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ptr_array_free
 * Params: void 
 * Returns: gpointer*
 * Assertion: Frees all of the memory allocated for the pointer array.  
 *            array : a GPtrArray.  
 *            free_seg : if TRUE the actual element data is freed as well. 
 * Params Values: gpa, TRUE
 * Expected: The data is NULL  
 */
static void test_purpose_2()
{
    #define GPA         gpa
    #define FREE_SEG    TRUE
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GPtrArray *gpa = NULL;
    gpointer *ret;
    gint i = 0;
    
    gpa = g_ptr_array_new();
    for (i = 0; i < 10; i++)
        g_ptr_array_add (gpa, GINT_TO_POINTER (i));
    ret = g_ptr_array_free(GPA, FREE_SEG);
    /* if TRUE the actual element data is freed as well */
    if (FREE_SEG){
        if (ret != NULL){
            TEST_FAIL("g_ptr_array_free: free failed", NULL);
        }
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ptr_array_add
 * Params: GPtrArray *array, gpointer data
 * Returns: void
 * Assertion: Adds a pointer to the end of the pointer array. The array will grow in size automatically if necessary. 
 *            array : a GPtrArray.  
 *            data : the pointer to add 
 * Params Values: gpa, 10
 * Expected: The data is same as to be added  
 */
static void test_purpose_3()
{
    #define GPA     gpa
    #define DATA    10
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GPtrArray *gpa = NULL;
    gint i = 0;
    
    gpa = g_ptr_array_new();
    for (i = 0; i < DATA; i++)
        g_ptr_array_add(GPA, GINT_TO_POINTER (i));
    /* check if the data has been added */
    for (i = 0; i < DATA; i++){
        if (g_ptr_array_index(gpa, i) != GINT_TO_POINTER (i)){
            TEST_FAIL("g_ptr_array_add: should be %d, now is %d", GINT_TO_POINTER (i), g_ptr_array_index (gpa, i));
        }
    }
    
    g_ptr_array_free(GPA, TRUE);
    
    #undef GPA
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ptr_array_set_size
 * Params: GPtrArray *array, gint length
 * Returns: void
 * Assertion: Sets the size of the array, expanding it if necessary. New elements are set to NULL.
 *            array : a GPtrArray.  
 *            length : the new length of the pointer array 
 * Params Values: gpa, 20
 * Expected: the length is 20 and the new elements are NULL  
 */
static void test_purpose_4()
{
    #define GPA	gpa
    #define LEN	20
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GPtrArray *gpa = NULL;
    gint i = 0;
    
    gpa = g_ptr_array_new();
    for (i = 0; i < 10; i++)
        g_ptr_array_add(GPA, GINT_TO_POINTER (i));
    g_ptr_array_set_size(GPA, LEN);
    /* check the length and if the new is NULL */
    if (GPA->len != LEN){
        TEST_FAIL("g_ptr_array_set_size: the length should be %d, now is %d", LEN, GPA->len);
    }
    else{
        for (i = 10; i < LEN; i++){
            if ((GPA->pdata)[i] != NULL){
                TEST_FAIL("g_ptr_array_set_size: the new data should be NULL", NULL);
                break;
            }
        }
    }
    g_ptr_array_free(gpa, TRUE);
    
    #undef GPA
    #undef LEN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ptr_array_remove
 * Params: GPtrArray *array, gpointer data
 * Returns: gboolean
 * Assertion: Removes the first occurrence of the given pointer from the pointer array. The following elements are moved down one place. It returns TRUE if the pointer was removed, or FALSE if the pointer was not found. 
 *            array : a GPtrArray.  
 *            data : the pointer to remove.  
 * Params Values: gpa, 20
 * Expected: FALSE  
 */
static void test_purpose_5()
{
    #define GPA     gpa
    #define DATA    20
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GPtrArray *gpa = NULL;
    gint i = 0;
    gboolean flag;
    
    gpa = g_ptr_array_new();
    for (i = 0; i < 10; i++)
        g_ptr_array_add(gpa, GINT_TO_POINTER (i));
    flag = g_ptr_array_remove(GPA, GINT_TO_POINTER(DATA));
    /* check if the data has been removed, and the following elements are moved down one place */
    if (flag){
        if (DATA > 9){
            TEST_FAIL("g_ptr_array_remove: should be FALSE", NULL);
        }
        else{
            for (i = DATA; i < 9; i++){
                if (g_ptr_array_index(gpa, i) != GINT_TO_POINTER(i + 1)){
                    TEST_FAIL("g_ptr_array_remove: remove failed", NULL);
                    break;
                }
            }
        }
    }
    /* if the element can not be found, the return value should be FALSE */
    else{
        if (DATA < 10){
            TEST_FAIL("g_ptr_array_remove: should be TRUE", NULL);
        }
    }
    g_ptr_array_free(gpa, TRUE);
    
    #undef GPA
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ptr_array_remove
 * Params: GPtrArray *array, gpointer data
 * Returns: gboolean
 * Assertion: Removes the first occurrence of the given pointer from the pointer array. The following elements are moved down one place. It returns TRUE if the pointer was removed, or FALSE if the pointer was not found. 
 *            array : a GPtrArray.  
 *            data : the pointer to remove.  
 * Params Values: gpa, 2
 * Expected: TRUE  
 */
static void test_purpose_6()
{
    #define GPA     gpa
    #define DATA    2
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GPtrArray *gpa = NULL;
    gint i = 0;
    gboolean flag;
    
    gpa = g_ptr_array_new();
    for (i = 0; i < 10; i++)
        g_ptr_array_add(gpa, GINT_TO_POINTER (i));
    flag = g_ptr_array_remove(GPA, GINT_TO_POINTER(DATA));
    /* check if the data has been removed, and the following elements are moved down one place */
    if (flag){
        if (DATA > 9){
            TEST_FAIL("g_ptr_array_remove: should be FALSE", NULL);
        }
        else{
            for (i = DATA; i < 9; i++){
                if (g_ptr_array_index(gpa, i) != GINT_TO_POINTER(i + 1)){
                    TEST_FAIL("g_ptr_array_remove: remove failed", NULL);
                    break;
                }
            }
        }
    }
    /* if the element can not be found, the return value should be FALSE */
    else{
        if (DATA < 10){
            TEST_FAIL("g_ptr_array_remove: should be TRUE", NULL);
        }
    }
    g_ptr_array_free(gpa, TRUE);
    
    #undef GPA
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ptr_array_remove_index
 * Params: GPtrArray *array, guint index_
 * Returns: gpointer
 * Assertion: Removes the pointer at the given index from the pointer array. The following elements are moved down one place 
 *            array : a GPtrArray.  
 *            index_ : the index of the pointer to remove 
 * Params Values: gpa, 5
 * Expected: The pointer is removed  
 */
static void test_purpose_7()
{
    #define GPA	gpa
    #define INX	5
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GPtrArray *gpa = NULL;
    gint i = 0;
    gpointer pm;
    
    gpa = g_ptr_array_new();
    for (i = 0; i < 10; i++)
        g_ptr_array_add(gpa, GINT_TO_POINTER (i));
    pm = g_ptr_array_remove_index(GPA, INX);
    if (GPOINTER_TO_INT(pm) != INX){
        TEST_FAIL("g_ptr_array_remove_index: the ruturn value should be %d, now is %d", INX, *(gint *)pm);
    }
    else{
        for (i = INX; i < 9; i++){
            if (g_ptr_array_index(gpa, i) != GINT_TO_POINTER(i + 1)){
                TEST_FAIL("g_ptr_array_remove_index: remove failed", NULL);
                break;
            }
        }
    }
    
    g_ptr_array_free(GPA, TRUE);
    
    #undef GPA
    #undef INX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ptr_array_sized_new
 * Params: guint reserved_size
 * Returns: GPtrArray*
 * Assertion: Creates a new GPtrArray with reserved_size pointers preallocated. This avoids frequent reallocation, if you are going to add many pointers to the array. Note however that the size of the array is still 0 
 *            reserved_size : number of pointers preallocated 
 * Params Values: 10           
 * Expected: GPtrArray*  
 */
static void test_purpose_8()
{
    #define REV	10
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GPtrArray *gpa = NULL;
    gint i = 0;
    
    gpa = g_ptr_array_sized_new(REV);
    if (gpa == NULL){
        TEST_FAIL("g_ptr_array_sized_new: alloc failed", NULL);
    }
    else{
        if (gpa->len != 0){
            TEST_FAIL("g_ptr_array_sized_new: the length should be 0", NULL);
        }
    }
    g_ptr_array_free(gpa, TRUE);
    
    #undef REV
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ptr_array_remove_fast
 * Params: GPtrArray *array, gpointer data
 * Returns: gboolean
 * Assertion: Removes the first occurrence of the given pointer from the pointer array. The last element in the array is used to fill in the space, so this function does not preserve the order of the array. But it is faster than g_ptr_array_remove(). 
 *            array : a GPtrArray.  
 *            data : the pointer to remove. 
 * Params Values: gpa, 2
 * Expected: TRUE  
 */
static void test_purpose_9()
{
    #define GPA  gpa
    #define DATA 2
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GPtrArray *gpa = NULL;
    gint i = 0;
    gboolean flag;
    
    gpa = g_ptr_array_new();
    for (i = 0; i < 10; i++)
        g_ptr_array_add(gpa, GINT_TO_POINTER(i));
    flag = g_ptr_array_remove_fast(GPA, GINT_TO_POINTER(DATA));
    /* check if the data has been removed, and the last element is filled in the space */
    if (flag){
        if (DATA > 9){
            TEST_FAIL("g_ptr_array_remove: should be FALSE", NULL);
        }
        else{
            if (g_ptr_array_index(GPA, DATA) != GINT_TO_POINTER(9)){
                TEST_FAIL("g_ptr_array_remove: the data should be 9", NULL);
            }
        }
    }
    /* if the element can not be found, the return value should be FALSE */
    else{
        if (DATA < 10){
            TEST_FAIL("g_ptr_array_remove: should be TRUE", NULL);
        }
    }
    g_ptr_array_free(gpa, TRUE);
    
    
    
    #undef GPA
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_ptr_array_remove_fast
 * Params: GPtrArray *array, gpointer data
 * Returns: gboolean
 * Assertion: Removes the first occurrence of the given pointer from the pointer array. The last element in the array is used to fill in the space, so this function does not preserve the order of the array. But it is faster than g_ptr_array_remove(). 
 *            array : a GPtrArray.  
 *            data : the pointer to remove. 
 * Params Values: gpa, 20
 * Expected: FALSE  
 */
static void test_purpose_10()
{
    #define GPA  gpa
    #define DATA 20
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GPtrArray *gpa = NULL;
    gint i = 0;
    gboolean flag;
    
    gpa = g_ptr_array_new();
    for (i = 0; i < 10; i++)
        g_ptr_array_add(gpa, GINT_TO_POINTER(i));
    flag = g_ptr_array_remove_fast(GPA, GINT_TO_POINTER(DATA));
    /* check if the data has been removed, and the last element is filled in the space */
    if (flag){
        if (DATA > 9){
            TEST_FAIL("g_ptr_array_remove: should be FALSE", NULL);
        }
        else{
            if (g_ptr_array_index(GPA, DATA) != GINT_TO_POINTER(9)){
                TEST_FAIL("g_ptr_array_remove: the data should be 9", NULL);
            }
        }
    }
    /* if the element can not be found, the return value should be FALSE */
    else{
        if (DATA < 10){
            TEST_FAIL("g_ptr_array_remove: should be TRUE", NULL);
        }
    }
    g_ptr_array_free(gpa, TRUE);
    
    
    
    #undef GPA
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GPtrArray ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {NULL,0}
};
