/*
 * GdkColormaps methods tests
 * Testing GdkColormaps methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;


/*
 * Name: gdk_colormap_get_system
 * Params: void
 * Returns: GdkColormap*
 * Assertion: Gets the system's default colormap for the default screen.
 * Params Values: void
 * Expected: the default colormap.  
 */
static void test_purpose_1()
{
    GdkColormap *colormap;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_get_visual
 * Params: GdkColormap *colormap
 * Returns: GdkVisual*
 * Assertion: Returns the visual for which a given colormap was created.
 * Params Values: a GdkColormap.
 * Expected: the visual of the colormap.  
 */
static void test_purpose_2()
{
    GdkColormap *colormap;
    GdkVisual *visual;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    visual = gdk_colormap_get_visual (colormap);
    
    if (!visual)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_VISUAL (visual))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_get_screen
 * Params: GdkColormap *colormap
 * Returns: GdkScreen*
 * Assertion: Gets the screen for which this colormap was created.
 * Params Values: a GdkColormap.
 * Expected: the screen for which this colormap was created.  
 */
static void test_purpose_3()
{
    GdkColormap *colormap;
    GdkScreen *screen;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    screen = gdk_colormap_get_screen (colormap);
    
    if (!screen)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_SCREEN (screen))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_alloc_color
 * Params: GdkColormap *colormap, GdkColor *color, gboolean writeable, gboolean best_match
 * Returns: gboolean
 * Assertion: Allocates a single color from a colormap.
 * Params Values: colormap : a GdkColormap. color : the color to allocate. On return the pixel field will be filled in if allocation succeeds. writeable : If TRUE, the color is allocated writeable (their values can later be changed using gdk_color_change()). Writeable colors cannot be shared between applications. best_match : If TRUE, GDK will attempt to do matching against existing colors if the color cannot be allocated as requested.
 * Expected: TRUE if the allocation succeeded.  
 */
static void test_purpose_4()
{
    #define COLOR {0, 65535, 0, 0}
    #define WRITEABLE FALSE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor color = COLOR;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (!gdk_colormap_alloc_color (colormap, &color, WRITEABLE, BEST_MATCH))
        TEST_FAIL ("gdk_colormap_alloc_color cannot allocate color from colormap", NULL);
    
    if (color.red !=0 || color.green != 0 || color.blue != 0)
        if (color.pixel == 0)
            TEST_FAIL ("gdk_colormap_alloc_color produced wrong pixel value", NULL);
    
    #undef COLOR
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_alloc_color
 * Params: GdkColormap *colormap, GdkColor *color, gboolean writeable, gboolean best_match
 * Returns: gboolean
 * Assertion: Allocates a single color from a colormap.
 * Params Values: colormap : a GdkColormap. color : the color to allocate. On return the pixel field will be filled in if allocation succeeds. writeable : If TRUE, the color is allocated writeable (their values can later be changed using gdk_color_change()). Writeable colors cannot be shared between applications. best_match : If TRUE, GDK will attempt to do matching against existing colors if the color cannot be allocated as requested.
 * Expected: TRUE if the allocation succeeded.  
 */
static void test_purpose_5()
{
    #define COLOR {0, 0, 65535, 0}
    #define WRITEABLE FALSE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor color = COLOR;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (!gdk_colormap_alloc_color (colormap, &color, WRITEABLE, BEST_MATCH))
        TEST_FAIL ("gdk_colormap_alloc_color cannot allocate color from colormap", NULL);
    
    if (color.red !=0 || color.green != 0 || color.blue != 0)
        if (color.pixel == 0)
            TEST_FAIL ("gdk_colormap_alloc_color produced wrong pixel value", NULL);
    
    #undef COLOR
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_alloc_color
 * Params: GdkColormap *colormap, GdkColor *color, gboolean writeable, gboolean best_match
 * Returns: gboolean
 * Assertion: Allocates a single color from a colormap.
 * Params Values: colormap : a GdkColormap. color : the color to allocate. On return the pixel field will be filled in if allocation succeeds. writeable : If TRUE, the color is allocated writeable (their values can later be changed using gdk_color_change()). Writeable colors cannot be shared between applications. best_match : If TRUE, GDK will attempt to do matching against existing colors if the color cannot be allocated as requested.
 * Expected: TRUE if the allocation succeeded.  
 */
static void test_purpose_6()
{
    #define COLOR {0, 0, 0, 65535}
    #define WRITEABLE FALSE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor color = COLOR;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (!gdk_colormap_alloc_color (colormap, &color, WRITEABLE, BEST_MATCH))
        TEST_FAIL ("gdk_colormap_alloc_color cannot allocate color from colormap", NULL);
    
    if (color.red !=0 || color.green != 0 || color.blue != 0)
        if (color.pixel == 0)
            TEST_FAIL ("gdk_colormap_alloc_color produced wrong pixel value", NULL);
    
    #undef COLOR
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_alloc_color
 * Params: GdkColormap *colormap, GdkColor *color, gboolean writeable, gboolean best_match
 * Returns: gboolean
 * Assertion: Allocates a single color from a colormap.
 * Params Values: colormap : a GdkColormap. color : the color to allocate. On return the pixel field will be filled in if allocation succeeds. writeable : If TRUE, the color is allocated writeable (their values can later be changed using gdk_color_change()). Writeable colors cannot be shared between applications. best_match : If TRUE, GDK will attempt to do matching against existing colors if the color cannot be allocated as requested.
 * Expected: TRUE if the allocation succeeded.  
 */
static void test_purpose_7()
{
    #define COLOR {0, 0, 0, 0}
    #define WRITEABLE TRUE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor color = COLOR;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (!gdk_colormap_alloc_color (colormap, &color, WRITEABLE, BEST_MATCH))
        TEST_FAIL ("gdk_colormap_alloc_color cannot allocate color from colormap", NULL);
    
    if (color.red !=0 || color.green != 0 || color.blue != 0)
        if (color.pixel == 0)
            TEST_FAIL ("gdk_colormap_alloc_color produced wrong pixel value", NULL);
    
    #undef COLOR
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_alloc_color
 * Params: GdkColormap *colormap, GdkColor *color, gboolean writeable, gboolean best_match
 * Returns: gboolean
 * Assertion: Allocates a single color from a colormap.
 * Params Values: colormap : a GdkColormap. color : the color to allocate. On return the pixel field will be filled in if allocation succeeds. writeable : If TRUE, the color is allocated writeable (their values can later be changed using gdk_color_change()). Writeable colors cannot be shared between applications. best_match : If TRUE, GDK will attempt to do matching against existing colors if the color cannot be allocated as requested.
 * Expected: TRUE if the allocation succeeded.  
 */
static void test_purpose_8()
{
    #define COLOR {0, 32768, 32768, 32768}
    #define WRITEABLE TRUE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor color = COLOR;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (!gdk_colormap_alloc_color (colormap, &color, WRITEABLE, BEST_MATCH))
        TEST_FAIL ("gdk_colormap_alloc_color cannot allocate color from colormap", NULL);
    
    if (color.red !=0 || color.green != 0 || color.blue != 0)
        if (color.pixel == 0)
            TEST_FAIL ("gdk_colormap_alloc_color produced wrong pixel value", NULL);
    
    #undef COLOR
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_alloc_color
 * Params: GdkColormap *colormap, GdkColor *color, gboolean writeable, gboolean best_match
 * Returns: gboolean
 * Assertion: Allocates a single color from a colormap.
 * Params Values: colormap : a GdkColormap. color : the color to allocate. On return the pixel field will be filled in if allocation succeeds. writeable : If TRUE, the color is allocated writeable (their values can later be changed using gdk_color_change()). Writeable colors cannot be shared between applications. best_match : If TRUE, GDK will attempt to do matching against existing colors if the color cannot be allocated as requested.
 * Expected: TRUE if the allocation succeeded.  
 */
static void test_purpose_9()
{
    #define COLOR {0, 65535, 65535, 65535}
    #define WRITEABLE TRUE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor color = COLOR;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (!gdk_colormap_alloc_color (colormap, &color, WRITEABLE, BEST_MATCH))
        TEST_FAIL ("gdk_colormap_alloc_color cannot allocate color from colormap", NULL);
    
    if (color.red !=0 || color.green != 0 || color.blue != 0)
        if (color.pixel == 0)
            TEST_FAIL ("gdk_colormap_alloc_color produced wrong pixel value", NULL);
    
    #undef COLOR
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_query_color
 * Params: GdkColormap *colormap, gulong pixel, GdkColor *result
 * Returns: void
 * Assertion: Locates the RGB color in colormap corresponding to the given hardware pixel pixel. pixel must be a valid pixel in the colormap; it's a programmer error to call this function with a pixel which is not in the colormap. Hardware pixels are normally obtained from gdk_colormap_alloc_colors(), or from a GdkImage. (A GdkImage contains image data in hardware format, a GdkPixbuf contains image data in a canonical 24-bit RGB format.)
 * Params Values: a GdkColormap, pixel value in hardware display format, GdkColor with red, green, blue fields initialized
 * Expected: void  
 */
static void test_purpose_10()
{
    #define COLOR {0, 65535, 0, 0}
    #define WRITEABLE FALSE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor color = COLOR;
    GdkColor result;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (!gdk_colormap_alloc_color (colormap, &color, WRITEABLE, BEST_MATCH))
        TEST_FAIL ("gdk_colormap_alloc_color cannot allocate color from colormap", NULL);
    
    gdk_colormap_query_color (colormap, color.pixel, &result);
    
    if (result.red != color.red)
        TEST_FAIL ("The red component of the color should be %x, not %x", color.red, result.red, NULL);
    
    if (result.green != color.green)
        TEST_FAIL ("The green component of the color should be %x, not %x", color.green, result.green, NULL);
    
    if (result.blue != color.blue)
        TEST_FAIL ("The blue component of the color should be %x, not %x", color.blue, result.blue, NULL);
    
    #undef COLOR
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_query_color
 * Params: GdkColormap *colormap, gulong pixel, GdkColor *result
 * Returns: void
 * Assertion: Locates the RGB color in colormap corresponding to the given hardware pixel pixel. pixel must be a valid pixel in the colormap; it's a programmer error to call this function with a pixel which is not in the colormap. Hardware pixels are normally obtained from gdk_colormap_alloc_colors(), or from a GdkImage. (A GdkImage contains image data in hardware format, a GdkPixbuf contains image data in a canonical 24-bit RGB format.)
 * Params Values: a GdkColormap, pixel value in hardware display format, GdkColor with red, green, blue fields initialized
 * Expected: void  
 */
static void test_purpose_11()
{
    #define COLOR {0, 0, 65535, 0}
    #define WRITEABLE FALSE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor color = COLOR;
    GdkColor result;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (!gdk_colormap_alloc_color (colormap, &color, WRITEABLE, BEST_MATCH))
        TEST_FAIL ("gdk_colormap_alloc_color cannot allocate color from colormap", NULL);
    
    gdk_colormap_query_color (colormap, color.pixel, &result);
    
    if (result.red != color.red)
        TEST_FAIL ("The red component of the color should be %x, not %x", color.red, result.red, NULL);
    
    if (result.green != color.green)
        TEST_FAIL ("The green component of the color should be %x, not %x", color.green, result.green, NULL);
    
    if (result.blue != color.blue)
        TEST_FAIL ("The blue component of the color should be %x, not %x", color.blue, result.blue, NULL);
    
    #undef COLOR
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_query_color
 * Params: GdkColormap *colormap, gulong pixel, GdkColor *result
 * Returns: void
 * Assertion: Locates the RGB color in colormap corresponding to the given hardware pixel pixel. pixel must be a valid pixel in the colormap; it's a programmer error to call this function with a pixel which is not in the colormap. Hardware pixels are normally obtained from gdk_colormap_alloc_colors(), or from a GdkImage. (A GdkImage contains image data in hardware format, a GdkPixbuf contains image data in a canonical 24-bit RGB format.)
 * Params Values: a GdkColormap, pixel value in hardware display format, GdkColor with red, green, blue fields initialized
 * Expected: void  
 */
static void test_purpose_12()
{
    #define COLOR {0, 0, 0, 65535}
    #define WRITEABLE FALSE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor color = COLOR;
    GdkColor result;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (!gdk_colormap_alloc_color (colormap, &color, WRITEABLE, BEST_MATCH))
        TEST_FAIL ("gdk_colormap_alloc_color cannot allocate color from colormap", NULL);
    
    gdk_colormap_query_color (colormap, color.pixel, &result);
    
    if (result.red != color.red)
        TEST_FAIL ("The red component of the color should be %x, not %x", color.red, result.red, NULL);
    
    if (result.green != color.green)
        TEST_FAIL ("The green component of the color should be %x, not %x", color.green, result.green, NULL);
    
    if (result.blue != color.blue)
        TEST_FAIL ("The blue component of the color should be %x, not %x", color.blue, result.blue, NULL);
    
    #undef COLOR
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_query_color
 * Params: GdkColormap *colormap, gulong pixel, GdkColor *result
 * Returns: void
 * Assertion: Locates the RGB color in colormap corresponding to the given hardware pixel pixel. pixel must be a valid pixel in the colormap; it's a programmer error to call this function with a pixel which is not in the colormap. Hardware pixels are normally obtained from gdk_colormap_alloc_colors(), or from a GdkImage. (A GdkImage contains image data in hardware format, a GdkPixbuf contains image data in a canonical 24-bit RGB format.)
 * Params Values: a GdkColormap, pixel value in hardware display format, GdkColor with red, green, blue fields initialized
 * Expected: void  
 */
static void test_purpose_13()
{
    #define COLOR {0, 0, 0, 0}
    #define WRITEABLE TRUE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor color = COLOR;
    GdkColor result;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (!gdk_colormap_alloc_color (colormap, &color, WRITEABLE, BEST_MATCH))
        TEST_FAIL ("gdk_colormap_alloc_color cannot allocate color from colormap", NULL);
    
    gdk_colormap_query_color (colormap, color.pixel, &result);
    
    if (result.red != color.red)
        TEST_FAIL ("The red component of the color should be %x, not %x", color.red, result.red, NULL);
    
    if (result.green != color.green)
        TEST_FAIL ("The green component of the color should be %x, not %x", color.green, result.green, NULL);
    
    if (result.blue != color.blue)
        TEST_FAIL ("The blue component of the color should be %x, not %x", color.blue, result.blue, NULL);
    
    #undef COLOR
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_query_color
 * Params: GdkColormap *colormap, gulong pixel, GdkColor *result
 * Returns: void
 * Assertion: Locates the RGB color in colormap corresponding to the given hardware pixel pixel. pixel must be a valid pixel in the colormap; it's a programmer error to call this function with a pixel which is not in the colormap. Hardware pixels are normally obtained from gdk_colormap_alloc_colors(), or from a GdkImage. (A GdkImage contains image data in hardware format, a GdkPixbuf contains image data in a canonical 24-bit RGB format.)
 * Params Values: a GdkColormap, pixel value in hardware display format, GdkColor with red, green, blue fields initialized
 * Expected: void  
 */
static void test_purpose_14()
{
    #define COLOR {0, 0, 65535, 0}
    #define WRITEABLE TRUE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor color = COLOR;
    GdkColor result;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (!gdk_colormap_alloc_color (colormap, &color, WRITEABLE, BEST_MATCH))
        TEST_FAIL ("gdk_colormap_alloc_color cannot allocate color from colormap", NULL);
    
    gdk_colormap_query_color (colormap, color.pixel, &result);
    
    if (result.red != color.red)
        TEST_FAIL ("The red component of the color should be %x, not %x", color.red, result.red, NULL);
    
    if (result.green != color.green)
        TEST_FAIL ("The green component of the color should be %x, not %x", color.green, result.green, NULL);
    
    if (result.blue != color.blue)
        TEST_FAIL ("The blue component of the color should be %x, not %x", color.blue, result.blue, NULL);
    
    #undef COLOR
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_query_color
 * Params: GdkColormap *colormap, gulong pixel, GdkColor *result
 * Returns: void
 * Assertion: Locates the RGB color in colormap corresponding to the given hardware pixel pixel. pixel must be a valid pixel in the colormap; it's a programmer error to call this function with a pixel which is not in the colormap. Hardware pixels are normally obtained from gdk_colormap_alloc_colors(), or from a GdkImage. (A GdkImage contains image data in hardware format, a GdkPixbuf contains image data in a canonical 24-bit RGB format.)
 * Params Values: a GdkColormap, pixel value in hardware display format, GdkColor with red, green, blue fields initialized
 * Expected: void  
 */
static void test_purpose_15()
{
    #define COLOR {0, 65535, 65535, 65535}
    #define WRITEABLE TRUE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor color = COLOR;
    GdkColor result;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (!gdk_colormap_alloc_color (colormap, &color, WRITEABLE, BEST_MATCH))
        TEST_FAIL ("gdk_colormap_alloc_color cannot allocate color from colormap", NULL);
    
    gdk_colormap_query_color (colormap, color.pixel, &result);
    
    if (result.red != color.red)
        TEST_FAIL ("The red component of the color should be %x, not %x", color.red, result.red, NULL);
    
    if (result.green != color.green)
        TEST_FAIL ("The green component of the color should be %x, not %x", color.green, result.green, NULL);
    
    if (result.blue != color.blue)
        TEST_FAIL ("The blue component of the color should be %x, not %x", color.blue, result.blue, NULL);
    
    #undef COLOR
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_alloc_colors
 * Params: GdkColormap *colormap, GdkColor *colors, gint ncolors, gboolean writeable, gboolean best_match, gboolean *success
 * Returns: gint
 * Assertion: Allocates colors from a colormap.
 * Params Values: colormap : a GdkColormap. colors : The color values to allocate. On return, the pixel values for allocated colors will be filled in. ncolors : The number of colors in colors. writeable : If TRUE, the colors are allocated writeable (their values can later be changed using gdk_color_change()). Writeable colors cannot be shared between applications. best_match : If TRUE, GDK will attempt to do matching against existing colors if the colors cannot be allocated as requested. success : An array of length ncolors. On return, this indicates whether the corresponding color in colors was successfully allocated or not.
 * Expected: The number of colors that were not successfully allocated.  
 */
static void test_purpose_16()
{
    #define COLORS {{0, 65535, 0, 0}}
    #define NCOLORS 1
    #define WRITEABLE FALSE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor colors[NCOLORS] = COLORS;
    gboolean success[NCOLORS];
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (gdk_colormap_alloc_colors (colormap, colors, NCOLORS, WRITEABLE, BEST_MATCH, success))
        TEST_FAIL ("gdk_colormap_alloc_colors cannot allocate colors from colormap", NULL);
    
    for (i = 0; i < NCOLORS; i++)
        if (colors[i].red !=0 || colors[i].green != 0 || colors[i].blue != 0)
            if (colors[i].pixel == 0)
                TEST_FAIL ("gdk_colormap_alloc_colors produced wrong pixel value", NULL);
    
    #undef COLORS
    #undef NCOLORS
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_alloc_colors
 * Params: GdkColormap *colormap, GdkColor *colors, gint ncolors, gboolean writeable, gboolean best_match, gboolean *success
 * Returns: gint
 * Assertion: Allocates colors from a colormap.
 * Params Values: colormap : a GdkColormap. colors : The color values to allocate. On return, the pixel values for allocated colors will be filled in. ncolors : The number of colors in colors. writeable : If TRUE, the colors are allocated writeable (their values can later be changed using gdk_color_change()). Writeable colors cannot be shared between applications. best_match : If TRUE, GDK will attempt to do matching against existing colors if the colors cannot be allocated as requested. success : An array of length ncolors. On return, this indicates whether the corresponding color in colors was successfully allocated or not.
 * Expected: The number of colors that were not successfully allocated.  
 */
static void test_purpose_17()
{
    #define COLORS {{0, 65535, 0, 0}, {0, 0, 65535, 0}}
    #define NCOLORS 2
    #define WRITEABLE FALSE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor colors[NCOLORS] = COLORS;
    gboolean success[NCOLORS];
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (gdk_colormap_alloc_colors (colormap, colors, NCOLORS, WRITEABLE, BEST_MATCH, success))
        TEST_FAIL ("gdk_colormap_alloc_colors cannot allocate colors from colormap", NULL);
    
    for (i = 0; i < NCOLORS; i++)
        if (colors[i].red !=0 || colors[i].green != 0 || colors[i].blue != 0)
            if (colors[i].pixel == 0)
                TEST_FAIL ("gdk_colormap_alloc_colors produced wrong pixel value", NULL);
    
    #undef COLORS
    #undef NCOLORS
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_alloc_colors
 * Params: GdkColormap *colormap, GdkColor *colors, gint ncolors, gboolean writeable, gboolean best_match, gboolean *success
 * Returns: gint
 * Assertion: Allocates colors from a colormap.
 * Params Values: colormap : a GdkColormap. colors : The color values to allocate. On return, the pixel values for allocated colors will be filled in. ncolors : The number of colors in colors. writeable : If TRUE, the colors are allocated writeable (their values can later be changed using gdk_color_change()). Writeable colors cannot be shared between applications. best_match : If TRUE, GDK will attempt to do matching against existing colors if the colors cannot be allocated as requested. success : An array of length ncolors. On return, this indicates whether the corresponding color in colors was successfully allocated or not.
 * Expected: The number of colors that were not successfully allocated.  
 */
static void test_purpose_18()
{
    #define COLORS {{0, 65535, 0, 0}, {0, 0, 65535, 0}, {0, 0, 0, 65535}}
    #define NCOLORS 3
    #define WRITEABLE FALSE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor colors[NCOLORS] = COLORS;
    gboolean success[NCOLORS];
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (gdk_colormap_alloc_colors (colormap, colors, NCOLORS, WRITEABLE, BEST_MATCH, success))
        TEST_FAIL ("gdk_colormap_alloc_colors cannot allocate colors from colormap", NULL);
    
    for (i = 0; i < NCOLORS; i++)
        if (colors[i].red !=0 || colors[i].green != 0 || colors[i].blue != 0)
            if (colors[i].pixel == 0)
                TEST_FAIL ("gdk_colormap_alloc_colors produced wrong pixel value", NULL);
    
    #undef COLORS
    #undef NCOLORS
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_alloc_colors
 * Params: GdkColormap *colormap, GdkColor *colors, gint ncolors, gboolean writeable, gboolean best_match, gboolean *success
 * Returns: gint
 * Assertion: Allocates colors from a colormap.
 * Params Values: colormap : a GdkColormap. colors : The color values to allocate. On return, the pixel values for allocated colors will be filled in. ncolors : The number of colors in colors. writeable : If TRUE, the colors are allocated writeable (their values can later be changed using gdk_color_change()). Writeable colors cannot be shared between applications. best_match : If TRUE, GDK will attempt to do matching against existing colors if the colors cannot be allocated as requested. success : An array of length ncolors. On return, this indicates whether the corresponding color in colors was successfully allocated or not.
 * Expected: The number of colors that were not successfully allocated.  
 */
static void test_purpose_19()
{
    #define COLORS {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}
    #define NCOLORS 3
    #define WRITEABLE TRUE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor colors[NCOLORS] = COLORS;
    gboolean success[NCOLORS];
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (gdk_colormap_alloc_colors (colormap, colors, NCOLORS, WRITEABLE, BEST_MATCH, success))
        TEST_FAIL ("gdk_colormap_alloc_colors cannot allocate colors from colormap", NULL);
    
    for (i = 0; i < NCOLORS; i++)
        if (colors[i].red !=0 || colors[i].green != 0 || colors[i].blue != 0)
            if (colors[i].pixel == 0)
                TEST_FAIL ("gdk_colormap_alloc_colors produced wrong pixel value", NULL);
    
    #undef COLORS
    #undef NCOLORS
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_alloc_colors
 * Params: GdkColormap *colormap, GdkColor *colors, gint ncolors, gboolean writeable, gboolean best_match, gboolean *success
 * Returns: gint
 * Assertion: Allocates colors from a colormap.
 * Params Values: colormap : a GdkColormap. colors : The color values to allocate. On return, the pixel values for allocated colors will be filled in. ncolors : The number of colors in colors. writeable : If TRUE, the colors are allocated writeable (their values can later be changed using gdk_color_change()). Writeable colors cannot be shared between applications. best_match : If TRUE, GDK will attempt to do matching against existing colors if the colors cannot be allocated as requested. success : An array of length ncolors. On return, this indicates whether the corresponding color in colors was successfully allocated or not.
 * Expected: The number of colors that were not successfully allocated.  
 */
static void test_purpose_20()
{
    #define COLORS {{0, 32768, 32768, 32768}, {0, 32768, 32768, 32768}, {0, 32768, 32768, 32768}}
    #define NCOLORS 3
    #define WRITEABLE TRUE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor colors[NCOLORS] = COLORS;
    gboolean success[NCOLORS];
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (gdk_colormap_alloc_colors (colormap, colors, NCOLORS, WRITEABLE, BEST_MATCH, success))
        TEST_FAIL ("gdk_colormap_alloc_colors cannot allocate colors from colormap", NULL);
    
    for (i = 0; i < NCOLORS; i++)
        if (colors[i].red !=0 || colors[i].green != 0 || colors[i].blue != 0)
            if (colors[i].pixel == 0)
                TEST_FAIL ("gdk_colormap_alloc_colors produced wrong pixel value", NULL);
    
    #undef COLORS
    #undef NCOLORS
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_alloc_colors
 * Params: GdkColormap *colormap, GdkColor *colors, gint ncolors, gboolean writeable, gboolean best_match, gboolean *success
 * Returns: gint
 * Assertion: Allocates colors from a colormap.
 * Params Values: colormap : a GdkColormap. colors : The color values to allocate. On return, the pixel values for allocated colors will be filled in. ncolors : The number of colors in colors. writeable : If TRUE, the colors are allocated writeable (their values can later be changed using gdk_color_change()). Writeable colors cannot be shared between applications. best_match : If TRUE, GDK will attempt to do matching against existing colors if the colors cannot be allocated as requested. success : An array of length ncolors. On return, this indicates whether the corresponding color in colors was successfully allocated or not.
 * Expected: The number of colors that were not successfully allocated.  
 */
static void test_purpose_21()
{
    #define COLORS {{0, 65535, 65535, 65535}, {0, 65535, 65535, 65535}, {0, 65535, 65535, 65535}}
    #define NCOLORS 3
    #define WRITEABLE TRUE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor colors[NCOLORS] = COLORS;
    gboolean success[NCOLORS];
    int i;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (gdk_colormap_alloc_colors (colormap, colors, NCOLORS, WRITEABLE, BEST_MATCH, success))
        TEST_FAIL ("gdk_colormap_alloc_colors cannot allocate colors from colormap", NULL);
    
    for (i = 0; i < NCOLORS; i++)
        if (colors[i].red !=0 || colors[i].green != 0 || colors[i].blue != 0)
            if (colors[i].pixel == 0)
                TEST_FAIL ("gdk_colormap_alloc_colors produced wrong pixel value", NULL);
    
    #undef COLORS
    #undef NCOLORS
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_free_colors
 * Params: GdkColormap *colormap, GdkColor *colors, gint ncolors
 * Returns: void
 * Assertion: Frees previously allocated colors.
 * Params Values: a GdkColormap, the colors to free, the number of colors in colors
 * Expected: void  
 */
static void test_purpose_22()
{
    #define COLORS {{0, 65535, 0, 0}}
    #define NCOLORS 1
    #define WRITEABLE FALSE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor colors[NCOLORS] = COLORS;
    gboolean success[NCOLORS];
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (gdk_colormap_alloc_colors (colormap, colors, NCOLORS, WRITEABLE, BEST_MATCH, success))
        TEST_FAIL ("gdk_colormap_alloc_colors cannot allocate colors from colormap", NULL);
    
    gdk_colormap_free_colors (colormap, colors, NCOLORS);
    
    #undef COLORS
    #undef NCOLORS
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_free_colors
 * Params: GdkColormap *colormap, GdkColor *colors, gint ncolors
 * Returns: void
 * Assertion: Frees previously allocated colors.
 * Params Values: a GdkColormap, the colors to free, the number of colors in colors
 * Expected: void  
 */
static void test_purpose_23()
{
    #define COLORS {{0, 65535, 0, 0}, {0, 0, 65535, 0}}
    #define NCOLORS 2
    #define WRITEABLE FALSE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor colors[NCOLORS] = COLORS;
    gboolean success[NCOLORS];
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (gdk_colormap_alloc_colors (colormap, colors, NCOLORS, WRITEABLE, BEST_MATCH, success))
        TEST_FAIL ("gdk_colormap_alloc_colors cannot allocate colors from colormap", NULL);
    
    gdk_colormap_free_colors (colormap, colors, NCOLORS);
    
    #undef COLORS
    #undef NCOLORS
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_free_colors
 * Params: GdkColormap *colormap, GdkColor *colors, gint ncolors
 * Returns: void
 * Assertion: Frees previously allocated colors.
 * Params Values: a GdkColormap, the colors to free, the number of colors in colors
 * Expected: void  
 */
static void test_purpose_24()
{
    #define COLORS {{0, 65535, 0, 0}, {0, 0, 65535, 0}, {0, 0, 0, 65535}}
    #define NCOLORS 3
    #define WRITEABLE FALSE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor colors[NCOLORS] = COLORS;
    gboolean success[NCOLORS];
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (gdk_colormap_alloc_colors (colormap, colors, NCOLORS, WRITEABLE, BEST_MATCH, success))
        TEST_FAIL ("gdk_colormap_alloc_colors cannot allocate colors from colormap", NULL);
    
    gdk_colormap_free_colors (colormap, colors, NCOLORS);
    
    #undef COLORS
    #undef NCOLORS
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_free_colors
 * Params: GdkColormap *colormap, GdkColor *colors, gint ncolors
 * Returns: void
 * Assertion: Frees previously allocated colors.
 * Params Values: a GdkColormap, the colors to free, the number of colors in colors
 * Expected: void  
 */
static void test_purpose_25()
{
    #define COLORS {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}
    #define NCOLORS 3
    #define WRITEABLE TRUE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor colors[NCOLORS] = COLORS;
    gboolean success[NCOLORS];
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (gdk_colormap_alloc_colors (colormap, colors, NCOLORS, WRITEABLE, BEST_MATCH, success))
        TEST_FAIL ("gdk_colormap_alloc_colors cannot allocate colors from colormap", NULL);
    
    gdk_colormap_free_colors (colormap, colors, NCOLORS);
    
    #undef COLORS
    #undef NCOLORS
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_free_colors
 * Params: GdkColormap *colormap, GdkColor *colors, gint ncolors
 * Returns: void
 * Assertion: Frees previously allocated colors.
 * Params Values: a GdkColormap, the colors to free, the number of colors in colors
 * Expected: void  
 */
static void test_purpose_26()
{
    #define COLORS {{0, 32768, 32768, 32768}, {0, 32768, 32768, 32768}, {0, 32768, 32768, 32768}}
    #define NCOLORS 3
    #define WRITEABLE TRUE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor colors[NCOLORS] = COLORS;
    gboolean success[NCOLORS];
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (gdk_colormap_alloc_colors (colormap, colors, NCOLORS, WRITEABLE, BEST_MATCH, success))
        TEST_FAIL ("gdk_colormap_alloc_colors cannot allocate colors from colormap", NULL);
    
    gdk_colormap_free_colors (colormap, colors, NCOLORS);
    
    #undef COLORS
    #undef NCOLORS
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_colormap_free_colors
 * Params: GdkColormap *colormap, GdkColor *colors, gint ncolors
 * Returns: void
 * Assertion: Frees previously allocated colors.
 * Params Values: a GdkColormap, the colors to free, the number of colors in colors
 * Expected: void  
 */
static void test_purpose_27()
{
    #define COLORS {{0, 65535, 65535, 65535}, {0, 65535, 65535, 65535}, {0, 65535, 65535, 65535}}
    #define NCOLORS 3
    #define WRITEABLE TRUE
    #define BEST_MATCH TRUE
    
    GdkColormap *colormap;
    GdkColor colors[NCOLORS] = COLORS;
    gboolean success[NCOLORS];
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    colormap = gdk_colormap_get_system ();
    
    if (!colormap)
    {
        TEST_FAIL (get_not_created_msg (), NULL);
        return;
    }
    
    if (!GDK_IS_COLORMAP (colormap))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL);
        return;
    }
    
    if (gdk_colormap_alloc_colors (colormap, colors, NCOLORS, WRITEABLE, BEST_MATCH, success))
        TEST_FAIL ("gdk_colormap_alloc_colors cannot allocate colors from colormap", NULL);
    
    gdk_colormap_free_colors (colormap, colors, NCOLORS);
    
    #undef COLORS
    #undef NCOLORS
    #undef WRITEABLE
    #undef BEST_MATCH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_equal
 * Params: const GdkColor *colora, const GdkColor *colorb
 * Returns: gboolean
 * Assertion: Compares two colors.
 * Params Values: a GdkColor, another GdkColor
 * Expected: TRUE if the two colors compare equal  
 */
static void test_purpose_28()
{
    #define COLORA {0, 65535, 0, 0}
    #define COLORB {0, 65535, 0, 0}
    #define RESULT TRUE
    
    GdkColor colora = COLORA;
    GdkColor colorb = COLORB;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if (gdk_color_equal (&colora, &colorb) != RESULT)
        TEST_FAIL ("gdk_color_equal should return %d", RESULT, NULL);
    
    #undef COLORA
    #undef COLORB
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_equal
 * Params: const GdkColor *colora, const GdkColor *colorb
 * Returns: gboolean
 * Assertion: Compares two colors.
 * Params Values: a GdkColor, another GdkColor
 * Expected: TRUE if the two colors compare equal  
 */
static void test_purpose_29()
{
    #define COLORA {0, 0, 65535, 0}
    #define COLORB {0, 0, 65535, 0}
    #define RESULT TRUE
    
    GdkColor colora = COLORA;
    GdkColor colorb = COLORB;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if (gdk_color_equal (&colora, &colorb) != RESULT)
        TEST_FAIL ("gdk_color_equal should return %d", RESULT, NULL);
    
    #undef COLORA
    #undef COLORB
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_equal
 * Params: const GdkColor *colora, const GdkColor *colorb
 * Returns: gboolean
 * Assertion: Compares two colors.
 * Params Values: a GdkColor, another GdkColor
 * Expected: TRUE if the two colors compare equal  
 */
static void test_purpose_30()
{
    #define COLORA {0, 0, 0, 65535}
    #define COLORB {0, 0, 0, 65535}
    #define RESULT TRUE
    
    GdkColor colora = COLORA;
    GdkColor colorb = COLORB;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if (gdk_color_equal (&colora, &colorb) != RESULT)
        TEST_FAIL ("gdk_color_equal should return %d", RESULT, NULL);
    
    #undef COLORA
    #undef COLORB
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_equal
 * Params: const GdkColor *colora, const GdkColor *colorb
 * Returns: gboolean
 * Assertion: Compares two colors.
 * Params Values: a GdkColor, another GdkColor
 * Expected: TRUE if the two colors compare equal  
 */
static void test_purpose_31()
{
    #define COLORA {0, 0, 0, 0}
    #define COLORB {0, 0, 0, 0}
    #define RESULT TRUE
    
    GdkColor colora = COLORA;
    GdkColor colorb = COLORB;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if (gdk_color_equal (&colora, &colorb) != RESULT)
        TEST_FAIL ("gdk_color_equal should return %d", RESULT, NULL);
    
    #undef COLORA
    #undef COLORB
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_equal
 * Params: const GdkColor *colora, const GdkColor *colorb
 * Returns: gboolean
 * Assertion: Compares two colors.
 * Params Values: a GdkColor, another GdkColor
 * Expected: TRUE if the two colors compare equal  
 */
static void test_purpose_32()
{
    #define COLORA {0, 65535, 65535, 65535}
    #define COLORB {0, 65535, 65535, 65535}
    #define RESULT TRUE
    
    GdkColor colora = COLORA;
    GdkColor colorb = COLORB;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if (gdk_color_equal (&colora, &colorb) != RESULT)
        TEST_FAIL ("gdk_color_equal should return %d", RESULT, NULL);
    
    #undef COLORA
    #undef COLORB
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_equal
 * Params: const GdkColor *colora, const GdkColor *colorb
 * Returns: gboolean
 * Assertion: Compares two colors.
 * Params Values: a GdkColor, another GdkColor
 * Expected: TRUE if the two colors compare equal  
 */
static void test_purpose_33()
{
    #define COLORA {0, 1, 22, 333}
    #define COLORB {0, 65535, 32768, 0}
    #define RESULT FALSE
    
    GdkColor colora = COLORA;
    GdkColor colorb = COLORB;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if (gdk_color_equal (&colora, &colorb) != RESULT)
        TEST_FAIL ("gdk_color_equal should return %d", RESULT, NULL);
    
    #undef COLORA
    #undef COLORB
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_copy
 * Params: const GdkColor *color
 * Returns: GdkColor*
 * Assertion: Makes a copy of a color structure. The result must be freed using gdk_color_free().
 * Params Values: a GdkColor
 * Expected: a copy of color.  
 */
static void test_purpose_34()
{
    #define COLOR {0, 65535, 0, 0}
    
    GdkColor color = COLOR;
    GdkColor *copy;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if ((copy = gdk_color_copy (&color)) == NULL)
        TEST_FAIL ("gdk_color_copy failed to make copy", NULL);
    
    if (!gdk_color_equal (&color, copy))
        TEST_FAIL ("copy of color is not equal to color", NULL);
    
    gdk_color_free (copy);
    
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_copy
 * Params: const GdkColor *color
 * Returns: GdkColor*
 * Assertion: Makes a copy of a color structure. The result must be freed using gdk_color_free().
 * Params Values: a GdkColor
 * Expected: a copy of color.  
 */
static void test_purpose_35()
{
    #define COLOR {0, 0, 65535, 0}
    
    GdkColor color = COLOR;
    GdkColor *copy;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if ((copy = gdk_color_copy (&color)) == NULL)
        TEST_FAIL ("gdk_color_copy failed to make copy", NULL);
    
    if (!gdk_color_equal (&color, copy))
        TEST_FAIL ("copy of color is not equal to color", NULL);
    
    gdk_color_free (copy);
    
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_copy
 * Params: const GdkColor *color
 * Returns: GdkColor*
 * Assertion: Makes a copy of a color structure. The result must be freed using gdk_color_free().
 * Params Values: a GdkColor
 * Expected: a copy of color.  
 */
static void test_purpose_36()
{
    #define COLOR {0, 0, 0, 65535}
    
    GdkColor color = COLOR;
    GdkColor *copy;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if ((copy = gdk_color_copy (&color)) == NULL)
        TEST_FAIL ("gdk_color_copy failed to make copy", NULL);
    
    if (!gdk_color_equal (&color, copy))
        TEST_FAIL ("copy of color is not equal to color", NULL);
    
    gdk_color_free (copy);
    
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_copy
 * Params: const GdkColor *color
 * Returns: GdkColor*
 * Assertion: Makes a copy of a color structure. The result must be freed using gdk_color_free().
 * Params Values: a GdkColor
 * Expected: a copy of color.  
 */
static void test_purpose_37()
{
    #define COLOR {0, 0, 0, 0}
    
    GdkColor color = COLOR;
    GdkColor *copy;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if ((copy = gdk_color_copy (&color)) == NULL)
        TEST_FAIL ("gdk_color_copy failed to make copy", NULL);
    
    if (!gdk_color_equal (&color, copy))
        TEST_FAIL ("copy of color is not equal to color", NULL);
    
    gdk_color_free (copy);
    
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_copy
 * Params: const GdkColor *color
 * Returns: GdkColor*
 * Assertion: Makes a copy of a color structure. The result must be freed using gdk_color_free().
 * Params Values: a GdkColor
 * Expected: a copy of color.  
 */
static void test_purpose_38()
{
    #define COLOR {0, 65535, 65535, 65535}
    
    GdkColor color = COLOR;
    GdkColor *copy;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if ((copy = gdk_color_copy (&color)) == NULL)
        TEST_FAIL ("gdk_color_copy failed to make copy", NULL);
    
    if (!gdk_color_equal (&color, copy))
        TEST_FAIL ("copy of color is not equal to color", NULL);
    
    gdk_color_free (copy);
    
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_copy
 * Params: const GdkColor *color
 * Returns: GdkColor*
 * Assertion: Makes a copy of a color structure. The result must be freed using gdk_color_free().
 * Params Values: a GdkColor
 * Expected: a copy of color.  
 */
static void test_purpose_39()
{
    #define COLOR {0, 65535, 32768, 0}
    
    GdkColor color = COLOR;
    GdkColor *copy;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if ((copy = gdk_color_copy (&color)) == NULL)
        TEST_FAIL ("gdk_color_copy failed to make copy", NULL);
    
    if (!gdk_color_equal (&color, copy))
        TEST_FAIL ("copy of color is not equal to color", NULL);
    
    gdk_color_free (copy);
    
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_free
 * Params: GdkColor *color
 * Returns: void
 * Assertion: Frees a color structure created with gdk_color_copy().
 * Params Values: a GdkColor
 * Expected: void  
 */
static void test_purpose_40()
{
    #define COLOR {0, 65535, 0, 0}
    
    GdkColor color = COLOR;
    GdkColor *copy;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if ((copy = gdk_color_copy (&color)) == NULL)
        TEST_FAIL ("gdk_color_copy failed to make copy", NULL);
    
    if (!gdk_color_equal (&color, copy))
        TEST_FAIL ("copy of color is not equal to color", NULL);
    
    gdk_color_free (copy);
    
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_free
 * Params: GdkColor *color
 * Returns: void
 * Assertion: Frees a color structure created with gdk_color_copy().
 * Params Values: a GdkColor
 * Expected: void  
 */
static void test_purpose_41()
{
    #define COLOR {0, 0, 65535, 0}
    
    GdkColor color = COLOR;
    GdkColor *copy;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if ((copy = gdk_color_copy (&color)) == NULL)
        TEST_FAIL ("gdk_color_copy failed to make copy", NULL);
    
    if (!gdk_color_equal (&color, copy))
        TEST_FAIL ("copy of color is not equal to color", NULL);
    
    gdk_color_free (copy);
    
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_free
 * Params: GdkColor *color
 * Returns: void
 * Assertion: Frees a color structure created with gdk_color_copy().
 * Params Values: a GdkColor
 * Expected: void  
 */
static void test_purpose_42()
{
    #define COLOR {0, 0, 0, 65535}
    
    GdkColor color = COLOR;
    GdkColor *copy;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if ((copy = gdk_color_copy (&color)) == NULL)
        TEST_FAIL ("gdk_color_copy failed to make copy", NULL);
    
    if (!gdk_color_equal (&color, copy))
        TEST_FAIL ("copy of color is not equal to color", NULL);
    
    gdk_color_free (copy);
    
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_free
 * Params: GdkColor *color
 * Returns: void
 * Assertion: Frees a color structure created with gdk_color_copy().
 * Params Values: a GdkColor
 * Expected: void  
 */
static void test_purpose_43()
{
    #define COLOR {0, 0, 0, 0}
    
    GdkColor color = COLOR;
    GdkColor *copy;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if ((copy = gdk_color_copy (&color)) == NULL)
        TEST_FAIL ("gdk_color_copy failed to make copy", NULL);
    
    if (!gdk_color_equal (&color, copy))
        TEST_FAIL ("copy of color is not equal to color", NULL);
    
    gdk_color_free (copy);
    
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_free
 * Params: GdkColor *color
 * Returns: void
 * Assertion: Frees a color structure created with gdk_color_copy().
 * Params Values: a GdkColor
 * Expected: void  
 */
static void test_purpose_44()
{
    #define COLOR {0, 65535, 65535, 65535}
    
    GdkColor color = COLOR;
    GdkColor *copy;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if ((copy = gdk_color_copy (&color)) == NULL)
        TEST_FAIL ("gdk_color_copy failed to make copy", NULL);
    
    if (!gdk_color_equal (&color, copy))
        TEST_FAIL ("copy of color is not equal to color", NULL);
    
    gdk_color_free (copy);
    
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_free
 * Params: GdkColor *color
 * Returns: void
 * Assertion: Frees a color structure created with gdk_color_copy().
 * Params Values: a GdkColor
 * Expected: void  
 */
static void test_purpose_45()
{
    #define COLOR {0, 65535, 32768, 0}
    
    GdkColor color = COLOR;
    GdkColor *copy;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if ((copy = gdk_color_copy (&color)) == NULL)
        TEST_FAIL ("gdk_color_copy failed to make copy", NULL);
    
    if (!gdk_color_equal (&color, copy))
        TEST_FAIL ("copy of color is not equal to color", NULL);
    
    gdk_color_free (copy);
    
    #undef COLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_parse
 * Params: const gchar *spec, GdkColor *color
 * Returns: gint
 * Assertion: Parses a textual specification of a color and fill in the red, green, and blue fields of a GdkColor structure. The color is not allocated, you must call gdk_colormap_alloc_color() yourself. The text string can be in any of the forms accepted by XParseColor; these include name for a color from rgb.txt, such as DarkSlateGray, or a hex specification such as 305050.
 * Params Values: the string specifying the color, the GdkColor to fill in.
 * Expected: TRUE if the parsing succeeded.  
 */
static void test_purpose_46()
{
    #define SPEC "red"
    #define RED 65535
    #define GREEN 0
    #define BLUE 0
    
    GdkColor color;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if (!gdk_color_parse (SPEC, &color))
        TEST_FAIL ("fail to parse %s", SPEC, NULL);
    
    if (color.red != RED)
        TEST_FAIL ("red value of color should be %d, not %d", RED, color.red, NULL);
    
    if (color.green != GREEN)
        TEST_FAIL ("green value of color should be %d, not %d", GREEN, color.green, NULL);
    
    if (color.blue != BLUE)
        TEST_FAIL ("blue value of color should be %d, not %d", BLUE, color.blue, NULL);
    
    #undef SPEC
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_parse
 * Params: const gchar *spec, GdkColor *color
 * Returns: gint
 * Assertion: Parses a textual specification of a color and fill in the red, green, and blue fields of a GdkColor structure. The color is not allocated, you must call gdk_colormap_alloc_color() yourself. The text string can be in any of the forms accepted by XParseColor; these include name for a color from rgb.txt, such as DarkSlateGray, or a hex specification such as 305050.
 * Params Values: the string specifying the color, the GdkColor to fill in.
 * Expected: TRUE if the parsing succeeded.  
 */
static void test_purpose_47()
{
    #define SPEC "green"
    #define RED 0
    #define GREEN 65535
    #define BLUE 0
    
    GdkColor color;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if (!gdk_color_parse (SPEC, &color))
        TEST_FAIL ("fail to parse %s", SPEC, NULL);
    
    if (color.red != RED)
        TEST_FAIL ("red value of color should be %d, not %d", RED, color.red, NULL);
    
    if (color.green != GREEN)
        TEST_FAIL ("green value of color should be %d, not %d", GREEN, color.green, NULL);
    
    if (color.blue != BLUE)
        TEST_FAIL ("blue value of color should be %d, not %d", BLUE, color.blue, NULL);
    
    #undef SPEC
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_parse
 * Params: const gchar *spec, GdkColor *color
 * Returns: gint
 * Assertion: Parses a textual specification of a color and fill in the red, green, and blue fields of a GdkColor structure. The color is not allocated, you must call gdk_colormap_alloc_color() yourself. The text string can be in any of the forms accepted by XParseColor; these include name for a color from rgb.txt, such as DarkSlateGray, or a hex specification such as 305050.
 * Params Values: the string specifying the color, the GdkColor to fill in.
 * Expected: TRUE if the parsing succeeded.  
 */
static void test_purpose_48()
{
    #define SPEC "blue"
    #define RED 0
    #define GREEN 0
    #define BLUE 65535
    
    GdkColor color;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if (!gdk_color_parse (SPEC, &color))
        TEST_FAIL ("fail to parse %s", SPEC, NULL);
    
    if (color.red != RED)
        TEST_FAIL ("red value of color should be %d, not %d", RED, color.red, NULL);
    
    if (color.green != GREEN)
        TEST_FAIL ("green value of color should be %d, not %d", GREEN, color.green, NULL);
    
    if (color.blue != BLUE)
        TEST_FAIL ("blue value of color should be %d, not %d", BLUE, color.blue, NULL);
    
    #undef SPEC
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_parse
 * Params: const gchar *spec, GdkColor *color
 * Returns: gint
 * Assertion: Parses a textual specification of a color and fill in the red, green, and blue fields of a GdkColor structure. The color is not allocated, you must call gdk_colormap_alloc_color() yourself. The text string can be in any of the forms accepted by XParseColor; these include name for a color from rgb.txt, such as DarkSlateGray, or a hex specification such as 305050.
 * Params Values: the string specifying the color, the GdkColor to fill in.
 * Expected: TRUE if the parsing succeeded.  
 */
static void test_purpose_49()
{
    #define SPEC "#000000000000"
    #define RED 0
    #define GREEN 0
    #define BLUE 0
    
    GdkColor color;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if (!gdk_color_parse (SPEC, &color))
        TEST_FAIL ("fail to parse %s", SPEC, NULL);
    
    if (color.red != RED)
        TEST_FAIL ("red value of color should be %d, not %d", RED, color.red, NULL);
    
    if (color.green != GREEN)
        TEST_FAIL ("green value of color should be %d, not %d", GREEN, color.green, NULL);
    
    if (color.blue != BLUE)
        TEST_FAIL ("blue value of color should be %d, not %d", BLUE, color.blue, NULL);
    
    #undef SPEC
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_parse
 * Params: const gchar *spec, GdkColor *color
 * Returns: gint
 * Assertion: Parses a textual specification of a color and fill in the red, green, and blue fields of a GdkColor structure. The color is not allocated, you must call gdk_colormap_alloc_color() yourself. The text string can be in any of the forms accepted by XParseColor; these include name for a color from rgb.txt, such as DarkSlateGray, or a hex specification such as 305050.
 * Params Values: the string specifying the color, the GdkColor to fill in.
 * Expected: TRUE if the parsing succeeded.  
 */
static void test_purpose_50()
{
    #define SPEC "#0000FFFF0000"
    #define RED 0
    #define GREEN 65535
    #define BLUE 0
    
    GdkColor color;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if (!gdk_color_parse (SPEC, &color))
        TEST_FAIL ("fail to parse %s", SPEC, NULL);
    
    if (color.red != RED)
        TEST_FAIL ("red value of color should be %d, not %d", RED, color.red, NULL);
    
    if (color.green != GREEN)
        TEST_FAIL ("green value of color should be %d, not %d", GREEN, color.green, NULL);
    
    if (color.blue != BLUE)
        TEST_FAIL ("blue value of color should be %d, not %d", BLUE, color.blue, NULL);
    
    #undef SPEC
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_color_parse
 * Params: const gchar *spec, GdkColor *color
 * Returns: gint
 * Assertion: Parses a textual specification of a color and fill in the red, green, and blue fields of a GdkColor structure. The color is not allocated, you must call gdk_colormap_alloc_color() yourself. The text string can be in any of the forms accepted by XParseColor; these include name for a color from rgb.txt, such as DarkSlateGray, or a hex specification such as 305050.
 * Params Values: the string specifying the color, the GdkColor to fill in.
 * Expected: TRUE if the parsing succeeded.  
 */
static void test_purpose_51()
{
    #define SPEC "#FFFFFFFFFFFF"
    #define RED 65535
    #define GREEN 65535
    #define BLUE 65535
    
    GdkColor color;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    if (!gdk_color_parse (SPEC, &color))
        TEST_FAIL ("fail to parse %s", SPEC, NULL);
    
    if (color.red != RED)
        TEST_FAIL ("red value of color should be %d, not %d", RED, color.red, NULL);
    
    if (color.green != GREEN)
        TEST_FAIL ("green value of color should be %d, not %d", GREEN, color.green, NULL);
    
    if (color.blue != BLUE)
        TEST_FAIL ("blue value of color should be %d, not %d", BLUE, color.blue, NULL);
    
    #undef SPEC
    #undef RED
    #undef GREEN
    #undef BLUE
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GdkColormaps ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {NULL,0}
};
