/*
 * GdkPixbufScaling methods tests
 * Testing GdkPixbufScaling methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gdk_pixbuf_scale_simple
 * Params: const GdkPixbuf *, int_, int, GdkInterpType 
 * Return: GdkPixbuf *
 * Assertion: Create a new GdkPixbuf containing a copy of src scaled to dest_width x dest_height. Leaves src unaffected. interp_type should be GDK_INTERP_NEAREST if you want maximum speed (but when scaling down GDK_INTERP_NEAREST is usually unusably ugly). The default interp_type should be GDK_INTERP_BILINEAR which offers reasonable quality and speed. 
 * Expected:  the new GdkPixbuf, or NULL if not enough memory could be allocated for it.  
 */
static void test_purpose_1()
{
    #define WIDTH 		    10
    #define HEIGHT 		    10
    #define TYPE		    GDK_INTERP_NEAREST
    #define EXP_RES		    TRUE
    
    GdkPixbuf * pixbuf_src = NULL;
    GdkPixbuf * pixbuf_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf_src = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,10,10);
    if(pixbuf_src == NULL){
    	TEST_FAIL("gdk_pixbuf_scale_simple: pixbuf_src is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_src) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_scale_simple\":pixbuf_src is not a GdkPixbuf object",NULL);
    	return;
    }
    pixbuf_dst = gdk_pixbuf_scale_simple(pixbuf_src,WIDTH,HEIGHT,TYPE);
    if(EXP_RES == TRUE){
    	if(pixbuf_dst == NULL){
    		TEST_FAIL("gdk_pixbuf_scale_simple:doesnt match expect result!",NULL);
    		return;
    	}
    	if(GDK_IS_PIXBUF(pixbuf_dst) != TRUE){
    		TEST_FAIL("\"gdk_pixbuf_scale_simple\":pixbuf_dst is not a GdkPixbuf object",NULL);
    		return;
    	}
    }
    if(EXP_RES == FALSE){
    	if(pixbuf_dst != NULL){
    		TEST_FAIL("gdk_pixbuf_scale_simple:doesnt match expect result!",NULL);
    		return;
    	}
    }
    
    if(pixbuf_src)
    	g_object_unref(pixbuf_src);
    if(pixbuf_dst)
    	g_object_unref(pixbuf_dst);
    
    #undef WIDTH
    #undef HEIGHT
    #undef TYPE
    #undef EXP_RES
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_scale_simple
 * Params: const GdkPixbuf *, int_, int, GdkInterpType 
 * Return: GdkPixbuf *
 * Assertion: Create a new GdkPixbuf containing a copy of src scaled to dest_width x dest_height. Leaves src unaffected. interp_type should be GDK_INTERP_NEAREST if you want maximum speed (but when scaling down GDK_INTERP_NEAREST is usually unusably ugly). The default interp_type should be GDK_INTERP_BILINEAR which offers reasonable quality and speed. 
 * Expected:  the new GdkPixbuf, or NULL if not enough memory could be allocated for it.  
 */
static void test_purpose_2()
{
    #define WIDTH 		    10
    #define HEIGHT 		    10
    #define TYPE		    GDK_INTERP_BILINEAR
    #define EXP_RES		    TRUE
    
    GdkPixbuf * pixbuf_src = NULL;
    GdkPixbuf * pixbuf_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf_src = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,10,10);
    if(pixbuf_src == NULL){
    	TEST_FAIL("gdk_pixbuf_scale_simple: pixbuf_src is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_src) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_scale_simple\":pixbuf_src is not a GdkPixbuf object",NULL);
    	return;
    }
    pixbuf_dst = gdk_pixbuf_scale_simple(pixbuf_src,WIDTH,HEIGHT,TYPE);
    if(EXP_RES == TRUE){
    	if(pixbuf_dst == NULL){
    		TEST_FAIL("gdk_pixbuf_scale_simple:doesnt match expect result!",NULL);
    		return;
    	}
    	if(GDK_IS_PIXBUF(pixbuf_dst) != TRUE){
    		TEST_FAIL("\"gdk_pixbuf_scale_simple\":pixbuf_dst is not a GdkPixbuf object",NULL);
    		return;
    	}
    }
    if(EXP_RES == FALSE){
    	if(pixbuf_dst != NULL){
    		TEST_FAIL("gdk_pixbuf_scale_simple:doesnt match expect result!",NULL);
    		return;
    	}
    }
    
    if(pixbuf_src)
    	g_object_unref(pixbuf_src);
    if(pixbuf_dst)
    	g_object_unref(pixbuf_dst);
    
    #undef WIDTH
    #undef HEIGHT
    #undef TYPE
    #undef EXP_RES
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_scale_simple
 * Params: const GdkPixbuf *, int_, int, GdkInterpType 
 * Return: GdkPixbuf *
 * Assertion: Create a new GdkPixbuf containing a copy of src scaled to dest_width x dest_height. Leaves src unaffected. interp_type should be GDK_INTERP_NEAREST if you want maximum speed (but when scaling down GDK_INTERP_NEAREST is usually unusably ugly). The default interp_type should be GDK_INTERP_BILINEAR which offers reasonable quality and speed. 
 * Expected:  the new GdkPixbuf, or NULL if not enough memory could be allocated for it.  
 */
static void test_purpose_3()
{
    #define WIDTH 		    10
    #define HEIGHT 		    10
    #define TYPE		    GDK_INTERP_TILES
    #define EXP_RES		    TRUE
    
    GdkPixbuf * pixbuf_src = NULL;
    GdkPixbuf * pixbuf_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf_src = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,10,10);
    if(pixbuf_src == NULL){
    	TEST_FAIL("gdk_pixbuf_scale_simple: pixbuf_src is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_src) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_scale_simple\":pixbuf_src is not a GdkPixbuf object",NULL);
    	return;
    }
    pixbuf_dst = gdk_pixbuf_scale_simple(pixbuf_src,WIDTH,HEIGHT,TYPE);
    if(EXP_RES == TRUE){
    	if(pixbuf_dst == NULL){
    		TEST_FAIL("gdk_pixbuf_scale_simple:doesnt match expect result!",NULL);
    		return;
    	}
    	if(GDK_IS_PIXBUF(pixbuf_dst) != TRUE){
    		TEST_FAIL("\"gdk_pixbuf_scale_simple\":pixbuf_dst is not a GdkPixbuf object",NULL);
    		return;
    	}
    }
    if(EXP_RES == FALSE){
    	if(pixbuf_dst != NULL){
    		TEST_FAIL("gdk_pixbuf_scale_simple:doesnt match expect result!",NULL);
    		return;
    	}
    }
    
    if(pixbuf_src)
    	g_object_unref(pixbuf_src);
    if(pixbuf_dst)
    	g_object_unref(pixbuf_dst);
    
    #undef WIDTH
    #undef HEIGHT
    #undef TYPE
    #undef EXP_RES
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_scale_simple
 * Params: const GdkPixbuf *, int_, int, GdkInterpType 
 * Return: GdkPixbuf *
 * Assertion: Create a new GdkPixbuf containing a copy of src scaled to dest_width x dest_height. Leaves src unaffected. interp_type should be GDK_INTERP_NEAREST if you want maximum speed (but when scaling down GDK_INTERP_NEAREST is usually unusably ugly). The default interp_type should be GDK_INTERP_BILINEAR which offers reasonable quality and speed. 
 * Expected:  the new GdkPixbuf, or NULL if not enough memory could be allocated for it.  
 */
static void test_purpose_4()
{
    #define WIDTH 		    10
    #define HEIGHT 		    10
    #define TYPE		    GDK_INTERP_HYPER
    #define EXP_RES		    TRUE
    
    GdkPixbuf * pixbuf_src = NULL;
    GdkPixbuf * pixbuf_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf_src = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,10,10);
    if(pixbuf_src == NULL){
    	TEST_FAIL("gdk_pixbuf_scale_simple: pixbuf_src is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_src) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_scale_simple\":pixbuf_src is not a GdkPixbuf object",NULL);
    	return;
    }
    pixbuf_dst = gdk_pixbuf_scale_simple(pixbuf_src,WIDTH,HEIGHT,TYPE);
    if(EXP_RES == TRUE){
    	if(pixbuf_dst == NULL){
    		TEST_FAIL("gdk_pixbuf_scale_simple:doesnt match expect result!",NULL);
    		return;
    	}
    	if(GDK_IS_PIXBUF(pixbuf_dst) != TRUE){
    		TEST_FAIL("\"gdk_pixbuf_scale_simple\":pixbuf_dst is not a GdkPixbuf object",NULL);
    		return;
    	}
    }
    if(EXP_RES == FALSE){
    	if(pixbuf_dst != NULL){
    		TEST_FAIL("gdk_pixbuf_scale_simple:doesnt match expect result!",NULL);
    		return;
    	}
    }
    
    if(pixbuf_src)
    	g_object_unref(pixbuf_src);
    if(pixbuf_dst)
    	g_object_unref(pixbuf_dst);
    
    #undef WIDTH
    #undef HEIGHT
    #undef TYPE
    #undef EXP_RES
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_scale_simple
 * Params: const GdkPixbuf *, int_, int, GdkInterpType 
 * Return: GdkPixbuf *
 * Assertion: Create a new GdkPixbuf containing a copy of src scaled to dest_width x dest_height. Leaves src unaffected. interp_type should be GDK_INTERP_NEAREST if you want maximum speed (but when scaling down GDK_INTERP_NEAREST is usually unusably ugly). The default interp_type should be GDK_INTERP_BILINEAR which offers reasonable quality and speed. 
 * Expected:  the new GdkPixbuf, or NULL if not enough memory could be allocated for it.  
 */
static void test_purpose_5()
{
    #define WIDTH 		    10000000
    #define HEIGHT 		    10000000
    #define TYPE		    GDK_INTERP_NEAREST
    #define EXP_RES		    FALSE
    
    GdkPixbuf * pixbuf_src = NULL;
    GdkPixbuf * pixbuf_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf_src = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,10,10);
    if(pixbuf_src == NULL){
    	TEST_FAIL("gdk_pixbuf_scale_simple: pixbuf_src is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_src) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_scale_simple\":pixbuf_src is not a GdkPixbuf object",NULL);
    	return;
    }
    pixbuf_dst = gdk_pixbuf_scale_simple(pixbuf_src,WIDTH,HEIGHT,TYPE);
    if(EXP_RES == TRUE){
    	if(pixbuf_dst == NULL){
    		TEST_FAIL("gdk_pixbuf_scale_simple:doesnt match expect result!",NULL);
    		return;
    	}
    	if(GDK_IS_PIXBUF(pixbuf_dst) != TRUE){
    		TEST_FAIL("\"gdk_pixbuf_scale_simple\":pixbuf_dst is not a GdkPixbuf object",NULL);
    		return;
    	}
    }
    if(EXP_RES == FALSE){
    	if(pixbuf_dst != NULL){
    		TEST_FAIL("gdk_pixbuf_scale_simple:doesnt match expect result!",NULL);
    		return;
    	}
    }
    
    if(pixbuf_src)
    	g_object_unref(pixbuf_src);
    if(pixbuf_dst)
    	g_object_unref(pixbuf_dst);
    
    #undef WIDTH
    #undef HEIGHT
    #undef TYPE
    #undef EXP_RES
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_composite
 * Params: const GdkPixbuf *src,GdkPixbuf *dest,int dest_x,int dest_y,int dest_width,int dest_height,double offset_x,double offset_y,double scale_x,double scale_y,GdkInterpType interp_type,int overall_alpha
 * Return: void
 * Assertion: Creates a transformation of the source image src by scaling by scale_x and scale_y then translating by offset_x and offset_y. This gives an image in the coordinates of the destination pixbuf. The rectangle (dest_x, dest_y, dest_width, dest_height) is then composited onto the corresponding rectangle of the original destination image.When the destination rectangle contains parts not in the source image, the data at the edges of the source image is replicated to infinity. 
 * Expected:   
 */
static void test_purpose_6()
{
    #define DEST_X		     1
    #define DEST_Y		     1
    #define DEST_W		     10
    #define DEST_H		     10
    #define OFF_X		     1
    #define OFF_Y	1
    #define SCALE_X		     10
    #define SCALE_Y	10
    #define TYPE		     GDK_INTERP_BILINEAR
    #define ALPHA	0	
    GdkPixbuf * pixbuf_src = NULL;
    GdkPixbuf * pixbuf_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf_src = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,100,100);
    if(pixbuf_src == NULL){
    	TEST_FAIL("gdk_pixbuf_composite: pixbuf_src is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_src) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_compsite\":pixbuf_src is not a GdkPixbuf object",NULL);
    	return;
    }
    pixbuf_dst = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,100,100);
    if(pixbuf_dst == NULL){
    	TEST_FAIL("gdk_pixbuf_composite: pixbuf_dst is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_dst) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_composite\":pixbuf_dst is not a GdkPixbuf object",NULL);
    	return;
    }
    
    gdk_pixbuf_composite(pixbuf_src,pixbuf_dst,DEST_X,DEST_Y,DEST_W,DEST_Y,OFF_X,OFF_Y,SCALE_X,SCALE_Y,TYPE,ALPHA);
    
    if(pixbuf_src)
    	g_object_unref(pixbuf_src);
    if(pixbuf_dst)
    	g_object_unref(pixbuf_dst);
    #undef DEST_X
    #undef DEST_Y
    #undef DEST_W
    #undef DEST_H
    #undef OFF_X
    #undef OFF_Y
    #undef SCALE_X
    #undef SCALE_Y
    #undef TYPE
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_composite
 * Params: const GdkPixbuf *src,GdkPixbuf *dest,int dest_x,int dest_y,int dest_width,int dest_height,double offset_x,double offset_y,double scale_x,double scale_y,GdkInterpType interp_type,int overall_alpha
 * Return: void
 * Assertion: Creates a transformation of the source image src by scaling by scale_x and scale_y then translating by offset_x and offset_y. This gives an image in the coordinates of the destination pixbuf. The rectangle (dest_x, dest_y, dest_width, dest_height) is then composited onto the corresponding rectangle of the original destination image.When the destination rectangle contains parts not in the source image, the data at the edges of the source image is replicated to infinity. 
 * Expected:   
 */
static void test_purpose_7()
{
    #define DEST_X		     1
    #define DEST_Y		     1
    #define DEST_W		     10
    #define DEST_H		     10
    #define OFF_X		     1
    #define OFF_Y	1
    #define SCALE_X		     10
    #define SCALE_Y	10
    #define TYPE		     GDK_INTERP_BILINEAR
    #define ALPHA	255	
    GdkPixbuf * pixbuf_src = NULL;
    GdkPixbuf * pixbuf_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf_src = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,100,100);
    if(pixbuf_src == NULL){
    	TEST_FAIL("gdk_pixbuf_composite: pixbuf_src is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_src) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_compsite\":pixbuf_src is not a GdkPixbuf object",NULL);
    	return;
    }
    pixbuf_dst = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,100,100);
    if(pixbuf_dst == NULL){
    	TEST_FAIL("gdk_pixbuf_composite: pixbuf_dst is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_dst) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_composite\":pixbuf_dst is not a GdkPixbuf object",NULL);
    	return;
    }
    
    gdk_pixbuf_composite(pixbuf_src,pixbuf_dst,DEST_X,DEST_Y,DEST_W,DEST_Y,OFF_X,OFF_Y,SCALE_X,SCALE_Y,TYPE,ALPHA);
    
    if(pixbuf_src)
    	g_object_unref(pixbuf_src);
    if(pixbuf_dst)
    	g_object_unref(pixbuf_dst);
    #undef DEST_X
    #undef DEST_Y
    #undef DEST_W
    #undef DEST_H
    #undef OFF_X
    #undef OFF_Y
    #undef SCALE_X
    #undef SCALE_Y
    #undef TYPE
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_composite
 * Params: const GdkPixbuf *src,GdkPixbuf *dest,int dest_x,int dest_y,int dest_width,int dest_height,double offset_x,double offset_y,double scale_x,double scale_y,GdkInterpType interp_type,int overall_alpha
 * Return: void
 * Assertion: Creates a transformation of the source image src by scaling by scale_x and scale_y then translating by offset_x and offset_y. This gives an image in the coordinates of the destination pixbuf. The rectangle (dest_x, dest_y, dest_width, dest_height) is then composited onto the corresponding rectangle of the original destination image.When the destination rectangle contains parts not in the source image, the data at the edges of the source image is replicated to infinity. 
 * Expected:   
 */
static void test_purpose_8()
{
    #define DEST_X		     2
    #define DEST_Y		     2
    #define DEST_W		     20
    #define DEST_H		     20
    #define OFF_X		     1
    #define OFF_Y	1
    #define SCALE_X		     10
    #define SCALE_Y	10
    #define TYPE		     GDK_INTERP_BILINEAR
    #define ALPHA	0	
    GdkPixbuf * pixbuf_src = NULL;
    GdkPixbuf * pixbuf_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf_src = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,100,100);
    if(pixbuf_src == NULL){
    	TEST_FAIL("gdk_pixbuf_composite: pixbuf_src is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_src) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_compsite\":pixbuf_src is not a GdkPixbuf object",NULL);
    	return;
    }
    pixbuf_dst = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,100,100);
    if(pixbuf_dst == NULL){
    	TEST_FAIL("gdk_pixbuf_composite: pixbuf_dst is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_dst) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_composite\":pixbuf_dst is not a GdkPixbuf object",NULL);
    	return;
    }
    
    gdk_pixbuf_composite(pixbuf_src,pixbuf_dst,DEST_X,DEST_Y,DEST_W,DEST_Y,OFF_X,OFF_Y,SCALE_X,SCALE_Y,TYPE,ALPHA);
    
    if(pixbuf_src)
    	g_object_unref(pixbuf_src);
    if(pixbuf_dst)
    	g_object_unref(pixbuf_dst);
    #undef DEST_X
    #undef DEST_Y
    #undef DEST_W
    #undef DEST_H
    #undef OFF_X
    #undef OFF_Y
    #undef SCALE_X
    #undef SCALE_Y
    #undef TYPE
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_composite
 * Params: const GdkPixbuf *src,GdkPixbuf *dest,int dest_x,int dest_y,int dest_width,int dest_height,double offset_x,double offset_y,double scale_x,double scale_y,GdkInterpType interp_type,int overall_alpha
 * Return: void
 * Assertion: Creates a transformation of the source image src by scaling by scale_x and scale_y then translating by offset_x and offset_y. This gives an image in the coordinates of the destination pixbuf. The rectangle (dest_x, dest_y, dest_width, dest_height) is then composited onto the corresponding rectangle of the original destination image.When the destination rectangle contains parts not in the source image, the data at the edges of the source image is replicated to infinity. 
 * Expected:   
 */
static void test_purpose_9()
{
    #define DEST_X		     2
    #define DEST_Y		     2
    #define DEST_W		     20
    #define DEST_H		     20
    #define OFF_X		     1
    #define OFF_Y	1
    #define SCALE_X		     10
    #define SCALE_Y	10
    #define TYPE		     GDK_INTERP_BILINEAR
    #define ALPHA	255	
    GdkPixbuf * pixbuf_src = NULL;
    GdkPixbuf * pixbuf_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf_src = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,100,100);
    if(pixbuf_src == NULL){
    	TEST_FAIL("gdk_pixbuf_composite: pixbuf_src is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_src) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_compsite\":pixbuf_src is not a GdkPixbuf object",NULL);
    	return;
    }
    pixbuf_dst = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,100,100);
    if(pixbuf_dst == NULL){
    	TEST_FAIL("gdk_pixbuf_composite: pixbuf_dst is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_dst) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_composite\":pixbuf_dst is not a GdkPixbuf object",NULL);
    	return;
    }
    
    gdk_pixbuf_composite(pixbuf_src,pixbuf_dst,DEST_X,DEST_Y,DEST_W,DEST_Y,OFF_X,OFF_Y,SCALE_X,SCALE_Y,TYPE,ALPHA);
    
    if(pixbuf_src)
    	g_object_unref(pixbuf_src);
    if(pixbuf_dst)
    	g_object_unref(pixbuf_dst);
    #undef DEST_X
    #undef DEST_Y
    #undef DEST_W
    #undef DEST_H
    #undef OFF_X
    #undef OFF_Y
    #undef SCALE_X
    #undef SCALE_Y
    #undef TYPE
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_composite
 * Params: const GdkPixbuf *src,GdkPixbuf *dest,int dest_x,int dest_y,int dest_width,int dest_height,double offset_x,double offset_y,double scale_x,double scale_y,GdkInterpType interp_type,int overall_alpha
 * Return: void
 * Assertion: Creates a transformation of the source image src by scaling by scale_x and scale_y then translating by offset_x and offset_y. This gives an image in the coordinates of the destination pixbuf. The rectangle (dest_x, dest_y, dest_width, dest_height) is then composited onto the corresponding rectangle of the original destination image.When the destination rectangle contains parts not in the source image, the data at the edges of the source image is replicated to infinity. 
 * Expected:   
 */
static void test_purpose_10()
{
    #define DEST_X		     1
    #define DEST_Y		     1
    #define DEST_W		     10
    #define DEST_H		     10
    #define OFF_X		     98
    #define OFF_Y	98
    #define SCALE_X		     1
    #define SCALE_Y	1
    #define TYPE		     GDK_INTERP_BILINEAR
    #define ALPHA	0	
    GdkPixbuf * pixbuf_src = NULL;
    GdkPixbuf * pixbuf_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf_src = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,100,100);
    if(pixbuf_src == NULL){
    	TEST_FAIL("gdk_pixbuf_composite: pixbuf_src is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_src) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_compsite\":pixbuf_src is not a GdkPixbuf object",NULL);
    	return;
    }
    pixbuf_dst = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,100,100);
    if(pixbuf_dst == NULL){
    	TEST_FAIL("gdk_pixbuf_composite: pixbuf_dst is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_dst) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_composite\":pixbuf_dst is not a GdkPixbuf object",NULL);
    	return;
    }
    
    gdk_pixbuf_composite(pixbuf_src,pixbuf_dst,DEST_X,DEST_Y,DEST_W,DEST_Y,OFF_X,OFF_Y,SCALE_X,SCALE_Y,TYPE,ALPHA);
    
    if(pixbuf_src)
    	g_object_unref(pixbuf_src);
    if(pixbuf_dst)
    	g_object_unref(pixbuf_dst);
    #undef DEST_X
    #undef DEST_Y
    #undef DEST_W
    #undef DEST_H
    #undef OFF_X
    #undef OFF_Y
    #undef SCALE_X
    #undef SCALE_Y
    #undef TYPE
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_composite
 * Params: const GdkPixbuf *src,GdkPixbuf *dest,int dest_x,int dest_y,int dest_width,int dest_height,double offset_x,double offset_y,double scale_x,double scale_y,GdkInterpType interp_type,int overall_alpha
 * Return: void
 * Assertion: Creates a transformation of the source image src by scaling by scale_x and scale_y then translating by offset_x and offset_y. This gives an image in the coordinates of the destination pixbuf. The rectangle (dest_x, dest_y, dest_width, dest_height) is then composited onto the corresponding rectangle of the original destination image.When the destination rectangle contains parts not in the source image, the data at the edges of the source image is replicated to infinity. 
 * Expected:   
 */
static void test_purpose_11()
{
    #define DEST_X		     1
    #define DEST_Y		     1
    #define DEST_W		     10
    #define DEST_H		     10
    #define OFF_X		     98
    #define OFF_Y	98
    #define SCALE_X		     1
    #define SCALE_Y	1
    #define TYPE		     GDK_INTERP_BILINEAR
    #define ALPHA	255	
    GdkPixbuf * pixbuf_src = NULL;
    GdkPixbuf * pixbuf_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf_src = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,100,100);
    if(pixbuf_src == NULL){
    	TEST_FAIL("gdk_pixbuf_composite: pixbuf_src is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_src) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_compsite\":pixbuf_src is not a GdkPixbuf object",NULL);
    	return;
    }
    pixbuf_dst = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,100,100);
    if(pixbuf_dst == NULL){
    	TEST_FAIL("gdk_pixbuf_composite: pixbuf_dst is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_dst) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_composite\":pixbuf_dst is not a GdkPixbuf object",NULL);
    	return;
    }
    
    gdk_pixbuf_composite(pixbuf_src,pixbuf_dst,DEST_X,DEST_Y,DEST_W,DEST_Y,OFF_X,OFF_Y,SCALE_X,SCALE_Y,TYPE,ALPHA);
    
    if(pixbuf_src)
    	g_object_unref(pixbuf_src);
    if(pixbuf_dst)
    	g_object_unref(pixbuf_dst);
    #undef DEST_X
    #undef DEST_Y
    #undef DEST_W
    #undef DEST_H
    #undef OFF_X
    #undef OFF_Y
    #undef SCALE_X
    #undef SCALE_Y
    #undef TYPE
    #undef ALPHA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_scale
 * Params: const GdkPixbuf *src,GdkPixbuf *dest,int dest_x,int dest_y,int dest_width,int dest_height,double offset_x,double offset_y,double scale_x,double scale_y,GdkInterpType interp_type
 * Return: void
 * Assertion: Creates a transformation of the source image src by scaling by scale_x and scale_y then translating by offset_x and offset_y, then renders the rectangle (dest_x, dest_y, dest_width, dest_height) of the resulting image onto the destination image replacing the previous contents. 
 * Expected:   
 */
static void test_purpose_12()
{
    #define DEST_X		     1
    #define DEST_Y		     1
    #define DEST_W		     10
    #define DEST_H		     10
    #define OFF_X		     1
    #define OFF_Y	1
    #define SCALE_X		     10
    #define SCALE_Y	10
    #define TYPE		     GDK_INTERP_BILINEAR
    GdkPixbuf * pixbuf_src = NULL;
    GdkPixbuf * pixbuf_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf_src = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,100,100);
    if(pixbuf_src == NULL){
    	TEST_FAIL("gdk_pixbuf_scale: pixbuf_src is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_src) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_scale\":pixbuf_src is not a GdkPixbuf object",NULL);
    	return;
    }
    pixbuf_dst = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,100,100);
    if(pixbuf_dst == NULL){
    	TEST_FAIL("gdk_pixbuf_scale: pixbuf_dst is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_dst) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_scale\":pixbuf_dst is not a GdkPixbuf object",NULL);
    	return;
    }
    
    gdk_pixbuf_scale(pixbuf_src,pixbuf_dst,DEST_X,DEST_Y,DEST_W,DEST_Y,OFF_X,OFF_Y,SCALE_X,SCALE_Y,TYPE);
    
    if(pixbuf_src)
    	g_object_unref(pixbuf_src);
    if(pixbuf_dst)
    	g_object_unref(pixbuf_dst);
    #undef DEST_X
    #undef DEST_Y
    #undef DEST_W
    #undef DEST_H
    #undef OFF_X
    #undef OFF_Y
    #undef SCALE_X
    #undef SCALE_Y
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_scale
 * Params: const GdkPixbuf *src,GdkPixbuf *dest,int dest_x,int dest_y,int dest_width,int dest_height,double offset_x,double offset_y,double scale_x,double scale_y,GdkInterpType interp_type
 * Return: void
 * Assertion: Creates a transformation of the source image src by scaling by scale_x and scale_y then translating by offset_x and offset_y, then renders the rectangle (dest_x, dest_y, dest_width, dest_height) of the resulting image onto the destination image replacing the previous contents. 
 * Expected:   
 */
static void test_purpose_13()
{
    #define DEST_X		     2
    #define DEST_Y		     2
    #define DEST_W		     20
    #define DEST_H		     20
    #define OFF_X		     1
    #define OFF_Y	1
    #define SCALE_X		     10
    #define SCALE_Y	10
    #define TYPE		     GDK_INTERP_BILINEAR
    GdkPixbuf * pixbuf_src = NULL;
    GdkPixbuf * pixbuf_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf_src = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,100,100);
    if(pixbuf_src == NULL){
    	TEST_FAIL("gdk_pixbuf_scale: pixbuf_src is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_src) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_scale\":pixbuf_src is not a GdkPixbuf object",NULL);
    	return;
    }
    pixbuf_dst = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,100,100);
    if(pixbuf_dst == NULL){
    	TEST_FAIL("gdk_pixbuf_scale: pixbuf_dst is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_dst) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_scale\":pixbuf_dst is not a GdkPixbuf object",NULL);
    	return;
    }
    
    gdk_pixbuf_scale(pixbuf_src,pixbuf_dst,DEST_X,DEST_Y,DEST_W,DEST_Y,OFF_X,OFF_Y,SCALE_X,SCALE_Y,TYPE);
    
    if(pixbuf_src)
    	g_object_unref(pixbuf_src);
    if(pixbuf_dst)
    	g_object_unref(pixbuf_dst);
    #undef DEST_X
    #undef DEST_Y
    #undef DEST_W
    #undef DEST_H
    #undef OFF_X
    #undef OFF_Y
    #undef SCALE_X
    #undef SCALE_Y
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_scale
 * Params: const GdkPixbuf *src,GdkPixbuf *dest,int dest_x,int dest_y,int dest_width,int dest_height,double offset_x,double offset_y,double scale_x,double scale_y,GdkInterpType interp_type
 * Return: void
 * Assertion: Creates a transformation of the source image src by scaling by scale_x and scale_y then translating by offset_x and offset_y, then renders the rectangle (dest_x, dest_y, dest_width, dest_height) of the resulting image onto the destination image replacing the previous contents. 
 * Expected:   
 */
static void test_purpose_14()
{
    #define DEST_X		     1
    #define DEST_Y		     1
    #define DEST_W		     10
    #define DEST_H		     10
    #define OFF_X		     98
    #define OFF_Y	98
    #define SCALE_X		     1
    #define SCALE_Y	1
    #define TYPE		     GDK_INTERP_BILINEAR
    GdkPixbuf * pixbuf_src = NULL;
    GdkPixbuf * pixbuf_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf_src = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,100,100);
    if(pixbuf_src == NULL){
    	TEST_FAIL("gdk_pixbuf_scale: pixbuf_src is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_src) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_scale\":pixbuf_src is not a GdkPixbuf object",NULL);
    	return;
    }
    pixbuf_dst = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,100,100);
    if(pixbuf_dst == NULL){
    	TEST_FAIL("gdk_pixbuf_scale: pixbuf_dst is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_dst) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_scale\":pixbuf_dst is not a GdkPixbuf object",NULL);
    	return;
    }
    
    gdk_pixbuf_scale(pixbuf_src,pixbuf_dst,DEST_X,DEST_Y,DEST_W,DEST_Y,OFF_X,OFF_Y,SCALE_X,SCALE_Y,TYPE);
    
    if(pixbuf_src)
    	g_object_unref(pixbuf_src);
    if(pixbuf_dst)
    	g_object_unref(pixbuf_dst);
    #undef DEST_X
    #undef DEST_Y
    #undef DEST_W
    #undef DEST_H
    #undef OFF_X
    #undef OFF_Y
    #undef SCALE_X
    #undef SCALE_Y
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GdkPixbufScaling ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {NULL,0}
};
