/*
 * GdkPixbufUtilities methods tests
 * Testing GdkPixbufUtilities methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gdk_pixbuf_fill
 * Params: GdkPixbuf *pixbuf, guint32 pixel
 * Return: void
 * Assertion: Clears a pixbuf to the given RGBA value, converting the RGBA value into the pixbuf pixel format. The alpha will be ignored if the pixbuf doesn't have an alpha channel.
 * Expected: RGBA pixel to clear to pixel  
 */
static void test_purpose_1()
{
    #define HAS_ALPHA		      TRUE
    #define PIXELS			      0x12345678
    
    guchar * pixels = NULL;
    GdkPixbuf * pixbuf = NULL;
    guint32 w,h;
    guchar r, g, b, a;
    guint32    pixel = PIXELS;
    guchar *p;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB,HAS_ALPHA,8,10,10);
    if(pixbuf == NULL){
    	TEST_FAIL("\"gdk_pixbuf_fill\":pixbuf is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_fill\":pixbuf is not a GdkPixbuf object",NULL);
    	return;
    }
    gdk_pixbuf_fill(pixbuf,PIXELS);
    
    pixels = gdk_pixbuf_get_pixels(pixbuf);
    p = pixels;
    
    r = (guchar)((pixel & 0xff000000) >> 24);
    g = (guchar)((pixel & 0x00ff0000) >> 16);
    b = (guchar)((pixel & 0x0000ff00) >> 8);
    a = (guchar)(pixel & 0x000000ff);
    
    h = gdk_pixbuf_get_height(pixbuf);
    
    while(h--){
    	w = gdk_pixbuf_get_width(pixbuf);
    	p = pixels;
    	switch (HAS_ALPHA) {
                    case FALSE:
                            while (w--) {
    				if(p[0] != r || p[1] != g || p[2] != b){
    					TEST_FAIL("gdk_pixbuf_fill:doesnt match expect!!",NULL);
    					return;
    				}
                                    p += 3;
                            }
                            break;
                    case TRUE:
                            while (w--) {
    				if(p[0] != r || p[1] != g || p[2] != b || p[3] != a){
    					TEST_FAIL("gdk_pixbuf_fill:doesnt match expect!!",NULL);
    					return;
    				}
                                    p += 4;
                            }
                            break;
                    }
    		pixels += gdk_pixbuf_get_rowstride(pixbuf);
    }
    if(pixbuf)
    	g_object_unref(pixbuf);
    #undef HAS_ALPHA
    #undef PIXELS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_fill
 * Params: GdkPixbuf *pixbuf, guint32 pixel
 * Return: void
 * Assertion: Clears a pixbuf to the given RGBA value, converting the RGBA value into the pixbuf pixel format. The alpha will be ignored if the pixbuf doesn't have an alpha channel.
 * Expected: RGBA pixel to clear to pixel  
 */
static void test_purpose_2()
{
    #define HAS_ALPHA		      TRUE
    #define PIXELS			      0x00000000
    
    guchar * pixels = NULL;
    GdkPixbuf * pixbuf = NULL;
    guint32 w,h;
    guchar r, g, b, a;
    guint32    pixel = PIXELS;
    guchar *p;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB,HAS_ALPHA,8,10,10);
    if(pixbuf == NULL){
    	TEST_FAIL("\"gdk_pixbuf_fill\":pixbuf is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_fill\":pixbuf is not a GdkPixbuf object",NULL);
    	return;
    }
    gdk_pixbuf_fill(pixbuf,PIXELS);
    
    pixels = gdk_pixbuf_get_pixels(pixbuf);
    p = pixels;
    
    r = (guchar)((pixel & 0xff000000) >> 24);
    g = (guchar)((pixel & 0x00ff0000) >> 16);
    b = (guchar)((pixel & 0x0000ff00) >> 8);
    a = (guchar)(pixel & 0x000000ff);
    
    h = gdk_pixbuf_get_height(pixbuf);
    
    while(h--){
    	w = gdk_pixbuf_get_width(pixbuf);
    	p = pixels;
    	switch (HAS_ALPHA) {
                    case FALSE:
                            while (w--) {
    				if(p[0] != r || p[1] != g || p[2] != b){
    					TEST_FAIL("gdk_pixbuf_fill:doesnt match expect!!",NULL);
    					return;
    				}
                                    p += 3;
                            }
                            break;
                    case TRUE:
                            while (w--) {
    				if(p[0] != r || p[1] != g || p[2] != b || p[3] != a){
    					TEST_FAIL("gdk_pixbuf_fill:doesnt match expect!!",NULL);
    					return;
    				}
                                    p += 4;
                            }
                            break;
                    }
    		pixels += gdk_pixbuf_get_rowstride(pixbuf);
    }
    if(pixbuf)
    	g_object_unref(pixbuf);
    #undef HAS_ALPHA
    #undef PIXELS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_fill
 * Params: GdkPixbuf *pixbuf, guint32 pixel
 * Return: void
 * Assertion: Clears a pixbuf to the given RGBA value, converting the RGBA value into the pixbuf pixel format. The alpha will be ignored if the pixbuf doesn't have an alpha channel.
 * Expected: RGBA pixel to clear to pixel  
 */
static void test_purpose_3()
{
    #define HAS_ALPHA		      TRUE
    #define PIXELS			      0xffffffff
    
    guchar * pixels = NULL;
    GdkPixbuf * pixbuf = NULL;
    guint32 w,h;
    guchar r, g, b, a;
    guint32    pixel = PIXELS;
    guchar *p;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB,HAS_ALPHA,8,10,10);
    if(pixbuf == NULL){
    	TEST_FAIL("\"gdk_pixbuf_fill\":pixbuf is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_fill\":pixbuf is not a GdkPixbuf object",NULL);
    	return;
    }
    gdk_pixbuf_fill(pixbuf,PIXELS);
    
    pixels = gdk_pixbuf_get_pixels(pixbuf);
    p = pixels;
    
    r = (guchar)((pixel & 0xff000000) >> 24);
    g = (guchar)((pixel & 0x00ff0000) >> 16);
    b = (guchar)((pixel & 0x0000ff00) >> 8);
    a = (guchar)(pixel & 0x000000ff);
    
    h = gdk_pixbuf_get_height(pixbuf);
    
    while(h--){
    	w = gdk_pixbuf_get_width(pixbuf);
    	p = pixels;
    	switch (HAS_ALPHA) {
                    case FALSE:
                            while (w--) {
    				if(p[0] != r || p[1] != g || p[2] != b){
    					TEST_FAIL("gdk_pixbuf_fill:doesnt match expect!!",NULL);
    					return;
    				}
                                    p += 3;
                            }
                            break;
                    case TRUE:
                            while (w--) {
    				if(p[0] != r || p[1] != g || p[2] != b || p[3] != a){
    					TEST_FAIL("gdk_pixbuf_fill:doesnt match expect!!",NULL);
    					return;
    				}
                                    p += 4;
                            }
                            break;
                    }
    		pixels += gdk_pixbuf_get_rowstride(pixbuf);
    }
    if(pixbuf)
    	g_object_unref(pixbuf);
    #undef HAS_ALPHA
    #undef PIXELS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_fill
 * Params: GdkPixbuf *pixbuf, guint32 pixel
 * Return: void
 * Assertion: Clears a pixbuf to the given RGBA value, converting the RGBA value into the pixbuf pixel format. The alpha will be ignored if the pixbuf doesn't have an alpha channel.
 * Expected: RGBA pixel to clear to pixel  
 */
static void test_purpose_4()
{
    #define HAS_ALPHA		      TRUE
    #define PIXELS			      0x09abcdef
    
    guchar * pixels = NULL;
    GdkPixbuf * pixbuf = NULL;
    guint32 w,h;
    guchar r, g, b, a;
    guint32    pixel = PIXELS;
    guchar *p;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB,HAS_ALPHA,8,10,10);
    if(pixbuf == NULL){
    	TEST_FAIL("\"gdk_pixbuf_fill\":pixbuf is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_fill\":pixbuf is not a GdkPixbuf object",NULL);
    	return;
    }
    gdk_pixbuf_fill(pixbuf,PIXELS);
    
    pixels = gdk_pixbuf_get_pixels(pixbuf);
    p = pixels;
    
    r = (guchar)((pixel & 0xff000000) >> 24);
    g = (guchar)((pixel & 0x00ff0000) >> 16);
    b = (guchar)((pixel & 0x0000ff00) >> 8);
    a = (guchar)(pixel & 0x000000ff);
    
    h = gdk_pixbuf_get_height(pixbuf);
    
    while(h--){
    	w = gdk_pixbuf_get_width(pixbuf);
    	p = pixels;
    	switch (HAS_ALPHA) {
                    case FALSE:
                            while (w--) {
    				if(p[0] != r || p[1] != g || p[2] != b){
    					TEST_FAIL("gdk_pixbuf_fill:doesnt match expect!!",NULL);
    					return;
    				}
                                    p += 3;
                            }
                            break;
                    case TRUE:
                            while (w--) {
    				if(p[0] != r || p[1] != g || p[2] != b || p[3] != a){
    					TEST_FAIL("gdk_pixbuf_fill:doesnt match expect!!",NULL);
    					return;
    				}
                                    p += 4;
                            }
                            break;
                    }
    		pixels += gdk_pixbuf_get_rowstride(pixbuf);
    }
    if(pixbuf)
    	g_object_unref(pixbuf);
    #undef HAS_ALPHA
    #undef PIXELS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_fill
 * Params: GdkPixbuf *pixbuf, guint32 pixel
 * Return: void
 * Assertion: Clears a pixbuf to the given RGBA value, converting the RGBA value into the pixbuf pixel format. The alpha will be ignored if the pixbuf doesn't have an alpha channel.
 * Expected: RGBA pixel to clear to pixel  
 */
static void test_purpose_5()
{
    #define HAS_ALPHA		      FALSE
    #define PIXELS			      0x12345678
    
    guchar * pixels = NULL;
    GdkPixbuf * pixbuf = NULL;
    guint32 w,h;
    guchar r, g, b, a;
    guint32    pixel = PIXELS;
    guchar *p;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB,HAS_ALPHA,8,10,10);
    if(pixbuf == NULL){
    	TEST_FAIL("\"gdk_pixbuf_fill\":pixbuf is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_fill\":pixbuf is not a GdkPixbuf object",NULL);
    	return;
    }
    gdk_pixbuf_fill(pixbuf,PIXELS);
    
    pixels = gdk_pixbuf_get_pixels(pixbuf);
    p = pixels;
    
    r = (guchar)((pixel & 0xff000000) >> 24);
    g = (guchar)((pixel & 0x00ff0000) >> 16);
    b = (guchar)((pixel & 0x0000ff00) >> 8);
    a = (guchar)(pixel & 0x000000ff);
    
    h = gdk_pixbuf_get_height(pixbuf);
    
    while(h--){
    	w = gdk_pixbuf_get_width(pixbuf);
    	p = pixels;
    	switch (HAS_ALPHA) {
                    case FALSE:
                            while (w--) {
    				if(p[0] != r || p[1] != g || p[2] != b){
    					TEST_FAIL("gdk_pixbuf_fill:doesnt match expect!!",NULL);
    					return;
    				}
                                    p += 3;
                            }
                            break;
                    case TRUE:
                            while (w--) {
    				if(p[0] != r || p[1] != g || p[2] != b || p[3] != a){
    					TEST_FAIL("gdk_pixbuf_fill:doesnt match expect!!",NULL);
    					return;
    				}
                                    p += 4;
                            }
                            break;
                    }
    		pixels += gdk_pixbuf_get_rowstride(pixbuf);
    }
    if(pixbuf)
    	g_object_unref(pixbuf);
    #undef HAS_ALPHA
    #undef PIXELS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_fill
 * Params: GdkPixbuf *pixbuf, guint32 pixel
 * Return: void
 * Assertion: Clears a pixbuf to the given RGBA value, converting the RGBA value into the pixbuf pixel format. The alpha will be ignored if the pixbuf doesn't have an alpha channel.
 * Expected: RGBA pixel to clear to pixel  
 */
static void test_purpose_6()
{
    #define HAS_ALPHA		      FALSE
    #define PIXELS			      0x00000000
    
    guchar * pixels = NULL;
    GdkPixbuf * pixbuf = NULL;
    guint32 w,h;
    guchar r, g, b, a;
    guint32    pixel = PIXELS;
    guchar *p;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB,HAS_ALPHA,8,10,10);
    if(pixbuf == NULL){
    	TEST_FAIL("\"gdk_pixbuf_fill\":pixbuf is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_fill\":pixbuf is not a GdkPixbuf object",NULL);
    	return;
    }
    gdk_pixbuf_fill(pixbuf,PIXELS);
    
    pixels = gdk_pixbuf_get_pixels(pixbuf);
    p = pixels;
    
    r = (guchar)((pixel & 0xff000000) >> 24);
    g = (guchar)((pixel & 0x00ff0000) >> 16);
    b = (guchar)((pixel & 0x0000ff00) >> 8);
    a = (guchar)(pixel & 0x000000ff);
    
    h = gdk_pixbuf_get_height(pixbuf);
    
    while(h--){
    	w = gdk_pixbuf_get_width(pixbuf);
    	p = pixels;
    	switch (HAS_ALPHA) {
                    case FALSE:
                            while (w--) {
    				if(p[0] != r || p[1] != g || p[2] != b){
    					TEST_FAIL("gdk_pixbuf_fill:doesnt match expect!!",NULL);
    					return;
    				}
                                    p += 3;
                            }
                            break;
                    case TRUE:
                            while (w--) {
    				if(p[0] != r || p[1] != g || p[2] != b || p[3] != a){
    					TEST_FAIL("gdk_pixbuf_fill:doesnt match expect!!",NULL);
    					return;
    				}
                                    p += 4;
                            }
                            break;
                    }
    		pixels += gdk_pixbuf_get_rowstride(pixbuf);
    }
    if(pixbuf)
    	g_object_unref(pixbuf);
    #undef HAS_ALPHA
    #undef PIXELS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_fill
 * Params: GdkPixbuf *pixbuf, guint32 pixel
 * Return: void
 * Assertion: Clears a pixbuf to the given RGBA value, converting the RGBA value into the pixbuf pixel format. The alpha will be ignored if the pixbuf doesn't have an alpha channel.
 * Expected: RGBA pixel to clear to pixel  
 */
static void test_purpose_7()
{
    #define HAS_ALPHA		      FALSE
    #define PIXELS			      0xffffffff
    
    guchar * pixels = NULL;
    GdkPixbuf * pixbuf = NULL;
    guint32 w,h;
    guchar r, g, b, a;
    guint32    pixel = PIXELS;
    guchar *p;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB,HAS_ALPHA,8,10,10);
    if(pixbuf == NULL){
    	TEST_FAIL("\"gdk_pixbuf_fill\":pixbuf is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_fill\":pixbuf is not a GdkPixbuf object",NULL);
    	return;
    }
    gdk_pixbuf_fill(pixbuf,PIXELS);
    
    pixels = gdk_pixbuf_get_pixels(pixbuf);
    p = pixels;
    
    r = (guchar)((pixel & 0xff000000) >> 24);
    g = (guchar)((pixel & 0x00ff0000) >> 16);
    b = (guchar)((pixel & 0x0000ff00) >> 8);
    a = (guchar)(pixel & 0x000000ff);
    
    h = gdk_pixbuf_get_height(pixbuf);
    
    while(h--){
    	w = gdk_pixbuf_get_width(pixbuf);
    	p = pixels;
    	switch (HAS_ALPHA) {
                    case FALSE:
                            while (w--) {
    				if(p[0] != r || p[1] != g || p[2] != b){
    					TEST_FAIL("gdk_pixbuf_fill:doesnt match expect!!",NULL);
    					return;
    				}
                                    p += 3;
                            }
                            break;
                    case TRUE:
                            while (w--) {
    				if(p[0] != r || p[1] != g || p[2] != b || p[3] != a){
    					TEST_FAIL("gdk_pixbuf_fill:doesnt match expect!!",NULL);
    					return;
    				}
                                    p += 4;
                            }
                            break;
                    }
    		pixels += gdk_pixbuf_get_rowstride(pixbuf);
    }
    if(pixbuf)
    	g_object_unref(pixbuf);
    #undef HAS_ALPHA
    #undef PIXELS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_fill
 * Params: GdkPixbuf *pixbuf, guint32 pixel
 * Return: void
 * Assertion: Clears a pixbuf to the given RGBA value, converting the RGBA value into the pixbuf pixel format. The alpha will be ignored if the pixbuf doesn't have an alpha channel.
 * Expected: RGBA pixel to clear to pixel  
 */
static void test_purpose_8()
{
    #define HAS_ALPHA		      FALSE
    #define PIXELS			      0x09abcdef
    
    guchar * pixels = NULL;
    GdkPixbuf * pixbuf = NULL;
    guint32 w,h;
    guchar r, g, b, a;
    guint32    pixel = PIXELS;
    guchar *p;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf = gdk_pixbuf_new(GDK_COLORSPACE_RGB,HAS_ALPHA,8,10,10);
    if(pixbuf == NULL){
    	TEST_FAIL("\"gdk_pixbuf_fill\":pixbuf is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_fill\":pixbuf is not a GdkPixbuf object",NULL);
    	return;
    }
    gdk_pixbuf_fill(pixbuf,PIXELS);
    
    pixels = gdk_pixbuf_get_pixels(pixbuf);
    p = pixels;
    
    r = (guchar)((pixel & 0xff000000) >> 24);
    g = (guchar)((pixel & 0x00ff0000) >> 16);
    b = (guchar)((pixel & 0x0000ff00) >> 8);
    a = (guchar)(pixel & 0x000000ff);
    
    h = gdk_pixbuf_get_height(pixbuf);
    
    while(h--){
    	w = gdk_pixbuf_get_width(pixbuf);
    	p = pixels;
    	switch (HAS_ALPHA) {
                    case FALSE:
                            while (w--) {
    				if(p[0] != r || p[1] != g || p[2] != b){
    					TEST_FAIL("gdk_pixbuf_fill:doesnt match expect!!",NULL);
    					return;
    				}
                                    p += 3;
                            }
                            break;
                    case TRUE:
                            while (w--) {
    				if(p[0] != r || p[1] != g || p[2] != b || p[3] != a){
    					TEST_FAIL("gdk_pixbuf_fill:doesnt match expect!!",NULL);
    					return;
    				}
                                    p += 4;
                            }
                            break;
                    }
    		pixels += gdk_pixbuf_get_rowstride(pixbuf);
    }
    if(pixbuf)
    	g_object_unref(pixbuf);
    #undef HAS_ALPHA
    #undef PIXELS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_add_alpha
 * Params: const GdkPixbuf *pixbuf,gboolean substitute_color,guchar r, guchar g, guchar b
 * Return: GdkPixbuf*
 * Assertion:  Takes an existing pixbuf and adds an alpha channel to it. If the existing pixbuf already had an alpha channel, the channel values are copied from the original; otherwise, the alpha channel is initialized to 255 (full opacity). If substitute_color is TRUE, then the color specified by (r, g, b) will be assigned zero opacity. That is, if you pass (255, 255, 255) for the substitute color, all white pixels will become fully transparent.
 * Expected: A newly-created pixbuf  
 */
static void test_purpose_9()
{
    #define HAS_ALPHA		     TRUE
    #define RENEWCOLOR	TRUE
    
    GdkPixbuf * pixbuf_original = NULL;
    GdkPixbuf * pixbuf_new = NULL;
    guint32 w,h;
    guchar r, g, b, a;
    guchar * pixels = NULL;
    int i = 0;
    int x;
    int y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf_original = gdk_pixbuf_new(GDK_COLORSPACE_RGB,HAS_ALPHA,8,10,10);
    if(pixbuf_original == NULL){
    	TEST_FAIL("gdk_pixbuf_add_alpha: pixbuf_original is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_original) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_add_alpha\":pixbuf_original is not a GdkPixbuf object",NULL);
    	return;
    }
    pixbuf_new = gdk_pixbuf_add_alpha(pixbuf_original,RENEWCOLOR,'1','1','1');
    if(pixbuf_new == NULL){
    	TEST_FAIL("gdk_pixbuf_add_alpha: pixbuf_new is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_new) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_add_alpha\":pixbuf_new is not a GdkPixbuf object",NULL);
    	return;
    }
    
    for (y = 0; y < gdk_pixbuf_get_height(pixbuf_new); y++) {
    	guchar *src, *dest;
    	guchar tr, tg, tb;
    
    	src = gdk_pixbuf_get_pixels(pixbuf_original) + y * gdk_pixbuf_get_rowstride(pixbuf_original);
    	dest = gdk_pixbuf_get_pixels(pixbuf_new) + y * gdk_pixbuf_get_rowstride(pixbuf_new);
                    
            if (gdk_pixbuf_get_has_alpha(pixbuf_original)) {
    		for (x = 0; x < gdk_pixbuf_get_width(pixbuf_original); x++) {
            	        if (src[0] == '1' && src[1] == '1' && src[2] == '1'){
                                            if(dest[3] != 0){
    						TEST_FAIL("gdk_pixbuf_add_alpha: copy fail",NULL);
    						return;
    					};
    				}
                                    src += 4;
                                    dest += 4;
                            }
                    } else {                        
                            for (x = 0; x < gdk_pixbuf_get_width(pixbuf_original); x++) {
                                    tr = *dest++ = *src++;
                                    tg = *dest++ = *src++;
                                    tb = *dest++ = *src++;
    
    				if (RENEWCOLOR && tr == '1' && tg == '1' && tb == '1'){
                                            if(*dest++ != 0){
    						TEST_FAIL("gdk_pixbuf_add_alpha: fill 0x00 fail",NULL);
    						return;
    					};
    				}
                                    else{
                                            if(*dest++ != 255){
    						TEST_FAIL("gdk_pixbuf_add_alpha: fill 0xFF fail",NULL);
    						return;
    					};
    				}
                                    
                     }
    	}
    }
    
    
    if(pixbuf_original)
    	g_object_unref(pixbuf_original);
    if(pixbuf_new)
    	g_object_unref(pixbuf_new);
    #undef HAS_ALPHA
    #undef RENEWCOLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_add_alpha
 * Params: const GdkPixbuf *pixbuf,gboolean substitute_color,guchar r, guchar g, guchar b
 * Return: GdkPixbuf*
 * Assertion:  Takes an existing pixbuf and adds an alpha channel to it. If the existing pixbuf already had an alpha channel, the channel values are copied from the original; otherwise, the alpha channel is initialized to 255 (full opacity). If substitute_color is TRUE, then the color specified by (r, g, b) will be assigned zero opacity. That is, if you pass (255, 255, 255) for the substitute color, all white pixels will become fully transparent.
 * Expected: A newly-created pixbuf  
 */
static void test_purpose_10()
{
    #define HAS_ALPHA		     TRUE
    #define RENEWCOLOR	FALSE
    
    GdkPixbuf * pixbuf_original = NULL;
    GdkPixbuf * pixbuf_new = NULL;
    guint32 w,h;
    guchar r, g, b, a;
    guchar * pixels = NULL;
    int i = 0;
    int x;
    int y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf_original = gdk_pixbuf_new(GDK_COLORSPACE_RGB,HAS_ALPHA,8,10,10);
    if(pixbuf_original == NULL){
    	TEST_FAIL("gdk_pixbuf_add_alpha: pixbuf_original is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_original) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_add_alpha\":pixbuf_original is not a GdkPixbuf object",NULL);
    	return;
    }
    pixbuf_new = gdk_pixbuf_add_alpha(pixbuf_original,RENEWCOLOR,'1','1','1');
    if(pixbuf_new == NULL){
    	TEST_FAIL("gdk_pixbuf_add_alpha: pixbuf_new is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_new) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_add_alpha\":pixbuf_new is not a GdkPixbuf object",NULL);
    	return;
    }
    
    for (y = 0; y < gdk_pixbuf_get_height(pixbuf_new); y++) {
    	guchar *src, *dest;
    	guchar tr, tg, tb;
    
    	src = gdk_pixbuf_get_pixels(pixbuf_original) + y * gdk_pixbuf_get_rowstride(pixbuf_original);
    	dest = gdk_pixbuf_get_pixels(pixbuf_new) + y * gdk_pixbuf_get_rowstride(pixbuf_new);
                    
            if (gdk_pixbuf_get_has_alpha(pixbuf_original)) {
    		for (x = 0; x < gdk_pixbuf_get_width(pixbuf_original); x++) {
            	        if (src[0] == '1' && src[1] == '1' && src[2] == '1'){
                                            if(dest[3] != 0){
    						TEST_FAIL("gdk_pixbuf_add_alpha: copy fail",NULL);
    						return;
    					};
    				}
                                    src += 4;
                                    dest += 4;
                            }
                    } else {                        
                            for (x = 0; x < gdk_pixbuf_get_width(pixbuf_original); x++) {
                                    tr = *dest++ = *src++;
                                    tg = *dest++ = *src++;
                                    tb = *dest++ = *src++;
    
    				if (RENEWCOLOR && tr == '1' && tg == '1' && tb == '1'){
                                            if(*dest++ != 0){
    						TEST_FAIL("gdk_pixbuf_add_alpha: fill 0x00 fail",NULL);
    						return;
    					};
    				}
                                    else{
                                            if(*dest++ != 255){
    						TEST_FAIL("gdk_pixbuf_add_alpha: fill 0xFF fail",NULL);
    						return;
    					};
    				}
                                    
                     }
    	}
    }
    
    
    if(pixbuf_original)
    	g_object_unref(pixbuf_original);
    if(pixbuf_new)
    	g_object_unref(pixbuf_new);
    #undef HAS_ALPHA
    #undef RENEWCOLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_add_alpha
 * Params: const GdkPixbuf *pixbuf,gboolean substitute_color,guchar r, guchar g, guchar b
 * Return: GdkPixbuf*
 * Assertion:  Takes an existing pixbuf and adds an alpha channel to it. If the existing pixbuf already had an alpha channel, the channel values are copied from the original; otherwise, the alpha channel is initialized to 255 (full opacity). If substitute_color is TRUE, then the color specified by (r, g, b) will be assigned zero opacity. That is, if you pass (255, 255, 255) for the substitute color, all white pixels will become fully transparent.
 * Expected: A newly-created pixbuf  
 */
static void test_purpose_11()
{
    #define HAS_ALPHA		     FALSE
    #define RENEWCOLOR	TRUE
    
    GdkPixbuf * pixbuf_original = NULL;
    GdkPixbuf * pixbuf_new = NULL;
    guint32 w,h;
    guchar r, g, b, a;
    guchar * pixels = NULL;
    int i = 0;
    int x;
    int y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf_original = gdk_pixbuf_new(GDK_COLORSPACE_RGB,HAS_ALPHA,8,10,10);
    if(pixbuf_original == NULL){
    	TEST_FAIL("gdk_pixbuf_add_alpha: pixbuf_original is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_original) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_add_alpha\":pixbuf_original is not a GdkPixbuf object",NULL);
    	return;
    }
    pixbuf_new = gdk_pixbuf_add_alpha(pixbuf_original,RENEWCOLOR,'1','1','1');
    if(pixbuf_new == NULL){
    	TEST_FAIL("gdk_pixbuf_add_alpha: pixbuf_new is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_new) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_add_alpha\":pixbuf_new is not a GdkPixbuf object",NULL);
    	return;
    }
    
    for (y = 0; y < gdk_pixbuf_get_height(pixbuf_new); y++) {
    	guchar *src, *dest;
    	guchar tr, tg, tb;
    
    	src = gdk_pixbuf_get_pixels(pixbuf_original) + y * gdk_pixbuf_get_rowstride(pixbuf_original);
    	dest = gdk_pixbuf_get_pixels(pixbuf_new) + y * gdk_pixbuf_get_rowstride(pixbuf_new);
                    
            if (gdk_pixbuf_get_has_alpha(pixbuf_original)) {
    		for (x = 0; x < gdk_pixbuf_get_width(pixbuf_original); x++) {
            	        if (src[0] == '1' && src[1] == '1' && src[2] == '1'){
                                            if(dest[3] != 0){
    						TEST_FAIL("gdk_pixbuf_add_alpha: copy fail",NULL);
    						return;
    					};
    				}
                                    src += 4;
                                    dest += 4;
                            }
                    } else {                        
                            for (x = 0; x < gdk_pixbuf_get_width(pixbuf_original); x++) {
                                    tr = *dest++ = *src++;
                                    tg = *dest++ = *src++;
                                    tb = *dest++ = *src++;
    
    				if (RENEWCOLOR && tr == '1' && tg == '1' && tb == '1'){
                                            if(*dest++ != 0){
    						TEST_FAIL("gdk_pixbuf_add_alpha: fill 0x00 fail",NULL);
    						return;
    					};
    				}
                                    else{
                                            if(*dest++ != 255){
    						TEST_FAIL("gdk_pixbuf_add_alpha: fill 0xFF fail",NULL);
    						return;
    					};
    				}
                                    
                     }
    	}
    }
    
    
    if(pixbuf_original)
    	g_object_unref(pixbuf_original);
    if(pixbuf_new)
    	g_object_unref(pixbuf_new);
    #undef HAS_ALPHA
    #undef RENEWCOLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_add_alpha
 * Params: const GdkPixbuf *pixbuf,gboolean substitute_color,guchar r, guchar g, guchar b
 * Return: GdkPixbuf*
 * Assertion:  Takes an existing pixbuf and adds an alpha channel to it. If the existing pixbuf already had an alpha channel, the channel values are copied from the original; otherwise, the alpha channel is initialized to 255 (full opacity). If substitute_color is TRUE, then the color specified by (r, g, b) will be assigned zero opacity. That is, if you pass (255, 255, 255) for the substitute color, all white pixels will become fully transparent.
 * Expected: A newly-created pixbuf  
 */
static void test_purpose_12()
{
    #define HAS_ALPHA		     FALSE
    #define RENEWCOLOR	FALSE
    
    GdkPixbuf * pixbuf_original = NULL;
    GdkPixbuf * pixbuf_new = NULL;
    guint32 w,h;
    guchar r, g, b, a;
    guchar * pixels = NULL;
    int i = 0;
    int x;
    int y;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf_original = gdk_pixbuf_new(GDK_COLORSPACE_RGB,HAS_ALPHA,8,10,10);
    if(pixbuf_original == NULL){
    	TEST_FAIL("gdk_pixbuf_add_alpha: pixbuf_original is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_original) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_add_alpha\":pixbuf_original is not a GdkPixbuf object",NULL);
    	return;
    }
    pixbuf_new = gdk_pixbuf_add_alpha(pixbuf_original,RENEWCOLOR,'1','1','1');
    if(pixbuf_new == NULL){
    	TEST_FAIL("gdk_pixbuf_add_alpha: pixbuf_new is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_new) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_add_alpha\":pixbuf_new is not a GdkPixbuf object",NULL);
    	return;
    }
    
    for (y = 0; y < gdk_pixbuf_get_height(pixbuf_new); y++) {
    	guchar *src, *dest;
    	guchar tr, tg, tb;
    
    	src = gdk_pixbuf_get_pixels(pixbuf_original) + y * gdk_pixbuf_get_rowstride(pixbuf_original);
    	dest = gdk_pixbuf_get_pixels(pixbuf_new) + y * gdk_pixbuf_get_rowstride(pixbuf_new);
                    
            if (gdk_pixbuf_get_has_alpha(pixbuf_original)) {
    		for (x = 0; x < gdk_pixbuf_get_width(pixbuf_original); x++) {
            	        if (src[0] == '1' && src[1] == '1' && src[2] == '1'){
                                            if(dest[3] != 0){
    						TEST_FAIL("gdk_pixbuf_add_alpha: copy fail",NULL);
    						return;
    					};
    				}
                                    src += 4;
                                    dest += 4;
                            }
                    } else {                        
                            for (x = 0; x < gdk_pixbuf_get_width(pixbuf_original); x++) {
                                    tr = *dest++ = *src++;
                                    tg = *dest++ = *src++;
                                    tb = *dest++ = *src++;
    
    				if (RENEWCOLOR && tr == '1' && tg == '1' && tb == '1'){
                                            if(*dest++ != 0){
    						TEST_FAIL("gdk_pixbuf_add_alpha: fill 0x00 fail",NULL);
    						return;
    					};
    				}
                                    else{
                                            if(*dest++ != 255){
    						TEST_FAIL("gdk_pixbuf_add_alpha: fill 0xFF fail",NULL);
    						return;
    					};
    				}
                                    
                     }
    	}
    }
    
    
    if(pixbuf_original)
    	g_object_unref(pixbuf_original);
    if(pixbuf_new)
    	g_object_unref(pixbuf_new);
    #undef HAS_ALPHA
    #undef RENEWCOLOR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_pixbuf_copy_area
 * Params: const GdkPixbuf *src_pixbuf,int src_x,int src_y,int width,int height,GdkPixbuf *dest_pixbuf,int dest_x,int dest_y
 * Return: void
 * Assertion: Copies a rectangular area from src_pixbuf to dest_pixbuf. Conversion of pixbuf formats is done automatically.
 * Expected:   
 */
static void test_purpose_13()
{
    GdkPixbuf * pixbuf_original = NULL;
    GdkPixbuf * pixbuf_destination = NULL;
    guchar * pixels_ori = NULL;
    guchar * pixels_dst = NULL;
    int i = 0;
    int j = 0;
    int rowstride = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pixbuf_original = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,10,10);
    if(pixbuf_original == NULL){
    	TEST_FAIL("gdk_pixbuf_copy_area: pixbuf_original is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_original) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_copy_area\":pixbuf_src is not a GdkPixbuf object",NULL);
    	return;
    }
    pixbuf_destination = gdk_pixbuf_new(GDK_COLORSPACE_RGB,TRUE,8,10,10);
    if(pixbuf_destination == NULL){
    	TEST_FAIL("gdk_pixbuf_copy_area: pixbuf_destination is NULL",NULL);
    	return;
    }
    if(GDK_IS_PIXBUF(pixbuf_destination) != TRUE){
    	TEST_FAIL("\"gdk_pixbuf_copy_area\":pixbuf_src is not a GdkPixbuf object",NULL);
    	return;
    }
    
    gdk_pixbuf_fill(pixbuf_original,0x12345678);
    gdk_pixbuf_fill(pixbuf_destination,0x09abcdef);
    
    gdk_pixbuf_copy_area(pixbuf_original,0,0,10,10,pixbuf_destination,0,0);
    pixels_ori = gdk_pixbuf_get_pixels(pixbuf_original);
    pixels_dst = gdk_pixbuf_get_pixels(pixbuf_destination);
    
    if(strncmp(pixels_ori,pixels_dst,400)){
    	TEST_FAIL("gdk_pixbuf_copy_area: copy area fail",NULL);
    	return;
    }
    
    if(pixbuf_original)
    	g_object_unref(pixbuf_original);
    if(pixbuf_destination)
    	g_object_unref(pixbuf_destination);
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GdkPixbufUtilities ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {NULL,0}
};
