/*
 * GdkRectangle methods tests
 * Testing GdkRectangle methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gdk_rectangle_intersect
 * Params: GdkRectangle *src1,GdkRectangle *src2,GdkRectangle *dest
 * Return: gboolean
 * Assertion: Calculates the intersection of two rectangles.
 * Expected: TRUE if the rectangles intersect.  
 */
static void test_purpose_1()
{
    #define SRC1_X		1
    #define SRC1_Y		1
    #define SRC1_W		30
    #define SRC1_H		30
    #define SRC2_X		2
    #define SRC2_Y		2
    #define SRC2_W		40
    #define SRC2_H		40
    #define EXPECTED	TRUE
    GdkRectangle src1;
    GdkRectangle src2;
    GdkRectangle dst;
    gint dest_x, dest_y;
    gint dest_w, dest_h;
    gboolean ret ;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    src1.x = SRC1_X;
    src1.y = SRC1_Y;
    src1.width = SRC1_W;
    src1.height = SRC1_H;
    src2.x = SRC2_X;
    src2.y = SRC2_Y;
    src2.width = SRC2_W;
    src2.height = SRC2_H;
    
    ret = gdk_rectangle_intersect(&src1,&src2,&dst);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_rectangle_intersect: doesnt match expected!",NULL);
    	return;
    }
    if(EXPECTED == TRUE){
    	dest_x = MAX (src1.x, src2.x);
    	dest_y = MAX (src1.y, src2.y);
    	dest_w = MIN (src1.x + src1.width, src2.x + src2.width) - dest_x;
    	dest_h = MIN (src1.y + src1.height, src2.y + src2.height) - dest_y;
    	if(dst.x != dest_x || dst.y != dest_y || dst.width != dest_w || dst.height != dest_h){
    		TEST_FAIL("gdk_rectangle_intersect: destination rectangle is not the expected one",NULL);
    		return;
    	}
    }else{
    	if(dst.width != 0 || dst.height != 0){
    		TEST_FAIL("gdk_rectangle_intersect: destination rectangle is not the expected one!",NULL);
    		return;
    	}
    }
    #undef SRC1_X
    #undef SRC1_Y
    #undef SRC1_W
    #undef SRC1_H
    #undef SRC2_X
    #undef SRC2_Y
    #undef SRC2_W
    #undef SRC2_H
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_rectangle_intersect
 * Params: GdkRectangle *src1,GdkRectangle *src2,GdkRectangle *dest
 * Return: gboolean
 * Assertion: Calculates the intersection of two rectangles.
 * Expected: TRUE if the rectangles intersect.  
 */
static void test_purpose_2()
{
    #define SRC1_X		1
    #define SRC1_Y		1
    #define SRC1_W		30
    #define SRC1_H		30
    #define SRC2_X		1
    #define SRC2_Y		1
    #define SRC2_W		30
    #define SRC2_H		30
    #define EXPECTED	TRUE
    GdkRectangle src1;
    GdkRectangle src2;
    GdkRectangle dst;
    gint dest_x, dest_y;
    gint dest_w, dest_h;
    gboolean ret ;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    src1.x = SRC1_X;
    src1.y = SRC1_Y;
    src1.width = SRC1_W;
    src1.height = SRC1_H;
    src2.x = SRC2_X;
    src2.y = SRC2_Y;
    src2.width = SRC2_W;
    src2.height = SRC2_H;
    
    ret = gdk_rectangle_intersect(&src1,&src2,&dst);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_rectangle_intersect: doesnt match expected!",NULL);
    	return;
    }
    if(EXPECTED == TRUE){
    	dest_x = MAX (src1.x, src2.x);
    	dest_y = MAX (src1.y, src2.y);
    	dest_w = MIN (src1.x + src1.width, src2.x + src2.width) - dest_x;
    	dest_h = MIN (src1.y + src1.height, src2.y + src2.height) - dest_y;
    	if(dst.x != dest_x || dst.y != dest_y || dst.width != dest_w || dst.height != dest_h){
    		TEST_FAIL("gdk_rectangle_intersect: destination rectangle is not the expected one",NULL);
    		return;
    	}
    }else{
    	if(dst.width != 0 || dst.height != 0){
    		TEST_FAIL("gdk_rectangle_intersect: destination rectangle is not the expected one!",NULL);
    		return;
    	}
    }
    #undef SRC1_X
    #undef SRC1_Y
    #undef SRC1_W
    #undef SRC1_H
    #undef SRC2_X
    #undef SRC2_Y
    #undef SRC2_W
    #undef SRC2_H
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_rectangle_intersect
 * Params: GdkRectangle *src1,GdkRectangle *src2,GdkRectangle *dest
 * Return: gboolean
 * Assertion: Calculates the intersection of two rectangles.
 * Expected: TRUE if the rectangles intersect.  
 */
static void test_purpose_3()
{
    #define SRC1_X		1
    #define SRC1_Y		1
    #define SRC1_W		30
    #define SRC1_H		30
    #define SRC2_X		40
    #define SRC2_Y		40
    #define SRC2_W		50
    #define SRC2_H		50
    #define EXPECTED	FALSE
    GdkRectangle src1;
    GdkRectangle src2;
    GdkRectangle dst;
    gint dest_x, dest_y;
    gint dest_w, dest_h;
    gboolean ret ;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    src1.x = SRC1_X;
    src1.y = SRC1_Y;
    src1.width = SRC1_W;
    src1.height = SRC1_H;
    src2.x = SRC2_X;
    src2.y = SRC2_Y;
    src2.width = SRC2_W;
    src2.height = SRC2_H;
    
    ret = gdk_rectangle_intersect(&src1,&src2,&dst);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_rectangle_intersect: doesnt match expected!",NULL);
    	return;
    }
    if(EXPECTED == TRUE){
    	dest_x = MAX (src1.x, src2.x);
    	dest_y = MAX (src1.y, src2.y);
    	dest_w = MIN (src1.x + src1.width, src2.x + src2.width) - dest_x;
    	dest_h = MIN (src1.y + src1.height, src2.y + src2.height) - dest_y;
    	if(dst.x != dest_x || dst.y != dest_y || dst.width != dest_w || dst.height != dest_h){
    		TEST_FAIL("gdk_rectangle_intersect: destination rectangle is not the expected one",NULL);
    		return;
    	}
    }else{
    	if(dst.width != 0 || dst.height != 0){
    		TEST_FAIL("gdk_rectangle_intersect: destination rectangle is not the expected one!",NULL);
    		return;
    	}
    }
    #undef SRC1_X
    #undef SRC1_Y
    #undef SRC1_W
    #undef SRC1_H
    #undef SRC2_X
    #undef SRC2_Y
    #undef SRC2_W
    #undef SRC2_H
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_get_rectangles
 * Params: GdkRegion * , GdkRectangle * , gint *
 * return: void
 * Assertion: Obtains the area covered by the region as a list of rectangles. The array returned in rectangles must be freed with g_free().
 * expected: return location for an array of rectangles   
 */
static void test_purpose_4()
{
    GdkRectangle src;
    GdkRegion * region;
    GdkRegion * reg;
    GdkRegion * r;
    GdkRectangle * rectangles;
    GdkPoint pts[11];
    gint n_rectangles;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pts[0].x = 1;
    pts[0].y = 1;
    pts[1].x = 100;
    pts[1].y = 1;
    pts[2].x = 100;
    pts[2].y = 10;
    pts[3].x = 50;
    pts[3].y = 10;
    pts[4].x = 50;
    pts[4].y = 20;
    pts[5].x = 20;
    pts[5].y = 20;
    pts[6].x = 20;
    pts[6].y = 10;
    pts[7].x = 10;
    pts[7].y = 10;
    pts[8].x = 10;
    pts[8].y = 20;
    pts[9].x = 1;
    pts[9].y = 20;
    pts[10].x = 1;
    pts[10].y = 1;
    src.x = 1;
    src.y = 1;
    src.width = 10;
    src.height = 10;
    r = gdk_region_rectangle(&src);
    reg = gdk_region_new();
    region = gdk_region_polygon(pts,11,GDK_EVEN_ODD_RULE);
    if((!reg) || (!r) || !(region)){
    	TEST_FAIL("gdk_region_get_rectangles: region is NULL",NULL);
    	return;
    }
    gdk_region_get_rectangles(reg,&rectangles,&n_rectangles);
    if(n_rectangles != 0){
    	TEST_FAIL("gdk_region_get_rectangles: number of the rectangles is wrong",NULL);
    	return;
    }
    if(rectangles)
    	g_free(rectangles);
    gdk_region_get_rectangles(r,&rectangles,&n_rectangles);
    if(n_rectangles != 1){
    	TEST_FAIL("gdk_region_get_rectangles: number of the rectangles is wrong",NULL);
    	return;
    }
    if(rectangles)
    	g_free(rectangles);
    gdk_region_get_rectangles(region,&rectangles,&n_rectangles);
    if(n_rectangles != 21){
    	TEST_FAIL("gdk_region_get_rectangles: number of the rectangles is wrong",NULL);
    	return;
    }
    
    if(rectangles)
    	g_free(rectangles);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_destroy
 * Params: GdkRegion *
 * Return: void
 * Assertion: Destroys a GdkRegion
 * Expected:   
 */
static void test_purpose_5()
{
    GdkRegion * region = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    region = gdk_region_new();
    if(!region){
    	TEST_FAIL("gdk_region_new: region is NULL",NULL);
    	return;
    }
    gdk_region_destroy(region);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_rectangle
 * Params: GdkRectangle
 * Return: GdkRegion
 * Assertion: Creates a new region containing the area rectangle.
 * Expected: a new GdkRegion  
 */
static void test_purpose_6()
{
    #define RECT_X 	     1
    #define RECT_Y 	     1
    #define RECT_W 	     10
    #define RECT_H 	     10
    GdkRectangle rect;
    GdkRegion * region;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    rect.x = RECT_X;
    rect.y = RECT_X;
    rect.width = RECT_W;
    rect.height = RECT_H;
    region = gdk_region_rectangle(&rect);
    if(!region){
    	TEST_FAIL("gdk_region_rectangle: region is NULL",NULL);
    	return;
    }
    #undef RECT_X
    #undef RECT_Y
    #undef RECT_W
    #undef RECT_H
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_rectangle
 * Params: GdkRectangle
 * Return: GdkRegion
 * Assertion: Creates a new region containing the area rectangle.
 * Expected: a new GdkRegion  
 */
static void test_purpose_7()
{
    #define RECT_X 	     1
    #define RECT_Y 	     1
    #define RECT_W 	     0
    #define RECT_H 	     0
    GdkRectangle rect;
    GdkRegion * region;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    rect.x = RECT_X;
    rect.y = RECT_X;
    rect.width = RECT_W;
    rect.height = RECT_H;
    region = gdk_region_rectangle(&rect);
    if(!region){
    	TEST_FAIL("gdk_region_rectangle: region is NULL",NULL);
    	return;
    }
    #undef RECT_X
    #undef RECT_Y
    #undef RECT_W
    #undef RECT_H
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_get_clipbox
 * Params: GdkRegion *, GdkRectangle *
 * Return: void
 * Assertion: Returns the smallest rectangle which includes the entire GdkRegion.
 * Expected: set the parameters of smallest rectangle which includes all of region to param 'rectanle'.  
 */
static void test_purpose_8()
{
    GdkRegion * region;
    GdkRegion * reg;
    GdkRegion * r;
    GdkRectangle src;
    GdkRectangle rect;
    GdkPoint pts[11];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pts[0].x = 1;
    pts[0].y = 1;
    pts[1].x = 100;
    pts[1].y = 1;
    pts[2].x = 100;
    pts[2].y = 10;
    pts[3].x = 50;
    pts[3].y = 10;
    pts[4].x = 50;
    pts[4].y = 20;
    pts[5].x = 20;
    pts[5].y = 20;
    pts[6].x = 20;
    pts[6].y = 10;
    pts[7].x = 10;
    pts[7].y = 10;
    pts[8].x = 10;
    pts[8].y = 20;
    pts[9].x = 1;
    pts[9].y = 20;
    pts[10].x = 1;
    pts[10].y = 1;
    src.x = 1;
    src.y = 1;
    src.width = 10;
    src.height = 10;
    r = gdk_region_rectangle(&src);
    reg = gdk_region_new();
    region = gdk_region_polygon(pts,11,GDK_EVEN_ODD_RULE);
    if((!reg) || (!r) || !(region)){
    	TEST_FAIL("gdk_region_get_clipbox: region is NULL",NULL);
    	return;
    }
    gdk_region_get_clipbox(region,&rect);//region
    if(rect.x != 1 || rect.y != 1 || rect.width != 99 || rect.height != 19){
    	TEST_FAIL("gdk_region_get_clipbox: the clipbox is not the expected one!",NULL);
    	return;
    }
    gdk_region_get_clipbox(r,&rect);//r
    if(rect.x != 1 || rect.y != 1 || rect.width != 10 || rect.height != 10){
    	TEST_FAIL("gdk_region_get_clipbox: the clipbox is not the expected one!",NULL);
    	return;
    }
    gdk_region_get_clipbox(reg,&rect);//reg
    if(rect.x != 0 || rect.y != 0 || rect.width != 0 || rect.height != 0){
    	TEST_FAIL("gdk_region_get_clipbox: the clipbox is not the expected one!",NULL);
    	return;
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_empty
 * Params: GdkRegion
 * Return: gboolean
 * Assertion: Returns TRUE if the GdkRegion is empty.
 * Expected: TRUE if region is empty.  
 */
static void test_purpose_9()
{
    GdkRegion * reg = NULL;
    GdkRegion * r = NULL;
    GdkRectangle src;
    gboolean ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    src.x = 1;
    src.y = 1;
    src.width = 10;
    src.height = 10;
    r = gdk_region_rectangle(&src);
    reg = gdk_region_new();
    if((!reg) || (!r)){
    	TEST_FAIL("gdk_region_get_clipbox: region is NULL",NULL);
    	return;
    }
    ret = gdk_region_empty(r);
    if(ret == TRUE){
    	TEST_FAIL("gdk_region_get_clipbox: not a expected non-empty region",NULL);
    	return;
    }
    ret = gdk_region_empty(reg);
    if(ret == FALSE){
    	TEST_FAIL("gdk_region_get_clipbox: not a expected empty region",NULL);
    	return;
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_subtract
 * Params: GdkRegion * ,GdkRegion *
 * Return: void
 * Assertion: Subtracts the area of source2 from the area source1. The resulting area is the set of pixels contained in source1 but not in source2.
 * Expected:   
 */
static void test_purpose_10()
{
    GdkRectangle src1;
    GdkRectangle src2;
    GdkRectangle src3;
    GdkRegion * region1 = NULL;
    GdkRegion * region2 = NULL;
    GdkRegion * region3 = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    src1.x = 1;
    src1.y = 1;
    src1.width = 100;
    src1.height = 100;
    src2.x = 51;
    src2.y = 1;
    src2.width = 50;
    src2.height = 100;
    src3.x = 1;
    src3.y = 1;
    src3.width = 50;
    src3.height = 100;
    
    region1 = gdk_region_rectangle(&src1);
    region2 = gdk_region_rectangle(&src2);
    region3 = gdk_region_rectangle(&src3);
    if((!region1)||(!region2)||(!region3)){
    	TEST_FAIL("gdk_region_subtract: region is NULL",NULL);
    	return;
    };
    gdk_region_subtract(region1,region2);
    
    if(gdk_region_equal(region1,region3) != TRUE){
    	TEST_FAIL("gdk_region_subtract: not a expected result region",NULL);
    	return;
    }
    
    gdk_region_destroy(region1);
    gdk_region_destroy(region2);
    gdk_region_destroy(region3);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_new
 * Params: void
 * Return: GdkRegion
 * Assertion: Creates a new empty GdkRegion.
 * Expected: a new empty GdkRegion.  
 */
static void test_purpose_11()
{
    GdkRegion * region = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    region = gdk_region_new();
    if(!region){
    	TEST_FAIL("gdk_region_new: region is NULL",NULL);
    	return;
    }
    if(region)
    	gdk_region_destroy(region);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_rect_in
 * Params: GdkRectangle *, GdkRectangle *
 * Return: GdkOverlapType
 * Assertion: Tests whether a rectangle is within a region.
 * Expected: GDK_OVERLAP_RECTANGLE_IN, GDK_OVERLAP_RECTANGLE_OUT, or GDK_OVERLAP_RECTANGLE_PART, depending on whether the rectangle is inside, outside, or partly inside the GdkRegion, respectively.  
 */
static void test_purpose_12()
{
    #define RECT 		&rect_in
    #define EXPECTED	GDK_OVERLAP_RECTANGLE_IN
    GdkRectangle src;
    GdkRectangle rect_in;
    GdkRectangle rect_out;
    GdkRectangle rect_part;
    GdkRegion * region;
    GdkOverlapType ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    src.x = 1;
    src.y = 1;
    src.width = 100;
    src.height = 100;
    rect_in.x = 2;
    rect_in.y = 2;
    rect_in.width = 10;
    rect_in.height = 10;
    rect_out.x = 110;
    rect_out.y = 110;
    rect_out.width = 10;
    rect_out.height = 10;
    rect_part.x = 50;
    rect_part.y = 50;
    rect_part.width = 100;
    rect_part.height = 100;
    
    region = gdk_region_rectangle(&src);
    
    if(!region){
    	TEST_FAIL("gdk_region_rect_in: region is NULL",NULL);
    	return;
    }
    
    ret = gdk_region_rect_in(region,RECT);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_region_rect_in: doesnt match expected value",NULL);
    	return;
    }
    gdk_region_destroy(region);
    #undef RECT
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_rect_in
 * Params: GdkRectangle *, GdkRectangle *
 * Return: GdkOverlapType
 * Assertion: Tests whether a rectangle is within a region.
 * Expected: GDK_OVERLAP_RECTANGLE_IN, GDK_OVERLAP_RECTANGLE_OUT, or GDK_OVERLAP_RECTANGLE_PART, depending on whether the rectangle is inside, outside, or partly inside the GdkRegion, respectively.  
 */
static void test_purpose_13()
{
    #define RECT 		&rect_out
    #define EXPECTED	GDK_OVERLAP_RECTANGLE_OUT
    GdkRectangle src;
    GdkRectangle rect_in;
    GdkRectangle rect_out;
    GdkRectangle rect_part;
    GdkRegion * region;
    GdkOverlapType ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    src.x = 1;
    src.y = 1;
    src.width = 100;
    src.height = 100;
    rect_in.x = 2;
    rect_in.y = 2;
    rect_in.width = 10;
    rect_in.height = 10;
    rect_out.x = 110;
    rect_out.y = 110;
    rect_out.width = 10;
    rect_out.height = 10;
    rect_part.x = 50;
    rect_part.y = 50;
    rect_part.width = 100;
    rect_part.height = 100;
    
    region = gdk_region_rectangle(&src);
    
    if(!region){
    	TEST_FAIL("gdk_region_rect_in: region is NULL",NULL);
    	return;
    }
    
    ret = gdk_region_rect_in(region,RECT);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_region_rect_in: doesnt match expected value",NULL);
    	return;
    }
    gdk_region_destroy(region);
    #undef RECT
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_rect_in
 * Params: GdkRectangle *, GdkRectangle *
 * Return: GdkOverlapType
 * Assertion: Tests whether a rectangle is within a region.
 * Expected: GDK_OVERLAP_RECTANGLE_IN, GDK_OVERLAP_RECTANGLE_OUT, or GDK_OVERLAP_RECTANGLE_PART, depending on whether the rectangle is inside, outside, or partly inside the GdkRegion, respectively.  
 */
static void test_purpose_14()
{
    #define RECT 		&rect_part
    #define EXPECTED	GDK_OVERLAP_RECTANGLE_PART
    GdkRectangle src;
    GdkRectangle rect_in;
    GdkRectangle rect_out;
    GdkRectangle rect_part;
    GdkRegion * region;
    GdkOverlapType ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    src.x = 1;
    src.y = 1;
    src.width = 100;
    src.height = 100;
    rect_in.x = 2;
    rect_in.y = 2;
    rect_in.width = 10;
    rect_in.height = 10;
    rect_out.x = 110;
    rect_out.y = 110;
    rect_out.width = 10;
    rect_out.height = 10;
    rect_part.x = 50;
    rect_part.y = 50;
    rect_part.width = 100;
    rect_part.height = 100;
    
    region = gdk_region_rectangle(&src);
    
    if(!region){
    	TEST_FAIL("gdk_region_rect_in: region is NULL",NULL);
    	return;
    }
    
    ret = gdk_region_rect_in(region,RECT);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_region_rect_in: doesnt match expected value",NULL);
    	return;
    }
    gdk_region_destroy(region);
    #undef RECT
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_point_in
 * Params: GdkRegion *, gint , gint
 * Return: gboolean
 * Assertion: Returns TRUE if a point is in a region
 * Expected: TRUE if the point is in region   
 */
static void test_purpose_15()
{
    #define POINT_X		10
    #define POINT_Y 	10
    #define EXPECTED 	TRUE
    GdkRectangle rect;
    GdkRegion * region;
    gboolean ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    rect.x = 1;
    rect.y = 1;
    rect.width = 100;
    rect.height = 100;
    
    region = gdk_region_rectangle(&rect);
    if(!region){
    	TEST_FAIL("gdk_region_point_in: region is NULL",NULL);
    	return;
    }
    
    ret = gdk_region_point_in(region,POINT_X,POINT_Y);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_region_point_in: doesnt match expected!",NULL);
    	return;
    }
    gdk_region_destroy(region);
    #undef POINT_X
    #undef POINT_Y
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_point_in
 * Params: GdkRegion *, gint , gint
 * Return: gboolean
 * Assertion: Returns TRUE if a point is in a region
 * Expected: TRUE if the point is in region   
 */
static void test_purpose_16()
{
    #define POINT_X		1
    #define POINT_Y 	10
    #define EXPECTED 	TRUE
    GdkRectangle rect;
    GdkRegion * region;
    gboolean ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    rect.x = 1;
    rect.y = 1;
    rect.width = 100;
    rect.height = 100;
    
    region = gdk_region_rectangle(&rect);
    if(!region){
    	TEST_FAIL("gdk_region_point_in: region is NULL",NULL);
    	return;
    }
    
    ret = gdk_region_point_in(region,POINT_X,POINT_Y);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_region_point_in: doesnt match expected!",NULL);
    	return;
    }
    gdk_region_destroy(region);
    #undef POINT_X
    #undef POINT_Y
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_point_in
 * Params: GdkRegion *, gint , gint
 * Return: gboolean
 * Assertion: Returns TRUE if a point is in a region
 * Expected: TRUE if the point is in region   
 */
static void test_purpose_17()
{
    #define POINT_X		120
    #define POINT_Y 	10
    #define EXPECTED 	FALSE
    GdkRectangle rect;
    GdkRegion * region;
    gboolean ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    rect.x = 1;
    rect.y = 1;
    rect.width = 100;
    rect.height = 100;
    
    region = gdk_region_rectangle(&rect);
    if(!region){
    	TEST_FAIL("gdk_region_point_in: region is NULL",NULL);
    	return;
    }
    
    ret = gdk_region_point_in(region,POINT_X,POINT_Y);
    if(ret != EXPECTED){
    	TEST_FAIL("gdk_region_point_in: doesnt match expected!",NULL);
    	return;
    }
    gdk_region_destroy(region);
    #undef POINT_X
    #undef POINT_Y
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_copy
 * Params: GdkRegion*
 * Return: GdkRegion*
 * Assertion: Copies region, creating an identical new region
 * Expected: a new region identical to region   
 */
static void test_purpose_18()
{
    GdkRectangle rect;
    GdkRegion * src = NULL;
    GdkRegion * new = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    rect.x = 1;
    rect.y = 1;
    rect.width = 100;
    rect.height = 100;
    src = gdk_region_rectangle(&rect);
    if(!src){
    	TEST_FAIL("gdk_region_copy: src region is NULL",NULL);
    	return;
    }
    new = gdk_region_copy(src);
    if(!new){
    	TEST_FAIL("gdk_region_copy: new region is NULL",NULL);
    	return;
    }
    if(gdk_region_equal(src,new) != TRUE){
    	TEST_FAIL("gdk_region_copy: copy region failed!",NULL);
    	return;
    }
    gdk_region_destroy(src);
    gdk_region_destroy(new);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_polygon
 * Params: GdkPoint *points,gint npoints,GdkFillRule fill_rule
 * Return: Gdkregion *
 * Assertion: Creates a new GdkRegion using the polygon defined by a number of points.
 * Expected: a new GdkRegion based on the given polygon.  
 */
static void test_purpose_19()
{
    GdkPoint pts[11];
    GdkRegion * region = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    pts[0].x = 1;
    pts[0].y = 1;
    pts[1].x = 100;
    pts[1].y = 1;
    pts[2].x = 100;
    pts[2].y = 10;
    pts[3].x = 50;
    pts[3].y = 10;
    pts[4].x = 50;
    pts[4].y = 20;
    pts[5].x = 20;
    pts[5].y = 20;
    pts[6].x = 20;
    pts[6].y = 10;
    pts[7].x = 10;
    pts[7].y = 10;
    pts[8].x = 10;
    pts[8].y = 20;
    pts[9].x = 1;
    pts[9].y = 20;
    pts[10].x = 1;
    pts[10].y = 1;
    
    region = gdk_region_polygon(pts,11,GDK_EVEN_ODD_RULE);
    if(!region){
    	TEST_FAIL("gdk_region_polygon: region is NULL",NULL);
    	return;
    }
    gdk_region_destroy(region);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gkd_region_equal
 * Params: GdkRegion *, GdkRegion *
 * Return: gboolean
 * Asserion: Returns TRUE if the two regions are the same.
 * Expected: TRUE if region1 and region2 are equal.  
 */
static void test_purpose_20()
{
    #define OBJECT_REGION	region2
    #define EXPECTED	FALSE
    GdkRectangle src1;
    GdkRectangle src2;
    GdkRectangle src3;
    GdkRegion * region1 = NULL;
    GdkRegion * region2 = NULL;
    GdkRegion * region3 = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    src1.x = 1;
    src1.y = 1;
    src1.width = 100;
    src1.height = 100;
    src2.x = 1;
    src2.y = 1;
    src2.width = 10;
    src2.height = 10;
    src3.x = 1;
    src3.y = 1;
    src3.width = 100;
    src3.height = 100;
    
    region1 = gdk_region_rectangle(&src1);
    region2 = gdk_region_rectangle(&src2);
    region3 = gdk_region_rectangle(&src3);
    
    if((!region1)||(!region2)||(!region3)){
    	TEST_FAIL("gdk_region_equal: region is NULL",NULL);
    	return;
    }
    
    if(gdk_region_equal(region1,OBJECT_REGION) != EXPECTED){
    	TEST_FAIL("gdk_region_equal: doesnt match expected",NULL);
    	return;
    }
    gdk_region_destroy(region1);
    gdk_region_destroy(region2);
    gdk_region_destroy(region3);
    #undef OBJECT_REGION
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gkd_region_equal
 * Params: GdkRegion *, GdkRegion *
 * Return: gboolean
 * Asserion: Returns TRUE if the two regions are the same.
 * Expected: TRUE if region1 and region2 are equal.  
 */
static void test_purpose_21()
{
    #define OBJECT_REGION	region3
    #define EXPECTED		    TRUE
    GdkRectangle src1;
    GdkRectangle src2;
    GdkRectangle src3;
    GdkRegion * region1 = NULL;
    GdkRegion * region2 = NULL;
    GdkRegion * region3 = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    src1.x = 1;
    src1.y = 1;
    src1.width = 100;
    src1.height = 100;
    src2.x = 1;
    src2.y = 1;
    src2.width = 10;
    src2.height = 10;
    src3.x = 1;
    src3.y = 1;
    src3.width = 100;
    src3.height = 100;
    
    region1 = gdk_region_rectangle(&src1);
    region2 = gdk_region_rectangle(&src2);
    region3 = gdk_region_rectangle(&src3);
    
    if((!region1)||(!region2)||(!region3)){
    	TEST_FAIL("gdk_region_equal: region is NULL",NULL);
    	return;
    }
    
    if(gdk_region_equal(region1,OBJECT_REGION) != EXPECTED){
    	TEST_FAIL("gdk_region_equal: doesnt match expected",NULL);
    	return;
    }
    gdk_region_destroy(region1);
    gdk_region_destroy(region2);
    gdk_region_destroy(region3);
    #undef OBJECT_REGION
    #undef EXPECTED
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_offset
 * Params: GdkRegion *,gint , gint
 * Return: void 
 * Assertion: Moves a region the specified distance
 * Expected: the param of the region is correct after moveing.  
 */
static void test_purpose_22()
{
    GdkRectangle src;
    GdkRectangle dst;
    GdkRegion * region_src = NULL;
    GdkRegion * region_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    src.x = 1;
    src.y = 1;
    src.width = 100;
    src.height = 100;
    dst.x = 11;
    dst.y = 11;
    dst.width = 100;
    dst.height = 100;
    
    region_src = gdk_region_rectangle(&src);
    region_dst = gdk_region_rectangle(&dst);
    
    if((!region_src)||(!region_dst)){
    	TEST_FAIL("gdk_region_offset: region is NULL",NULL);
    	return;
    }
    gdk_region_offset(region_src,10,10);
    if(gdk_region_equal(region_src,region_dst) != TRUE){
    	TEST_FAIL("gdk_region_offset: the position of the region is not the same as the expected",NULL);
    	return;
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_shrink
 * Params: GdkRegion *,gint , gint
 * Return: void 
 * Assertion: Resizes a region by the specified amount. Positive values shrink the region. Negative values expand it.
 * Expected: the param of the region is correct after resizeing.  
 */
static void test_purpose_23()
{
    GdkRectangle src;
    GdkRectangle dst;
    GdkRectangle test;
    GdkRegion * region_src = NULL;
    GdkRegion * region_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    src.x = 1;
    src.y = 1;
    src.width = 100;
    src.height = 100;
    dst.x = 11;
    dst.y = 11;
    dst.width = 80;
    dst.height = 80;
    
    region_src = gdk_region_rectangle(&src);
    region_dst = gdk_region_rectangle(&dst);
    
    if((!region_src)||(!region_dst)){
    	TEST_FAIL("gdk_region_shrink: region is NULL",NULL);
    	return;
    }
    gdk_region_shrink(region_src,10,10);
    
    if(gdk_region_equal(region_src,region_dst) != TRUE){
    	TEST_FAIL("gdk_region_shrink: the size of the region is not the same as the expected",NULL);
    	return;
    }
    
    free(region_src);
    free(region_dst);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_intersect
 * Params: GdkRegion *, GdkRegion *
 * Return: void
 * Assertion: Sets the area of source1 to the intersection of the areas of source1 and source2. The resulting area is the set of pixels contained in both source1 and source2.
 * Expected:   
 */
static void test_purpose_24()
{
    #define SRC_X	1
    #define SRC_Y	1
    #define SRC_W	100
    #define SRC_H	100
    #define DST_X	50
    #define DST_Y	1
    #define DST_W	100
    #define DST_H	100
    #define EXP_X	50
    #define EXP_Y	1
    #define EXP_W	51
    #define EXP_H	100
    GdkRectangle expect;
    GdkRectangle src;
    GdkRectangle dst;
    GdkRegion * region_expect = NULL;
    GdkRegion * region_src = NULL;
    GdkRegion * region_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    src.x = SRC_X;
    src.y = SRC_Y;
    src.width = SRC_W;
    src.height = SRC_H;
    
    dst.x = DST_X;
    dst.y = DST_Y;
    dst.width = DST_W;
    dst.height = DST_H;
    
    expect.x = EXP_X;
    expect.y = EXP_Y;
    expect.width = EXP_W;
    expect.height = EXP_H;
    
    region_src = gdk_region_rectangle(&src);
    region_dst = gdk_region_rectangle(&dst);
    region_expect = gdk_region_rectangle(&expect);
    
    if((!region_src)||(!region_dst)||(!region_expect)){
    	TEST_FAIL("gdk_region_intersect: region is NULL",NULL);
    	return;
    }
    
    gdk_region_intersect(region_src,region_dst);
    
    if(gdk_region_equal(region_src,region_expect) != TRUE){
    	TEST_FAIL("gdk_region_intersect: the size of the region is not the same as the expected",NULL);
    	return;
    }
    
    free(region_src);
    free(region_dst);
    free(region_expect);
    #undef SRC_X
    #undef SRC_Y
    #undef SRC_W
    #undef SRC_H
    #undef DST_X
    #undef DST_Y
    #undef DST_W
    #undef DST_H
    #undef EXP_X
    #undef EXP_Y
    #undef EXP_W
    #undef EXP_H
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_intersect
 * Params: GdkRegion *, GdkRegion *
 * Return: void
 * Assertion: Sets the area of source1 to the intersection of the areas of source1 and source2. The resulting area is the set of pixels contained in both source1 and source2.
 * Expected:   
 */
static void test_purpose_25()
{
    #define SRC_X	1
    #define SRC_Y	1
    #define SRC_W	100
    #define SRC_H	100
    #define DST_X	50
    #define DST_Y	50
    #define DST_W	100
    #define DST_H	100
    #define EXP_X	50
    #define EXP_Y	50
    #define EXP_W	51
    #define EXP_H	51
    GdkRectangle expect;
    GdkRectangle src;
    GdkRectangle dst;
    GdkRegion * region_expect = NULL;
    GdkRegion * region_src = NULL;
    GdkRegion * region_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    src.x = SRC_X;
    src.y = SRC_Y;
    src.width = SRC_W;
    src.height = SRC_H;
    
    dst.x = DST_X;
    dst.y = DST_Y;
    dst.width = DST_W;
    dst.height = DST_H;
    
    expect.x = EXP_X;
    expect.y = EXP_Y;
    expect.width = EXP_W;
    expect.height = EXP_H;
    
    region_src = gdk_region_rectangle(&src);
    region_dst = gdk_region_rectangle(&dst);
    region_expect = gdk_region_rectangle(&expect);
    
    if((!region_src)||(!region_dst)||(!region_expect)){
    	TEST_FAIL("gdk_region_intersect: region is NULL",NULL);
    	return;
    }
    
    gdk_region_intersect(region_src,region_dst);
    
    if(gdk_region_equal(region_src,region_expect) != TRUE){
    	TEST_FAIL("gdk_region_intersect: the size of the region is not the same as the expected",NULL);
    	return;
    }
    
    free(region_src);
    free(region_dst);
    free(region_expect);
    #undef SRC_X
    #undef SRC_Y
    #undef SRC_W
    #undef SRC_H
    #undef DST_X
    #undef DST_Y
    #undef DST_W
    #undef DST_H
    #undef EXP_X
    #undef EXP_Y
    #undef EXP_W
    #undef EXP_H
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_region_intersect
 * Params: GdkRegion *, GdkRegion *
 * Return: void
 * Assertion: Sets the area of source1 to the intersection of the areas of source1 and source2. The resulting area is the set of pixels contained in both source1 and source2.
 * Expected:   
 */
static void test_purpose_26()
{
    #define SRC_X	1
    #define SRC_Y	1
    #define SRC_W	10
    #define SRC_H	10
    #define DST_X	50
    #define DST_Y	50
    #define DST_W	100
    #define DST_H	100
    #define EXP_X	1
    #define EXP_Y	1
    #define EXP_W	0
    #define EXP_H	0
    GdkRectangle expect;
    GdkRectangle src;
    GdkRectangle dst;
    GdkRegion * region_expect = NULL;
    GdkRegion * region_src = NULL;
    GdkRegion * region_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    src.x = SRC_X;
    src.y = SRC_Y;
    src.width = SRC_W;
    src.height = SRC_H;
    
    dst.x = DST_X;
    dst.y = DST_Y;
    dst.width = DST_W;
    dst.height = DST_H;
    
    expect.x = EXP_X;
    expect.y = EXP_Y;
    expect.width = EXP_W;
    expect.height = EXP_H;
    
    region_src = gdk_region_rectangle(&src);
    region_dst = gdk_region_rectangle(&dst);
    region_expect = gdk_region_rectangle(&expect);
    
    if((!region_src)||(!region_dst)||(!region_expect)){
    	TEST_FAIL("gdk_region_intersect: region is NULL",NULL);
    	return;
    }
    
    gdk_region_intersect(region_src,region_dst);
    
    if(gdk_region_equal(region_src,region_expect) != TRUE){
    	TEST_FAIL("gdk_region_intersect: the size of the region is not the same as the expected",NULL);
    	return;
    }
    
    free(region_src);
    free(region_dst);
    free(region_expect);
    #undef SRC_X
    #undef SRC_Y
    #undef SRC_W
    #undef SRC_H
    #undef DST_X
    #undef DST_Y
    #undef DST_W
    #undef DST_H
    #undef EXP_X
    #undef EXP_Y
    #undef EXP_W
    #undef EXP_H
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_retion_union
 * Params: GdkRegion *, GdkRegion *
 * Return: void
 * Assertion: Sets the area of source1 to the intersection of the areas of source1 and source2. The resulting area is the set of pixels contained in both source1 and source2.
 * Expected:   
 */
static void test_purpose_27()
{
    #define SRC_X	1
    #define SRC_Y	1
    #define SRC_W	100
    #define SRC_H	100
    #define DST_X	1
    #define DST_Y	1
    #define DST_W	50
    #define DST_H	50
    #define EXP_X	1
    #define EXP_Y	1
    #define EXP_W	100
    #define EXP_H	100
    GdkRectangle expect;
    GdkRectangle src;
    GdkRectangle dst;
    GdkRegion * region_expect = NULL;
    GdkRegion * region_src = NULL;
    GdkRegion * region_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    src.x = SRC_X;
    src.y = SRC_Y;
    src.width = SRC_W;
    src.height = SRC_H;
    
    dst.x = DST_X;
    dst.y = DST_Y;
    dst.width = DST_W;
    dst.height = DST_H;
    
    expect.x = EXP_X;
    expect.y = EXP_Y;
    expect.width = EXP_W;
    expect.height = EXP_H;
    
    region_src = gdk_region_rectangle(&src);
    region_dst = gdk_region_rectangle(&dst);
    region_expect = gdk_region_rectangle(&expect);
    
    if((!region_src)||(!region_dst)||(!region_expect)){
    	TEST_FAIL("gdk_region_intersect: region is NULL",NULL);
    	return;
    }
    
    gdk_region_union(region_src,region_dst);
    
    if(gdk_region_equal(region_src,region_expect) != TRUE){
    	TEST_FAIL("gdk_region_intersect: the size of the region is not the same as the expected",NULL);
    	return;
    }
    
    free(region_src);
    free(region_dst);
    free(region_expect);
    #undef SRC_X
    #undef SRC_Y
    #undef SRC_W
    #undef SRC_H
    #undef DST_X
    #undef DST_Y
    #undef DST_W
    #undef DST_H
    #undef EXP_X
    #undef EXP_Y
    #undef EXP_W
    #undef EXP_H
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_retion_union
 * Params: GdkRegion *, GdkRegion *
 * Return: void
 * Assertion: Sets the area of source1 to the intersection of the areas of source1 and source2. The resulting area is the set of pixels contained in both source1 and source2.
 * Expected:   
 */
static void test_purpose_28()
{
    #define SRC_X	1
    #define SRC_Y	1
    #define SRC_W	50
    #define SRC_H	50
    #define DST_X	51
    #define DST_Y	1
    #define DST_W	100
    #define DST_H	50
    #define EXP_X	1
    #define EXP_Y	1
    #define EXP_W	150
    #define EXP_H	50
    GdkRectangle expect;
    GdkRectangle src;
    GdkRectangle dst;
    GdkRegion * region_expect = NULL;
    GdkRegion * region_src = NULL;
    GdkRegion * region_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    src.x = SRC_X;
    src.y = SRC_Y;
    src.width = SRC_W;
    src.height = SRC_H;
    
    dst.x = DST_X;
    dst.y = DST_Y;
    dst.width = DST_W;
    dst.height = DST_H;
    
    expect.x = EXP_X;
    expect.y = EXP_Y;
    expect.width = EXP_W;
    expect.height = EXP_H;
    
    region_src = gdk_region_rectangle(&src);
    region_dst = gdk_region_rectangle(&dst);
    region_expect = gdk_region_rectangle(&expect);
    
    if((!region_src)||(!region_dst)||(!region_expect)){
    	TEST_FAIL("gdk_region_intersect: region is NULL",NULL);
    	return;
    }
    
    gdk_region_union(region_src,region_dst);
    
    if(gdk_region_equal(region_src,region_expect) != TRUE){
    	TEST_FAIL("gdk_region_intersect: the size of the region is not the same as the expected",NULL);
    	return;
    }
    
    free(region_src);
    free(region_dst);
    free(region_expect);
    #undef SRC_X
    #undef SRC_Y
    #undef SRC_W
    #undef SRC_H
    #undef DST_X
    #undef DST_Y
    #undef DST_W
    #undef DST_H
    #undef EXP_X
    #undef EXP_Y
    #undef EXP_W
    #undef EXP_H
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gdk_retion_union
 * Params: GdkRegion *, GdkRegion *
 * Return: void
 * Assertion: Sets the area of source1 to the intersection of the areas of source1 and source2. The resulting area is the set of pixels contained in both source1 and source2.
 * Expected:   
 */
static void test_purpose_29()
{
    #define SRC_X	10
    #define SRC_Y	10
    #define SRC_W	10
    #define SRC_H	10
    #define DST_X	1
    #define DST_Y	1
    #define DST_W	100
    #define DST_H	100
    #define EXP_X	1
    #define EXP_Y	1
    #define EXP_W	100
    #define EXP_H	100
    GdkRectangle expect;
    GdkRectangle src;
    GdkRectangle dst;
    GdkRegion * region_expect = NULL;
    GdkRegion * region_src = NULL;
    GdkRegion * region_dst = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    src.x = SRC_X;
    src.y = SRC_Y;
    src.width = SRC_W;
    src.height = SRC_H;
    
    dst.x = DST_X;
    dst.y = DST_Y;
    dst.width = DST_W;
    dst.height = DST_H;
    
    expect.x = EXP_X;
    expect.y = EXP_Y;
    expect.width = EXP_W;
    expect.height = EXP_H;
    
    region_src = gdk_region_rectangle(&src);
    region_dst = gdk_region_rectangle(&dst);
    region_expect = gdk_region_rectangle(&expect);
    
    if((!region_src)||(!region_dst)||(!region_expect)){
    	TEST_FAIL("gdk_region_intersect: region is NULL",NULL);
    	return;
    }
    
    gdk_region_union(region_src,region_dst);
    
    if(gdk_region_equal(region_src,region_expect) != TRUE){
    	TEST_FAIL("gdk_region_intersect: the size of the region is not the same as the expected",NULL);
    	return;
    }
    
    free(region_src);
    free(region_dst);
    free(region_expect);
    #undef SRC_X
    #undef SRC_Y
    #undef SRC_W
    #undef SRC_H
    #undef DST_X
    #undef DST_Y
    #undef DST_W
    #undef DST_H
    #undef EXP_X
    #undef EXP_Y
    #undef EXP_W
    #undef EXP_H
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GdkRectangle ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {NULL,0}
};
