/*
 * GtkBin methods tests
 * Testing GtkBin methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name:  gtk_bin_get_child
 * Params: GtkBin* bin
 * Returns: GtkWidget*
 * Assertion: Gets the child of the GtkBin, or NULL if the bin contains no child widget.
 * Params Values: a newly created GtkBin*
 * Expected: GtkWidget*, or NULL  
 */
static void test_purpose_1()
{
    #define ADD_CHILD TRUE
    
    GtkWidget *bin;
    GtkWidget *widget;
    GtkWidget *bin_contents;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    bin = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    if (ADD_CHILD)
    {
        widget = gtk_button_new ();
        gtk_container_add (GTK_CONTAINER (bin), widget);
    
        bin_contents = gtk_bin_get_child (GTK_BIN (bin));
        if (bin_contents != widget)
        {
            TEST_FAIL ("the contents of bin differs from the widget was added", 
                       NULL);
        }
    
        /******* VISUALISATION *******/
        TEST_VISUALIZE_TOPLEVEL (bin);
        /******* -------------  *******/  
        gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    } else {
        bin_contents = gtk_bin_get_child (GTK_BIN (bin));
        if (bin_contents != NULL)
        {
            TEST_FAIL ("the contents of bin should be NULL but it is not", 
                       NULL);
        }
        gtk_widget_destroy (gtk_widget_get_toplevel (bin));
    }
    
    
    
    #undef ADD_CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_bin_get_child
 * Params: GtkBin* bin
 * Returns: GtkWidget*
 * Assertion: Gets the child of the GtkBin, or NULL if the bin contains no child widget.
 * Params Values: a newly created GtkBin*
 * Expected: GtkWidget*, or NULL  
 */
static void test_purpose_2()
{
    #define ADD_CHILD FALSE
    
    GtkWidget *bin;
    GtkWidget *widget;
    GtkWidget *bin_contents;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    bin = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    if (ADD_CHILD)
    {
        widget = gtk_button_new ();
        gtk_container_add (GTK_CONTAINER (bin), widget);
    
        bin_contents = gtk_bin_get_child (GTK_BIN (bin));
        if (bin_contents != widget)
        {
            TEST_FAIL ("the contents of bin differs from the widget was added", 
                       NULL);
        }
    
        /******* VISUALISATION *******/
        TEST_VISUALIZE_TOPLEVEL (bin);
        /******* -------------  *******/  
        gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    } else {
        bin_contents = gtk_bin_get_child (GTK_BIN (bin));
        if (bin_contents != NULL)
        {
            TEST_FAIL ("the contents of bin should be NULL but it is not", 
                       NULL);
        }
        gtk_widget_destroy (gtk_widget_get_toplevel (bin));
    }
    
    
    
    #undef ADD_CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_bin_get_child
 * Params: GtkBin* bin
 * Returns: GtkWidget*
 * Assertion: The returned widget does not have a reference added, so you do not need to unref it.
 * Params Values: a newly created GtkBin*
 * Expected: GtkWidget*, or NULL  
 */
static void test_purpose_3()
{
    GtkWidget *bin;
    GtkWidget *widget;
    GtkWidget *bin_contents;
    gint ref_count_1;
    gint ref_count_2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    bin = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    
    widget = gtk_button_new ();
    ref_count_1 = G_OBJECT (widget)->ref_count;
    
    gtk_container_add (GTK_CONTAINER (bin), widget);
    
    bin_contents = gtk_bin_get_child (GTK_BIN (bin));
    if (bin_contents != widget)
    {
        TEST_FAIL ("the contents of bin differs from the widget was added", 
                   NULL);
        return;
    }
    
    ref_count_2 = G_OBJECT (bin_contents)->ref_count;
    
    if (ref_count_1 != ref_count_2)
    {
        TEST_FAIL ("ref_count_1 = %d, ref_count_2 = %d, they should be equal", 
                   ref_count_1, ref_count_2);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_TOPLEVEL (bin);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkBin ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {NULL,0}
};
