/*
 * GtkButtonBox methods tests
 * Testing GtkButtonBox methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_button_box_set_layout 
 * Params: GtkButtonBox *widget,GtkButtonBoxStyle layout_style
 * Returns: void
 * Assertion: Changes the way buttons are arranged in their container. 
 * Params Values: a newly created GtkButtonBox*, gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_1()
{
    #define WIDGET gtk_hbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_DEFAULT_STYLE
    
    GtkWidget* widget;
    GtkButtonBoxStyle layout_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget),LAYOUT_STYLE);
    
    g_object_get(GTK_OBJECT (widget), "layout-style", &layout_style, NULL);
    if (layout_style != LAYOUT_STYLE)
    {
        TEST_FAIL ("layout_style is '%s', should be '%s'", layout_style,LAYOUT_STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_set_layout 
 * Params: GtkButtonBox *widget,GtkButtonBoxStyle layout_style
 * Returns: void
 * Assertion: Changes the way buttons are arranged in their container. 
 * Params Values: a newly created GtkButtonBox*, gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_2()
{
    #define WIDGET gtk_hbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_SPREAD
    
    GtkWidget* widget;
    GtkButtonBoxStyle layout_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget),LAYOUT_STYLE);
    
    g_object_get(GTK_OBJECT (widget), "layout-style", &layout_style, NULL);
    if (layout_style != LAYOUT_STYLE)
    {
        TEST_FAIL ("layout_style is '%s', should be '%s'", layout_style,LAYOUT_STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_set_layout 
 * Params: GtkButtonBox *widget,GtkButtonBoxStyle layout_style
 * Returns: void
 * Assertion: Changes the way buttons are arranged in their container. 
 * Params Values: a newly created GtkButtonBox*, gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_3()
{
    #define WIDGET gtk_hbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_EDGE
    
    GtkWidget* widget;
    GtkButtonBoxStyle layout_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget),LAYOUT_STYLE);
    
    g_object_get(GTK_OBJECT (widget), "layout-style", &layout_style, NULL);
    if (layout_style != LAYOUT_STYLE)
    {
        TEST_FAIL ("layout_style is '%s', should be '%s'", layout_style,LAYOUT_STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_set_layout 
 * Params: GtkButtonBox *widget,GtkButtonBoxStyle layout_style
 * Returns: void
 * Assertion: Changes the way buttons are arranged in their container. 
 * Params Values: a newly created GtkButtonBox*, gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_4()
{
    #define WIDGET gtk_hbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_START
    
    GtkWidget* widget;
    GtkButtonBoxStyle layout_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget),LAYOUT_STYLE);
    
    g_object_get(GTK_OBJECT (widget), "layout-style", &layout_style, NULL);
    if (layout_style != LAYOUT_STYLE)
    {
        TEST_FAIL ("layout_style is '%s', should be '%s'", layout_style,LAYOUT_STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_set_layout 
 * Params: GtkButtonBox *widget,GtkButtonBoxStyle layout_style
 * Returns: void
 * Assertion: Changes the way buttons are arranged in their container. 
 * Params Values: a newly created GtkButtonBox*, gtk_hbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_5()
{
    #define WIDGET gtk_hbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_END
    
    GtkWidget* widget;
    GtkButtonBoxStyle layout_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget),LAYOUT_STYLE);
    
    g_object_get(GTK_OBJECT (widget), "layout-style", &layout_style, NULL);
    if (layout_style != LAYOUT_STYLE)
    {
        TEST_FAIL ("layout_style is '%s', should be '%s'", layout_style,LAYOUT_STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_set_layout 
 * Params: GtkButtonBox *widget,GtkButtonBoxStyle layout_style
 * Returns: void
 * Assertion: Changes the way buttons are arranged in their container. 
 * Params Values: a newly created GtkButtonBox*, gtk_vbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_6()
{
    #define WIDGET gtk_vbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_DEFAULT_STYLE
    
    GtkWidget* widget;
    GtkButtonBoxStyle layout_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget),LAYOUT_STYLE);
    
    g_object_get(GTK_OBJECT (widget), "layout-style", &layout_style, NULL);
    if (layout_style != LAYOUT_STYLE)
    {
        TEST_FAIL ("layout_style is '%s', should be '%s'", layout_style,LAYOUT_STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_set_layout 
 * Params: GtkButtonBox *widget,GtkButtonBoxStyle layout_style
 * Returns: void
 * Assertion: Changes the way buttons are arranged in their container. 
 * Params Values: a newly created GtkButtonBox*, gtk_vbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_7()
{
    #define WIDGET gtk_vbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_SPREAD
    
    GtkWidget* widget;
    GtkButtonBoxStyle layout_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget),LAYOUT_STYLE);
    
    g_object_get(GTK_OBJECT (widget), "layout-style", &layout_style, NULL);
    if (layout_style != LAYOUT_STYLE)
    {
        TEST_FAIL ("layout_style is '%s', should be '%s'", layout_style,LAYOUT_STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_set_layout 
 * Params: GtkButtonBox *widget,GtkButtonBoxStyle layout_style
 * Returns: void
 * Assertion: Changes the way buttons are arranged in their container. 
 * Params Values: a newly created GtkButtonBox*, gtk_vbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_8()
{
    #define WIDGET gtk_vbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_EDGE
    
    GtkWidget* widget;
    GtkButtonBoxStyle layout_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget),LAYOUT_STYLE);
    
    g_object_get(GTK_OBJECT (widget), "layout-style", &layout_style, NULL);
    if (layout_style != LAYOUT_STYLE)
    {
        TEST_FAIL ("layout_style is '%s', should be '%s'", layout_style,LAYOUT_STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_set_layout 
 * Params: GtkButtonBox *widget,GtkButtonBoxStyle layout_style
 * Returns: void
 * Assertion: Changes the way buttons are arranged in their container. 
 * Params Values: a newly created GtkButtonBox*, gtk_vbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_9()
{
    #define WIDGET gtk_vbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_START
    
    GtkWidget* widget;
    GtkButtonBoxStyle layout_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget),LAYOUT_STYLE);
    
    g_object_get(GTK_OBJECT (widget), "layout-style", &layout_style, NULL);
    if (layout_style != LAYOUT_STYLE)
    {
        TEST_FAIL ("layout_style is '%s', should be '%s'", layout_style,LAYOUT_STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_set_layout 
 * Params: GtkButtonBox *widget,GtkButtonBoxStyle layout_style
 * Returns: void
 * Assertion: Changes the way buttons are arranged in their container. 
 * Params Values: a newly created GtkButtonBox*, gtk_vbutton_box_new ()
 * Expected: void  
 */
static void test_purpose_10()
{
    #define WIDGET gtk_vbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_END
    
    GtkWidget* widget;
    GtkButtonBoxStyle layout_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget),LAYOUT_STYLE);
    
    g_object_get(GTK_OBJECT (widget), "layout-style", &layout_style, NULL);
    if (layout_style != LAYOUT_STYLE)
    {
        TEST_FAIL ("layout_style is '%s', should be '%s'", layout_style,LAYOUT_STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_get_layout 
 * Params: GtkButtonBox *widget
 * Returns: GtkButtonBoxStyle
 * Assertion: Retrieves the method being used to arrange the buttons in a button box. 
 * Params Values: a newly created GtkButtonBox*
 * Expected: GtkButtonBoxStyle  
 */
static void test_purpose_11()
{
    #define WIDGET gtk_hbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_DEFAULT_STYLE
    
    GtkWidget* widget;
    GtkButtonBoxStyle layout_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "layout-style", LAYOUT_STYLE, NULL);
    
    layout_style = gtk_button_box_get_layout (GTK_BUTTON_BOX (widget));
    
    if (layout_style != LAYOUT_STYLE)
    {
        TEST_FAIL ("layout_style is '%s', should be '%s'", layout_style,LAYOUT_STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_get_layout 
 * Params: GtkButtonBox *widget
 * Returns: GtkButtonBoxStyle
 * Assertion: Retrieves the method being used to arrange the buttons in a button box. 
 * Params Values: a newly created GtkButtonBox*
 * Expected: GtkButtonBoxStyle  
 */
static void test_purpose_12()
{
    #define WIDGET gtk_hbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_SPREAD
    
    GtkWidget* widget;
    GtkButtonBoxStyle layout_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "layout-style", LAYOUT_STYLE, NULL);
    
    layout_style = gtk_button_box_get_layout (GTK_BUTTON_BOX (widget));
    
    if (layout_style != LAYOUT_STYLE)
    {
        TEST_FAIL ("layout_style is '%s', should be '%s'", layout_style,LAYOUT_STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_get_layout 
 * Params: GtkButtonBox *widget
 * Returns: GtkButtonBoxStyle
 * Assertion: Retrieves the method being used to arrange the buttons in a button box. 
 * Params Values: a newly created GtkButtonBox*
 * Expected: GtkButtonBoxStyle  
 */
static void test_purpose_13()
{
    #define WIDGET gtk_hbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_EDGE
    
    GtkWidget* widget;
    GtkButtonBoxStyle layout_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "layout-style", LAYOUT_STYLE, NULL);
    
    layout_style = gtk_button_box_get_layout (GTK_BUTTON_BOX (widget));
    
    if (layout_style != LAYOUT_STYLE)
    {
        TEST_FAIL ("layout_style is '%s', should be '%s'", layout_style,LAYOUT_STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_get_layout 
 * Params: GtkButtonBox *widget
 * Returns: GtkButtonBoxStyle
 * Assertion: Retrieves the method being used to arrange the buttons in a button box. 
 * Params Values: a newly created GtkButtonBox*
 * Expected: GtkButtonBoxStyle  
 */
static void test_purpose_14()
{
    #define WIDGET gtk_hbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_START
    
    GtkWidget* widget;
    GtkButtonBoxStyle layout_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "layout-style", LAYOUT_STYLE, NULL);
    
    layout_style = gtk_button_box_get_layout (GTK_BUTTON_BOX (widget));
    
    if (layout_style != LAYOUT_STYLE)
    {
        TEST_FAIL ("layout_style is '%s', should be '%s'", layout_style,LAYOUT_STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_get_layout 
 * Params: GtkButtonBox *widget
 * Returns: GtkButtonBoxStyle
 * Assertion: Retrieves the method being used to arrange the buttons in a button box. 
 * Params Values: a newly created GtkButtonBox*
 * Expected: GtkButtonBoxStyle  
 */
static void test_purpose_15()
{
    #define WIDGET gtk_hbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_END
    
    GtkWidget* widget;
    GtkButtonBoxStyle layout_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "layout-style", LAYOUT_STYLE, NULL);
    
    layout_style = gtk_button_box_get_layout (GTK_BUTTON_BOX (widget));
    
    if (layout_style != LAYOUT_STYLE)
    {
        TEST_FAIL ("layout_style is '%s', should be '%s'", layout_style,LAYOUT_STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_get_layout 
 * Params: GtkButtonBox *widget
 * Returns: GtkButtonBoxStyle
 * Assertion: Retrieves the method being used to arrange the buttons in a button box. 
 * Params Values: a newly created GtkButtonBox*
 * Expected: GtkButtonBoxStyle  
 */
static void test_purpose_16()
{
    #define WIDGET gtk_vbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_DEFAULT_STYLE
    
    GtkWidget* widget;
    GtkButtonBoxStyle layout_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "layout-style", LAYOUT_STYLE, NULL);
    
    layout_style = gtk_button_box_get_layout (GTK_BUTTON_BOX (widget));
    
    if (layout_style != LAYOUT_STYLE)
    {
        TEST_FAIL ("layout_style is '%s', should be '%s'", layout_style,LAYOUT_STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_get_layout 
 * Params: GtkButtonBox *widget
 * Returns: GtkButtonBoxStyle
 * Assertion: Retrieves the method being used to arrange the buttons in a button box. 
 * Params Values: a newly created GtkButtonBox*
 * Expected: GtkButtonBoxStyle  
 */
static void test_purpose_17()
{
    #define WIDGET gtk_vbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_SPREAD
    
    GtkWidget* widget;
    GtkButtonBoxStyle layout_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "layout-style", LAYOUT_STYLE, NULL);
    
    layout_style = gtk_button_box_get_layout (GTK_BUTTON_BOX (widget));
    
    if (layout_style != LAYOUT_STYLE)
    {
        TEST_FAIL ("layout_style is '%s', should be '%s'", layout_style,LAYOUT_STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_get_layout 
 * Params: GtkButtonBox *widget
 * Returns: GtkButtonBoxStyle
 * Assertion: Retrieves the method being used to arrange the buttons in a button box. 
 * Params Values: a newly created GtkButtonBox*
 * Expected: GtkButtonBoxStyle  
 */
static void test_purpose_18()
{
    #define WIDGET gtk_vbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_EDGE
    
    GtkWidget* widget;
    GtkButtonBoxStyle layout_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "layout-style", LAYOUT_STYLE, NULL);
    
    layout_style = gtk_button_box_get_layout (GTK_BUTTON_BOX (widget));
    
    if (layout_style != LAYOUT_STYLE)
    {
        TEST_FAIL ("layout_style is '%s', should be '%s'", layout_style,LAYOUT_STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_get_layout 
 * Params: GtkButtonBox *widget
 * Returns: GtkButtonBoxStyle
 * Assertion: Retrieves the method being used to arrange the buttons in a button box. 
 * Params Values: a newly created GtkButtonBox*
 * Expected: GtkButtonBoxStyle  
 */
static void test_purpose_19()
{
    #define WIDGET gtk_vbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_START
    
    GtkWidget* widget;
    GtkButtonBoxStyle layout_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "layout-style", LAYOUT_STYLE, NULL);
    
    layout_style = gtk_button_box_get_layout (GTK_BUTTON_BOX (widget));
    
    if (layout_style != LAYOUT_STYLE)
    {
        TEST_FAIL ("layout_style is '%s', should be '%s'", layout_style,LAYOUT_STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_get_layout 
 * Params: GtkButtonBox *widget
 * Returns: GtkButtonBoxStyle
 * Assertion: Retrieves the method being used to arrange the buttons in a button box. 
 * Params Values: a newly created GtkButtonBox*
 * Expected: GtkButtonBoxStyle  
 */
static void test_purpose_20()
{
    #define WIDGET gtk_vbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_END
    
    GtkWidget* widget;
    GtkButtonBoxStyle layout_style;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT (widget), "layout-style", LAYOUT_STYLE, NULL);
    
    layout_style = gtk_button_box_get_layout (GTK_BUTTON_BOX (widget));
    
    if (layout_style != LAYOUT_STYLE)
    {
        TEST_FAIL ("layout_style is '%s', should be '%s'", layout_style,LAYOUT_STYLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_set_child_secondary
 * Params: GtkButtonBox *widget, GtkWidget *child, gboolean is_secondary
 * Returns: void
 * Assertion: Sets whether child should appear in a secondary group of children.
 * Params Values: a newly created GtkButtonBox*, one of its children, GTK_BUTTONBOX_DEFAULT_STYLE
 * Expected: void  
 */
static void test_purpose_21()
{
    #define WIDGET gtk_hbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_DEFAULT_STYLE
    #define IS_SECONDARY TRUE
    
    GtkWidget* widget;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_button_new_with_label ("label");
    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget), LAYOUT_STYLE);
    gtk_container_add (GTK_CONTAINER (widget), child);
    gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (widget), child, IS_SECONDARY);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (child));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    #undef IS_SECONDARY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_set_child_secondary
 * Params: GtkButtonBox *widget, GtkWidget *child, gboolean is_secondary
 * Returns: void
 * Assertion: Sets whether child should appear in a secondary group of children.
 * Params Values: a newly created GtkButtonBox*, one of its children, GTK_BUTTONBOX_SPREAD
 * Expected: void  
 */
static void test_purpose_22()
{
    #define WIDGET gtk_hbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_SPREAD
    #define IS_SECONDARY TRUE
    
    GtkWidget* widget;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_button_new_with_label ("label");
    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget), LAYOUT_STYLE);
    gtk_container_add (GTK_CONTAINER (widget), child);
    gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (widget), child, IS_SECONDARY);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (child));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    #undef IS_SECONDARY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_set_child_secondary
 * Params: GtkButtonBox *widget, GtkWidget *child, gboolean is_secondary
 * Returns: void
 * Assertion: Sets whether child should appear in a secondary group of children.
 * Params Values: a newly created GtkButtonBox*, one of its children, GTK_BUTTONBOX_EDGE
 * Expected: void  
 */
static void test_purpose_23()
{
    #define WIDGET gtk_hbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_EDGE
    #define IS_SECONDARY TRUE
    
    GtkWidget* widget;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_button_new_with_label ("label");
    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget), LAYOUT_STYLE);
    gtk_container_add (GTK_CONTAINER (widget), child);
    gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (widget), child, IS_SECONDARY);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (child));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    #undef IS_SECONDARY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_set_child_secondary
 * Params: GtkButtonBox *widget, GtkWidget *child, gboolean is_secondary
 * Returns: void
 * Assertion: Sets whether child should appear in a secondary group of children.
 * Params Values: a newly created GtkButtonBox*, one of its children, GTK_BUTTONBOX_START
 * Expected: void  
 */
static void test_purpose_24()
{
    #define WIDGET gtk_vbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_START
    #define IS_SECONDARY TRUE
    
    GtkWidget* widget;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_button_new_with_label ("label");
    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget), LAYOUT_STYLE);
    gtk_container_add (GTK_CONTAINER (widget), child);
    gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (widget), child, IS_SECONDARY);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (child));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    #undef IS_SECONDARY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_set_child_secondary
 * Params: GtkButtonBox *widget, GtkWidget *child, gboolean is_secondary
 * Returns: void
 * Assertion: Sets whether child should appear in a secondary group of children.
 * Params Values: a newly created GtkButtonBox*, one of its children, GTK_BUTTONBOX_END
 * Expected: void  
 */
static void test_purpose_25()
{
    #define WIDGET gtk_hbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_END
    #define IS_SECONDARY TRUE
    
    GtkWidget* widget;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_button_new_with_label ("label");
    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget), LAYOUT_STYLE);
    gtk_container_add (GTK_CONTAINER (widget), child);
    gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (widget), child, IS_SECONDARY);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (child));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    #undef IS_SECONDARY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_set_child_secondary
 * Params: GtkButtonBox *widget, GtkWidget *child, gboolean is_secondary
 * Returns: void
 * Assertion: Sets whether child should appear in a secondary group of children.
 * Params Values: a newly created GtkButtonBox*, one of its children, GTK_BUTTONBOX_DEFAULT_STYLE
 * Expected: void  
 */
static void test_purpose_26()
{
    #define WIDGET gtk_vbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_DEFAULT_STYLE
    #define IS_SECONDARY FALSE
    
    GtkWidget* widget;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_button_new_with_label ("label");
    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget), LAYOUT_STYLE);
    gtk_container_add (GTK_CONTAINER (widget), child);
    gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (widget), child, IS_SECONDARY);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (child));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    #undef IS_SECONDARY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_set_child_secondary
 * Params: GtkButtonBox *widget, GtkWidget *child, gboolean is_secondary
 * Returns: void
 * Assertion: Sets whether child should appear in a secondary group of children.
 * Params Values: a newly created GtkButtonBox*, one of its children, GTK_BUTTONBOX_SPREAD
 * Expected: void  
 */
static void test_purpose_27()
{
    #define WIDGET gtk_hbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_SPREAD
    #define IS_SECONDARY FALSE
    
    GtkWidget* widget;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_button_new_with_label ("label");
    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget), LAYOUT_STYLE);
    gtk_container_add (GTK_CONTAINER (widget), child);
    gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (widget), child, IS_SECONDARY);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (child));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    #undef IS_SECONDARY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_set_child_secondary
 * Params: GtkButtonBox *widget, GtkWidget *child, gboolean is_secondary
 * Returns: void
 * Assertion: Sets whether child should appear in a secondary group of children.
 * Params Values: a newly created GtkButtonBox*, one of its children, GTK_BUTTONBOX_EDGE
 * Expected: void  
 */
static void test_purpose_28()
{
    #define WIDGET gtk_vbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_EDGE
    #define IS_SECONDARY FALSE
    
    GtkWidget* widget;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_button_new_with_label ("label");
    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget), LAYOUT_STYLE);
    gtk_container_add (GTK_CONTAINER (widget), child);
    gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (widget), child, IS_SECONDARY);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (child));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    #undef IS_SECONDARY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_set_child_secondary
 * Params: GtkButtonBox *widget, GtkWidget *child, gboolean is_secondary
 * Returns: void
 * Assertion: Sets whether child should appear in a secondary group of children.
 * Params Values: a newly created GtkButtonBox*, one of its children, GTK_BUTTONBOX_START
 * Expected: void  
 */
static void test_purpose_29()
{
    #define WIDGET gtk_hbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_START
    #define IS_SECONDARY FALSE
    
    GtkWidget* widget;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_button_new_with_label ("label");
    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget), LAYOUT_STYLE);
    gtk_container_add (GTK_CONTAINER (widget), child);
    gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (widget), child, IS_SECONDARY);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (child));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    #undef IS_SECONDARY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_box_set_child_secondary
 * Params: GtkButtonBox *widget, GtkWidget *child, gboolean is_secondary
 * Returns: void
 * Assertion: Sets whether child should appear in a secondary group of children.
 * Params Values: a newly created GtkButtonBox*, one of its children, GTK_BUTTONBOX_END
 * Expected: void  
 */
static void test_purpose_30()
{
    #define WIDGET gtk_vbutton_box_new ()
    #define LAYOUT_STYLE GTK_BUTTONBOX_END
    #define IS_SECONDARY FALSE
    
    GtkWidget* widget;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_BUTTON_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    child = gtk_button_new_with_label ("label");
    gtk_button_box_set_layout (GTK_BUTTON_BOX (widget), LAYOUT_STYLE);
    gtk_container_add (GTK_CONTAINER (widget), child);
    gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (widget), child, IS_SECONDARY);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (child));
    
    #undef WIDGET
    #undef LAYOUT_STYLE
    #undef IS_SECONDARY
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkButtonBox ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {NULL,0}
};
