/*
 * GtkComboBox methods tests
 * Testing GtkComboBox methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;


/*
 * Name: gtk_combo_box_new_text
 * Params: void
 * Returns: GtkWidget*
 * Assertion: Convenience function which constructs a new text combo box, which is a GtkComboBox just displaying strings.
 * Params Values: void
 * Expected: A new text combo box  
 */
static void test_purpose_1()
{
    GtkWidget *widget;
    gint active;
    gboolean add_tearoffs;
    gint column_span_column;
    gboolean focus_on_click;
    gboolean has_frame;
    gint row_span_column;
    gint wrap_width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_combo_box_new_text ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_COMBO_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "active", &active, NULL);
    if (active != -1)
    {
        TEST_FAIL("active = %d, should be -1", active, NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "add-tearoffs", &add_tearoffs, NULL);
    if (add_tearoffs != FALSE)
    {
        TEST_FAIL("add_tearoffs = %d, should be FALSE", add_tearoffs, NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "column-span-column", &column_span_column, NULL);
    if (column_span_column != -1)
    {
        TEST_FAIL("column_span_column = %d, should be -1", column_span_column, NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "focus-on-click", &focus_on_click, NULL);
    if (focus_on_click != TRUE)
    {
        TEST_FAIL("focus_on_click = %d, should be TRUE", focus_on_click, NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "has-frame", &has_frame, NULL);
    if (has_frame != TRUE)
    {
        TEST_FAIL("has_frame = %d, should be TRUE", has_frame, NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "row-span-column", &row_span_column, NULL);
    if (row_span_column != -1)
    {
        TEST_FAIL("row_span_column = %d, should be -1", row_span_column, NULL);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap-width", &wrap_width, NULL);
    if (wrap_width != 0)
    {
        TEST_FAIL("wrap_width = %d, should be 0", wrap_width, NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_combo_box_append_text
 * Params: GtkComboBox *combo_box, const gchar *text
 * Returns: void
 * Assertion: Appends string to the list of strings stored in combo_box.
 * Params Values: a newly created GtkComboBox*, a string from {"String 1", "String 2", "String 3", "String 4"}
 * Expected: void  
 */
static void test_purpose_2()
{
    #define TEXTS "String 1", "String 2", "String 3", "String 4"
    #define NUM 4
    
    GtkWidget *widget;
    const gchar *texts[] = {TEXTS};
    gint i;
    gchar *active;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_combo_box_new_text ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_COMBO_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    for (i = 0; i < NUM; i++)
        gtk_combo_box_append_text (GTK_COMBO_BOX (widget), texts[i]);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    for (i = 0; i < NUM; i++) {
        gtk_combo_box_set_active (GTK_COMBO_BOX (widget), i);
        active = gtk_combo_box_get_active_text (GTK_COMBO_BOX (widget));
    
        if (strcmp (texts[i], active))
            TEST_FAIL ("String %d in combo box should be %s, not %s", i, texts[i], active, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXTS
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_combo_box_append_text
 * Params: GtkComboBox *combo_box, const gchar *text
 * Returns: void
 * Assertion: Appends string to the list of strings stored in combo_box.
 * Params Values: a newly created GtkComboBox*, a string from {"1", "2", "3", "4", "5", "6"}
 * Expected: void  
 */
static void test_purpose_3()
{
    #define TEXTS "1", "2", "3", "4", "5", "6"
    #define NUM 6
    
    GtkWidget *widget;
    const gchar *texts[] = {TEXTS};
    gint i;
    gchar *active;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_combo_box_new_text ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_COMBO_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    for (i = 0; i < NUM; i++)
        gtk_combo_box_append_text (GTK_COMBO_BOX (widget), texts[i]);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    for (i = 0; i < NUM; i++) {
        gtk_combo_box_set_active (GTK_COMBO_BOX (widget), i);
        active = gtk_combo_box_get_active_text (GTK_COMBO_BOX (widget));
    
        if (strcmp (texts[i], active))
            TEST_FAIL ("String %d in combo box should be %s, not %s", i, texts[i], active, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXTS
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_combo_box_append_text
 * Params: GtkComboBox *combo_box, const gchar *text
 * Returns: void
 * Assertion: Appends string to the list of strings stored in combo_box.
 * Params Values: a newly created GtkComboBox*, a string from {"      ", "\r\n\t", "~!@#$%^&*()", ""}
 * Expected: void  
 */
static void test_purpose_4()
{
    #define TEXTS "      ", "\r\n\t", "~!@#$%^&*()", ""
    #define NUM 4
    
    GtkWidget *widget;
    const gchar *texts[] = {TEXTS};
    gint i;
    gchar *active;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_combo_box_new_text ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_COMBO_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    for (i = 0; i < NUM; i++)
        gtk_combo_box_append_text (GTK_COMBO_BOX (widget), texts[i]);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    for (i = 0; i < NUM; i++) {
        gtk_combo_box_set_active (GTK_COMBO_BOX (widget), i);
        active = gtk_combo_box_get_active_text (GTK_COMBO_BOX (widget));
    
        if (strcmp (texts[i], active))
            TEST_FAIL ("String %d in combo box should be %s, not %s", i, texts[i], active, NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXTS
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_combo_box_get_active
 * Params: GtkComboBox *combo_box
 * Returns: gint
 * Assertion: Returns the index of the currently active item, or -1 if there's no active item. If the model is a non-flat treemodel, and the active item is not an immediate child of the root of the tree, this function returns gtk_tree_path_get_indices (path)[0], where path is the GtkTreePath of the active item.
 * Params Values: a newly created GtkComboBox*
 * Expected: An integer which is the index of the currently active item, or -1 if there's no active item.  
 */
static void test_purpose_5()
{
    #define TEXTS "String 1", "String 2", "String 3", "String 4"
    #define NUM 4
    #define INDEX 0
    
    GtkWidget *widget;
    const gchar *texts[] = {TEXTS};
    gint i;
    gint index;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_combo_box_new_text ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_COMBO_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    for (i = 0; i < NUM; i++)
        gtk_combo_box_append_text (GTK_COMBO_BOX (widget), texts[i]);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    index = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
    
    if (index != -1)
        TEST_FAIL ("There should be no active item currently", NULL);
    
    
    g_object_set (GTK_OBJECT (widget), "active", INDEX, NULL);
    
    index = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
    
    if (index != INDEX)
        TEST_FAIL ("The index of the currently active item should be %d, not %d", INDEX, index, NULL);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXTS
    #undef NUM
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_combo_box_get_active
 * Params: GtkComboBox *combo_box
 * Returns: gint
 * Assertion: Returns the index of the currently active item, or -1 if there's no active item. If the model is a non-flat treemodel, and the active item is not an immediate child of the root of the tree, this function returns gtk_tree_path_get_indices (path)[0], where path is the GtkTreePath of the active item.
 * Params Values: a newly created GtkComboBox*
 * Expected: An integer which is the index of the currently active item, or -1 if there's no active item.  
 */
static void test_purpose_6()
{
    #define TEXTS "String 1", "String 2", "String 3", "String 4"
    #define NUM 4
    #define INDEX 1
    
    GtkWidget *widget;
    const gchar *texts[] = {TEXTS};
    gint i;
    gint index;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_combo_box_new_text ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_COMBO_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    for (i = 0; i < NUM; i++)
        gtk_combo_box_append_text (GTK_COMBO_BOX (widget), texts[i]);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    index = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
    
    if (index != -1)
        TEST_FAIL ("There should be no active item currently", NULL);
    
    
    g_object_set (GTK_OBJECT (widget), "active", INDEX, NULL);
    
    index = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
    
    if (index != INDEX)
        TEST_FAIL ("The index of the currently active item should be %d, not %d", INDEX, index, NULL);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXTS
    #undef NUM
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_combo_box_get_active
 * Params: GtkComboBox *combo_box
 * Returns: gint
 * Assertion: Returns the index of the currently active item, or -1 if there's no active item. If the model is a non-flat treemodel, and the active item is not an immediate child of the root of the tree, this function returns gtk_tree_path_get_indices (path)[0], where path is the GtkTreePath of the active item.
 * Params Values: a newly created GtkComboBox*
 * Expected: An integer which is the index of the currently active item, or -1 if there's no active item.  
 */
static void test_purpose_7()
{
    #define TEXTS "String 1", "String 2", "String 3", "String 4"
    #define NUM 4
    #define INDEX 2
    
    GtkWidget *widget;
    const gchar *texts[] = {TEXTS};
    gint i;
    gint index;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_combo_box_new_text ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_COMBO_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    for (i = 0; i < NUM; i++)
        gtk_combo_box_append_text (GTK_COMBO_BOX (widget), texts[i]);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    index = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
    
    if (index != -1)
        TEST_FAIL ("There should be no active item currently", NULL);
    
    
    g_object_set (GTK_OBJECT (widget), "active", INDEX, NULL);
    
    index = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
    
    if (index != INDEX)
        TEST_FAIL ("The index of the currently active item should be %d, not %d", INDEX, index, NULL);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXTS
    #undef NUM
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_combo_box_get_active
 * Params: GtkComboBox *combo_box
 * Returns: gint
 * Assertion: Returns the index of the currently active item, or -1 if there's no active item. If the model is a non-flat treemodel, and the active item is not an immediate child of the root of the tree, this function returns gtk_tree_path_get_indices (path)[0], where path is the GtkTreePath of the active item.
 * Params Values: a newly created GtkComboBox*
 * Expected: An integer which is the index of the currently active item, or -1 if there's no active item.  
 */
static void test_purpose_8()
{
    #define TEXTS "String 1", "String 2", "String 3", "String 4"
    #define NUM 4
    #define INDEX 3
    
    GtkWidget *widget;
    const gchar *texts[] = {TEXTS};
    gint i;
    gint index;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_combo_box_new_text ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_COMBO_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    for (i = 0; i < NUM; i++)
        gtk_combo_box_append_text (GTK_COMBO_BOX (widget), texts[i]);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    index = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
    
    if (index != -1)
        TEST_FAIL ("There should be no active item currently", NULL);
    
    
    g_object_set (GTK_OBJECT (widget), "active", INDEX, NULL);
    
    index = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
    
    if (index != INDEX)
        TEST_FAIL ("The index of the currently active item should be %d, not %d", INDEX, index, NULL);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXTS
    #undef NUM
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_combo_box_set_active
 * Params: GtkComboBox *combo_box, gint index_
 * Returns: void
 * Assertion: Sets the active item of combo_box to be the item at index.
 * Params Values: a newly created GtkComboBox*, An index in the model passed during construction, or -1 to have no active item.
 * Expected: void  
 */
static void test_purpose_9()
{
    #define TEXTS "String 1", "String 2", "String 3", "String 4"
    #define NUM 4
    #define INDEX -1
    
    GtkWidget *widget;
    const gchar *texts[] = {TEXTS};
    gint i;
    gint index;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_combo_box_new_text ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_COMBO_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    for (i = 0; i < NUM; i++)
        gtk_combo_box_append_text (GTK_COMBO_BOX (widget), texts[i]);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_combo_box_set_active (GTK_COMBO_BOX (widget), INDEX);
    
    g_object_get (GTK_OBJECT (widget), "active", &index, NULL);
    
    if (index != INDEX)
        TEST_FAIL ("The index of the currently active item should be %d, not %d", INDEX, index, NULL);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXTS
    #undef NUM
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_combo_box_set_active
 * Params: GtkComboBox *combo_box, gint index_
 * Returns: void
 * Assertion: Sets the active item of combo_box to be the item at index.
 * Params Values: a newly created GtkComboBox*, An index in the model passed during construction, or -1 to have no active item.
 * Expected: void  
 */
static void test_purpose_10()
{
    #define TEXTS "String 1", "String 2", "String 3", "String 4"
    #define NUM 4
    #define INDEX 0
    
    GtkWidget *widget;
    const gchar *texts[] = {TEXTS};
    gint i;
    gint index;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_combo_box_new_text ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_COMBO_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    for (i = 0; i < NUM; i++)
        gtk_combo_box_append_text (GTK_COMBO_BOX (widget), texts[i]);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_combo_box_set_active (GTK_COMBO_BOX (widget), INDEX);
    
    g_object_get (GTK_OBJECT (widget), "active", &index, NULL);
    
    if (index != INDEX)
        TEST_FAIL ("The index of the currently active item should be %d, not %d", INDEX, index, NULL);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXTS
    #undef NUM
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_combo_box_set_active
 * Params: GtkComboBox *combo_box, gint index_
 * Returns: void
 * Assertion: Sets the active item of combo_box to be the item at index.
 * Params Values: a newly created GtkComboBox*, An index in the model passed during construction, or -1 to have no active item.
 * Expected: void  
 */
static void test_purpose_11()
{
    #define TEXTS "String 1", "String 2", "String 3", "String 4"
    #define NUM 4
    #define INDEX 1
    
    GtkWidget *widget;
    const gchar *texts[] = {TEXTS};
    gint i;
    gint index;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_combo_box_new_text ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_COMBO_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    for (i = 0; i < NUM; i++)
        gtk_combo_box_append_text (GTK_COMBO_BOX (widget), texts[i]);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_combo_box_set_active (GTK_COMBO_BOX (widget), INDEX);
    
    g_object_get (GTK_OBJECT (widget), "active", &index, NULL);
    
    if (index != INDEX)
        TEST_FAIL ("The index of the currently active item should be %d, not %d", INDEX, index, NULL);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXTS
    #undef NUM
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_combo_box_set_active
 * Params: GtkComboBox *combo_box, gint index_
 * Returns: void
 * Assertion: Sets the active item of combo_box to be the item at index.
 * Params Values: a newly created GtkComboBox*, An index in the model passed during construction, or -1 to have no active item.
 * Expected: void  
 */
static void test_purpose_12()
{
    #define TEXTS "String 1", "String 2", "String 3", "String 4"
    #define NUM 4
    #define INDEX 2
    
    GtkWidget *widget;
    const gchar *texts[] = {TEXTS};
    gint i;
    gint index;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_combo_box_new_text ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_COMBO_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    for (i = 0; i < NUM; i++)
        gtk_combo_box_append_text (GTK_COMBO_BOX (widget), texts[i]);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_combo_box_set_active (GTK_COMBO_BOX (widget), INDEX);
    
    g_object_get (GTK_OBJECT (widget), "active", &index, NULL);
    
    if (index != INDEX)
        TEST_FAIL ("The index of the currently active item should be %d, not %d", INDEX, index, NULL);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXTS
    #undef NUM
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_combo_box_set_active
 * Params: GtkComboBox *combo_box, gint index_
 * Returns: void
 * Assertion: Sets the active item of combo_box to be the item at index.
 * Params Values: a newly created GtkComboBox*, An index in the model passed during construction, or -1 to have no active item.
 * Expected: void  
 */
static void test_purpose_13()
{
    #define TEXTS "String 1", "String 2", "String 3", "String 4"
    #define NUM 4
    #define INDEX 3
    
    GtkWidget *widget;
    const gchar *texts[] = {TEXTS};
    gint i;
    gint index;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_combo_box_new_text ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_COMBO_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    for (i = 0; i < NUM; i++)
        gtk_combo_box_append_text (GTK_COMBO_BOX (widget), texts[i]);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_combo_box_set_active (GTK_COMBO_BOX (widget), INDEX);
    
    g_object_get (GTK_OBJECT (widget), "active", &index, NULL);
    
    if (index != INDEX)
        TEST_FAIL ("The index of the currently active item should be %d, not %d", INDEX, index, NULL);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXTS
    #undef NUM
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_combo_box_get_model
 * Params: GtkComboBox *combo_box
 * Returns: GtkTreeModel*
 * Assertion: Returns the GtkTreeModel which is acting as data source for combo_box.
 * Params Values: a newly created GtkComboBox*
 * Expected: A GtkTreeModel which was passed during construction.  
 */
static void test_purpose_14()
{
    #define MODEL GTK_TREE_MODEL (gtk_list_store_new (1, G_TYPE_UINT))
    
    GtkWidget *widget;
    GtkTreeModel *model_set;
    GtkTreeModel *model_get;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_combo_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_COMBO_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    model_set = MODEL;
    g_object_set (GTK_OBJECT (widget), "model", model_set, NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    model_get = gtk_combo_box_get_model (GTK_COMBO_BOX (widget));
    
    if (model_set != model_get)
        TEST_FAIL ("The GtkTreeModel acting as data source should be %p, not %p", model_set, model_get, NULL);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MODEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_combo_box_get_model
 * Params: GtkComboBox *combo_box
 * Returns: GtkTreeModel*
 * Assertion: Returns the GtkTreeModel which is acting as data source for combo_box.
 * Params Values: a newly created GtkComboBox*
 * Expected: A GtkTreeModel which was passed during construction.  
 */
static void test_purpose_15()
{
    #define MODEL GTK_TREE_MODEL (gtk_list_store_new (1, G_TYPE_STRING))
    
    GtkWidget *widget;
    GtkTreeModel *model_set;
    GtkTreeModel *model_get;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_combo_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_COMBO_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    model_set = MODEL;
    g_object_set (GTK_OBJECT (widget), "model", model_set, NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    model_get = gtk_combo_box_get_model (GTK_COMBO_BOX (widget));
    
    if (model_set != model_get)
        TEST_FAIL ("The GtkTreeModel acting as data source should be %p, not %p", model_set, model_get, NULL);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MODEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_combo_box_get_model
 * Params: GtkComboBox *combo_box
 * Returns: GtkTreeModel*
 * Assertion: Returns the GtkTreeModel which is acting as data source for combo_box.
 * Params Values: a newly created GtkComboBox*
 * Expected: A GtkTreeModel which was passed during construction.  
 */
static void test_purpose_16()
{
    #define MODEL GTK_TREE_MODEL (gtk_list_store_new (2, G_TYPE_UINT, G_TYPE_STRING))
    
    GtkWidget *widget;
    GtkTreeModel *model_set;
    GtkTreeModel *model_get;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_combo_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_COMBO_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    model_set = MODEL;
    g_object_set (GTK_OBJECT (widget), "model", model_set, NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    model_get = gtk_combo_box_get_model (GTK_COMBO_BOX (widget));
    
    if (model_set != model_get)
        TEST_FAIL ("The GtkTreeModel acting as data source should be %p, not %p", model_set, model_get, NULL);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MODEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_combo_box_get_model
 * Params: GtkComboBox *combo_box
 * Returns: GtkTreeModel*
 * Assertion: Returns the GtkTreeModel which is acting as data source for combo_box.
 * Params Values: a newly created GtkComboBox*
 * Expected: A GtkTreeModel which was passed during construction.  
 */
static void test_purpose_17()
{
    #define MODEL GTK_TREE_MODEL (gtk_tree_store_new (1, G_TYPE_UINT))
    
    GtkWidget *widget;
    GtkTreeModel *model_set;
    GtkTreeModel *model_get;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_combo_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_COMBO_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    model_set = MODEL;
    g_object_set (GTK_OBJECT (widget), "model", model_set, NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    model_get = gtk_combo_box_get_model (GTK_COMBO_BOX (widget));
    
    if (model_set != model_get)
        TEST_FAIL ("The GtkTreeModel acting as data source should be %p, not %p", model_set, model_get, NULL);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MODEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_combo_box_get_model
 * Params: GtkComboBox *combo_box
 * Returns: GtkTreeModel*
 * Assertion: Returns the GtkTreeModel which is acting as data source for combo_box.
 * Params Values: a newly created GtkComboBox*
 * Expected: A GtkTreeModel which was passed during construction.  
 */
static void test_purpose_18()
{
    #define MODEL GTK_TREE_MODEL (gtk_tree_store_new (1, G_TYPE_STRING))
    
    GtkWidget *widget;
    GtkTreeModel *model_set;
    GtkTreeModel *model_get;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_combo_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_COMBO_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    model_set = MODEL;
    g_object_set (GTK_OBJECT (widget), "model", model_set, NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    model_get = gtk_combo_box_get_model (GTK_COMBO_BOX (widget));
    
    if (model_set != model_get)
        TEST_FAIL ("The GtkTreeModel acting as data source should be %p, not %p", model_set, model_get, NULL);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MODEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_combo_box_get_model
 * Params: GtkComboBox *combo_box
 * Returns: GtkTreeModel*
 * Assertion: Returns the GtkTreeModel which is acting as data source for combo_box.
 * Params Values: a newly created GtkComboBox*
 * Expected: A GtkTreeModel which was passed during construction.  
 */
static void test_purpose_19()
{
    #define MODEL GTK_TREE_MODEL (gtk_tree_store_new (2, G_TYPE_UINT, G_TYPE_STRING))
    
    GtkWidget *widget;
    GtkTreeModel *model_set;
    GtkTreeModel *model_get;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_combo_box_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_COMBO_BOX (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    model_set = MODEL;
    g_object_set (GTK_OBJECT (widget), "model", model_set, NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    model_get = gtk_combo_box_get_model (GTK_COMBO_BOX (widget));
    
    if (model_set != model_get)
        TEST_FAIL ("The GtkTreeModel acting as data source should be %p, not %p", model_set, model_get, NULL);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef MODEL
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkComboBox ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {NULL,0}
};
