/*
 * GtkContainer methods tests
 * Testing GtkContainer methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

static gboolean result;
static gint global_count;


void  
global_find (GtkWidget *widget, gpointer data)
{
    if (widget == data)
    {
        result = TRUE;
    }
}  

void  
global_count_children (GtkWidget *widget, gpointer data)
{
    (*((gint*) data))++;
}  

void 
global_list  (gpointer data,  gpointer user_data)
{
    global_count++;
}  


/*
 * Name: gtk_container_set_resize_mode
 * Params: GtkContainer *container, GtkResizeMode resize_mode
 * Returns: void
 * Assertion: Sets the resize mode for the container.
 * Params Values: GtkContainer *container, GTK_RESIZE_PARENT     
 * Expected: void  
 */
static void test_purpose_1()
{
    #define CONTAINER gtk_frame_new ("Label")  
    #define MODE GTK_RESIZE_PARENT     
    
    GtkWidget *widget;
    GtkResizeMode resize_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_resize_mode(GTK_CONTAINER (widget), MODE);
    g_object_get (GTK_OBJECT (widget), "resize-mode", &resize_mode, NULL);
    
    if (resize_mode != MODE)
    {
        TEST_FAIL ("resize mode is %d, should be %d", resize_mode, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef MODE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_set_resize_mode
 * Params: GtkContainer *container, GtkResizeMode resize_mode
 * Returns: void
 * Assertion: Sets the resize mode for the container.
 * Params Values: GtkContainer *container, GTK_RESIZE_QUEUE
 * Expected: void  
 */
static void test_purpose_2()
{
    #define CONTAINER gtk_frame_new ("Label")  
    #define MODE GTK_RESIZE_QUEUE
    
    GtkWidget *widget;
    GtkResizeMode resize_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_resize_mode(GTK_CONTAINER (widget), MODE);
    g_object_get (GTK_OBJECT (widget), "resize-mode", &resize_mode, NULL);
    
    if (resize_mode != MODE)
    {
        TEST_FAIL ("resize mode is %d, should be %d", resize_mode, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef MODE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_set_resize_mode
 * Params: GtkContainer *container, GtkResizeMode resize_mode
 * Returns: void
 * Assertion: Sets the resize mode for the container.
 * Params Values: GtkContainer *container, GTK_RESIZE_IMMEDIATE          
 * Expected: void  
 */
static void test_purpose_3()
{
    #define CONTAINER gtk_frame_new ("Label")  
    #define MODE GTK_RESIZE_IMMEDIATE          
    
    GtkWidget *widget;
    GtkResizeMode resize_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_resize_mode(GTK_CONTAINER (widget), MODE);
    g_object_get (GTK_OBJECT (widget), "resize-mode", &resize_mode, NULL);
    
    if (resize_mode != MODE)
    {
        TEST_FAIL ("resize mode is %d, should be %d", resize_mode, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef MODE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_set_resize_mode
 * Params: GtkContainer *container, GtkResizeMode resize_mode
 * Returns: void
 * Assertion: Sets the resize mode for the container.
 * Params Values: GtkContainer *container, GTK_RESIZE_PARENT     
 * Expected: void  
 */
static void test_purpose_4()
{
    #define CONTAINER gtk_button_new ()  
    #define MODE GTK_RESIZE_PARENT     
    
    GtkWidget *widget;
    GtkResizeMode resize_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_resize_mode(GTK_CONTAINER (widget), MODE);
    g_object_get (GTK_OBJECT (widget), "resize-mode", &resize_mode, NULL);
    
    if (resize_mode != MODE)
    {
        TEST_FAIL ("resize mode is %d, should be %d", resize_mode, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef MODE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_set_resize_mode
 * Params: GtkContainer *container, GtkResizeMode resize_mode
 * Returns: void
 * Assertion: Sets the resize mode for the container.
 * Params Values: GtkContainer *container, GTK_RESIZE_QUEUE
 * Expected: void  
 */
static void test_purpose_5()
{
    #define CONTAINER gtk_window_new (GTK_WINDOW_TOPLEVEL)  
    #define MODE GTK_RESIZE_QUEUE
    
    GtkWidget *widget;
    GtkResizeMode resize_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_resize_mode(GTK_CONTAINER (widget), MODE);
    g_object_get (GTK_OBJECT (widget), "resize-mode", &resize_mode, NULL);
    
    if (resize_mode != MODE)
    {
        TEST_FAIL ("resize mode is %d, should be %d", resize_mode, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef MODE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_resize_mode
 * Params: GtkContainer *container
 * Returns: GtkResizeMode
 * Assertion: Returns the resize mode for the container.
 * Params Values: GtkContainer *container
 * Expected: GTK_RESIZE_PARENT       
 */
static void test_purpose_6()
{
    #define CONTAINER gtk_frame_new ("Label")  
    #define MODE GTK_RESIZE_PARENT     
    
    GtkWidget *widget;
    GtkResizeMode resize_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "resize-mode", MODE, NULL);
    resize_mode = gtk_container_get_resize_mode(GTK_CONTAINER (widget));
    
    if (resize_mode != MODE)
    {
        TEST_FAIL ("resize mode is %d, should be %d", resize_mode, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef MODE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_resize_mode
 * Params: GtkContainer *container
 * Returns: GtkResizeMode
 * Assertion: Returns the resize mode for the container.
 * Params Values: GtkContainer *container
 * Expected: GTK_RESIZE_QUEUE  
 */
static void test_purpose_7()
{
    #define CONTAINER gtk_frame_new ("Label")  
    #define MODE GTK_RESIZE_QUEUE
    
    GtkWidget *widget;
    GtkResizeMode resize_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "resize-mode", MODE, NULL);
    resize_mode = gtk_container_get_resize_mode(GTK_CONTAINER (widget));
    
    if (resize_mode != MODE)
    {
        TEST_FAIL ("resize mode is %d, should be %d", resize_mode, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef MODE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_resize_mode
 * Params: GtkContainer *container
 * Returns: GtkResizeMode
 * Assertion: Returns the resize mode for the container.
 * Params Values: GtkContainer *container
 * Expected: GTK_RESIZE_IMMEDIATE            
 */
static void test_purpose_8()
{
    #define CONTAINER gtk_frame_new ("Label")  
    #define MODE GTK_RESIZE_IMMEDIATE          
    
    GtkWidget *widget;
    GtkResizeMode resize_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "resize-mode", MODE, NULL);
    resize_mode = gtk_container_get_resize_mode(GTK_CONTAINER (widget));
    
    if (resize_mode != MODE)
    {
        TEST_FAIL ("resize mode is %d, should be %d", resize_mode, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef MODE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_resize_mode
 * Params: GtkContainer *container
 * Returns: GtkResizeMode
 * Assertion: Returns the resize mode for the container.
 * Params Values: GtkContainer *container
 * Expected: GTK_RESIZE_PARENT       
 */
static void test_purpose_9()
{
    #define CONTAINER gtk_button_new ()  
    #define MODE GTK_RESIZE_PARENT     
    
    GtkWidget *widget;
    GtkResizeMode resize_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "resize-mode", MODE, NULL);
    resize_mode = gtk_container_get_resize_mode(GTK_CONTAINER (widget));
    
    if (resize_mode != MODE)
    {
        TEST_FAIL ("resize mode is %d, should be %d", resize_mode, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef MODE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_resize_mode
 * Params: GtkContainer *container
 * Returns: GtkResizeMode
 * Assertion: Returns the resize mode for the container.
 * Params Values: GtkContainer *container
 * Expected: GTK_RESIZE_QUEUE  
 */
static void test_purpose_10()
{
    #define CONTAINER gtk_window_new (GTK_WINDOW_TOPLEVEL)  
    #define MODE GTK_RESIZE_QUEUE
    
    GtkWidget *widget;
    GtkResizeMode resize_mode;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "resize-mode", MODE, NULL);
    resize_mode = gtk_container_get_resize_mode(GTK_CONTAINER (widget));
    
    if (resize_mode != MODE)
    {
        TEST_FAIL ("resize mode is %d, should be %d", resize_mode, MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef MODE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_set_reallocate_redraws
 * Params: GtkContainer *container, gboolean needs_redraws
 * Returns: void
 * Assertion: Sets the reallocate_redraws flag of the container to the given value.
 * Params Values: GtkContainer *container, FALSE     
 * Expected: void  
 */
static void test_purpose_11()
{
    #define CONTAINER gtk_frame_new ("Label")  
    #define NEEDS_REDRAWS FALSE     
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_reallocate_redraws(GTK_CONTAINER (widget), NEEDS_REDRAWS);
    if (GTK_CONTAINER (widget)->reallocate_redraws != NEEDS_REDRAWS)
    {
        TEST_FAIL ("reallocate redraws fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef NEEDS_REDRAWS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_set_reallocate_redraws
 * Params: GtkContainer *container, gboolean needs_redraws
 * Returns: void
 * Assertion: Sets the reallocate_redraws flag of the container to the given value.
 * Params Values: GtkContainer *container, TRUE
 * Expected: void  
 */
static void test_purpose_12()
{
    #define CONTAINER gtk_frame_new ("Label")  
    #define NEEDS_REDRAWS TRUE
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_reallocate_redraws(GTK_CONTAINER (widget), NEEDS_REDRAWS);
    if (GTK_CONTAINER (widget)->reallocate_redraws != NEEDS_REDRAWS)
    {
        TEST_FAIL ("reallocate redraws fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef NEEDS_REDRAWS
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_focus_vadjustment
 * Params: GtkContainer *container, GtkAdjustment *adj
 * Returns: GtkAdjustment*
 * Assertion: Retrieves the vertical focus adjustment for the container.
 * Params Values: GtkContainer *container
 * Expected: GtkAdjustment*  
 */
static void test_purpose_13()
{
    #define CONTAINER gtk_frame_new ("Label")  
    #define ADJ GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0))
    
    GtkWidget *widget;
    GtkAdjustment *adj;
    GtkAdjustment *real_adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    adj = GTK_ADJUSTMENT (ADJ);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_focus_vadjustment(GTK_CONTAINER (widget), adj);
    real_adj = gtk_container_get_focus_vadjustment(GTK_CONTAINER (widget));
    
    if (!real_adj)
    {
        TEST_FAIL ("real_adj = NULL", NULL);
    } else {
        if (real_adj->lower != adj->lower)
        {
            TEST_FAIL ("real_adj->lower = %d, adj->lower = %d", 
                       real_adj->lower, adj->lower);
        }
    
        if (real_adj->upper != adj->upper)
        {
            TEST_FAIL ("real_adj->upper = %d, adj->upper = %d", 
                       real_adj->upper, adj->upper);
        }
    
        if (real_adj->value != adj->value)
        {
            TEST_FAIL ("real_adj->value = %d, adj->value = %d", 
                       real_adj->value, adj->value);
        }
    
        if (real_adj->step_increment != adj->step_increment)
        {
            TEST_FAIL ("real_adj->step_increment = %d, adj->step_increment = %d", 
                       real_adj->step_increment, adj->step_increment);
        }
    
        if (real_adj->page_increment != adj->page_increment)
        {
            TEST_FAIL ("real_adj->page_increment = %d, adj->page_increment = %d", 
                       real_adj->page_increment, adj->page_increment);
        }
    
        if (real_adj->page_size != adj->page_size)
        {
            TEST_FAIL ("real_adj->page_size = %d, adj->page_size = %d", 
                       real_adj->page_size, adj->page_size);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef ADJ
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_focus_vadjustment
 * Params: GtkContainer *container, GtkAdjustment *adj
 * Returns: GtkAdjustment*
 * Assertion: Retrieves the vertical focus adjustment for the container.
 * Params Values: GtkContainer *container
 * Expected: GtkAdjustment*  
 */
static void test_purpose_14()
{
    #define CONTAINER gtk_frame_new ("Label")  
    #define ADJ GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 20.0, 5.0, 10.0, 20.0))
    
    GtkWidget *widget;
    GtkAdjustment *adj;
    GtkAdjustment *real_adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    adj = GTK_ADJUSTMENT (ADJ);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_focus_vadjustment(GTK_CONTAINER (widget), adj);
    real_adj = gtk_container_get_focus_vadjustment(GTK_CONTAINER (widget));
    
    if (!real_adj)
    {
        TEST_FAIL ("real_adj = NULL", NULL);
    } else {
        if (real_adj->lower != adj->lower)
        {
            TEST_FAIL ("real_adj->lower = %d, adj->lower = %d", 
                       real_adj->lower, adj->lower);
        }
    
        if (real_adj->upper != adj->upper)
        {
            TEST_FAIL ("real_adj->upper = %d, adj->upper = %d", 
                       real_adj->upper, adj->upper);
        }
    
        if (real_adj->value != adj->value)
        {
            TEST_FAIL ("real_adj->value = %d, adj->value = %d", 
                       real_adj->value, adj->value);
        }
    
        if (real_adj->step_increment != adj->step_increment)
        {
            TEST_FAIL ("real_adj->step_increment = %d, adj->step_increment = %d", 
                       real_adj->step_increment, adj->step_increment);
        }
    
        if (real_adj->page_increment != adj->page_increment)
        {
            TEST_FAIL ("real_adj->page_increment = %d, adj->page_increment = %d", 
                       real_adj->page_increment, adj->page_increment);
        }
    
        if (real_adj->page_size != adj->page_size)
        {
            TEST_FAIL ("real_adj->page_size = %d, adj->page_size = %d", 
                       real_adj->page_size, adj->page_size);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef ADJ
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_focus_hadjustment
 * Params: GtkContainer *container, GtkAdjustment *adj
 * Returns: GtkAdjustment*
 * Assertion: Retrieves the horizontal focus adjustment for the container.
 * Params Values: GtkContainer *container
 * Expected: GtkAdjustment*  
 */
static void test_purpose_15()
{
    #define CONTAINER gtk_frame_new ("Label")  
    #define ADJ GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 2.0, 0.0, 0.0, 0.0))
    
    GtkWidget *widget;
    GtkAdjustment *adj;
    GtkAdjustment *real_adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    adj = GTK_ADJUSTMENT (ADJ);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_focus_hadjustment(GTK_CONTAINER (widget), adj);
    real_adj = gtk_container_get_focus_hadjustment(GTK_CONTAINER (widget));
    
    if (!real_adj)
    {
        TEST_FAIL ("real_adj = NULL", NULL);
    } else {
        if (real_adj->lower != adj->lower)
        {
            TEST_FAIL ("real_adj->lower = %d, adj->lower = %d", 
                       real_adj->lower, adj->lower);
        }
    
        if (real_adj->upper != adj->upper)
        {
            TEST_FAIL ("real_adj->upper = %d, adj->upper = %d", 
                       real_adj->upper, adj->upper);
        }
    
        if (real_adj->value != adj->value)
        {
            TEST_FAIL ("real_adj->value = %d, adj->value = %d", 
                       real_adj->value, adj->value);
        }
    
        if (real_adj->step_increment != adj->step_increment)
        {
            TEST_FAIL ("real_adj->step_increment = %d, adj->step_increment = %d", 
                       real_adj->step_increment, adj->step_increment);
        }
    
        if (real_adj->page_increment != adj->page_increment)
        {
            TEST_FAIL ("real_adj->page_increment = %d, adj->page_increment = %d", 
                       real_adj->page_increment, adj->page_increment);
        }
    
        if (real_adj->page_size != adj->page_size)
        {
            TEST_FAIL ("real_adj->page_size = %d, adj->page_size = %d", 
                       real_adj->page_size, adj->page_size);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef ADJ
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_focus_hadjustment
 * Params: GtkContainer *container, GtkAdjustment *adj
 * Returns: GtkAdjustment*
 * Assertion: Retrieves the horizontal focus adjustment for the container.
 * Params Values: GtkContainer *container
 * Expected: GtkAdjustment*  
 */
static void test_purpose_16()
{
    #define CONTAINER gtk_frame_new ("Label")  
    #define ADJ GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 0.0, 20.0, 5.0, 10.0, 20.0))
    
    GtkWidget *widget;
    GtkAdjustment *adj;
    GtkAdjustment *real_adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    adj = GTK_ADJUSTMENT (ADJ);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_focus_hadjustment(GTK_CONTAINER (widget), adj);
    real_adj = gtk_container_get_focus_hadjustment(GTK_CONTAINER (widget));
    
    if (!real_adj)
    {
        TEST_FAIL ("real_adj = NULL", NULL);
    } else {
        if (real_adj->lower != adj->lower)
        {
            TEST_FAIL ("real_adj->lower = %d, adj->lower = %d", 
                       real_adj->lower, adj->lower);
        }
    
        if (real_adj->upper != adj->upper)
        {
            TEST_FAIL ("real_adj->upper = %d, adj->upper = %d", 
                       real_adj->upper, adj->upper);
        }
    
        if (real_adj->value != adj->value)
        {
            TEST_FAIL ("real_adj->value = %d, adj->value = %d", 
                       real_adj->value, adj->value);
        }
    
        if (real_adj->step_increment != adj->step_increment)
        {
            TEST_FAIL ("real_adj->step_increment = %d, adj->step_increment = %d", 
                       real_adj->step_increment, adj->step_increment);
        }
    
        if (real_adj->page_increment != adj->page_increment)
        {
            TEST_FAIL ("real_adj->page_increment = %d, adj->page_increment = %d", 
                       real_adj->page_increment, adj->page_increment);
        }
    
        if (real_adj->page_size != adj->page_size)
        {
            TEST_FAIL ("real_adj->page_size = %d, adj->page_size = %d", 
                       real_adj->page_size, adj->page_size);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef ADJ
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_set_border_width
 * Params: GtkContainer *container, guint width
 * Returns: void
 * Assertion:  Sets the border width of the container.
 * Params Values: GtkContainer *container, 0     
 * Expected: void  
 */
static void test_purpose_17()
{
    #define CONTAINER gtk_frame_new ("Label")  
    #define WIDTH 0     
    
    GtkWidget *widget;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_border_width(GTK_CONTAINER (widget), WIDTH);
    g_object_get (GTK_OBJECT (widget), "border-width", &width, NULL);
    
    if (width != WIDTH)
    {
        TEST_FAIL ("border width = is %d, should be %d", width, WIDTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef WIDTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_set_border_width
 * Params: GtkContainer *container, guint width
 * Returns: void
 * Assertion:  Sets the border width of the container.
 * Params Values: GtkContainer *container, 10     
 * Expected: void  
 */
static void test_purpose_18()
{
    #define CONTAINER gtk_frame_new ("Label")  
    #define WIDTH 10     
    
    GtkWidget *widget;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_border_width(GTK_CONTAINER (widget), WIDTH);
    g_object_get (GTK_OBJECT (widget), "border-width", &width, NULL);
    
    if (width != WIDTH)
    {
        TEST_FAIL ("border width = is %d, should be %d", width, WIDTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef WIDTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_set_border_width
 * Params: GtkContainer *container, guint width
 * Returns: void
 * Assertion:  Sets the border width of the container.
 * Params Values: GtkContainer *container, 1000     
 * Expected: void  
 */
static void test_purpose_19()
{
    #define CONTAINER gtk_frame_new ("Label")  
    #define WIDTH 1000     
    
    GtkWidget *widget;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_border_width(GTK_CONTAINER (widget), WIDTH);
    g_object_get (GTK_OBJECT (widget), "border-width", &width, NULL);
    
    if (width != WIDTH)
    {
        TEST_FAIL ("border width = is %d, should be %d", width, WIDTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef WIDTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_set_border_width
 * Params: GtkContainer *container, guint width
 * Returns: void
 * Assertion:  Sets the border width of the container.
 * Params Values: GtkContainer *container, 0     
 * Expected: void  
 */
static void test_purpose_20()
{
    #define CONTAINER gtk_button_new ()  
    #define WIDTH 0     
    
    GtkWidget *widget;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_border_width(GTK_CONTAINER (widget), WIDTH);
    g_object_get (GTK_OBJECT (widget), "border-width", &width, NULL);
    
    if (width != WIDTH)
    {
        TEST_FAIL ("border width = is %d, should be %d", width, WIDTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef WIDTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_set_border_width
 * Params: GtkContainer *container, guint width
 * Returns: void
 * Assertion:  Sets the border width of the container.
 * Params Values: GtkContainer *container, 10     
 * Expected: void  
 */
static void test_purpose_21()
{
    #define CONTAINER gtk_button_new ()  
    #define WIDTH 10     
    
    GtkWidget *widget;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_border_width(GTK_CONTAINER (widget), WIDTH);
    g_object_get (GTK_OBJECT (widget), "border-width", &width, NULL);
    
    if (width != WIDTH)
    {
        TEST_FAIL ("border width = is %d, should be %d", width, WIDTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef WIDTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_set_border_width
 * Params: GtkContainer *container, guint width
 * Returns: void
 * Assertion:  Sets the border width of the container.
 * Params Values: GtkContainer *container, 1000
 * Expected: void  
 */
static void test_purpose_22()
{
    #define CONTAINER gtk_button_new ()  
    #define WIDTH 1000
    
    GtkWidget *widget;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_border_width(GTK_CONTAINER (widget), WIDTH);
    g_object_get (GTK_OBJECT (widget), "border-width", &width, NULL);
    
    if (width != WIDTH)
    {
        TEST_FAIL ("border width = is %d, should be %d", width, WIDTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef WIDTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_set_border_width
 * Params: GtkContainer *container, guint width
 * Returns: void
 * Assertion:  Sets the border width of the container.
 * Params Values: GtkContainer *container, 0     
 * Expected: void  
 */
static void test_purpose_23()
{
    #define CONTAINER gtk_button_new ()  
    #define WIDTH 0     
    
    GtkWidget *widget;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_border_width(GTK_CONTAINER (widget), WIDTH);
    g_object_get (GTK_OBJECT (widget), "border-width", &width, NULL);
    
    if (width != WIDTH)
    {
        TEST_FAIL ("border width = is %d, should be %d", width, WIDTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef WIDTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_set_border_width
 * Params: GtkContainer *container, guint width
 * Returns: void
 * Assertion:  Sets the border width of the container.
 * Params Values: GtkContainer *container, 10
 * Expected: void  
 */
static void test_purpose_24()
{
    #define CONTAINER gtk_button_new ()  
    #define WIDTH 10
    
    GtkWidget *widget;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_border_width(GTK_CONTAINER (widget), WIDTH);
    g_object_get (GTK_OBJECT (widget), "border-width", &width, NULL);
    
    if (width != WIDTH)
    {
        TEST_FAIL ("border width = is %d, should be %d", width, WIDTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef WIDTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_set_border_width
 * Params: GtkContainer *container, guint width
 * Returns: void
 * Assertion:  Sets the border width of the container.
 * Params Values: GtkContainer *container, 1000
 * Expected: void  
 */
static void test_purpose_25()
{
    #define CONTAINER gtk_button_new ()  
    #define WIDTH 1000
    
    GtkWidget *widget;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_border_width(GTK_CONTAINER (widget), WIDTH);
    g_object_get (GTK_OBJECT (widget), "border-width", &width, NULL);
    
    if (width != WIDTH)
    {
        TEST_FAIL ("border width = is %d, should be %d", width, WIDTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef WIDTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_border_width
 * Params: GtkContainer *container
 * Returns: guint
 * Assertion: Retrieves the border width of the container.
 * Params Values: GtkContainer *container
 * Expected: 0       
 */
static void test_purpose_26()
{
    #define CONTAINER gtk_frame_new ("Label")  
    #define WIDTH 0     
    
    GtkWidget *widget;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "border-width", WIDTH, NULL);
    width = gtk_container_get_border_width (GTK_CONTAINER (widget));
    
    if (width != WIDTH)
    {
        TEST_FAIL ("border width = is %d, should be %d", width, WIDTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef WIDTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_border_width
 * Params: GtkContainer *container
 * Returns: guint
 * Assertion: Retrieves the border width of the container.
 * Params Values: GtkContainer *container
 * Expected: 10       
 */
static void test_purpose_27()
{
    #define CONTAINER gtk_frame_new ("Label")  
    #define WIDTH 10     
    
    GtkWidget *widget;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "border-width", WIDTH, NULL);
    width = gtk_container_get_border_width (GTK_CONTAINER (widget));
    
    if (width != WIDTH)
    {
        TEST_FAIL ("border width = is %d, should be %d", width, WIDTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef WIDTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_border_width
 * Params: GtkContainer *container
 * Returns: guint
 * Assertion: Retrieves the border width of the container.
 * Params Values: GtkContainer *container
 * Expected: 1000       
 */
static void test_purpose_28()
{
    #define CONTAINER gtk_frame_new ("Label")  
    #define WIDTH 1000     
    
    GtkWidget *widget;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "border-width", WIDTH, NULL);
    width = gtk_container_get_border_width (GTK_CONTAINER (widget));
    
    if (width != WIDTH)
    {
        TEST_FAIL ("border width = is %d, should be %d", width, WIDTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef WIDTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_border_width
 * Params: GtkContainer *container
 * Returns: guint
 * Assertion: Retrieves the border width of the container.
 * Params Values: GtkContainer *container
 * Expected: 0       
 */
static void test_purpose_29()
{
    #define CONTAINER gtk_button_new ()  
    #define WIDTH 0     
    
    GtkWidget *widget;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "border-width", WIDTH, NULL);
    width = gtk_container_get_border_width (GTK_CONTAINER (widget));
    
    if (width != WIDTH)
    {
        TEST_FAIL ("border width = is %d, should be %d", width, WIDTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef WIDTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_border_width
 * Params: GtkContainer *container
 * Returns: guint
 * Assertion: Retrieves the border width of the container.
 * Params Values: GtkContainer *container
 * Expected: 10       
 */
static void test_purpose_30()
{
    #define CONTAINER gtk_button_new ()  
    #define WIDTH 10     
    
    GtkWidget *widget;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "border-width", WIDTH, NULL);
    width = gtk_container_get_border_width (GTK_CONTAINER (widget));
    
    if (width != WIDTH)
    {
        TEST_FAIL ("border width = is %d, should be %d", width, WIDTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef WIDTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_border_width
 * Params: GtkContainer *container
 * Returns: guint
 * Assertion: Retrieves the border width of the container.
 * Params Values: GtkContainer *container
 * Expected: 1000  
 */
static void test_purpose_31()
{
    #define CONTAINER gtk_button_new ()  
    #define WIDTH 1000
    
    GtkWidget *widget;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "border-width", WIDTH, NULL);
    width = gtk_container_get_border_width (GTK_CONTAINER (widget));
    
    if (width != WIDTH)
    {
        TEST_FAIL ("border width = is %d, should be %d", width, WIDTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef WIDTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_border_width
 * Params: GtkContainer *container
 * Returns: guint
 * Assertion: Retrieves the border width of the container.
 * Params Values: GtkContainer *container
 * Expected: 0       
 */
static void test_purpose_32()
{
    #define CONTAINER gtk_button_new ()  
    #define WIDTH 0     
    
    GtkWidget *widget;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "border-width", WIDTH, NULL);
    width = gtk_container_get_border_width (GTK_CONTAINER (widget));
    
    if (width != WIDTH)
    {
        TEST_FAIL ("border width = is %d, should be %d", width, WIDTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef WIDTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_border_width
 * Params: GtkContainer *container
 * Returns: guint
 * Assertion: Retrieves the border width of the container.
 * Params Values: GtkContainer *container
 * Expected: 10  
 */
static void test_purpose_33()
{
    #define CONTAINER gtk_button_new ()  
    #define WIDTH 10
    
    GtkWidget *widget;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "border-width", WIDTH, NULL);
    width = gtk_container_get_border_width (GTK_CONTAINER (widget));
    
    if (width != WIDTH)
    {
        TEST_FAIL ("border width = is %d, should be %d", width, WIDTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef WIDTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_border_width
 * Params: GtkContainer *container
 * Returns: guint
 * Assertion: Retrieves the border width of the container.
 * Params Values: GtkContainer *container
 * Expected: 1000  
 */
static void test_purpose_34()
{
    #define CONTAINER gtk_button_new ()  
    #define WIDTH 1000
    
    GtkWidget *widget;
    gint width;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "border-width", WIDTH, NULL);
    width = gtk_container_get_border_width (GTK_CONTAINER (widget));
    
    if (width != WIDTH)
    {
        TEST_FAIL ("border width = is %d, should be %d", width, WIDTH);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef WIDTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_container_add
 * Params: GtkContainer *container, GtkWidget *widget
 * Returns: void
 * Assertion: Adds widget to container.
 * Params Values: newly created GtkContainer*, newly created GtkWidget*
 * Expected: void  
 */
static void test_purpose_35()
{
    #define CONTAINER gtk_vbox_new (TRUE, 10)
    #define WIDGET gtk_button_new ()
    
    GtkWidget* container;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    container = CONTAINER;
    if (!container)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (container))
    {
        TEST_FAIL ("CONTAINER is not GTK_CONTAINER", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_container_add (GTK_CONTAINER (container), gtk_label_new ("Label1"));
    gtk_container_add (GTK_CONTAINER (container), gtk_label_new ("Label2"));
    gtk_container_add (GTK_CONTAINER (container), widget);
    
    gtk_container_foreach (GTK_CONTAINER (container), global_find, widget);
    if (!result)
    {
        TEST_FAIL ("'widget' is not added to 'container'", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER 
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_container_remove
 * Params: GtkContainer *container, GtkWidget *widget
 * Returns: void
 * Assertion: Removes widget from container.
 * Params Values: newly created GtkContainer*, GtkWidget* that is container child
 * Expected: void  
 */
static void test_purpose_36()
{
    #define CONTAINER gtk_vbox_new (TRUE, 10)
    #define WIDGET gtk_button_new ()
    
    GtkWidget* container;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    result = FALSE;
    container = CONTAINER;
    if (!container)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (container))
    {
        TEST_FAIL ("CONTAINER is not GTK_CONTAINER", NULL); 
        return;
    } 
    
    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    gtk_container_add (GTK_CONTAINER (container), gtk_label_new ("Label1"));
    gtk_container_add (GTK_CONTAINER (container), gtk_label_new ("Label2"));
    gtk_container_add (GTK_CONTAINER (container), widget);
    
    gtk_container_remove (GTK_CONTAINER (container), widget);
    gtk_container_foreach (GTK_CONTAINER (container), global_find, widget);
    if (result)
    {
        TEST_FAIL ("'widget' was not removed from 'container'", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (container));
    
    #undef CONTAINER 
    #undef WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_container_foreach
 * Params: GtkContainer *container, GtkCallback callback, gpointer callback_data
 * Returns: void
 * Assertion: Invokes callback on each non-internal child of container.
 * Params Values: newly created GtkContainer*, global_count_children, n_children
 * Expected: void  
 */
static void test_purpose_37()
{
    #define CONTAINER gtk_vbox_new (TRUE, 10)
    #define N_CHILDREN 0
    
    GtkWidget* container;
    gint i;
    gint n_children = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    container = CONTAINER;
    if (!container)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (container))
    {
        TEST_FAIL ("CONTAINER is not GTK_CONTAINER", NULL); 
        return;
    } 
    
    for (i = 0; i < N_CHILDREN; i++)
    {
        gtk_container_add (GTK_CONTAINER (container), gtk_frame_new ("Label"));
    }
    
    gtk_container_foreach (GTK_CONTAINER (container), global_count_children, &n_children);
    if (n_children != N_CHILDREN)
    {
        TEST_FAIL ("Invoke callback %i times instead of %i", n_children, N_CHILDREN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (container));
    
    #undef CONTAINER 
    #undef N_CHILDREN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_container_foreach
 * Params: GtkContainer *container, GtkCallback callback, gpointer callback_data
 * Returns: void
 * Assertion: Invokes callback on each non-internal child of container.
 * Params Values: newly created GtkContainer*, global_count_children, n_children
 * Expected: void  
 */
static void test_purpose_38()
{
    #define CONTAINER gtk_vbox_new (TRUE, 10)
    #define N_CHILDREN 7
    
    GtkWidget* container;
    gint i;
    gint n_children = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    container = CONTAINER;
    if (!container)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (container))
    {
        TEST_FAIL ("CONTAINER is not GTK_CONTAINER", NULL); 
        return;
    } 
    
    for (i = 0; i < N_CHILDREN; i++)
    {
        gtk_container_add (GTK_CONTAINER (container), gtk_frame_new ("Label"));
    }
    
    gtk_container_foreach (GTK_CONTAINER (container), global_count_children, &n_children);
    if (n_children != N_CHILDREN)
    {
        TEST_FAIL ("Invoke callback %i times instead of %i", n_children, N_CHILDREN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (container));
    
    #undef CONTAINER 
    #undef N_CHILDREN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_container_forall
 * Params: GtkContainer *container, GtkCallback callback, gpointer callback_data
 * Returns: void
 * Assertion: Invokes callback on each child of container, including children that are considered "internal" (implementation details of the container). 
 * Params Values: newly created GtkContainer*, global_count_children, n_children
 * Expected: void  
 */
static void test_purpose_39()
{
    #define CONTAINER gtk_vbox_new (TRUE, 10)
    #define N_CHILDREN 0
    
    GtkWidget* container;
    gint i;
    gint n_children = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    container = CONTAINER;
    if (!container)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (container))
    {
        TEST_FAIL ("CONTAINER is not GTK_CONTAINER", NULL); 
        return;
    } 
    
    for (i = 0; i < N_CHILDREN; i++)
    {
        gtk_container_add (GTK_CONTAINER (container), gtk_frame_new ("Label"));
    }
    
    gtk_container_forall (GTK_CONTAINER (container), global_count_children, &n_children);
    if (n_children != N_CHILDREN)
    {
        TEST_FAIL ("Invoke callback %i times instead of %i", n_children, N_CHILDREN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (container));
    
    #undef CONTAINER 
    #undef N_CHILDREN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_container_forall
 * Params: GtkContainer *container, GtkCallback callback, gpointer callback_data
 * Returns: void
 * Assertion: Invokes callback on each child of container, including children that are considered "internal" (implementation details of the container). 
 * Params Values: newly created GtkContainer*, global_count_children, n_children
 * Expected: void  
 */
static void test_purpose_40()
{
    #define CONTAINER gtk_vbox_new (TRUE, 10)
    #define N_CHILDREN 7
    
    GtkWidget* container;
    gint i;
    gint n_children = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    container = CONTAINER;
    if (!container)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_CONTAINER (container))
    {
        TEST_FAIL ("CONTAINER is not GTK_CONTAINER", NULL); 
        return;
    } 
    
    for (i = 0; i < N_CHILDREN; i++)
    {
        gtk_container_add (GTK_CONTAINER (container), gtk_frame_new ("Label"));
    }
    
    gtk_container_forall (GTK_CONTAINER (container), global_count_children, &n_children);
    if (n_children != N_CHILDREN)
    {
        TEST_FAIL ("Invoke callback %i times instead of %i", n_children, N_CHILDREN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (container);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (container));
    
    #undef CONTAINER 
    #undef N_CHILDREN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_children
 * Params: GtkContainer *container
 * Returns: GList*
 * Assertion: Returns the the container's non-internal children.'
 * Params Values: GtkContainer *container
 * Expected: GList*
 *   
 */
static void test_purpose_41()
{
    #define CONTAINER gtk_window_new (GTK_WINDOW_TOPLEVEL)  
    #define CHILD gtk_label_new ("Label")
    #define COUNT 1     
    
    GtkWidget *widget;
    GList *list;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    /* Must initialize list to NULL before first use */
    list = NULL;
    
    global_count = 0;
    widget = CONTAINER;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    for (i = 0; i < COUNT; i++)
    {
        gtk_container_add (GTK_CONTAINER (widget), CHILD);
    }
    
    list = gtk_container_get_children (GTK_CONTAINER (widget));
    
    g_list_foreach (list, global_list, NULL);
    
    if (global_count != COUNT)
    {
        TEST_FAIL ("global_count = %i, should be %i", global_count, COUNT);
    };
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    g_list_free (list);
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef CHILD
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_children
 * Params: GtkContainer *container
 * Returns: GList*
 * Assertion: Returns the the container's non-internal children.'
 * Params Values: GtkContainer *container
 * Expected: GList*
 *   
 */
static void test_purpose_42()
{
    #define CONTAINER gtk_window_new (GTK_WINDOW_TOPLEVEL)  
    #define CHILD gtk_button_new ()
    #define COUNT 1     
    
    GtkWidget *widget;
    GList *list;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    /* Must initialize list to NULL before first use */
    list = NULL;
    
    global_count = 0;
    widget = CONTAINER;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    for (i = 0; i < COUNT; i++)
    {
        gtk_container_add (GTK_CONTAINER (widget), CHILD);
    }
    
    list = gtk_container_get_children (GTK_CONTAINER (widget));
    
    g_list_foreach (list, global_list, NULL);
    
    if (global_count != COUNT)
    {
        TEST_FAIL ("global_count = %i, should be %i", global_count, COUNT);
    };
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    g_list_free (list);
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef CHILD
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_children
 * Params: GtkContainer *container
 * Returns: GList*
 * Assertion: Returns the the container's non-internal children.'
 * Params Values: GtkContainer *container
 * Expected: GList*
 *   
 */
static void test_purpose_43()
{
    #define CONTAINER gtk_vbutton_box_new ()
    #define CHILD gtk_button_new ()
    #define COUNT 10     
    
    GtkWidget *widget;
    GList *list;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    /* Must initialize list to NULL before first use */
    list = NULL;
    
    global_count = 0;
    widget = CONTAINER;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    for (i = 0; i < COUNT; i++)
    {
        gtk_container_add (GTK_CONTAINER (widget), CHILD);
    }
    
    list = gtk_container_get_children (GTK_CONTAINER (widget));
    
    g_list_foreach (list, global_list, NULL);
    
    if (global_count != COUNT)
    {
        TEST_FAIL ("global_count = %i, should be %i", global_count, COUNT);
    };
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    g_list_free (list);
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef CHILD
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_propagate_expose
 * Params: GtkContainer *container, GtkWidget *child, GdkEventExpose *event
 * Returns: void
 * Assertion: A container, when it receives an expose event, calls gtk_container_propagate_expose() once for each child, passing in the event the container received.
 * Params Values: GtkContainer *container, GtkWidget *child, GdkEventExpose *event
 * Expected: void  
 */
static void test_purpose_44()
{
    #define CONTAINER gtk_window_new (GTK_WINDOW_TOPLEVEL)  
    #define CHILD gtk_vbox_new (TRUE, 20)
    
    GtkWidget *widget;
    GtkWidget *child;
    GdkEventExpose event;
    GdkRectangle rect = {0, 0, 200, 100};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    widget = CONTAINER;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    child = CHILD;
    if (!child)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    g_signal_connect (G_OBJECT (child), "expose-event", GTK_SIGNAL_FUNC (global_list), NULL);  
    
    event.type = GDK_EXPOSE;
    event.window = child->window;
    event.area = rect;
    event.region = gdk_region_rectangle (&rect);;
    
    gtk_container_propagate_expose (GTK_CONTAINER (widget), child, &event);
    
    if (!global_count)
    {
        if (GTK_WIDGET_DRAWABLE (child) && GTK_WIDGET_NO_WINDOW (child))
            TEST_FAIL ("global_count = %i", global_count);
    };
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_propagate_expose
 * Params: GtkContainer *container, GtkWidget *child, GdkEventExpose *event
 * Returns: void
 * Assertion: A container, when it receives an expose event, calls gtk_container_propagate_expose() once for each child, passing in the event the container received.
 * Params Values: GtkContainer *container, GtkWidget *child, GdkEventExpose *event
 * Expected: void  
 */
static void test_purpose_45()
{
    #define CONTAINER gtk_window_new (GTK_WINDOW_TOPLEVEL)  
    #define CHILD gtk_label_new ("Label")
    
    GtkWidget *widget;
    GtkWidget *child;
    GdkEventExpose event;
    GdkRectangle rect = {0, 0, 200, 100};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    widget = CONTAINER;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    child = CHILD;
    if (!child)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    g_signal_connect (G_OBJECT (child), "expose-event", GTK_SIGNAL_FUNC (global_list), NULL);  
    
    event.type = GDK_EXPOSE;
    event.window = child->window;
    event.area = rect;
    event.region = gdk_region_rectangle (&rect);;
    
    gtk_container_propagate_expose (GTK_CONTAINER (widget), child, &event);
    
    if (!global_count)
    {
        if (GTK_WIDGET_DRAWABLE (child) && GTK_WIDGET_NO_WINDOW (child))
            TEST_FAIL ("global_count = %i", global_count);
    };
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_propagate_expose
 * Params: GtkContainer *container, GtkWidget *child, GdkEventExpose *event
 * Returns: void
 * Assertion: A container, when it receives an expose event, calls gtk_container_propagate_expose() once for each child, passing in the event the container received.
 * Params Values: GtkContainer *container, GtkWidget *child, GdkEventExpose *event
 * Expected: void  
 */
static void test_purpose_46()
{
    #define CONTAINER gtk_vbutton_box_new ()
    #define CHILD gtk_button_new ()
    
    GtkWidget *widget;
    GtkWidget *child;
    GdkEventExpose event;
    GdkRectangle rect = {0, 0, 200, 100};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    widget = CONTAINER;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    child = CHILD;
    if (!child)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    g_signal_connect (G_OBJECT (child), "expose-event", GTK_SIGNAL_FUNC (global_list), NULL);  
    
    event.type = GDK_EXPOSE;
    event.window = child->window;
    event.area = rect;
    event.region = gdk_region_rectangle (&rect);;
    
    gtk_container_propagate_expose (GTK_CONTAINER (widget), child, &event);
    
    if (!global_count)
    {
        if (GTK_WIDGET_DRAWABLE (child) && GTK_WIDGET_NO_WINDOW (child))
            TEST_FAIL ("global_count = %i", global_count);
    };
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_propagate_expose
 * Params: GtkContainer *container, GtkWidget *child, GdkEventExpose *event
 * Returns: void
 * Assertion: A container, when it receives an expose event, calls gtk_container_propagate_expose() once for each child, passing in the event the container received.
 * Params Values: GtkContainer *container, GtkWidget *child, GdkEventExpose *event
 * Expected: void  
 */
static void test_purpose_47()
{
    #define CONTAINER gtk_window_new (GTK_WINDOW_TOPLEVEL)  
    #define CHILD gtk_frame_new ("fr")
    
    GtkWidget *widget;
    GtkWidget *child;
    GdkEventExpose event;
    GdkRectangle rect = {0, 0, 200, 100};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    widget = CONTAINER;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    child = CHILD;
    if (!child)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    g_signal_connect (G_OBJECT (child), "expose-event", GTK_SIGNAL_FUNC (global_list), NULL);  
    
    event.type = GDK_EXPOSE;
    event.window = child->window;
    event.area = rect;
    event.region = gdk_region_rectangle (&rect);;
    
    gtk_container_propagate_expose (GTK_CONTAINER (widget), child, &event);
    
    if (!global_count)
    {
        if (GTK_WIDGET_DRAWABLE (child) && GTK_WIDGET_NO_WINDOW (child))
            TEST_FAIL ("global_count = %i", global_count);
    };
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_propagate_expose
 * Params: GtkContainer *container, GtkWidget *child, GdkEventExpose *event
 * Returns: void
 * Assertion: A container, when it receives an expose event, calls gtk_container_propagate_expose() once for each child, passing in the event the container received.
 * Params Values: GtkContainer *container, GtkWidget *child, GdkEventExpose *event
 * Expected: void  
 */
static void test_purpose_48()
{
    #define CONTAINER gtk_hbutton_box_new ()
    #define CHILD gtk_button_new_with_label ("Button")
    
    GtkWidget *widget;
    GtkWidget *child;
    GdkEventExpose event;
    GdkRectangle rect = {0, 0, 200, 100};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    widget = CONTAINER;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    child = CHILD;
    if (!child)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    g_signal_connect (G_OBJECT (child), "expose-event", GTK_SIGNAL_FUNC (global_list), NULL);  
    
    event.type = GDK_EXPOSE;
    event.window = child->window;
    event.area = rect;
    event.region = gdk_region_rectangle (&rect);;
    
    gtk_container_propagate_expose (GTK_CONTAINER (widget), child, &event);
    
    if (!global_count)
    {
        if (GTK_WIDGET_DRAWABLE (child) && GTK_WIDGET_NO_WINDOW (child))
            TEST_FAIL ("global_count = %i", global_count);
    };
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_propagate_expose
 * Params: GtkContainer *container, GtkWidget *child, GdkEventExpose *event
 * Returns: void
 * Assertion: A container, when it receives an expose event, calls gtk_container_propagate_expose() once for each child, passing in the event the container received.
 * Params Values: GtkContainer *container, GtkWidget *child, GdkEventExpose *event
 * Expected: void  
 */
static void test_purpose_49()
{
    #define CONTAINER gtk_window_new (GTK_WINDOW_POPUP)  
    #define CHILD gtk_label_new ("label")
    
    GtkWidget *widget;
    GtkWidget *child;
    GdkEventExpose event;
    GdkRectangle rect = {0, 0, 200, 100};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    widget = CONTAINER;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    child = CHILD;
    if (!child)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    g_signal_connect (G_OBJECT (child), "expose-event", GTK_SIGNAL_FUNC (global_list), NULL);  
    
    event.type = GDK_EXPOSE;
    event.window = child->window;
    event.area = rect;
    event.region = gdk_region_rectangle (&rect);;
    
    gtk_container_propagate_expose (GTK_CONTAINER (widget), child, &event);
    
    if (!global_count)
    {
        if (GTK_WIDGET_DRAWABLE (child) && GTK_WIDGET_NO_WINDOW (child))
            TEST_FAIL ("global_count = %i", global_count);
    };
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_propagate_expose
 * Params: GtkContainer *container, GtkWidget *child, GdkEventExpose *event
 * Returns: void
 * Assertion: A container, when it receives an expose event, calls gtk_container_propagate_expose() once for each child, passing in the event the container received.
 * Params Values: GtkContainer *container, GtkWidget *child, GdkEventExpose *event
 * Expected: void  
 */
static void test_purpose_50()
{
    #define CONTAINER gtk_window_new (GTK_WINDOW_TOPLEVEL)  
    #define CHILD gtk_hscale_new_with_range (0, 10, 1)
    
    GtkWidget *widget;
    GtkWidget *child;
    GdkEventExpose event;
    GdkRectangle rect = {0, 0, 200, 100};
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_count = 0;
    widget = CONTAINER;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    child = CHILD;
    if (!child)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    g_signal_connect (G_OBJECT (child), "expose-event", GTK_SIGNAL_FUNC (global_list), NULL);  
    
    event.type = GDK_EXPOSE;
    event.window = child->window;
    event.area = rect;
    event.region = gdk_region_rectangle (&rect);;
    
    gtk_container_propagate_expose (GTK_CONTAINER (widget), child, &event);
    
    if (!global_count)
    {
        if (GTK_WIDGET_DRAWABLE (child) && GTK_WIDGET_NO_WINDOW (child))
            TEST_FAIL ("global_count = %i", global_count);
    };
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_child_type
 * Params: GtkContainer *container
 * Returns: GType
 * Assertion: Returns the type of the children supported by the container.
 * Params Values: GtkContainer *container
 * Expected: GTK_TYPE_WIDGET
 * 
 * Name: gtk_container_child_type
 * Params: GtkContainer *container
 * Returns: GType
 * Assertion: Note that this may return G_TYPE_NONE to indicate that no more children can be added, e.g. for a GtkPaned which already has two children.
 * Params Values: GtkContainer *container
 * Expected: GTK_TYPE_WIDGET  
 */
static void test_purpose_51()
{
    #define CONTAINER gtk_window_new (GTK_WINDOW_TOPLEVEL)  
    #define TYPE GTK_TYPE_WIDGET
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (gtk_container_child_type (GTK_CONTAINER (widget)) != TYPE)
    {
        TEST_FAIL ("Type = %i, should be %i ", gtk_container_child_type (GTK_CONTAINER (widget)), TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_child_type
 * Params: GtkContainer *container
 * Returns: GType
 * Assertion: Returns the type of the children supported by the container.
 * Params Values: GtkContainer *container
 * Expected: GTK_TYPE_WIDGET     
 * 
 * Name: gtk_container_child_type
 * Params: GtkContainer *container
 * Returns: GType
 * Assertion: Note that this may return G_TYPE_NONE to indicate that no more children can be added, e.g. for a GtkPaned which already has two children.
 * Params Values: GtkContainer *container
 * Expected: GTK_TYPE_WIDGET       
 */
static void test_purpose_52()
{
    #define CONTAINER gtk_vbox_new (TRUE, 10)  
    #define TYPE GTK_TYPE_WIDGET     
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (gtk_container_child_type (GTK_CONTAINER (widget)) != TYPE)
    {
        TEST_FAIL ("Type = %i, should be %i ", gtk_container_child_type (GTK_CONTAINER (widget)), TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_child_type
 * Params: GtkContainer *container
 * Returns: GType
 * Assertion: Returns the type of the children supported by the container.
 * Params Values: GtkContainer *container
 * Expected: GTK_TYPE_WIDGET     
 * 
 * Name: gtk_container_child_type
 * Params: GtkContainer *container
 * Returns: GType
 * Assertion: Note that this may return G_TYPE_NONE to indicate that no more children can be added, e.g. for a GtkPaned which already has two children.
 * Params Values: GtkContainer *container
 * Expected: GTK_TYPE_WIDGET       
 */
static void test_purpose_53()
{
    #define CONTAINER gtk_hbox_new (FALSE, 10)  
    #define TYPE GTK_TYPE_WIDGET     
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (gtk_container_child_type (GTK_CONTAINER (widget)) != TYPE)
    {
        TEST_FAIL ("Type = %i, should be %i ", gtk_container_child_type (GTK_CONTAINER (widget)), TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_child_type
 * Params: GtkContainer *container
 * Returns: GType
 * Assertion: Returns the type of the children supported by the container.
 * Params Values: GtkContainer *container
 * Expected: GTK_TYPE_WIDGET
 * 
 * Name: gtk_container_child_type
 * Params: GtkContainer *container
 * Returns: GType
 * Assertion: Note that this may return G_TYPE_NONE to indicate that no more children can be added, e.g. for a GtkPaned which already has two children.
 * Params Values: GtkContainer *container
 * Expected: GTK_TYPE_WIDGET  
 */
static void test_purpose_54()
{
    #define CONTAINER gtk_hbutton_box_new ()  
    #define TYPE GTK_TYPE_WIDGET
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (gtk_container_child_type (GTK_CONTAINER (widget)) != TYPE)
    {
        TEST_FAIL ("Type = %i, should be %i ", gtk_container_child_type (GTK_CONTAINER (widget)), TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_child_type
 * Params: GtkContainer *container
 * Returns: GType
 * Assertion: Returns the type of the children supported by the container.
 * Params Values: GtkContainer *container
 * Expected: GTK_TYPE_WIDGET     
 * 
 * Name: gtk_container_child_type
 * Params: GtkContainer *container
 * Returns: GType
 * Assertion: Note that this may return G_TYPE_NONE to indicate that no more children can be added, e.g. for a GtkPaned which already has two children.
 * Params Values: GtkContainer *container
 * Expected: GTK_TYPE_WIDGET       
 */
static void test_purpose_55()
{
    #define CONTAINER gtk_viewport_new (NULL, NULL)  
    #define TYPE GTK_TYPE_WIDGET     
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (gtk_container_child_type (GTK_CONTAINER (widget)) != TYPE)
    {
        TEST_FAIL ("Type = %i, should be %i ", gtk_container_child_type (GTK_CONTAINER (widget)), TYPE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef TYPE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_unset_focus_chain
 * Params: GtkContainer *container
 * Returns: void
 * Assertion: Removes a focus chain explicitly set with gtk_container_set_focus_chain().
 * Params Values: GtkContainer *container
 * Expected: void  
 */
static void test_purpose_56()
{
    #define CONTAINER gtk_frame_new ("Label")  
    #define WIDGETS NULL     
    
    GtkWidget *widget;
    GList *list;
    GList *real_list;
    gboolean ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    /* Must initialize list to NULL before first use */
    list = NULL;
    
    widget = CONTAINER;
    list = WIDGETS;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_focus_chain (GTK_CONTAINER (widget), list);
    gtk_container_unset_focus_chain (GTK_CONTAINER (widget));
    
    ret = gtk_container_get_focus_chain (GTK_CONTAINER (widget), &real_list);
    if (ret)
    {
        TEST_FAIL ("list isn't NULL", NULL);
    } 
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef WIDGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_unset_focus_chain
 * Params: GtkContainer *container
 * Returns: void
 * Assertion: Removes a focus chain explicitly set with gtk_container_set_focus_chain().
 * Params Values: GtkContainer *container
 * Expected: void  
 */
static void test_purpose_57()
{
    #define CONTAINER gtk_frame_new ("Label")  
    #define WIDGETS g_list_append (g_list_append (list, gtk_button_new()), gtk_label_new("d"))     
    
    GtkWidget *widget;
    GList *list;
    GList *real_list;
    gboolean ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    /* Must initialize list to NULL before first use */
    list = NULL;
    
    widget = CONTAINER;
    list = WIDGETS;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    gtk_container_set_focus_chain (GTK_CONTAINER (widget), list);
    gtk_container_unset_focus_chain (GTK_CONTAINER (widget));
    
    ret = gtk_container_get_focus_chain (GTK_CONTAINER (widget), &real_list);
    if (ret)
    {
        TEST_FAIL ("list isn't NULL", NULL);
    } 
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CONTAINER
    #undef WIDGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_set_focus_chain
 * Params: GtkContainer *container, GList *focusable_widgets
 * Returns: void
 * Assertion: Sets a focus chain, overriding the one computed automatically by GTK+.
 * Params Values: GtkContainer *container, GList *focusable_widgets
 * Expected: void
 * 
 * Name: gtk_container_get_focus_chain
 * Params: GtkContainer *container, GList **focusable_widgets
 * Returns: gboolean
 * Assertion: Retrieves the focus chain of the container, if one has been set explicitly.
 * Params Values: GtkContainer *container, GList **focusable_widgets
 * Expected: <%2%>  
 */
static void test_purpose_58()
{
    #define CONTAINER gtk_window_new (GTK_WINDOW_TOPLEVEL)  
    #define WIDGETS NULL     
    
    GtkWidget *widget;
    GList *list;
    GList *real_list;
    gboolean ret;
    GtkWidget *child1;
    GtkWidget *child2;
    GtkWidget *child3;
    GtkWidget *layout;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    /* Must initialize list to NULL before first use */
    list = NULL;
    
    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    layout = gtk_vbutton_box_new ();
    
    child1 = gtk_button_new ();
    child2 = gtk_check_button_new();
    child3 = gtk_combo_box_new ();
    
    gtk_container_add (GTK_CONTAINER (layout), child1);
    gtk_container_add (GTK_CONTAINER (layout), child2);
    gtk_container_add (GTK_CONTAINER (layout), child3);
    gtk_container_add (GTK_CONTAINER (widget), layout);
    
    list = WIDGETS;
    
    gtk_container_set_focus_chain(GTK_CONTAINER (widget), list);
    
    ret = gtk_container_get_focus_chain(GTK_CONTAINER (widget), &real_list);
    if (ret != TRUE)
    {
        TEST_FAIL ("ret is %d, should be %d", ret, TRUE);
    } else {
        if (g_list_length (list) != g_list_length (real_list))
        {
            TEST_FAIL ("list != real_list, list length = %d, real_list length = %d",g_list_length (list), g_list_length (real_list));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    g_list_free (real_list);
    
    #undef CONTAINER
    #undef WIDGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_set_focus_chain
 * Params: GtkContainer *container, GList *focusable_widgets
 * Returns: void
 * Assertion: Sets a focus chain, overriding the one computed automatically by GTK+.
 * Params Values: GtkContainer *container, GList *focusable_widgets
 * Expected: void
 * 
 * Name: gtk_container_get_focus_chain
 * Params: GtkContainer *container, GList **focusable_widgets
 * Returns: gboolean
 * Assertion: Retrieves the focus chain of the container, if one has been set explicitly.
 * Params Values: GtkContainer *container, GList **focusable_widgets
 * Expected: <%2%>  
 */
static void test_purpose_59()
{
    #define CONTAINER gtk_window_new (GTK_WINDOW_TOPLEVEL)  
    #define WIDGETS g_list_prepend (g_list_prepend (list, child1), child3)     
    
    GtkWidget *widget;
    GList *list;
    GList *real_list;
    gboolean ret;
    GtkWidget *child1;
    GtkWidget *child2;
    GtkWidget *child3;
    GtkWidget *layout;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    /* Must initialize list to NULL before first use */
    list = NULL;
    
    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    layout = gtk_vbutton_box_new ();
    
    child1 = gtk_button_new ();
    child2 = gtk_check_button_new();
    child3 = gtk_combo_box_new ();
    
    gtk_container_add (GTK_CONTAINER (layout), child1);
    gtk_container_add (GTK_CONTAINER (layout), child2);
    gtk_container_add (GTK_CONTAINER (layout), child3);
    gtk_container_add (GTK_CONTAINER (widget), layout);
    
    list = WIDGETS;
    
    gtk_container_set_focus_chain(GTK_CONTAINER (widget), list);
    
    ret = gtk_container_get_focus_chain(GTK_CONTAINER (widget), &real_list);
    if (ret != TRUE)
    {
        TEST_FAIL ("ret is %d, should be %d", ret, TRUE);
    } else {
        if (g_list_length (list) != g_list_length (real_list))
        {
            TEST_FAIL ("list != real_list, list length = %d, real_list length = %d",g_list_length (list), g_list_length (real_list));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    g_list_free (real_list);
    
    #undef CONTAINER
    #undef WIDGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_set_focus_chain
 * Params: GtkContainer *container, GList *focusable_widgets
 * Returns: void
 * Assertion: Sets a focus chain, overriding the one computed automatically by GTK+.
 * Params Values: GtkContainer *container, GList *focusable_widgets
 * Expected: void
 * 
 * Name: gtk_container_get_focus_chain
 * Params: GtkContainer *container, GList **focusable_widgets
 * Returns: gboolean
 * Assertion: Retrieves the focus chain of the container, if one has been set explicitly.
 * Params Values: GtkContainer *container, GList **focusable_widgets
 * Expected: <%2%>  
 */
static void test_purpose_60()
{
    #define CONTAINER gtk_window_new (GTK_WINDOW_TOPLEVEL)  
    #define WIDGETS g_list_prepend (g_list_prepend (g_list_prepend (list, child1), child3), child2)
    
    GtkWidget *widget;
    GList *list;
    GList *real_list;
    gboolean ret;
    GtkWidget *child1;
    GtkWidget *child2;
    GtkWidget *child3;
    GtkWidget *layout;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    /* Must initialize list to NULL before first use */
    list = NULL;
    
    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    layout = gtk_vbutton_box_new ();
    
    child1 = gtk_button_new ();
    child2 = gtk_check_button_new();
    child3 = gtk_combo_box_new ();
    
    gtk_container_add (GTK_CONTAINER (layout), child1);
    gtk_container_add (GTK_CONTAINER (layout), child2);
    gtk_container_add (GTK_CONTAINER (layout), child3);
    gtk_container_add (GTK_CONTAINER (widget), layout);
    
    list = WIDGETS;
    
    gtk_container_set_focus_chain(GTK_CONTAINER (widget), list);
    
    ret = gtk_container_get_focus_chain(GTK_CONTAINER (widget), &real_list);
    if (ret != TRUE)
    {
        TEST_FAIL ("ret is %d, should be %d", ret, TRUE);
    } else {
        if (g_list_length (list) != g_list_length (real_list))
        {
            TEST_FAIL ("list != real_list, list length = %d, real_list length = %d",g_list_length (list), g_list_length (real_list));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    g_list_free (real_list);
    
    #undef CONTAINER
    #undef WIDGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_focus_chain
 * Params: GtkContainer *container, GList **focusable_widgets
 * Returns: gboolean
 * Assertion: If no focus chain has been explicitly set, GTK+ computes the focus chain based on the positions of the children.
 * Params Values: GtkContainer *container, GList **focusable_widgets
 * Expected: FALSE
 * 
 * Name: gtk_container_get_focus_chain
 * Params: GtkContainer *container, GList **focusable_widgets
 * Returns: gboolean
 * Assertion: In that case, GTK+ stores NULL in focusable_widgets and returns FALSE.
 * Params Values: GtkContainer *container, GList **focusable_widgets
 * Expected: FALSE  
 */
static void test_purpose_61()
{
    #define CONTAINER gtk_frame_new ("Label")  
    
    GtkWidget *widget;
    GList *list;
    GList *real_list;
    gboolean ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    /* Must initialize list to NULL before first use */
    list = NULL;
    
    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    ret = gtk_container_get_focus_chain(GTK_CONTAINER (widget), &real_list);
    if (ret != FALSE)
    {
        TEST_FAIL ("ret is %d, should be %d", ret, FALSE);
    } else {
        if (real_list != NULL)
        {
            TEST_FAIL ("real_list should be NULL", NULL);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    g_list_free (real_list);
    
    #undef CONTAINER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_focus_chain
 * Params: GtkContainer *container, GList **focusable_widgets
 * Returns: gboolean
 * Assertion: If no focus chain has been explicitly set, GTK+ computes the focus chain based on the positions of the children.
 * Params Values: GtkContainer *container, GList **focusable_widgets
 * Expected: FALSE
 * 
 * Name: gtk_container_get_focus_chain
 * Params: GtkContainer *container, GList **focusable_widgets
 * Returns: gboolean
 * Assertion: In that case, GTK+ stores NULL in focusable_widgets and returns FALSE.
 * Params Values: GtkContainer *container, GList **focusable_widgets
 * Expected: FALSE  
 */
static void test_purpose_62()
{
    #define CONTAINER gtk_combo_box_new ()  
    
    GtkWidget *widget;
    GList *list;
    GList *real_list;
    gboolean ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    /* Must initialize list to NULL before first use */
    list = NULL;
    
    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    ret = gtk_container_get_focus_chain(GTK_CONTAINER (widget), &real_list);
    if (ret != FALSE)
    {
        TEST_FAIL ("ret is %d, should be %d", ret, FALSE);
    } else {
        if (real_list != NULL)
        {
            TEST_FAIL ("real_list should be NULL", NULL);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    g_list_free (real_list);
    
    #undef CONTAINER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_focus_chain
 * Params: GtkContainer *container, GList **focusable_widgets
 * Returns: gboolean
 * Assertion: If no focus chain has been explicitly set, GTK+ computes the focus chain based on the positions of the children.
 * Params Values: GtkContainer *container, GList **focusable_widgets
 * Expected: FALSE
 * 
 * Name: gtk_container_get_focus_chain
 * Params: GtkContainer *container, GList **focusable_widgets
 * Returns: gboolean
 * Assertion: In that case, GTK+ stores NULL in focusable_widgets and returns FALSE.
 * Params Values: GtkContainer *container, GList **focusable_widgets
 * Expected: FALSE  
 */
static void test_purpose_63()
{
    #define CONTAINER gtk_socket_new ()  
    
    GtkWidget *widget;
    GList *list;
    GList *real_list;
    gboolean ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    /* Must initialize list to NULL before first use */
    list = NULL;
    
    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    ret = gtk_container_get_focus_chain(GTK_CONTAINER (widget), &real_list);
    if (ret != FALSE)
    {
        TEST_FAIL ("ret is %d, should be %d", ret, FALSE);
    } else {
        if (real_list != NULL)
        {
            TEST_FAIL ("real_list should be NULL", NULL);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    g_list_free (real_list);
    
    #undef CONTAINER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_focus_chain
 * Params: GtkContainer *container, GList **focusable_widgets
 * Returns: gboolean
 * Assertion: If no focus chain has been explicitly set, GTK+ computes the focus chain based on the positions of the children.
 * Params Values: GtkContainer *container, GList **focusable_widgets
 * Expected: FALSE
 * 
 * Name: gtk_container_get_focus_chain
 * Params: GtkContainer *container, GList **focusable_widgets
 * Returns: gboolean
 * Assertion: In that case, GTK+ stores NULL in focusable_widgets and returns FALSE.
 * Params Values: GtkContainer *container, GList **focusable_widgets
 * Expected: FALSE  
 */
static void test_purpose_64()
{
    #define CONTAINER gtk_color_selection_new ()  
    
    GtkWidget *widget;
    GList *list;
    GList *real_list;
    gboolean ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    /* Must initialize list to NULL before first use */
    list = NULL;
    
    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    ret = gtk_container_get_focus_chain(GTK_CONTAINER (widget), &real_list);
    if (ret != FALSE)
    {
        TEST_FAIL ("ret is %d, should be %d", ret, FALSE);
    } else {
        if (real_list != NULL)
        {
            TEST_FAIL ("real_list should be NULL", NULL);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    g_list_free (real_list);
    
    #undef CONTAINER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_container_get_focus_chain
 * Params: GtkContainer *container, GList **focusable_widgets
 * Returns: gboolean
 * Assertion: If no focus chain has been explicitly set, GTK+ computes the focus chain based on the positions of the children.
 * Params Values: GtkContainer *container, GList **focusable_widgets
 * Expected: FALSE
 * 
 * Name: gtk_container_get_focus_chain
 * Params: GtkContainer *container, GList **focusable_widgets
 * Returns: gboolean
 * Assertion: In that case, GTK+ stores NULL in focusable_widgets and returns FALSE.
 * Params Values: GtkContainer *container, GList **focusable_widgets
 * Expected: FALSE  
 */
static void test_purpose_65()
{
    #define CONTAINER gtk_font_selection_new ()  
    
    GtkWidget *widget;
    GList *list;
    GList *real_list;
    gboolean ret;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    /* Must initialize list to NULL before first use */
    list = NULL;
    
    widget = CONTAINER;
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    ret = gtk_container_get_focus_chain(GTK_CONTAINER (widget), &real_list);
    if (ret != FALSE)
    {
        TEST_FAIL ("ret is %d, should be %d", ret, FALSE);
    } else {
        if (real_list != NULL)
        {
            TEST_FAIL ("real_list should be NULL", NULL);
        }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    g_list_free (real_list);
    
    #undef CONTAINER
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkContainer ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {NULL,0}
};
