/*
 * GtkRuler methods tests
 * Testing GtkRuler methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
#include <float.h>

/*
 * Name: gtk_ruler_set_metric
 * Params: GtkRuler* ruler, GtkMetricType metric
 * Returns: void
 * Assertion: This calls the GTKMetricType to set the ruler to units defined.
 * Params Values: newly created GtkRuler*, GTK_PIXELS
 * Expected: void
 * 
 * Name: gtk_ruler_get_metric
 * Params: GtkRuler* ruler
 * Returns: GtkMetricType
 * Assertion: Gets the units used for a GtkRuler.
 * Params Values: newly created GtkRuler*
 * Expected: GTK_PIXELS  
 */
static void test_purpose_1()
{
    #define WIDGET gtk_hruler_new ()         
    #define METRIC GTK_PIXELS
    
    GtkWidget *widget;
    GtkMetricType metric;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_ruler_set_metric (GTK_RULER (widget), METRIC);
    metric = gtk_ruler_get_metric (GTK_RULER (widget));
    
    if (metric != METRIC)
    {
        TEST_FAIL("GtkHRuler metric type = %i, should be %i", metric, METRIC);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef METRIC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ruler_set_metric
 * Params: GtkRuler* ruler, GtkMetricType metric
 * Returns: void
 * Assertion: This calls the GTKMetricType to set the ruler to units defined.
 * Params Values: newly created GtkRuler*, GTK_PIXELS
 * Expected: void
 * 
 * Name: gtk_ruler_get_metric
 * Params: GtkRuler* ruler
 * Returns: GtkMetricType
 * Assertion: Gets the units used for a GtkRuler.
 * Params Values: newly created GtkRuler*
 * Expected: GTK_PIXELS  
 */
static void test_purpose_2()
{
    #define WIDGET gtk_vruler_new ()         
    #define METRIC GTK_PIXELS
    
    GtkWidget *widget;
    GtkMetricType metric;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_ruler_set_metric (GTK_RULER (widget), METRIC);
    metric = gtk_ruler_get_metric (GTK_RULER (widget));
    
    if (metric != METRIC)
    {
        TEST_FAIL("GtkHRuler metric type = %i, should be %i", metric, METRIC);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef METRIC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ruler_set_metric
 * Params: GtkRuler* ruler, GtkMetricType metric
 * Returns: void
 * Assertion: This calls the GTKMetricType to set the ruler to units defined.
 * Params Values: newly created GtkRuler*, GTK_INCHES
 * Expected: void
 * 
 * Name: gtk_ruler_get_metric
 * Params: GtkRuler* ruler
 * Returns: GtkMetricType
 * Assertion: Gets the units used for a GtkRuler.
 * Params Values: newly created GtkRuler*
 * Expected: GTK_INCHES  
 */
static void test_purpose_3()
{
    #define WIDGET gtk_hruler_new ()         
    #define METRIC GTK_INCHES
    
    GtkWidget *widget;
    GtkMetricType metric;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_ruler_set_metric (GTK_RULER (widget), METRIC);
    metric = gtk_ruler_get_metric (GTK_RULER (widget));
    
    if (metric != METRIC)
    {
        TEST_FAIL("GtkHRuler metric type = %i, should be %i", metric, METRIC);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef METRIC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ruler_set_metric
 * Params: GtkRuler* ruler, GtkMetricType metric
 * Returns: void
 * Assertion: This calls the GTKMetricType to set the ruler to units defined.
 * Params Values: newly created GtkRuler*, GTK_INCHES
 * Expected: void
 * 
 * Name: gtk_ruler_get_metric
 * Params: GtkRuler* ruler
 * Returns: GtkMetricType
 * Assertion: Gets the units used for a GtkRuler.
 * Params Values: newly created GtkRuler*
 * Expected: GTK_INCHES  
 */
static void test_purpose_4()
{
    #define WIDGET gtk_vruler_new ()         
    #define METRIC GTK_INCHES
    
    GtkWidget *widget;
    GtkMetricType metric;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_ruler_set_metric (GTK_RULER (widget), METRIC);
    metric = gtk_ruler_get_metric (GTK_RULER (widget));
    
    if (metric != METRIC)
    {
        TEST_FAIL("GtkHRuler metric type = %i, should be %i", metric, METRIC);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef METRIC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ruler_set_metric
 * Params: GtkRuler* ruler, GtkMetricType metric
 * Returns: void
 * Assertion: This calls the GTKMetricType to set the ruler to units defined.
 * Params Values: newly created GtkRuler*, GTK_CENTIMETERS
 * Expected: void
 * 
 * Name: gtk_ruler_get_metric
 * Params: GtkRuler* ruler
 * Returns: GtkMetricType
 * Assertion: Gets the units used for a GtkRuler.
 * Params Values: newly created GtkRuler*
 * Expected: GTK_CENTIMETERS  
 */
static void test_purpose_5()
{
    #define WIDGET gtk_hruler_new ()         
    #define METRIC GTK_CENTIMETERS
    
    GtkWidget *widget;
    GtkMetricType metric;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_ruler_set_metric (GTK_RULER (widget), METRIC);
    metric = gtk_ruler_get_metric (GTK_RULER (widget));
    
    if (metric != METRIC)
    {
        TEST_FAIL("GtkHRuler metric type = %i, should be %i", metric, METRIC);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef METRIC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ruler_set_metric
 * Params: GtkRuler* ruler, GtkMetricType metric
 * Returns: void
 * Assertion: This calls the GTKMetricType to set the ruler to units defined.
 * Params Values: newly created GtkRuler*, GTK_CENTIMETERS
 * Expected: void
 * 
 * Name: gtk_ruler_get_metric
 * Params: GtkRuler* ruler
 * Returns: GtkMetricType
 * Assertion: Gets the units used for a GtkRuler.
 * Params Values: newly created GtkRuler*
 * Expected: GTK_CENTIMETERS  
 */
static void test_purpose_6()
{
    #define WIDGET gtk_vruler_new ()         
    #define METRIC GTK_CENTIMETERS
    
    GtkWidget *widget;
    GtkMetricType metric;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_ruler_set_metric (GTK_RULER (widget), METRIC);
    metric = gtk_ruler_get_metric (GTK_RULER (widget));
    
    if (metric != METRIC)
    {
        TEST_FAIL("GtkHRuler metric type = %i, should be %i", metric, METRIC);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef METRIC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ruler_set_metric
 * Params: GtkRuler* ruler, GtkMetricType metric
 * Returns: void
 * Assertion: The default unit of measurement is GTK_PIXELS.
 * Params Values: newly created GtkRuler*, GTK_PIXELS
 * Expected: void  
 */
static void test_purpose_7()
{
    #define WIDGET gtk_vruler_new ()         
    #define METRIC GTK_PIXELS
    
    GtkWidget *widget;
    GtkMetricType metric;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    metric = gtk_ruler_get_metric (GTK_RULER (widget));
    
    if (metric != METRIC)
    {
        TEST_FAIL("GtkHRuler metric type = %i, should be %i", metric, METRIC);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef METRIC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ruler_set_metric
 * Params: GtkRuler* ruler, GtkMetricType metric
 * Returns: void
 * Assertion: The default unit of measurement is GTK_PIXELS.
 * Params Values: newly created GtkRuler*, GTK_PIXELS
 * Expected: void  
 */
static void test_purpose_8()
{
    #define WIDGET gtk_hruler_new ()         
    #define METRIC GTK_PIXELS
    
    GtkWidget *widget;
    GtkMetricType metric;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    metric = gtk_ruler_get_metric (GTK_RULER (widget));
    
    if (metric != METRIC)
    {
        TEST_FAIL("GtkHRuler metric type = %i, should be %i", metric, METRIC);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef METRIC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ruler_set_range
 * Params: GtkRuler* ruler, gdouble lower, gdouble upper, gdouble position, gdouble max_size
 * Returns: void
 * Assertion: This sets the range of the ruler using gfloat lower, gfloat upper, gfloat position, and gfloat max_size. 
 * Params Values: newly created GtkRuler*, 0, 0, 0, 0
 * Expected: void
 * 
 * Name: gtk_ruler_get_range
 * Params: GtkRuler* ruler
 * Returns: void
 * Assertion: Retrieves values indicating the range and current position of a GtkRuler.
 * Params Values: newly created GtkRuler*, *lower, *upper, *position, *max_size
 * Expected: void, lower = 0, upper = 0, position = 0, max_size = 0  
 */
static void test_purpose_9()
{
    #define WIDGET gtk_hruler_new ()         
    #define LOWER 0
    #define UPPER 0
    #define POSITION 0
    #define MAX_SIZE 0
    
    GtkWidget *widget;
    gdouble lower;
    gdouble upper;
    gdouble position;
    gdouble max_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_ruler_set_range (GTK_RULER (widget), LOWER, UPPER, POSITION, MAX_SIZE);
    gtk_ruler_get_range (GTK_RULER (widget), &lower, &upper, &position, &max_size);
    
    if (lower != (gdouble)LOWER)
    {
        TEST_FAIL("GtkHRuler lower = %lf, should be %lf", lower, LOWER);
    }
    
    if (upper != (gdouble)UPPER)
    {
        TEST_FAIL("GtkHRuler upper = %lf, should be %lf", upper, UPPER);
    }
    
    if (position != (gdouble)POSITION)
    {
        TEST_FAIL("GtkHRuler position = %lf, should be %lf", position, POSITION);
    }
    
    if (max_size != (gdouble)MAX_SIZE)
    {
        TEST_FAIL("GtkHRuler max_size = %lf, should be %lf", max_size, MAX_SIZE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LOWER 
    #undef UPPER 
    #undef POSITION 
    #undef MAX_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ruler_set_range
 * Params: GtkRuler* ruler, gdouble lower, gdouble upper, gdouble position, gdouble max_size
 * Returns: void
 * Assertion: This sets the range of the ruler using gfloat lower, gfloat upper, gfloat position, and gfloat max_size. 
 * Params Values: newly created GtkRuler*, 0, 0, 0, 0
 * Expected: void
 * 
 * Name: gtk_ruler_get_range
 * Params: GtkRuler* ruler
 * Returns: void
 * Assertion: Retrieves values indicating the range and current position of a GtkRuler.
 * Params Values: newly created GtkRuler*, *lower, *upper, *position, *max_size
 * Expected: void, lower = 0, upper = 0, position = 0, max_size = 0  
 */
static void test_purpose_10()
{
    #define WIDGET gtk_vruler_new ()         
    #define LOWER 0
    #define UPPER 0
    #define POSITION 0
    #define MAX_SIZE 0
    
    GtkWidget *widget;
    gdouble lower;
    gdouble upper;
    gdouble position;
    gdouble max_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_ruler_set_range (GTK_RULER (widget), LOWER, UPPER, POSITION, MAX_SIZE);
    gtk_ruler_get_range (GTK_RULER (widget), &lower, &upper, &position, &max_size);
    
    if (lower != (gdouble)LOWER)
    {
        TEST_FAIL("GtkHRuler lower = %lf, should be %lf", lower, LOWER);
    }
    
    if (upper != (gdouble)UPPER)
    {
        TEST_FAIL("GtkHRuler upper = %lf, should be %lf", upper, UPPER);
    }
    
    if (position != (gdouble)POSITION)
    {
        TEST_FAIL("GtkHRuler position = %lf, should be %lf", position, POSITION);
    }
    
    if (max_size != (gdouble)MAX_SIZE)
    {
        TEST_FAIL("GtkHRuler max_size = %lf, should be %lf", max_size, MAX_SIZE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LOWER 
    #undef UPPER 
    #undef POSITION 
    #undef MAX_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ruler_set_range
 * Params: GtkRuler* ruler, gdouble lower, gdouble upper, gdouble position, gdouble max_size
 * Returns: void
 * Assertion: This sets the range of the ruler using gfloat lower, gfloat upper, gfloat position, and gfloat max_size. 
 * Params Values: newly created GtkRuler*, G_MINDOUBLE, G_MINDOUBLE, G_MINDOUBLE, G_MINDOUBLE
 * Expected: void
 * 
 * Name: gtk_ruler_get_range
 * Params: GtkRuler* ruler
 * Returns: void
 * Assertion: Retrieves values indicating the range and current position of a GtkRuler.
 * Params Values: newly created GtkRuler*, *lower, *upper, *position, *max_size
 * Expected: void, lower = G_MINDOUBLE, upper = G_MINDOUBLE, position = G_MINDOUBLE, max_size = G_MINDOUBLE  
 */
static void test_purpose_11()
{
    #define WIDGET gtk_hruler_new ()         
    #define LOWER G_MINDOUBLE
    #define UPPER G_MINDOUBLE
    #define POSITION G_MINDOUBLE
    #define MAX_SIZE G_MINDOUBLE
    
    GtkWidget *widget;
    gdouble lower;
    gdouble upper;
    gdouble position;
    gdouble max_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_ruler_set_range (GTK_RULER (widget), LOWER, UPPER, POSITION, MAX_SIZE);
    gtk_ruler_get_range (GTK_RULER (widget), &lower, &upper, &position, &max_size);
    
    if (lower != (gdouble)LOWER)
    {
        TEST_FAIL("GtkHRuler lower = %lf, should be %lf", lower, LOWER);
    }
    
    if (upper != (gdouble)UPPER)
    {
        TEST_FAIL("GtkHRuler upper = %lf, should be %lf", upper, UPPER);
    }
    
    if (position != (gdouble)POSITION)
    {
        TEST_FAIL("GtkHRuler position = %lf, should be %lf", position, POSITION);
    }
    
    if (max_size != (gdouble)MAX_SIZE)
    {
        TEST_FAIL("GtkHRuler max_size = %lf, should be %lf", max_size, MAX_SIZE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LOWER 
    #undef UPPER 
    #undef POSITION 
    #undef MAX_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ruler_set_range
 * Params: GtkRuler* ruler, gdouble lower, gdouble upper, gdouble position, gdouble max_size
 * Returns: void
 * Assertion: This sets the range of the ruler using gfloat lower, gfloat upper, gfloat position, and gfloat max_size. 
 * Params Values: newly created GtkRuler*, G_MINDOUBLE, G_MINDOUBLE, G_MINDOUBLE, G_MINDOUBLE
 * Expected: void
 * 
 * Name: gtk_ruler_get_range
 * Params: GtkRuler* ruler
 * Returns: void
 * Assertion: Retrieves values indicating the range and current position of a GtkRuler.
 * Params Values: newly created GtkRuler*, *lower, *upper, *position, *max_size
 * Expected: void, lower = G_MINDOUBLE, upper = G_MINDOUBLE, position = G_MINDOUBLE, max_size = G_MINDOUBLE  
 */
static void test_purpose_12()
{
    #define WIDGET gtk_vruler_new ()         
    #define LOWER G_MINDOUBLE
    #define UPPER G_MINDOUBLE
    #define POSITION G_MINDOUBLE
    #define MAX_SIZE G_MINDOUBLE
    
    GtkWidget *widget;
    gdouble lower;
    gdouble upper;
    gdouble position;
    gdouble max_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_ruler_set_range (GTK_RULER (widget), LOWER, UPPER, POSITION, MAX_SIZE);
    gtk_ruler_get_range (GTK_RULER (widget), &lower, &upper, &position, &max_size);
    
    if (lower != (gdouble)LOWER)
    {
        TEST_FAIL("GtkHRuler lower = %lf, should be %lf", lower, LOWER);
    }
    
    if (upper != (gdouble)UPPER)
    {
        TEST_FAIL("GtkHRuler upper = %lf, should be %lf", upper, UPPER);
    }
    
    if (position != (gdouble)POSITION)
    {
        TEST_FAIL("GtkHRuler position = %lf, should be %lf", position, POSITION);
    }
    
    if (max_size != (gdouble)MAX_SIZE)
    {
        TEST_FAIL("GtkHRuler max_size = %lf, should be %lf", max_size, MAX_SIZE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LOWER 
    #undef UPPER 
    #undef POSITION 
    #undef MAX_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ruler_set_range
 * Params: GtkRuler* ruler, gdouble lower, gdouble upper, gdouble position, gdouble max_size
 * Returns: void
 * Assertion: This sets the range of the ruler using gfloat lower, gfloat upper, gfloat position, and gfloat max_size. 
 * Params Values: newly created GtkRuler*, G_MAXDOUBLE, G_MAXDOUBLE, G_MAXDOUBLE, G_MAXDOUBLE
 * Expected: void
 * 
 * Name: gtk_ruler_get_range
 * Params: GtkRuler* ruler
 * Returns: void
 * Assertion: Retrieves values indicating the range and current position of a GtkRuler.
 * Params Values: newly created GtkRuler*, *lower, *upper, *position, *max_size
 * Expected: void, lower = G_MAXDOUBLE, upper = G_MAXDOUBLE, position = G_MAXDOUBLE, max_size = G_MAXDOUBLE  
 */
static void test_purpose_13()
{
    #define WIDGET gtk_hruler_new ()         
    #define LOWER G_MAXDOUBLE
    #define UPPER G_MAXDOUBLE
    #define POSITION G_MAXDOUBLE
    #define MAX_SIZE G_MAXDOUBLE
    
    GtkWidget *widget;
    gdouble lower;
    gdouble upper;
    gdouble position;
    gdouble max_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_ruler_set_range (GTK_RULER (widget), LOWER, UPPER, POSITION, MAX_SIZE);
    gtk_ruler_get_range (GTK_RULER (widget), &lower, &upper, &position, &max_size);
    
    if (lower != (gdouble)LOWER)
    {
        TEST_FAIL("GtkHRuler lower = %lf, should be %lf", lower, LOWER);
    }
    
    if (upper != (gdouble)UPPER)
    {
        TEST_FAIL("GtkHRuler upper = %lf, should be %lf", upper, UPPER);
    }
    
    if (position != (gdouble)POSITION)
    {
        TEST_FAIL("GtkHRuler position = %lf, should be %lf", position, POSITION);
    }
    
    if (max_size != (gdouble)MAX_SIZE)
    {
        TEST_FAIL("GtkHRuler max_size = %lf, should be %lf", max_size, MAX_SIZE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LOWER 
    #undef UPPER 
    #undef POSITION 
    #undef MAX_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ruler_set_range
 * Params: GtkRuler* ruler, gdouble lower, gdouble upper, gdouble position, gdouble max_size
 * Returns: void
 * Assertion: This sets the range of the ruler using gfloat lower, gfloat upper, gfloat position, and gfloat max_size. 
 * Params Values: newly created GtkRuler*, G_MAXDOUBLE, G_MAXDOUBLE, G_MAXDOUBLE, G_MAXDOUBLE
 * Expected: void
 * 
 * Name: gtk_ruler_get_range
 * Params: GtkRuler* ruler
 * Returns: void
 * Assertion: Retrieves values indicating the range and current position of a GtkRuler.
 * Params Values: newly created GtkRuler*, *lower, *upper, *position, *max_size
 * Expected: void, lower = G_MAXDOUBLE, upper = G_MAXDOUBLE, position = G_MAXDOUBLE, max_size = G_MAXDOUBLE  
 */
static void test_purpose_14()
{
    #define WIDGET gtk_vruler_new ()         
    #define LOWER G_MAXDOUBLE
    #define UPPER G_MAXDOUBLE
    #define POSITION G_MAXDOUBLE
    #define MAX_SIZE G_MAXDOUBLE
    
    GtkWidget *widget;
    gdouble lower;
    gdouble upper;
    gdouble position;
    gdouble max_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_ruler_set_range (GTK_RULER (widget), LOWER, UPPER, POSITION, MAX_SIZE);
    gtk_ruler_get_range (GTK_RULER (widget), &lower, &upper, &position, &max_size);
    
    if (lower != (gdouble)LOWER)
    {
        TEST_FAIL("GtkHRuler lower = %lf, should be %lf", lower, LOWER);
    }
    
    if (upper != (gdouble)UPPER)
    {
        TEST_FAIL("GtkHRuler upper = %lf, should be %lf", upper, UPPER);
    }
    
    if (position != (gdouble)POSITION)
    {
        TEST_FAIL("GtkHRuler position = %lf, should be %lf", position, POSITION);
    }
    
    if (max_size != (gdouble)MAX_SIZE)
    {
        TEST_FAIL("GtkHRuler max_size = %lf, should be %lf", max_size, MAX_SIZE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LOWER 
    #undef UPPER 
    #undef POSITION 
    #undef MAX_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ruler_set_range
 * Params: GtkRuler* ruler, gdouble lower, gdouble upper, gdouble position, gdouble max_size
 * Returns: void
 * Assertion: This sets the range of the ruler using gfloat lower, gfloat upper, gfloat position, and gfloat max_size. 
 * Params Values: newly created GtkRuler*, 10.0, 1.3, 7.0, 177.5
 * Expected: void
 * 
 * Name: gtk_ruler_get_range
 * Params: GtkRuler* ruler
 * Returns: void
 * Assertion: Retrieves values indicating the range and current position of a GtkRuler.
 * Params Values: newly created GtkRuler*, *lower, *upper, *position, *max_size
 * Expected: void, lower = 10.0, upper = 1.3, position = 7.0, max_size = 177.5  
 */
static void test_purpose_15()
{
    #define WIDGET gtk_hruler_new ()         
    #define LOWER 10.0
    #define UPPER 1.3
    #define POSITION 7.0
    #define MAX_SIZE 177.5
    
    GtkWidget *widget;
    gdouble lower;
    gdouble upper;
    gdouble position;
    gdouble max_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_ruler_set_range (GTK_RULER (widget), LOWER, UPPER, POSITION, MAX_SIZE);
    gtk_ruler_get_range (GTK_RULER (widget), &lower, &upper, &position, &max_size);
    
    if (lower != (gdouble)LOWER)
    {
        TEST_FAIL("GtkHRuler lower = %lf, should be %lf", lower, LOWER);
    }
    
    if (upper != (gdouble)UPPER)
    {
        TEST_FAIL("GtkHRuler upper = %lf, should be %lf", upper, UPPER);
    }
    
    if (position != (gdouble)POSITION)
    {
        TEST_FAIL("GtkHRuler position = %lf, should be %lf", position, POSITION);
    }
    
    if (max_size != (gdouble)MAX_SIZE)
    {
        TEST_FAIL("GtkHRuler max_size = %lf, should be %lf", max_size, MAX_SIZE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LOWER 
    #undef UPPER 
    #undef POSITION 
    #undef MAX_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ruler_set_range
 * Params: GtkRuler* ruler, gdouble lower, gdouble upper, gdouble position, gdouble max_size
 * Returns: void
 * Assertion: This sets the range of the ruler using gfloat lower, gfloat upper, gfloat position, and gfloat max_size. 
 * Params Values: newly created GtkRuler*, -10.883, -3.14, -2.75, -177.5
 * Expected: void
 * 
 * Name: gtk_ruler_get_range
 * Params: GtkRuler* ruler
 * Returns: void
 * Assertion: Retrieves values indicating the range and current position of a GtkRuler.
 * Params Values: newly created GtkRuler*, *lower, *upper, *position, *max_size
 * Expected: void, lower = -10.883, upper = -3.14, position = -2.75, max_size = -177.5  
 */
static void test_purpose_16()
{
    #define WIDGET gtk_vruler_new ()         
    #define LOWER -10.883
    #define UPPER -3.14
    #define POSITION -2.75
    #define MAX_SIZE -177.5
    
    GtkWidget *widget;
    gdouble lower;
    gdouble upper;
    gdouble position;
    gdouble max_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = WIDGET;
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_ruler_set_range (GTK_RULER (widget), LOWER, UPPER, POSITION, MAX_SIZE);
    gtk_ruler_get_range (GTK_RULER (widget), &lower, &upper, &position, &max_size);
    
    if (lower != (gdouble)LOWER)
    {
        TEST_FAIL("GtkHRuler lower = %lf, should be %lf", lower, LOWER);
    }
    
    if (upper != (gdouble)UPPER)
    {
        TEST_FAIL("GtkHRuler upper = %lf, should be %lf", upper, UPPER);
    }
    
    if (position != (gdouble)POSITION)
    {
        TEST_FAIL("GtkHRuler position = %lf, should be %lf", position, POSITION);
    }
    
    if (max_size != (gdouble)MAX_SIZE)
    {
        TEST_FAIL("GtkHRuler max_size = %lf, should be %lf", max_size, MAX_SIZE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);   
    /******* -------------  *******/ 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGET
    #undef LOWER 
    #undef UPPER 
    #undef POSITION 
    #undef MAX_SIZE 
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkRuler ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {NULL,0}
};
