/*
 * GtkScrolledWindow methods tests
 * Testing GtkScrolledWindow methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_scrolled_window_new
 * Params: GtkAdjustment *hadjustment, GtkAdjustment *vadjustment
 * Returns: GtkWidget*
 * Assertion: Creates a new scrolled window
 * Params Values: GTK_ADJUSTMENT(gtk_adjustment_new(1.0, 0.0, 2.0, 0.0, 0.0, 0.0)), GTK_ADJUSTMENT(gtk_adjustment_new(1.0, 0.0, 2.0, 0.0, 0.0, 0.0))
 * Expected: GtkScrolledWindow*   
 */
static void test_purpose_1()
{
    #define HADJUSTMENT GTK_ADJUSTMENT(gtk_adjustment_new(1.0, 0.0, 2.0, 0.0, 0.0, 0.0))
    #define VADJUSTMENT GTK_ADJUSTMENT(gtk_adjustment_new(1.0, 0.0, 2.0, 0.0, 0.0, 0.0))
    
    GtkWidget *widget;
    GtkAdjustment *hadjustment;
    GtkAdjustment *vadjustment;
    GtkAdjustment *real_vadjustment;
    GtkAdjustment *real_hadjustment;
    GtkPolicyType  hscrollbar_policy;
    GtkPolicyType  vscrollbar_policy;
    GtkCornerType  window_placement;
    GtkShadowType  shadow;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    hadjustment = HADJUSTMENT;
    vadjustment = VADJUSTMENT;
    
    widget = gtk_scrolled_window_new (hadjustment,vadjustment);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL);
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "hadjustment", &real_hadjustment, NULL);
    if (real_hadjustment != hadjustment)
    {
        TEST_FAIL("hadjustment fails", NULL);
    }
    
    g_object_get (GTK_OBJECT (widget), "vadjustment", &real_vadjustment, NULL);
    if (real_vadjustment != vadjustment)
    {
        TEST_FAIL("vadjustment fails", NULL);
    }
    
    g_object_get (GTK_OBJECT (widget), "hscrollbar-policy", &hscrollbar_policy, NULL);
    if (hscrollbar_policy != GTK_POLICY_ALWAYS)
    {
        TEST_FAIL("hscrollbar policy fails", NULL);
    }
    
    g_object_get (GTK_OBJECT (widget), "vscrollbar-policy", &vscrollbar_policy, NULL);
    if (vscrollbar_policy != GTK_POLICY_ALWAYS)
    {
        TEST_FAIL("vscrollbar policy fails", NULL);
    }
    
    g_object_get (GTK_OBJECT (widget), "window-placement", &window_placement, NULL);
    if (window_placement != GTK_CORNER_TOP_LEFT)
    {
        TEST_FAIL("window placement fails", NULL);
    }
    
    g_object_get (GTK_OBJECT (widget), "shadow_type", &shadow, NULL);
    if (shadow != GTK_SHADOW_NONE)
    {
        TEST_FAIL("shadow fails", NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HADJUSTMENT 
    #undef VADJUSTMENT 
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_set_hadjustment
 * Params: GtkViewport *window, GtkAdjustment *adjustment
 * Returns: void
 * Assertion: Sets the GtkAdjustment for the horizontal scrollbar
 * Params Values: GtkViewport *window, GtkAdjustment *adjustment
 * Expected: void  
 */
static void test_purpose_2()
{
    #define    ADJ gtk_adjustment_new (10.0, 1.0, 100.0, 5.0, 20.0, 50.0) 
    
    GtkWidget* widget;
    GtkAdjustment* ad;
    GtkAdjustment* adj;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    adj = GTK_ADJUSTMENT (ADJ);
    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_scrolled_window_set_hadjustment (GTK_SCROLLED_WINDOW (widget), adj);
    g_object_get(GTK_OBJECT(widget), "hadjustment", &ad, NULL);
    
    if (adj != ad)
    {
        TEST_FAIL("set hadjustment fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  ADJ
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_set_hadjustment
 * Params: GtkViewport *window, GtkAdjustment *adjustment
 * Returns: void
 * Assertion: Sets the GtkAdjustment for the horizontal scrollbar
 * Params Values: GtkViewport *window, GtkAdjustment *adjustment
 * Expected: void  
 */
static void test_purpose_3()
{
    #define    ADJ gtk_adjustment_new (0.0, 0.0, 10.0, 1.0, 5.0, 10.0) 
    
    GtkWidget* widget;
    GtkAdjustment* ad;
    GtkAdjustment* adj;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    adj = GTK_ADJUSTMENT (ADJ);
    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_scrolled_window_set_hadjustment (GTK_SCROLLED_WINDOW (widget), adj);
    g_object_get(GTK_OBJECT(widget), "hadjustment", &ad, NULL);
    
    if (adj != ad)
    {
        TEST_FAIL("set hadjustment fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  ADJ
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_set_vadjustment
 * Params: GtkScrolledWindow *window, GtkAdjustment *adjustment
 * Returns: void
 * Assertion: Sets the GtkAdjustment for the vertical scrollbar
 * Params Values: GtkScrolledWindow *window, GtkAdjustment *adjustment
 * Expected: void  
 */
static void test_purpose_4()
{
    #define    ADJ gtk_adjustment_new (10.0, 1.0, 100.0, 5.0, 20.0, 50.0) 
    
    GtkWidget* widget;
    GtkAdjustment* ad;
    GtkAdjustment* adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adj = GTK_ADJUSTMENT (ADJ);
    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_scrolled_window_set_vadjustment (GTK_SCROLLED_WINDOW (widget), adj);
    g_object_get(GTK_OBJECT(widget), "vadjustment", &ad, NULL);
    if (adj != ad)
    {
        TEST_FAIL("set vadjustment fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  ADJ
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_set_vadjustment
 * Params: GtkScrolledWindow *window, GtkAdjustment *adjustment
 * Returns: void
 * Assertion: Sets the GtkAdjustment for the vertical scrollbar
 * Params Values: GtkScrolledWindow *window, GtkAdjustment *adjustment
 * Expected: void  
 */
static void test_purpose_5()
{
    #define    ADJ gtk_adjustment_new (0.0, 0.0, 10.0, 1.0, 5.0, 10.0) 
    
    GtkWidget* widget;
    GtkAdjustment* ad;
    GtkAdjustment* adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adj = GTK_ADJUSTMENT (ADJ);
    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_scrolled_window_set_vadjustment (GTK_SCROLLED_WINDOW (widget), adj);
    g_object_get(GTK_OBJECT(widget), "vadjustment", &ad, NULL);
    if (adj != ad)
    {
        TEST_FAIL("set vadjustment fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  ADJ
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_get_hadjustment
 * Params: GtkScrolledWindow *window
 * Returns: GtkAdjustment*
 * Assertion: Returns the horizontal scrollbar's adjustment, used to connect the horizontal scrollbar to the child widget's horizontal scroll functionality.
 * Params Values: GtkScrolledWindow *window
 * Expected: GtkAdjustment*  
 */
static void test_purpose_6()
{
    #define    ADJ gtk_adjustment_new (10.0, 1.0, 100.0, 5.0, 20.0, 50.0) 
    
    GtkWidget* widget;
    GtkAdjustment* adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adj = GTK_ADJUSTMENT (ADJ);
    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "hadjustment", adj, NULL);
    if (adj != gtk_scrolled_window_get_hadjustment (GTK_SCROLLED_WINDOW (widget)))
    {
        TEST_FAIL("get hadjustment fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  ADJ
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_get_hadjustment
 * Params: GtkScrolledWindow *window
 * Returns: GtkAdjustment*
 * Assertion: Returns the horizontal scrollbar's adjustment, used to connect the horizontal scrollbar to the child widget's horizontal scroll functionality.
 * Params Values: GtkScrolledWindow *window
 * Expected: GtkAdjustment*  
 */
static void test_purpose_7()
{
    #define    ADJ gtk_adjustment_new (0.0, 0.0, 10.0, 1.0, 5.0, 10.0) 
    
    GtkWidget* widget;
    GtkAdjustment* adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adj = GTK_ADJUSTMENT (ADJ);
    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "hadjustment", adj, NULL);
    if (adj != gtk_scrolled_window_get_hadjustment (GTK_SCROLLED_WINDOW (widget)))
    {
        TEST_FAIL("get hadjustment fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  ADJ
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_get_vadjustment
 * Params: GtkScrolledWindow *window
 * Returns: GtkAdjustment*
 * Assertion: Returns the vertical scrollbar's adjustment, used to connect the vertical scrollbar to the child widget's vertical scroll functionality
 * Params Values: GtkScrolledWindow *window
 * Expected: GtkAdjustment*  
 */
static void test_purpose_8()
{
    #define    ADJ gtk_adjustment_new (10.0, 1.0, 100.0, 5.0, 20.0, 50.0) 
    
    GtkWidget* widget;
    GtkAdjustment* adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adj = GTK_ADJUSTMENT (ADJ);
    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "vadjustment", adj, NULL);
    if (adj != gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (widget)))
    {
        TEST_FAIL("get vadjustment fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  ADJ
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_get_vadjustment
 * Params: GtkScrolledWindow *window
 * Returns: GtkAdjustment*
 * Assertion: Returns the vertical scrollbar's adjustment, used to connect the vertical scrollbar to the child widget's vertical scroll functionality
 * Params Values: GtkScrolledWindow *window
 * Expected: GtkAdjustment*  
 */
static void test_purpose_9()
{
    #define    ADJ gtk_adjustment_new (0.0, 0.0, 10.0, 1.0, 5.0, 10.0) 
    
    GtkWidget* widget;
    GtkAdjustment* adj;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    adj = GTK_ADJUSTMENT (ADJ);
    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "vadjustment", adj, NULL);
    if (adj != gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (widget)))
    {
        TEST_FAIL("get vadjustment fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  ADJ
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_set_shadow_type
 * Params: GtkScrolledWindow *window, GtkShadowType type
 * Returns: void
 * Assertion: Changes the type of shadow drawn around the contents of scrolled_window
 * Params Values: GtkScrolledWindow *window, GTK_SHADOW_NONE
 * Expected: void  
 */
static void test_purpose_10()
{
    #define    SHADOW GTK_SHADOW_NONE
    
    GtkWidget* widget;
    GtkShadowType shadow_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), SHADOW);
    g_object_get (GTK_OBJECT (widget), "shadow_type", &shadow_type, NULL);
    if (shadow_type != SHADOW)
    {
        TEST_FAIL("shadow type fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  SHADOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_set_shadow_type
 * Params: GtkScrolledWindow *window, GtkShadowType type
 * Returns: void
 * Assertion: Changes the type of shadow drawn around the contents of scrolled_window
 * Params Values: GtkScrolledWindow *window, GTK_SHADOW_IN
 * Expected: void  
 */
static void test_purpose_11()
{
    #define    SHADOW GTK_SHADOW_IN
    
    GtkWidget* widget;
    GtkShadowType shadow_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), SHADOW);
    g_object_get (GTK_OBJECT (widget), "shadow_type", &shadow_type, NULL);
    if (shadow_type != SHADOW)
    {
        TEST_FAIL("shadow type fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  SHADOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_set_shadow_type
 * Params: GtkScrolledWindow *window, GtkShadowType type
 * Returns: void
 * Assertion: Changes the type of shadow drawn around the contents of scrolled_window
 * Params Values: GtkScrolledWindow *window, GTK_SHADOW_OUT
 * Expected: void  
 */
static void test_purpose_12()
{
    #define    SHADOW GTK_SHADOW_OUT
    
    GtkWidget* widget;
    GtkShadowType shadow_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), SHADOW);
    g_object_get (GTK_OBJECT (widget), "shadow_type", &shadow_type, NULL);
    if (shadow_type != SHADOW)
    {
        TEST_FAIL("shadow type fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  SHADOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_set_shadow_type
 * Params: GtkScrolledWindow *window, GtkShadowType type
 * Returns: void
 * Assertion: Changes the type of shadow drawn around the contents of scrolled_window
 * Params Values: GtkScrolledWindow *window, GTK_SHADOW_ETCHED_IN
 * Expected: void  
 */
static void test_purpose_13()
{
    #define    SHADOW GTK_SHADOW_ETCHED_IN
    
    GtkWidget* widget;
    GtkShadowType shadow_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), SHADOW);
    g_object_get (GTK_OBJECT (widget), "shadow_type", &shadow_type, NULL);
    if (shadow_type != SHADOW)
    {
        TEST_FAIL("shadow type fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  SHADOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_set_shadow_type
 * Params: GtkScrolledWindow *window, GtkShadowType type
 * Returns: void
 * Assertion: Changes the type of shadow drawn around the contents of scrolled_window
 * Params Values: GtkScrolledWindow *window, GTK_SHADOW_ETCHED_OUT
 * Expected: void  
 */
static void test_purpose_14()
{
    #define    SHADOW GTK_SHADOW_ETCHED_OUT
    
    GtkWidget* widget;
    GtkShadowType shadow_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), SHADOW);
    g_object_get (GTK_OBJECT (widget), "shadow_type", &shadow_type, NULL);
    if (shadow_type != SHADOW)
    {
        TEST_FAIL("shadow type fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  SHADOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_get_shadow_type
 * Params: GtkScrolledWindow *window
 * Returns: GtkShadowType 
 * Assertion: Gets the shadow type of the scrolled window.
 * Params Values: GtkScrolledWindow *window
 * Expected: GTK_SHADOW_NONE  
 */
static void test_purpose_15()
{
    #define    SHADOW GTK_SHADOW_NONE
    
    GtkWidget* widget;
    GtkShadowType shadow_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "shadow_type", SHADOW, NULL);
    shadow_type = gtk_scrolled_window_get_shadow_type (GTK_SCROLLED_WINDOW (widget));
    if (shadow_type != SHADOW)
    {
        TEST_FAIL("shadow type fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  SHADOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_get_shadow_type
 * Params: GtkScrolledWindow *window
 * Returns: GtkShadowType 
 * Assertion: Gets the shadow type of the scrolled window.
 * Params Values: GtkScrolledWindow *window
 * Expected: GTK_SHADOW_IN  
 */
static void test_purpose_16()
{
    #define    SHADOW GTK_SHADOW_IN
    
    GtkWidget* widget;
    GtkShadowType shadow_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "shadow_type", SHADOW, NULL);
    shadow_type = gtk_scrolled_window_get_shadow_type (GTK_SCROLLED_WINDOW (widget));
    if (shadow_type != SHADOW)
    {
        TEST_FAIL("shadow type fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  SHADOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_get_shadow_type
 * Params: GtkScrolledWindow *window
 * Returns: GtkShadowType 
 * Assertion: Gets the shadow type of the scrolled window.
 * Params Values: GtkScrolledWindow *window
 * Expected: GTK_SHADOW_OUT  
 */
static void test_purpose_17()
{
    #define    SHADOW GTK_SHADOW_OUT
    
    GtkWidget* widget;
    GtkShadowType shadow_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "shadow_type", SHADOW, NULL);
    shadow_type = gtk_scrolled_window_get_shadow_type (GTK_SCROLLED_WINDOW (widget));
    if (shadow_type != SHADOW)
    {
        TEST_FAIL("shadow type fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  SHADOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_get_shadow_type
 * Params: GtkScrolledWindow *window
 * Returns: GtkShadowType 
 * Assertion: Gets the shadow type of the scrolled window.
 * Params Values: GtkScrolledWindow *window
 * Expected: GTK_SHADOW_ETCHED_IN  
 */
static void test_purpose_18()
{
    #define    SHADOW GTK_SHADOW_ETCHED_IN
    
    GtkWidget* widget;
    GtkShadowType shadow_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "shadow_type", SHADOW, NULL);
    shadow_type = gtk_scrolled_window_get_shadow_type (GTK_SCROLLED_WINDOW (widget));
    if (shadow_type != SHADOW)
    {
        TEST_FAIL("shadow type fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  SHADOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_get_shadow_type
 * Params: GtkScrolledWindow *window
 * Returns: GtkShadowType 
 * Assertion: Gets the shadow type of the scrolled window.
 * Params Values: GtkScrolledWindow *window
 * Expected: GTK_SHADOW_ETCHED_OUT  
 */
static void test_purpose_19()
{
    #define    SHADOW GTK_SHADOW_ETCHED_OUT
    
    GtkWidget* widget;
    GtkShadowType shadow_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "shadow_type", SHADOW, NULL);
    shadow_type = gtk_scrolled_window_get_shadow_type (GTK_SCROLLED_WINDOW (widget));
    if (shadow_type != SHADOW)
    {
        TEST_FAIL("shadow type fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  SHADOW
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_set_placement
 * Params: GtkScrolledWindow *window, GtkCornerType window_placement
 * Returns: void
 * Assertion: Determines the location of the child widget with respect to the scrollbars
 * Params Values: GtkScrolledWindow *window, GTK_CORNER_TOP_LEFT
 * Expected: void
 * 
 * Name:  gtk_scrolled_window_set_placement
 * Params: GtkScrolledWindow *window, GtkCornerType window_placement
 * Returns: void
 * Assertion: The default is GTK_CORNER_TOP_LEFT, meaning the child is in the top left, with the scrollbars underneath and to the right. 
 * Params Values: GtkScrolledWindow *window, GTK_CORNER_TOP_LEFT
 * Expected: void  
 */
static void test_purpose_20()
{
    #define    PLACEMENT GTK_CORNER_TOP_LEFT
    
    GtkWidget* widget;
    GtkCornerType window_placement;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "window-placement", &window_placement, NULL);
    if (window_placement != GTK_CORNER_TOP_LEFT)
    {
        TEST_FAIL("default window placement should be GTK_CORNER_TOP_LEFT", NULL );
    }
    
    gtk_scrolled_window_set_placement (GTK_SCROLLED_WINDOW (widget), PLACEMENT);
    g_object_get (GTK_OBJECT (widget), "window-placement", &window_placement, NULL);
    if (window_placement != PLACEMENT)
    {
        TEST_FAIL("window placement fails", NULL );
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  PLACEMENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_set_placement
 * Params: GtkScrolledWindow *window, GtkCornerType window_placement
 * Returns: void
 * Assertion: Determines the location of the child widget with respect to the scrollbars
 * Params Values: GtkScrolledWindow *window, GTK_CORNER_BOTTOM_LEFT
 * Expected: void
 * 
 * Name:  gtk_scrolled_window_set_placement
 * Params: GtkScrolledWindow *window, GtkCornerType window_placement
 * Returns: void
 * Assertion: The default is GTK_CORNER_TOP_LEFT, meaning the child is in the top left, with the scrollbars underneath and to the right. 
 * Params Values: GtkScrolledWindow *window, GTK_CORNER_BOTTOM_LEFT
 * Expected: void  
 */
static void test_purpose_21()
{
    #define    PLACEMENT GTK_CORNER_BOTTOM_LEFT
    
    GtkWidget* widget;
    GtkCornerType window_placement;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "window-placement", &window_placement, NULL);
    if (window_placement != GTK_CORNER_TOP_LEFT)
    {
        TEST_FAIL("default window placement should be GTK_CORNER_TOP_LEFT", NULL );
    }
    
    gtk_scrolled_window_set_placement (GTK_SCROLLED_WINDOW (widget), PLACEMENT);
    g_object_get (GTK_OBJECT (widget), "window-placement", &window_placement, NULL);
    if (window_placement != PLACEMENT)
    {
        TEST_FAIL("window placement fails", NULL );
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  PLACEMENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_set_placement
 * Params: GtkScrolledWindow *window, GtkCornerType window_placement
 * Returns: void
 * Assertion: Determines the location of the child widget with respect to the scrollbars
 * Params Values: GtkScrolledWindow *window, GTK_CORNER_TOP_RIGHT
 * Expected: void
 * 
 * Name:  gtk_scrolled_window_set_placement
 * Params: GtkScrolledWindow *window, GtkCornerType window_placement
 * Returns: void
 * Assertion: The default is GTK_CORNER_TOP_LEFT, meaning the child is in the top left, with the scrollbars underneath and to the right. 
 * Params Values: GtkScrolledWindow *window, GTK_CORNER_TOP_RIGHT
 * Expected: void  
 */
static void test_purpose_22()
{
    #define    PLACEMENT GTK_CORNER_TOP_RIGHT
    
    GtkWidget* widget;
    GtkCornerType window_placement;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "window-placement", &window_placement, NULL);
    if (window_placement != GTK_CORNER_TOP_LEFT)
    {
        TEST_FAIL("default window placement should be GTK_CORNER_TOP_LEFT", NULL );
    }
    
    gtk_scrolled_window_set_placement (GTK_SCROLLED_WINDOW (widget), PLACEMENT);
    g_object_get (GTK_OBJECT (widget), "window-placement", &window_placement, NULL);
    if (window_placement != PLACEMENT)
    {
        TEST_FAIL("window placement fails", NULL );
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  PLACEMENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_set_placement
 * Params: GtkScrolledWindow *window, GtkCornerType window_placement
 * Returns: void
 * Assertion: Determines the location of the child widget with respect to the scrollbars
 * Params Values: GtkScrolledWindow *window, GTK_CORNER_BOTTOM_RIGHT
 * Expected: void
 * 
 * Name:  gtk_scrolled_window_set_placement
 * Params: GtkScrolledWindow *window, GtkCornerType window_placement
 * Returns: void
 * Assertion: The default is GTK_CORNER_TOP_LEFT, meaning the child is in the top left, with the scrollbars underneath and to the right. 
 * Params Values: GtkScrolledWindow *window, GTK_CORNER_BOTTOM_RIGHT
 * Expected: void  
 */
static void test_purpose_23()
{
    #define    PLACEMENT GTK_CORNER_BOTTOM_RIGHT
    
    GtkWidget* widget;
    GtkCornerType window_placement;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT (widget), "window-placement", &window_placement, NULL);
    if (window_placement != GTK_CORNER_TOP_LEFT)
    {
        TEST_FAIL("default window placement should be GTK_CORNER_TOP_LEFT", NULL );
    }
    
    gtk_scrolled_window_set_placement (GTK_SCROLLED_WINDOW (widget), PLACEMENT);
    g_object_get (GTK_OBJECT (widget), "window-placement", &window_placement, NULL);
    if (window_placement != PLACEMENT)
    {
        TEST_FAIL("window placement fails", NULL );
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  PLACEMENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scrolled_window_get_placement
 * Params: GtkScrolledWindow *window 
 * Returns: GtkCornerType
 * Assertion: Gets the placement of the scrollbars for the scrolled window.
 * Params Values: GtkScrolledWindow *window
 * Expected: GTK_CORNER_TOP_LEFT  
 */
static void test_purpose_24()
{
    #define    PLACEMENT GTK_CORNER_TOP_LEFT
    
    GtkWidget* widget;
    GtkCornerType window_placement;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "window-placement", PLACEMENT, NULL);
    window_placement = gtk_scrolled_window_get_placement (GTK_SCROLLED_WINDOW (widget));
    if (window_placement != PLACEMENT)
    {
        TEST_FAIL("window placement fails", NULL );
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  PLACEMENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scrolled_window_get_placement
 * Params: GtkScrolledWindow *window 
 * Returns: GtkCornerType
 * Assertion: Gets the placement of the scrollbars for the scrolled window.
 * Params Values: GtkScrolledWindow *window
 * Expected: GTK_CORNER_BOTTOM_LEFT  
 */
static void test_purpose_25()
{
    #define    PLACEMENT GTK_CORNER_BOTTOM_LEFT
    
    GtkWidget* widget;
    GtkCornerType window_placement;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "window-placement", PLACEMENT, NULL);
    window_placement = gtk_scrolled_window_get_placement (GTK_SCROLLED_WINDOW (widget));
    if (window_placement != PLACEMENT)
    {
        TEST_FAIL("window placement fails", NULL );
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  PLACEMENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scrolled_window_get_placement
 * Params: GtkScrolledWindow *window 
 * Returns: GtkCornerType
 * Assertion: Gets the placement of the scrollbars for the scrolled window.
 * Params Values: GtkScrolledWindow *window
 * Expected: GTK_CORNER_TOP_RIGHT  
 */
static void test_purpose_26()
{
    #define    PLACEMENT GTK_CORNER_TOP_RIGHT
    
    GtkWidget* widget;
    GtkCornerType window_placement;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "window-placement", PLACEMENT, NULL);
    window_placement = gtk_scrolled_window_get_placement (GTK_SCROLLED_WINDOW (widget));
    if (window_placement != PLACEMENT)
    {
        TEST_FAIL("window placement fails", NULL );
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  PLACEMENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_scrolled_window_get_placement
 * Params: GtkScrolledWindow *window 
 * Returns: GtkCornerType
 * Assertion: Gets the placement of the scrollbars for the scrolled window.
 * Params Values: GtkScrolledWindow *window
 * Expected: GTK_CORNER_BOTTOM_RIGHT  
 */
static void test_purpose_27()
{
    #define    PLACEMENT GTK_CORNER_BOTTOM_RIGHT
    
    GtkWidget* widget;
    GtkCornerType window_placement;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "window-placement", PLACEMENT, NULL);
    window_placement = gtk_scrolled_window_get_placement (GTK_SCROLLED_WINDOW (widget));
    if (window_placement != PLACEMENT)
    {
        TEST_FAIL("window placement fails", NULL );
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  PLACEMENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_set_policy
 * Params: GtkScrolledWindow *window, GtkPolicyType hscrollbar_policy,  GtkPolicyType vscrollbar_policy
 * Returns: void
 * Assertion: Sets the scrollbar policy for the horizontal and vertical scrollbars
 * Params Values: GtkScrolledWindow *window, GTK_CORNER_TOP_LEFT, GTK_CORNER_TOP_LEFT
 * Expected: void  
 */
static void test_purpose_28()
{
    #define    HPOLICY GTK_CORNER_TOP_LEFT
    #define    VPOLICY GTK_CORNER_TOP_LEFT
    
    GtkWidget* widget;
    GtkPolicyType hscrollbar_policy;
    GtkPolicyType vscrollbar_policy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), (GtkPolicyType)HPOLICY, (GtkPolicyType)VPOLICY);
    g_object_get (GTK_OBJECT (widget), "hscrollbar-policy", &hscrollbar_policy, NULL);
    if (hscrollbar_policy != HPOLICY)
    {
        TEST_FAIL("hscrollbar policy fails", NULL);
    }
    
    g_object_get(GTK_OBJECT (widget), "vscrollbar-policy", &vscrollbar_policy, NULL);
    if (vscrollbar_policy != VPOLICY)
    {
        TEST_FAIL("vscrollbar policy fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HPOLICY
    #undef VPOLICY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_set_policy
 * Params: GtkScrolledWindow *window, GtkPolicyType hscrollbar_policy,  GtkPolicyType vscrollbar_policy
 * Returns: void
 * Assertion: Sets the scrollbar policy for the horizontal and vertical scrollbars
 * Params Values: GtkScrolledWindow *window, GTK_CORNER_BOTTOM_LEFT, GTK_CORNER_BOTTOM_LEFT
 * Expected: void  
 */
static void test_purpose_29()
{
    #define    HPOLICY GTK_CORNER_BOTTOM_LEFT
    #define    VPOLICY GTK_CORNER_BOTTOM_LEFT
    
    GtkWidget* widget;
    GtkPolicyType hscrollbar_policy;
    GtkPolicyType vscrollbar_policy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), (GtkPolicyType)HPOLICY, (GtkPolicyType)VPOLICY);
    g_object_get (GTK_OBJECT (widget), "hscrollbar-policy", &hscrollbar_policy, NULL);
    if (hscrollbar_policy != HPOLICY)
    {
        TEST_FAIL("hscrollbar policy fails", NULL);
    }
    
    g_object_get(GTK_OBJECT (widget), "vscrollbar-policy", &vscrollbar_policy, NULL);
    if (vscrollbar_policy != VPOLICY)
    {
        TEST_FAIL("vscrollbar policy fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HPOLICY
    #undef VPOLICY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_set_policy
 * Params: GtkScrolledWindow *window, GtkPolicyType hscrollbar_policy,  GtkPolicyType vscrollbar_policy
 * Returns: void
 * Assertion: Sets the scrollbar policy for the horizontal and vertical scrollbars
 * Params Values: GtkScrolledWindow *window, GTK_CORNER_TOP_RIGHT, GTK_CORNER_BOTTOM_RIGHT
 * Expected: void  
 */
static void test_purpose_30()
{
    #define    HPOLICY GTK_CORNER_TOP_RIGHT
    #define    VPOLICY GTK_CORNER_BOTTOM_RIGHT
    
    GtkWidget* widget;
    GtkPolicyType hscrollbar_policy;
    GtkPolicyType vscrollbar_policy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), (GtkPolicyType)HPOLICY, (GtkPolicyType)VPOLICY);
    g_object_get (GTK_OBJECT (widget), "hscrollbar-policy", &hscrollbar_policy, NULL);
    if (hscrollbar_policy != HPOLICY)
    {
        TEST_FAIL("hscrollbar policy fails", NULL);
    }
    
    g_object_get(GTK_OBJECT (widget), "vscrollbar-policy", &vscrollbar_policy, NULL);
    if (vscrollbar_policy != VPOLICY)
    {
        TEST_FAIL("vscrollbar policy fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HPOLICY
    #undef VPOLICY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_set_policy
 * Params: GtkScrolledWindow *window, GtkPolicyType hscrollbar_policy,  GtkPolicyType vscrollbar_policy
 * Returns: void
 * Assertion: Sets the scrollbar policy for the horizontal and vertical scrollbars
 * Params Values: GtkScrolledWindow *window, GTK_CORNER_TOP_LEFT, GTK_CORNER_TOP_RIGHT
 * Expected: void  
 */
static void test_purpose_31()
{
    #define    HPOLICY GTK_CORNER_TOP_LEFT
    #define    VPOLICY GTK_CORNER_TOP_RIGHT
    
    GtkWidget* widget;
    GtkPolicyType hscrollbar_policy;
    GtkPolicyType vscrollbar_policy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), (GtkPolicyType)HPOLICY, (GtkPolicyType)VPOLICY);
    g_object_get (GTK_OBJECT (widget), "hscrollbar-policy", &hscrollbar_policy, NULL);
    if (hscrollbar_policy != HPOLICY)
    {
        TEST_FAIL("hscrollbar policy fails", NULL);
    }
    
    g_object_get(GTK_OBJECT (widget), "vscrollbar-policy", &vscrollbar_policy, NULL);
    if (vscrollbar_policy != VPOLICY)
    {
        TEST_FAIL("vscrollbar policy fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HPOLICY
    #undef VPOLICY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_get_policy
 * Params: GtkScrolledWindow *window, GtkPolicyType* hscrollbar_policy,  GtkPolicyType* vscrollbar_policy
 * Returns: void
 * Assertion: Retrieves the current policy values for the horizontal and vertical scrollbars.
 * Params Values: GtkScrolledWindow *window, GTK_CORNER_TOP_LEFT, GTK_CORNER_TOP_LEFT
 * Expected: void  
 */
static void test_purpose_32()
{
    #define    HPOLICY GTK_CORNER_TOP_LEFT
    #define    VPOLICY GTK_CORNER_TOP_LEFT
    
    GtkWidget* widget;
    GtkPolicyType hscrollbar_policy;
    GtkPolicyType vscrollbar_policy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "hscrollbar-policy", HPOLICY, NULL);
    g_object_set (GTK_OBJECT (widget), "vscrollbar-policy", VPOLICY, NULL);
    
    gtk_scrolled_window_get_policy (GTK_SCROLLED_WINDOW (widget), &hscrollbar_policy,  &vscrollbar_policy);
    
    if (hscrollbar_policy != HPOLICY)
    {
        TEST_FAIL("hscrollbar policy fails", NULL);
    }
    
    if (vscrollbar_policy != VPOLICY)
    {
        TEST_FAIL("vscrollbar policy fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HPOLICY
    #undef VPOLICY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_get_policy
 * Params: GtkScrolledWindow *window, GtkPolicyType* hscrollbar_policy,  GtkPolicyType* vscrollbar_policy
 * Returns: void
 * Assertion: Retrieves the current policy values for the horizontal and vertical scrollbars.
 * Params Values: GtkScrolledWindow *window, GTK_CORNER_BOTTOM_LEFT, GTK_CORNER_BOTTOM_LEFT
 * Expected: void  
 */
static void test_purpose_33()
{
    #define    HPOLICY GTK_CORNER_BOTTOM_LEFT
    #define    VPOLICY GTK_CORNER_BOTTOM_LEFT
    
    GtkWidget* widget;
    GtkPolicyType hscrollbar_policy;
    GtkPolicyType vscrollbar_policy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "hscrollbar-policy", HPOLICY, NULL);
    g_object_set (GTK_OBJECT (widget), "vscrollbar-policy", VPOLICY, NULL);
    
    gtk_scrolled_window_get_policy (GTK_SCROLLED_WINDOW (widget), &hscrollbar_policy,  &vscrollbar_policy);
    
    if (hscrollbar_policy != HPOLICY)
    {
        TEST_FAIL("hscrollbar policy fails", NULL);
    }
    
    if (vscrollbar_policy != VPOLICY)
    {
        TEST_FAIL("vscrollbar policy fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HPOLICY
    #undef VPOLICY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_get_policy
 * Params: GtkScrolledWindow *window, GtkPolicyType* hscrollbar_policy,  GtkPolicyType* vscrollbar_policy
 * Returns: void
 * Assertion: Retrieves the current policy values for the horizontal and vertical scrollbars.
 * Params Values: GtkScrolledWindow *window, GTK_CORNER_TOP_RIGHT, GTK_CORNER_BOTTOM_LEFT
 * Expected: void  
 */
static void test_purpose_34()
{
    #define    HPOLICY GTK_CORNER_TOP_RIGHT
    #define    VPOLICY GTK_CORNER_BOTTOM_LEFT
    
    GtkWidget* widget;
    GtkPolicyType hscrollbar_policy;
    GtkPolicyType vscrollbar_policy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "hscrollbar-policy", HPOLICY, NULL);
    g_object_set (GTK_OBJECT (widget), "vscrollbar-policy", VPOLICY, NULL);
    
    gtk_scrolled_window_get_policy (GTK_SCROLLED_WINDOW (widget), &hscrollbar_policy,  &vscrollbar_policy);
    
    if (hscrollbar_policy != HPOLICY)
    {
        TEST_FAIL("hscrollbar policy fails", NULL);
    }
    
    if (vscrollbar_policy != VPOLICY)
    {
        TEST_FAIL("vscrollbar policy fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HPOLICY
    #undef VPOLICY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_get_policy
 * Params: GtkScrolledWindow *window, GtkPolicyType* hscrollbar_policy,  GtkPolicyType* vscrollbar_policy
 * Returns: void
 * Assertion: Retrieves the current policy values for the horizontal and vertical scrollbars.
 * Params Values: GtkScrolledWindow *window, GTK_CORNER_TOP_LEFT, GTK_CORNER_TOP_RIGHT
 * Expected: void  
 */
static void test_purpose_35()
{
    #define    HPOLICY GTK_CORNER_TOP_LEFT
    #define    VPOLICY GTK_CORNER_TOP_RIGHT
    
    GtkWidget* widget;
    GtkPolicyType hscrollbar_policy;
    GtkPolicyType vscrollbar_policy;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)),
                                      GTK_ADJUSTMENT (gtk_adjustment_new (1.0, 2.0, 5.0, 5.0, 20.0, 50.0)));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    } 
    
    if (!GTK_IS_SCROLLED_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT (widget), "hscrollbar-policy", HPOLICY, NULL);
    g_object_set (GTK_OBJECT (widget), "vscrollbar-policy", VPOLICY, NULL);
    
    gtk_scrolled_window_get_policy (GTK_SCROLLED_WINDOW (widget), &hscrollbar_policy,  &vscrollbar_policy);
    
    if (hscrollbar_policy != HPOLICY)
    {
        TEST_FAIL("hscrollbar policy fails", NULL);
    }
    
    if (vscrollbar_policy != VPOLICY)
    {
        TEST_FAIL("vscrollbar policy fails", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef HPOLICY
    #undef VPOLICY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_add_with_viewport
 * Params: GtkScrolledWindow *scrolled_window, GtkWidget *child
 * Returns: void
 * Assertion: Used to add children without native scrolling capabilities.
 * Params Values: a newly created GtkScrolledWindow*, gtk_vbox_new (FALSE,0);
 * Expected: void  
 */
static void test_purpose_36()
{
    #define    CHILD gtk_vbox_new (FALSE,0);
    
    GtkWidget* widget;
    GtkWidget* child;
    GtkWidget* real_child;
    GList* children;
    GtkBin* bin;
    GtkWidget* viewport;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (NULL,NULL);
    child = CHILD;
    gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (widget),child);
    
    bin = GTK_BIN (widget);
    viewport = gtk_bin_get_child (bin);
    
    children = gtk_container_get_children (GTK_CONTAINER (viewport));
    real_child = children->data;
    if (child != real_child)
    {
        TEST_FAIL ("Children is not added",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_add_with_viewport
 * Params: GtkScrolledWindow *scrolled_window, GtkWidget *child
 * Returns: void
 * Assertion: Used to add children without native scrolling capabilities.
 * Params Values: a newly created GtkScrolledWindow*, gtk_drawing_area_new ();
 * Expected: void  
 */
static void test_purpose_37()
{
    #define    CHILD gtk_drawing_area_new ();
    
    GtkWidget* widget;
    GtkWidget* child;
    GtkWidget* real_child;
    GList* children;
    GtkBin* bin;
    GtkWidget* viewport;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (NULL,NULL);
    child = CHILD;
    gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (widget),child);
    
    bin = GTK_BIN (widget);
    viewport = gtk_bin_get_child (bin);
    
    children = gtk_container_get_children (GTK_CONTAINER (viewport));
    real_child = children->data;
    if (child != real_child)
    {
        TEST_FAIL ("Children is not added",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_add_with_viewport
 * Params: GtkScrolledWindow *scrolled_window, GtkWidget *child
 * Returns: void
 * Assertion: Used to add children without native scrolling capabilities.
 * Params Values: a newly created GtkScrolledWindow*, gtk_widget_new (GTK_TYPE_IMAGE,NULL);
 * Expected: void  
 */
static void test_purpose_38()
{
    #define    CHILD gtk_widget_new (GTK_TYPE_IMAGE,NULL);
    
    GtkWidget* widget;
    GtkWidget* child;
    GtkWidget* real_child;
    GList* children;
    GtkBin* bin;
    GtkWidget* viewport;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (NULL,NULL);
    child = CHILD;
    gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (widget),child);
    
    bin = GTK_BIN (widget);
    viewport = gtk_bin_get_child (bin);
    
    children = gtk_container_get_children (GTK_CONTAINER (viewport));
    real_child = children->data;
    if (child != real_child)
    {
        TEST_FAIL ("Children is not added",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  CHILD
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_scrolled_window_add_with_viewport
 * Params: GtkScrolledWindow *scrolled_window, GtkWidget *child
 * Returns: void
 * Assertion: Used to add children without native scrolling capabilities.
 * Params Values: a newly created GtkScrolledWindow*, gtk_table_new (10,10,FALSE);
 * Expected: void  
 */
static void test_purpose_39()
{
    #define    CHILD gtk_table_new (10,10,FALSE);
    
    GtkWidget* widget;
    GtkWidget* child;
    GtkWidget* real_child;
    GList* children;
    GtkBin* bin;
    GtkWidget* viewport;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_scrolled_window_new (NULL,NULL);
    child = CHILD;
    gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (widget),child);
    
    bin = GTK_BIN (widget);
    viewport = gtk_bin_get_child (bin);
    
    children = gtk_container_get_children (GTK_CONTAINER (viewport));
    real_child = children->data;
    if (child != real_child)
    {
        TEST_FAIL ("Children is not added",NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  CHILD
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkScrolledWindow ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {NULL,0}
};
