/*
 * GtkTextTagTable methods tests
 * Testing GtkTextTagTable methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
GtkTextTagTable *global_widget;
gint global_counter;

void 
global_function_1 (GtkTextTag* tag, gpointer data)
{
    global_counter++;
}

void 
global_function_2 (GtkTextTag* tag, gpointer data)
{
    global_counter--;
}

gboolean 
global_event (GtkTextTag *texttag, GObject *arg1, GdkEvent *event, GtkTextIter arg2, gpointer user_data)
{
    global_counter++;
    return FALSE;
}


/*
 * Name: gtk_text_tag_table_new
 * Params: void
 * Returns: GtkTextTagTable*
 * Assertion: Creates a new GtkTextTagTable. 
 * Params Values: void
 * Expected: GtkTextTagTable*  
 */
static void test_purpose_1()
{
    GtkTextTagTable *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_new
 * Params: void
 * Returns: GtkTextTagTable*
 * Assertion: The table contains no tags by default.
 * Params Values: void
 * Expected: GtkTextTagTable*  
 */
static void test_purpose_2()
{
    GtkTextTagTable *widget;
    gint num = 0;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    num = gtk_text_tag_table_get_size (GTK_TEXT_TAG_TABLE (widget));
    if (num !=0)
    {
        TEST_FAIL ("The table contains no tags by default",NULL);
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_add 
 * Params: GtkTextTagTable *table,  GtkTextTag *tag
 * Returns: void
 * Assertion: Add a tag to the table.
 * Params Values: a newly created GtkTextTagTable*, a newly created GtkTextTag*
 * Expected: void  
 */
static void test_purpose_3()
{
    #define TEXT NULL
    
    GtkTextTagTable *widget;
    GtkTextTag *tag;
    gint num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    tag = gtk_text_tag_new (TEXT);
    
    gtk_text_tag_table_add (widget,tag);
    
    num = gtk_text_tag_table_get_size (widget);
    if (num != 1)
    {
        TEST_FAIL ("Tag is not added",NULL);
    }
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_add 
 * Params: GtkTextTagTable *table,  GtkTextTag *tag
 * Returns: void
 * Assertion: Add a tag to the table.
 * Params Values: a newly created GtkTextTagTable*, a newly created GtkTextTag*
 * Expected: void  
 */
static void test_purpose_4()
{
    #define TEXT ""
    
    GtkTextTagTable *widget;
    GtkTextTag *tag;
    gint num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    tag = gtk_text_tag_new (TEXT);
    
    gtk_text_tag_table_add (widget,tag);
    
    num = gtk_text_tag_table_get_size (widget);
    if (num != 1)
    {
        TEST_FAIL ("Tag is not added",NULL);
    }
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_add 
 * Params: GtkTextTagTable *table,  GtkTextTag *tag
 * Returns: void
 * Assertion: Add a tag to the table.
 * Params Values: a newly created GtkTextTagTable*, a newly created GtkTextTag*
 * Expected: void  
 */
static void test_purpose_5()
{
    #define TEXT " "
    
    GtkTextTagTable *widget;
    GtkTextTag *tag;
    gint num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    tag = gtk_text_tag_new (TEXT);
    
    gtk_text_tag_table_add (widget,tag);
    
    num = gtk_text_tag_table_get_size (widget);
    if (num != 1)
    {
        TEST_FAIL ("Tag is not added",NULL);
    }
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_add 
 * Params: GtkTextTagTable *table,  GtkTextTag *tag
 * Returns: void
 * Assertion: Add a tag to the table.
 * Params Values: a newly created GtkTextTagTable*, a newly created GtkTextTag*
 * Expected: void  
 */
static void test_purpose_6()
{
    #define TEXT "Label"
    
    GtkTextTagTable *widget;
    GtkTextTag *tag;
    gint num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    tag = gtk_text_tag_new (TEXT);
    
    gtk_text_tag_table_add (widget,tag);
    
    num = gtk_text_tag_table_get_size (widget);
    if (num != 1)
    {
        TEST_FAIL ("Tag is not added",NULL);
    }
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_add 
 * Params: GtkTextTagTable *table,  GtkTextTag *tag
 * Returns: void
 * Assertion: Add a tag to the table.
 * Params Values: a newly created GtkTextTagTable*, a newly created GtkTextTag*
 * Expected: void  
 */
static void test_purpose_7()
{
    #define TEXT "\b\t\n"
    
    GtkTextTagTable *widget;
    GtkTextTag *tag;
    gint num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    tag = gtk_text_tag_new (TEXT);
    
    gtk_text_tag_table_add (widget,tag);
    
    num = gtk_text_tag_table_get_size (widget);
    if (num != 1)
    {
        TEST_FAIL ("Tag is not added",NULL);
    }
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_add 
 * Params: GtkTextTagTable *table,  GtkTextTag *tag
 * Returns: void
 * Assertion: Add a tag to the table.
 * Params Values: a newly created GtkTextTagTable*, a newly created GtkTextTag*
 * Expected: void  
 */
static void test_purpose_8()
{
    #define TEXT "!@#$%^&*"
    
    GtkTextTagTable *widget;
    GtkTextTag *tag;
    gint num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    tag = gtk_text_tag_new (TEXT);
    
    gtk_text_tag_table_add (widget,tag);
    
    num = gtk_text_tag_table_get_size (widget);
    if (num != 1)
    {
        TEST_FAIL ("Tag is not added",NULL);
    }
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_add 
 * Params: GtkTextTagTable *table,  GtkTextTag *tag
 * Returns: void
 * Assertion: Add a tag to the table.
 * Params Values: a newly created GtkTextTagTable*, a newly created GtkTextTag*
 * Expected: void  
 */
static void test_purpose_9()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    
    GtkTextTagTable *widget;
    GtkTextTag *tag;
    gint num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    tag = gtk_text_tag_new (TEXT);
    
    gtk_text_tag_table_add (widget,tag);
    
    num = gtk_text_tag_table_get_size (widget);
    if (num != 1)
    {
        TEST_FAIL ("Tag is not added",NULL);
    }
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_add 
 * Params: GtkTextTagTable *table,  GtkTextTag *tag
 * Returns: void
 * Assertion: The tag is assigned the highest priority in the table.
 * Params Values: a newly created GtkTextTagTable*, a newly created GtkTextTag*
 * Expected: void  
 */
static void test_purpose_10()
{
    
    GtkTextTagTable *widget;
    GtkTextTag *tag;
    gint num;
    gint prior2;
    gint prior3;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    tag = gtk_text_tag_new ("Tag 1");
    gtk_text_tag_table_add (widget,tag);
    
    tag = gtk_text_tag_new ("Tag 2");
    gtk_text_tag_table_add (widget,tag);
    prior2 = gtk_text_tag_get_priority (GTK_TEXT_TAG (tag));
    
    tag = gtk_text_tag_new ("Tag 3");
    gtk_text_tag_table_add (widget,tag);
    prior3 = gtk_text_tag_get_priority (GTK_TEXT_TAG (tag));
    
    if(prior3 < prior2)
    {
        TEST_FAIL ("The tag is assigned the highest priority in the table",NULL);
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_remove 
 * Params: GtkTextTagTable *table,  GtkTextTag *tag
 * Returns: void
 * Assertion: Remove a tag from the table.
 * Params Values: a newly created GtkTextTagTable*, a newly created GtkTextTag*
 * Expected: void
 * 
 * Name: gtk_text_tag_table_remove 
 * Params: GtkTextTagTable *table,  GtkTextTag *tag
 * Returns: void
 * Assertion: This will remove the table's reference to the tag, so be careful - the tag will end up destroyed if you don't have a reference to it.
 * Params Values: a newly created GtkTextTagTable*, a newly created GtkTextTag*
 * Expected: void  
 */
static void test_purpose_11()
{
    GtkTextTagTable *widget;
    GtkTextTag *tag;
    GtkTextTag *tag1;
    gint num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    tag = gtk_text_tag_new ("Tag 1");
    gtk_text_tag_table_add (widget, tag);
    
    tag1 = gtk_text_tag_new ("Tag 2");
    gtk_text_tag_table_add (widget, tag1);
    
    gtk_text_tag_table_remove (widget, tag);
    num = gtk_text_tag_table_get_size (widget);
    
    if (num != 1)
    {
        TEST_FAIL ("Tag is not removed",NULL);
    }
    
    if (G_OBJECT (tag)->ref_count != 1)
    {
        TEST_FAIL ("ref_count = %i, should be 1", G_OBJECT (tag)->ref_count);
    }
    
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_lookup 
 * Params: GtkTextTagTable *table, const gchar *name 
 * Returns: GtkTextTag*
 * Assertion: Look up a named tag.
 * Params Values: a newly created GtkTextTagTable*, "Tag 1"
 * Expected: GtkTextTag*  
 */
static void test_purpose_12()
{
    #define TEXT "Tag 1"
    #define CORRECT_TEXT "Tag 1"
    
    GtkTextTagTable *widget;
    GtkTextTag *tag;
    GtkTextTag *tag1;
    gint num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    tag = gtk_text_tag_new ("Tag 1");
    gtk_text_tag_table_add (widget,tag);
    
    tag1 = gtk_text_tag_table_lookup (widget,TEXT);
    if (!strcmp(TEXT,CORRECT_TEXT))
    {
        if(!tag1)
        {
            TEST_FAIL ("Tag is in the table",NULL);
        }
    } else {
        if (tag1)
        {
            TEST_FAIL ("Tag is not in the table",NULL);
        }
    }
    
    #undef TEXT
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_lookup 
 * Params: GtkTextTagTable *table, const gchar *name 
 * Returns: GtkTextTag*
 * Assertion: Look up a named tag.
 * Params Values: a newly created GtkTextTagTable*, ""
 * Expected: GtkTextTag*  
 */
static void test_purpose_13()
{
    #define TEXT ""
    #define CORRECT_TEXT "Tag 1"
    
    GtkTextTagTable *widget;
    GtkTextTag *tag;
    GtkTextTag *tag1;
    gint num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    tag = gtk_text_tag_new ("Tag 1");
    gtk_text_tag_table_add (widget,tag);
    
    tag1 = gtk_text_tag_table_lookup (widget,TEXT);
    if (!strcmp(TEXT,CORRECT_TEXT))
    {
        if(!tag1)
        {
            TEST_FAIL ("Tag is in the table",NULL);
        }
    } else {
        if (tag1)
        {
            TEST_FAIL ("Tag is not in the table",NULL);
        }
    }
    
    #undef TEXT
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_lookup 
 * Params: GtkTextTagTable *table, const gchar *name 
 * Returns: GtkTextTag*
 * Assertion: Look up a named tag.
 * Params Values: a newly created GtkTextTagTable*, " "
 * Expected: GtkTextTag*  
 */
static void test_purpose_14()
{
    #define TEXT " "
    #define CORRECT_TEXT "Tag 1"
    
    GtkTextTagTable *widget;
    GtkTextTag *tag;
    GtkTextTag *tag1;
    gint num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    tag = gtk_text_tag_new ("Tag 1");
    gtk_text_tag_table_add (widget,tag);
    
    tag1 = gtk_text_tag_table_lookup (widget,TEXT);
    if (!strcmp(TEXT,CORRECT_TEXT))
    {
        if(!tag1)
        {
            TEST_FAIL ("Tag is in the table",NULL);
        }
    } else {
        if (tag1)
        {
            TEST_FAIL ("Tag is not in the table",NULL);
        }
    }
    
    #undef TEXT
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_lookup 
 * Params: GtkTextTagTable *table, const gchar *name 
 * Returns: GtkTextTag*
 * Assertion: Look up a named tag.
 * Params Values: a newly created GtkTextTagTable*, "Label"
 * Expected: GtkTextTag*  
 */
static void test_purpose_15()
{
    #define TEXT "Label"
    #define CORRECT_TEXT "Tag 1"
    
    GtkTextTagTable *widget;
    GtkTextTag *tag;
    GtkTextTag *tag1;
    gint num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    tag = gtk_text_tag_new ("Tag 1");
    gtk_text_tag_table_add (widget,tag);
    
    tag1 = gtk_text_tag_table_lookup (widget,TEXT);
    if (!strcmp(TEXT,CORRECT_TEXT))
    {
        if(!tag1)
        {
            TEST_FAIL ("Tag is in the table",NULL);
        }
    } else {
        if (tag1)
        {
            TEST_FAIL ("Tag is not in the table",NULL);
        }
    }
    
    #undef TEXT
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_lookup 
 * Params: GtkTextTagTable *table, const gchar *name 
 * Returns: GtkTextTag*
 * Assertion: Look up a named tag.
 * Params Values: a newly created GtkTextTagTable*, "\b\t\n"
 * Expected: GtkTextTag*  
 */
static void test_purpose_16()
{
    #define TEXT "\b\t\n"
    #define CORRECT_TEXT "Tag 1"
    
    GtkTextTagTable *widget;
    GtkTextTag *tag;
    GtkTextTag *tag1;
    gint num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    tag = gtk_text_tag_new ("Tag 1");
    gtk_text_tag_table_add (widget,tag);
    
    tag1 = gtk_text_tag_table_lookup (widget,TEXT);
    if (!strcmp(TEXT,CORRECT_TEXT))
    {
        if(!tag1)
        {
            TEST_FAIL ("Tag is in the table",NULL);
        }
    } else {
        if (tag1)
        {
            TEST_FAIL ("Tag is not in the table",NULL);
        }
    }
    
    #undef TEXT
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_lookup 
 * Params: GtkTextTagTable *table, const gchar *name 
 * Returns: GtkTextTag*
 * Assertion: Look up a named tag.
 * Params Values: a newly created GtkTextTagTable*, "!@#$%^&*"
 * Expected: GtkTextTag*  
 */
static void test_purpose_17()
{
    #define TEXT "!@#$%^&*"
    #define CORRECT_TEXT "Tag 1"
    
    GtkTextTagTable *widget;
    GtkTextTag *tag;
    GtkTextTag *tag1;
    gint num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    tag = gtk_text_tag_new ("Tag 1");
    gtk_text_tag_table_add (widget,tag);
    
    tag1 = gtk_text_tag_table_lookup (widget,TEXT);
    if (!strcmp(TEXT,CORRECT_TEXT))
    {
        if(!tag1)
        {
            TEST_FAIL ("Tag is in the table",NULL);
        }
    } else {
        if (tag1)
        {
            TEST_FAIL ("Tag is not in the table",NULL);
        }
    }
    
    #undef TEXT
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_lookup 
 * Params: GtkTextTagTable *table, const gchar *name 
 * Returns: GtkTextTag*
 * Assertion: Look up a named tag.
 * Params Values: a newly created GtkTextTagTable*, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
 * Expected: GtkTextTag*  
 */
static void test_purpose_18()
{
    #define TEXT "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ123456789"
    #define CORRECT_TEXT "Tag 1"
    
    GtkTextTagTable *widget;
    GtkTextTag *tag;
    GtkTextTag *tag1;
    gint num;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    tag = gtk_text_tag_new ("Tag 1");
    gtk_text_tag_table_add (widget,tag);
    
    tag1 = gtk_text_tag_table_lookup (widget,TEXT);
    if (!strcmp(TEXT,CORRECT_TEXT))
    {
        if(!tag1)
        {
            TEST_FAIL ("Tag is in the table",NULL);
        }
    } else {
        if (tag1)
        {
            TEST_FAIL ("Tag is not in the table",NULL);
        }
    }
    
    #undef TEXT
    #undef CORRECT_TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_get_size
 * Params: GtkTextTagTable *table
 * Returns: gint
 * Assertion: Returns the size of the table (number of tags) 
 * Params Values: a newly created GtkTextTagTable*
 * Expected: gint  
 */
static void test_purpose_19()
{
    #define NUM 1
    GtkTextTagTable *widget;
    GtkTextTag *tag;
    GtkTextTag *tag1;
    gint num;
    gint i;
    gchar buff[100];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 1; i <= NUM; i++)
    {
        sprintf (buff, "Tag %i", i);
        gtk_text_tag_table_add (widget, gtk_text_tag_new (buff));
    } 
    
    
    num = gtk_text_tag_table_get_size (widget);
    
    if (num != NUM)
    {
        TEST_FAIL ("number of tags is '%d', should be '%d'",num,NUM);
    }
    
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_get_size
 * Params: GtkTextTagTable *table
 * Returns: gint
 * Assertion: Returns the size of the table (number of tags) 
 * Params Values: a newly created GtkTextTagTable*
 * Expected: gint  
 */
static void test_purpose_20()
{
    #define NUM 2
    GtkTextTagTable *widget;
    GtkTextTag *tag;
    GtkTextTag *tag1;
    gint num;
    gint i;
    gchar buff[100];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 1; i <= NUM; i++)
    {
        sprintf (buff, "Tag %i", i);
        gtk_text_tag_table_add (widget, gtk_text_tag_new (buff));
    } 
    
    
    num = gtk_text_tag_table_get_size (widget);
    
    if (num != NUM)
    {
        TEST_FAIL ("number of tags is '%d', should be '%d'",num,NUM);
    }
    
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_get_size
 * Params: GtkTextTagTable *table
 * Returns: gint
 * Assertion: Returns the size of the table (number of tags) 
 * Params Values: a newly created GtkTextTagTable*
 * Expected: gint  
 */
static void test_purpose_21()
{
    #define NUM 10
    GtkTextTagTable *widget;
    GtkTextTag *tag;
    GtkTextTag *tag1;
    gint num;
    gint i;
    gchar buff[100];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 1; i <= NUM; i++)
    {
        sprintf (buff, "Tag %i", i);
        gtk_text_tag_table_add (widget, gtk_text_tag_new (buff));
    } 
    
    
    num = gtk_text_tag_table_get_size (widget);
    
    if (num != NUM)
    {
        TEST_FAIL ("number of tags is '%d', should be '%d'",num,NUM);
    }
    
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_get_size
 * Params: GtkTextTagTable *table
 * Returns: gint
 * Assertion: Returns the size of the table (number of tags) 
 * Params Values: a newly created GtkTextTagTable*
 * Expected: gint  
 */
static void test_purpose_22()
{
    #define NUM 100
    GtkTextTagTable *widget;
    GtkTextTag *tag;
    GtkTextTag *tag1;
    gint num;
    gint i;
    gchar buff[100];
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_tag_table_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 1; i <= NUM; i++)
    {
        sprintf (buff, "Tag %i", i);
        gtk_text_tag_table_add (widget, gtk_text_tag_new (buff));
    } 
    
    
    num = gtk_text_tag_table_get_size (widget);
    
    if (num != NUM)
    {
        TEST_FAIL ("number of tags is '%d', should be '%d'",num,NUM);
    }
    
    #undef NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_tag_table_foreach
 * Params: GtkTextTagTable *table, GtkTextTagTableForeach func, gpointer data 
 * Returns: void
 * Assertion: Calls func on each tag in table, with user data data. 
 * Params Values: a newly created GtkTextTagTable*,GtkTextTagTableForeach,gpointer
 * Expected: void  
 */
static void test_purpose_23()
{
    GtkTextTag *tag1;
    GtkTextTag *tag2;
    GtkTextTag *tag3;
    GtkTextTag *tag4;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    global_widget = gtk_text_tag_table_new ();
    
    if (!global_widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_TEXT_TAG_TABLE (global_widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    tag1 = gtk_text_tag_new ("Tag 1");
    gtk_text_tag_table_add (global_widget, tag1);
    
    tag2 = gtk_text_tag_new ("Tag 2");
    gtk_text_tag_table_add (global_widget, tag2);
    
    tag3 = gtk_text_tag_new ("Tag 3");
    gtk_text_tag_table_add (global_widget, tag3);
    
    tag4 = gtk_text_tag_new ("Tag 4");
    gtk_text_tag_table_add (global_widget, tag4);
    
    gtk_text_tag_table_foreach (global_widget, &global_function_1, tag4);
    if (global_counter != 4)
    {
        TEST_FAIL ("global_counter = %d, should be %d", global_counter, 4);
    }
    
    gtk_text_tag_table_foreach (global_widget, &global_function_2, tag4);
    if (global_counter != 0)
    {
        TEST_FAIL ("global_counter = %d, should be %d", global_counter, 0);
    }
    
    
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkTextTagTable ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {NULL,0}
};
