/*
 * GtkUIManager methods tests
 * Testing GtkUIManager methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

static void
lookup_character_action ()
{
    g_print ("lookup\n");
}

static void
clear_character_action ()
{
    g_print ("clear\n");
}

static void
quit_action ()
{
    gtk_main_quit();
}

static void
bar_action ()
{
    g_print ("Bar\n");
}

static GtkActionEntry entries[] =
{
    { "FileMenuAction", NULL, "_File" },                  /* name, stock id, label */
    { "CharacterMenuAction", NULL, "_Character" },


    { "LookupAction", GTK_STOCK_FIND,                     /* name, stock id */
        "_Lookup", "<control>L",                          /* label, accelerator */
        "Look-up the character drawn",                    /* tooltip */
        G_CALLBACK (lookup_character_action) },

    { "ClearAction", GTK_STOCK_OPEN,
        "_Clear","<control>C",
        "Clear the drawing area",
        G_CALLBACK (clear_character_action) },

    { "QuitAction", GTK_STOCK_QUIT,
        "_Quit", "<control>Q",
        "Quit",
        G_CALLBACK (quit_action) }
};

static guint n_entries = G_N_ELEMENTS (entries);

static void
menu_add_widget (GtkUIManager *ui, GtkWidget *widget, GtkContainer *container)
{
    gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
}


/*
 * Name: gtk_ui_manager_new
 * Params: void
 * Returns: GtkUIManager*
 * Assertion: Creates a new ui manager object.
 * Params Values: void
 * Expected: a new ui manager object.  
 */
static void test_purpose_1()
{
    GtkUIManager *ui_manager;
    gboolean add_tearoffs;
    gchararray ui;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(G_OBJECT(ui_manager), "add-tearoffs", &add_tearoffs, NULL);
    if (add_tearoffs != FALSE)
    {
        TEST_FAIL("add_tearoffs = %d, should be FALSE", add_tearoffs, NULL);
    }
    
    g_object_get(G_OBJECT(ui_manager), "ui", &ui, NULL);
    if (strcmp (ui, "<ui>\n</ui>\n"))
    {
        TEST_FAIL("ui = %s, should be <ui>\n</ui>\n", ui, NULL);
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_widget
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkWidget*
 * Assertion: Looks up a widget by following a path. The path consists of the names specified in the XML description of the UI. separated by '/'. Elements which don't have a name or action attribute in the XML (e.g. <popup>) can be addressed by their XML element name (e.g. "popup"). The root element ("/ui") can be omitted in the path. Note that the widget found by following a path that ends in a <menu> element is the menuitem to which the menu is attached, not the menu itself.
 * Params Values: a GtkUIManager, a path
 * Expected: the widget found by following the path.  
 */
static void test_purpose_2()
{
    #define PATH "/ui/menubar"
    #define GTK_IS_TYPE GTK_IS_MENU_BAR
    #define ASSERTION "GTK_IS_MENU_BAR"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (!GTK_IS_WIDGET (widget))
    {
        TEST_FAIL ("Did not find the widget following the path %s", PATH, NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL (ASSERTION " failed for the widget found by following the path %s", PATH, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef GTK_IS_TYPE
    #undef ASSERTION
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_widget
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkWidget*
 * Assertion: Looks up a widget by following a path. The path consists of the names specified in the XML description of the UI. separated by '/'. Elements which don't have a name or action attribute in the XML (e.g. <popup>) can be addressed by their XML element name (e.g. "popup"). The root element ("/ui") can be omitted in the path. Note that the widget found by following a path that ends in a <menu> element is the menuitem to which the menu is attached, not the menu itself.
 * Params Values: a GtkUIManager, a path
 * Expected: the widget found by following the path.  
 */
static void test_purpose_3()
{
    #define PATH "/menubar"
    #define GTK_IS_TYPE GTK_IS_MENU_BAR
    #define ASSERTION "GTK_IS_MENU_BAR"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (!GTK_IS_WIDGET (widget))
    {
        TEST_FAIL ("Did not find the widget following the path %s", PATH, NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL (ASSERTION " failed for the widget found by following the path %s", PATH, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef GTK_IS_TYPE
    #undef ASSERTION
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_widget
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkWidget*
 * Assertion: Looks up a widget by following a path. The path consists of the names specified in the XML description of the UI. separated by '/'. Elements which don't have a name or action attribute in the XML (e.g. <popup>) can be addressed by their XML element name (e.g. "popup"). The root element ("/ui") can be omitted in the path. Note that the widget found by following a path that ends in a <menu> element is the menuitem to which the menu is attached, not the menu itself.
 * Params Values: a GtkUIManager, a path
 * Expected: the widget found by following the path.  
 */
static void test_purpose_4()
{
    #define PATH "/ui/menubar/FileMenu"
    #define GTK_IS_TYPE GTK_IS_MENU_ITEM
    #define ASSERTION "GTK_IS_MENU_ITEM"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (!GTK_IS_WIDGET (widget))
    {
        TEST_FAIL ("Did not find the widget following the path %s", PATH, NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL (ASSERTION " failed for the widget found by following the path %s", PATH, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef GTK_IS_TYPE
    #undef ASSERTION
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_widget
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkWidget*
 * Assertion: Looks up a widget by following a path. The path consists of the names specified in the XML description of the UI. separated by '/'. Elements which don't have a name or action attribute in the XML (e.g. <popup>) can be addressed by their XML element name (e.g. "popup"). The root element ("/ui") can be omitted in the path. Note that the widget found by following a path that ends in a <menu> element is the menuitem to which the menu is attached, not the menu itself.
 * Params Values: a GtkUIManager, a path
 * Expected: the widget found by following the path.  
 */
static void test_purpose_5()
{
    #define PATH "/menubar/FileMenu"
    #define GTK_IS_TYPE GTK_IS_MENU_ITEM
    #define ASSERTION "GTK_IS_MENU_ITEM"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (!GTK_IS_WIDGET (widget))
    {
        TEST_FAIL ("Did not find the widget following the path %s", PATH, NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL (ASSERTION " failed for the widget found by following the path %s", PATH, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef GTK_IS_TYPE
    #undef ASSERTION
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_widget
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkWidget*
 * Assertion: Looks up a widget by following a path. The path consists of the names specified in the XML description of the UI. separated by '/'. Elements which don't have a name or action attribute in the XML (e.g. <popup>) can be addressed by their XML element name (e.g. "popup"). The root element ("/ui") can be omitted in the path. Note that the widget found by following a path that ends in a <menu> element is the menuitem to which the menu is attached, not the menu itself.
 * Params Values: a GtkUIManager, a path
 * Expected: the widget found by following the path.  
 */
static void test_purpose_6()
{
    #define PATH "/ui/menubar/FileMenu/Quit"
    #define GTK_IS_TYPE GTK_IS_MENU_ITEM
    #define ASSERTION "GTK_IS_MENU_ITEM"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (!GTK_IS_WIDGET (widget))
    {
        TEST_FAIL ("Did not find the widget following the path %s", PATH, NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL (ASSERTION " failed for the widget found by following the path %s", PATH, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef GTK_IS_TYPE
    #undef ASSERTION
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_widget
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkWidget*
 * Assertion: Looks up a widget by following a path. The path consists of the names specified in the XML description of the UI. separated by '/'. Elements which don't have a name or action attribute in the XML (e.g. <popup>) can be addressed by their XML element name (e.g. "popup"). The root element ("/ui") can be omitted in the path. Note that the widget found by following a path that ends in a <menu> element is the menuitem to which the menu is attached, not the menu itself.
 * Params Values: a GtkUIManager, a path
 * Expected: the widget found by following the path.  
 */
static void test_purpose_7()
{
    #define PATH "/menubar/FileMenu/Quit"
    #define GTK_IS_TYPE GTK_IS_MENU_ITEM
    #define ASSERTION "GTK_IS_MENU_ITEM"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (!GTK_IS_WIDGET (widget))
    {
        TEST_FAIL ("Did not find the widget following the path %s", PATH, NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL (ASSERTION " failed for the widget found by following the path %s", PATH, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef GTK_IS_TYPE
    #undef ASSERTION
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_widget
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkWidget*
 * Assertion: Looks up a widget by following a path. The path consists of the names specified in the XML description of the UI. separated by '/'. Elements which don't have a name or action attribute in the XML (e.g. <popup>) can be addressed by their XML element name (e.g. "popup"). The root element ("/ui") can be omitted in the path. Note that the widget found by following a path that ends in a <menu> element is the menuitem to which the menu is attached, not the menu itself.
 * Params Values: a GtkUIManager, a path
 * Expected: the widget found by following the path.  
 */
static void test_purpose_8()
{
    #define PATH "/ui/menubar/CharacterMenu"
    #define GTK_IS_TYPE GTK_IS_MENU_ITEM
    #define ASSERTION "GTK_IS_MENU_ITEM"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (!GTK_IS_WIDGET (widget))
    {
        TEST_FAIL ("Did not find the widget following the path %s", PATH, NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL (ASSERTION " failed for the widget found by following the path %s", PATH, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef GTK_IS_TYPE
    #undef ASSERTION
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_widget
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkWidget*
 * Assertion: Looks up a widget by following a path. The path consists of the names specified in the XML description of the UI. separated by '/'. Elements which don't have a name or action attribute in the XML (e.g. <popup>) can be addressed by their XML element name (e.g. "popup"). The root element ("/ui") can be omitted in the path. Note that the widget found by following a path that ends in a <menu> element is the menuitem to which the menu is attached, not the menu itself.
 * Params Values: a GtkUIManager, a path
 * Expected: the widget found by following the path.  
 */
static void test_purpose_9()
{
    #define PATH "/menubar/CharacterMenu"
    #define GTK_IS_TYPE GTK_IS_MENU_ITEM
    #define ASSERTION "GTK_IS_MENU_ITEM"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (!GTK_IS_WIDGET (widget))
    {
        TEST_FAIL ("Did not find the widget following the path %s", PATH, NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL (ASSERTION " failed for the widget found by following the path %s", PATH, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef GTK_IS_TYPE
    #undef ASSERTION
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_widget
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkWidget*
 * Assertion: Looks up a widget by following a path. The path consists of the names specified in the XML description of the UI. separated by '/'. Elements which don't have a name or action attribute in the XML (e.g. <popup>) can be addressed by their XML element name (e.g. "popup"). The root element ("/ui") can be omitted in the path. Note that the widget found by following a path that ends in a <menu> element is the menuitem to which the menu is attached, not the menu itself.
 * Params Values: a GtkUIManager, a path
 * Expected: the widget found by following the path.  
 */
static void test_purpose_10()
{
    #define PATH "/ui/menubar/CharacterMenu/Lookup"
    #define GTK_IS_TYPE GTK_IS_MENU_ITEM
    #define ASSERTION "GTK_IS_MENU_ITEM"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (!GTK_IS_WIDGET (widget))
    {
        TEST_FAIL ("Did not find the widget following the path %s", PATH, NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL (ASSERTION " failed for the widget found by following the path %s", PATH, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef GTK_IS_TYPE
    #undef ASSERTION
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_widget
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkWidget*
 * Assertion: Looks up a widget by following a path. The path consists of the names specified in the XML description of the UI. separated by '/'. Elements which don't have a name or action attribute in the XML (e.g. <popup>) can be addressed by their XML element name (e.g. "popup"). The root element ("/ui") can be omitted in the path. Note that the widget found by following a path that ends in a <menu> element is the menuitem to which the menu is attached, not the menu itself.
 * Params Values: a GtkUIManager, a path
 * Expected: the widget found by following the path.  
 */
static void test_purpose_11()
{
    #define PATH "/menubar/CharacterMenu/Lookup"
    #define GTK_IS_TYPE GTK_IS_MENU_ITEM
    #define ASSERTION "GTK_IS_MENU_ITEM"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (!GTK_IS_WIDGET (widget))
    {
        TEST_FAIL ("Did not find the widget following the path %s", PATH, NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL (ASSERTION " failed for the widget found by following the path %s", PATH, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef GTK_IS_TYPE
    #undef ASSERTION
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_widget
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkWidget*
 * Assertion: Looks up a widget by following a path. The path consists of the names specified in the XML description of the UI. separated by '/'. Elements which don't have a name or action attribute in the XML (e.g. <popup>) can be addressed by their XML element name (e.g. "popup"). The root element ("/ui") can be omitted in the path. Note that the widget found by following a path that ends in a <menu> element is the menuitem to which the menu is attached, not the menu itself.
 * Params Values: a GtkUIManager, a path
 * Expected: the widget found by following the path.  
 */
static void test_purpose_12()
{
    #define PATH "/ui/MainMenuBar"
    #define GTK_IS_TYPE GTK_IS_TOOLBAR
    #define ASSERTION "GTK_IS_TOOLBAR"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (!GTK_IS_WIDGET (widget))
    {
        TEST_FAIL ("Did not find the widget following the path %s", PATH, NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL (ASSERTION " failed for the widget found by following the path %s", PATH, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef GTK_IS_TYPE
    #undef ASSERTION
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_widget
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkWidget*
 * Assertion: Looks up a widget by following a path. The path consists of the names specified in the XML description of the UI. separated by '/'. Elements which don't have a name or action attribute in the XML (e.g. <popup>) can be addressed by their XML element name (e.g. "popup"). The root element ("/ui") can be omitted in the path. Note that the widget found by following a path that ends in a <menu> element is the menuitem to which the menu is attached, not the menu itself.
 * Params Values: a GtkUIManager, a path
 * Expected: the widget found by following the path.  
 */
static void test_purpose_13()
{
    #define PATH "/MainMenuBar"
    #define GTK_IS_TYPE GTK_IS_TOOLBAR
    #define ASSERTION "GTK_IS_TOOLBAR"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (!GTK_IS_WIDGET (widget))
    {
        TEST_FAIL ("Did not find the widget following the path %s", PATH, NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL (ASSERTION " failed for the widget found by following the path %s", PATH, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef GTK_IS_TYPE
    #undef ASSERTION
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_widget
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkWidget*
 * Assertion: Looks up a widget by following a path. The path consists of the names specified in the XML description of the UI. separated by '/'. Elements which don't have a name or action attribute in the XML (e.g. <popup>) can be addressed by their XML element name (e.g. "popup"). The root element ("/ui") can be omitted in the path. Note that the widget found by following a path that ends in a <menu> element is the menuitem to which the menu is attached, not the menu itself.
 * Params Values: a GtkUIManager, a path
 * Expected: the widget found by following the path.  
 */
static void test_purpose_14()
{
    #define PATH "/ui/MainMenuBar/ToolItems/Clear"
    #define GTK_IS_TYPE GTK_IS_TOOL_ITEM
    #define ASSERTION "GTK_IS_TOOL_ITEM"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (!GTK_IS_WIDGET (widget))
    {
        TEST_FAIL ("Did not find the widget following the path %s", PATH, NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL (ASSERTION " failed for the widget found by following the path %s", PATH, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef GTK_IS_TYPE
    #undef ASSERTION
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_widget
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkWidget*
 * Assertion: Looks up a widget by following a path. The path consists of the names specified in the XML description of the UI. separated by '/'. Elements which don't have a name or action attribute in the XML (e.g. <popup>) can be addressed by their XML element name (e.g. "popup"). The root element ("/ui") can be omitted in the path. Note that the widget found by following a path that ends in a <menu> element is the menuitem to which the menu is attached, not the menu itself.
 * Params Values: a GtkUIManager, a path
 * Expected: the widget found by following the path.  
 */
static void test_purpose_15()
{
    #define PATH "/MainMenuBar/ToolItems/Clear"
    #define GTK_IS_TYPE GTK_IS_TOOL_ITEM
    #define ASSERTION "GTK_IS_TOOL_ITEM"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (!GTK_IS_WIDGET (widget))
    {
        TEST_FAIL ("Did not find the widget following the path %s", PATH, NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL (ASSERTION " failed for the widget found by following the path %s", PATH, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef GTK_IS_TYPE
    #undef ASSERTION
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_widget
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkWidget*
 * Assertion: Looks up a widget by following a path. The path consists of the names specified in the XML description of the UI. separated by '/'. Elements which don't have a name or action attribute in the XML (e.g. <popup>) can be addressed by their XML element name (e.g. "popup"). The root element ("/ui") can be omitted in the path. Note that the widget found by following a path that ends in a <menu> element is the menuitem to which the menu is attached, not the menu itself.
 * Params Values: a GtkUIManager, a path
 * Expected: the widget found by following the path.  
 */
static void test_purpose_16()
{
    #define PATH "/ui/MainMenuBar/ToolItems/Lookup"
    #define GTK_IS_TYPE GTK_IS_TOOL_ITEM
    #define ASSERTION "GTK_IS_TOOL_ITEM"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (!GTK_IS_WIDGET (widget))
    {
        TEST_FAIL ("Did not find the widget following the path %s", PATH, NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL (ASSERTION " failed for the widget found by following the path %s", PATH, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef GTK_IS_TYPE
    #undef ASSERTION
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_widget
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkWidget*
 * Assertion: Looks up a widget by following a path. The path consists of the names specified in the XML description of the UI. separated by '/'. Elements which don't have a name or action attribute in the XML (e.g. <popup>) can be addressed by their XML element name (e.g. "popup"). The root element ("/ui") can be omitted in the path. Note that the widget found by following a path that ends in a <menu> element is the menuitem to which the menu is attached, not the menu itself.
 * Params Values: a GtkUIManager, a path
 * Expected: the widget found by following the path.  
 */
static void test_purpose_17()
{
    #define PATH "/MainMenuBar/ToolItems/Lookup"
    #define GTK_IS_TYPE GTK_IS_TOOL_ITEM
    #define ASSERTION "GTK_IS_TOOL_ITEM"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (!GTK_IS_WIDGET (widget))
    {
        TEST_FAIL ("Did not find the widget following the path %s", PATH, NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL (ASSERTION " failed for the widget found by following the path %s", PATH, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef GTK_IS_TYPE
    #undef ASSERTION
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_widget
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkWidget*
 * Assertion: Looks up a widget by following a path. The path consists of the names specified in the XML description of the UI. separated by '/'. Elements which don't have a name or action attribute in the XML (e.g. <popup>) can be addressed by their XML element name (e.g. "popup"). The root element ("/ui") can be omitted in the path. Note that the widget found by following a path that ends in a <menu> element is the menuitem to which the menu is attached, not the menu itself.
 * Params Values: a GtkUIManager, an invalid path
 * Expected: NULL if no widget was found.  
 */
static void test_purpose_18()
{
    #define PATH "/foo/bar"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (widget != NULL)
    {
        TEST_FAIL ("Widget should be NULL", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_widget
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkWidget*
 * Assertion: Looks up a widget by following a path. The path consists of the names specified in the XML description of the UI. separated by '/'. Elements which don't have a name or action attribute in the XML (e.g. <popup>) can be addressed by their XML element name (e.g. "popup"). The root element ("/ui") can be omitted in the path. Note that the widget found by following a path that ends in a <menu> element is the menuitem to which the menu is attached, not the menu itself.
 * Params Values: a GtkUIManager, an invalid path
 * Expected: NULL if no widget was found.  
 */
static void test_purpose_19()
{
    #define PATH "/123456"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (widget != NULL)
    {
        TEST_FAIL ("Widget should be NULL", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_widget
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkWidget*
 * Assertion: Looks up a widget by following a path. The path consists of the names specified in the XML description of the UI. separated by '/'. Elements which don't have a name or action attribute in the XML (e.g. <popup>) can be addressed by their XML element name (e.g. "popup"). The root element ("/ui") can be omitted in the path. Note that the widget found by following a path that ends in a <menu> element is the menuitem to which the menu is attached, not the menu itself.
 * Params Values: a GtkUIManager, an invalid path
 * Expected: NULL if no widget was found.  
 */
static void test_purpose_20()
{
    #define PATH "/~!@#$%^&*()_+"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (widget != NULL)
    {
        TEST_FAIL ("Widget should be NULL", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_action
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkAction*
 * Assertion: Looks up an action by following a path.
 * Params Values: a GtkUIManager, a path
 * Expected: the action whose proxy widget is found by following the path.  
 */
static void test_purpose_21()
{
    #define PATH "/ui/menubar/FileMenu"
    #define NAME "FileMenuAction"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    GtkAction *action;
    const gchar *action_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    action = gtk_ui_manager_get_action  (ui_manager, PATH);
    
    if (!GTK_IS_ACTION (action))
    {
        TEST_FAIL ("Did not find the action following the path %s", PATH, NULL);
    }
    
    action_name = gtk_action_get_name (action);
    
    if (!action_name || strcmp (action_name, NAME))
    {
        TEST_FAIL ("Action name should be %s, not %s", NAME, action_name, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef NAME
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_action
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkAction*
 * Assertion: Looks up an action by following a path.
 * Params Values: a GtkUIManager, a path
 * Expected: the action whose proxy widget is found by following the path.  
 */
static void test_purpose_22()
{
    #define PATH "/menubar/FileMenu"
    #define NAME "FileMenuAction"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    GtkAction *action;
    const gchar *action_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    action = gtk_ui_manager_get_action  (ui_manager, PATH);
    
    if (!GTK_IS_ACTION (action))
    {
        TEST_FAIL ("Did not find the action following the path %s", PATH, NULL);
    }
    
    action_name = gtk_action_get_name (action);
    
    if (!action_name || strcmp (action_name, NAME))
    {
        TEST_FAIL ("Action name should be %s, not %s", NAME, action_name, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef NAME
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_action
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkAction*
 * Assertion: Looks up an action by following a path.
 * Params Values: a GtkUIManager, a path
 * Expected: the action whose proxy widget is found by following the path.  
 */
static void test_purpose_23()
{
    #define PATH "/ui/menubar/CharacterMenu"
    #define NAME "CharacterMenuAction"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    GtkAction *action;
    const gchar *action_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    action = gtk_ui_manager_get_action  (ui_manager, PATH);
    
    if (!GTK_IS_ACTION (action))
    {
        TEST_FAIL ("Did not find the action following the path %s", PATH, NULL);
    }
    
    action_name = gtk_action_get_name (action);
    
    if (!action_name || strcmp (action_name, NAME))
    {
        TEST_FAIL ("Action name should be %s, not %s", NAME, action_name, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef NAME
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_action
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkAction*
 * Assertion: Looks up an action by following a path.
 * Params Values: a GtkUIManager, a path
 * Expected: the action whose proxy widget is found by following the path.  
 */
static void test_purpose_24()
{
    #define PATH "/menubar/CharacterMenu"
    #define NAME "CharacterMenuAction"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    GtkAction *action;
    const gchar *action_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    action = gtk_ui_manager_get_action  (ui_manager, PATH);
    
    if (!GTK_IS_ACTION (action))
    {
        TEST_FAIL ("Did not find the action following the path %s", PATH, NULL);
    }
    
    action_name = gtk_action_get_name (action);
    
    if (!action_name || strcmp (action_name, NAME))
    {
        TEST_FAIL ("Action name should be %s, not %s", NAME, action_name, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef NAME
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_action
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkAction*
 * Assertion: Looks up an action by following a path.
 * Params Values: a GtkUIManager, a path
 * Expected: the action whose proxy widget is found by following the path.  
 */
static void test_purpose_25()
{
    #define PATH "/ui/menubar/FileMenu/Quit"
    #define NAME "QuitAction"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    GtkAction *action;
    const gchar *action_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    action = gtk_ui_manager_get_action  (ui_manager, PATH);
    
    if (!GTK_IS_ACTION (action))
    {
        TEST_FAIL ("Did not find the action following the path %s", PATH, NULL);
    }
    
    action_name = gtk_action_get_name (action);
    
    if (!action_name || strcmp (action_name, NAME))
    {
        TEST_FAIL ("Action name should be %s, not %s", NAME, action_name, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef NAME
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_action
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkAction*
 * Assertion: Looks up an action by following a path.
 * Params Values: a GtkUIManager, a path
 * Expected: the action whose proxy widget is found by following the path.  
 */
static void test_purpose_26()
{
    #define PATH "/menubar/FileMenu/Quit"
    #define NAME "QuitAction"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    GtkAction *action;
    const gchar *action_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    action = gtk_ui_manager_get_action  (ui_manager, PATH);
    
    if (!GTK_IS_ACTION (action))
    {
        TEST_FAIL ("Did not find the action following the path %s", PATH, NULL);
    }
    
    action_name = gtk_action_get_name (action);
    
    if (!action_name || strcmp (action_name, NAME))
    {
        TEST_FAIL ("Action name should be %s, not %s", NAME, action_name, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef NAME
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_action
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkAction*
 * Assertion: Looks up an action by following a path.
 * Params Values: a GtkUIManager, a path
 * Expected: the action whose proxy widget is found by following the path.  
 */
static void test_purpose_27()
{
    #define PATH "/ui/menubar/CharacterMenu/Clear"
    #define NAME "ClearAction"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    GtkAction *action;
    const gchar *action_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    action = gtk_ui_manager_get_action  (ui_manager, PATH);
    
    if (!GTK_IS_ACTION (action))
    {
        TEST_FAIL ("Did not find the action following the path %s", PATH, NULL);
    }
    
    action_name = gtk_action_get_name (action);
    
    if (!action_name || strcmp (action_name, NAME))
    {
        TEST_FAIL ("Action name should be %s, not %s", NAME, action_name, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef NAME
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_action
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkAction*
 * Assertion: Looks up an action by following a path.
 * Params Values: a GtkUIManager, a path
 * Expected: the action whose proxy widget is found by following the path.  
 */
static void test_purpose_28()
{
    #define PATH "/menubar/CharacterMenu/Clear"
    #define NAME "ClearAction"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    GtkAction *action;
    const gchar *action_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    action = gtk_ui_manager_get_action  (ui_manager, PATH);
    
    if (!GTK_IS_ACTION (action))
    {
        TEST_FAIL ("Did not find the action following the path %s", PATH, NULL);
    }
    
    action_name = gtk_action_get_name (action);
    
    if (!action_name || strcmp (action_name, NAME))
    {
        TEST_FAIL ("Action name should be %s, not %s", NAME, action_name, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef NAME
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_action
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkAction*
 * Assertion: Looks up an action by following a path.
 * Params Values: a GtkUIManager, a path
 * Expected: the action whose proxy widget is found by following the path.  
 */
static void test_purpose_29()
{
    #define PATH "/ui/menubar/CharacterMenu/Lookup"
    #define NAME "LookupAction"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    GtkAction *action;
    const gchar *action_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    action = gtk_ui_manager_get_action  (ui_manager, PATH);
    
    if (!GTK_IS_ACTION (action))
    {
        TEST_FAIL ("Did not find the action following the path %s", PATH, NULL);
    }
    
    action_name = gtk_action_get_name (action);
    
    if (!action_name || strcmp (action_name, NAME))
    {
        TEST_FAIL ("Action name should be %s, not %s", NAME, action_name, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef NAME
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_action
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkAction*
 * Assertion: Looks up an action by following a path.
 * Params Values: a GtkUIManager, a path
 * Expected: the action whose proxy widget is found by following the path.  
 */
static void test_purpose_30()
{
    #define PATH "/menubar/CharacterMenu/Lookup"
    #define NAME "LookupAction"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    GtkAction *action;
    const gchar *action_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    action = gtk_ui_manager_get_action  (ui_manager, PATH);
    
    if (!GTK_IS_ACTION (action))
    {
        TEST_FAIL ("Did not find the action following the path %s", PATH, NULL);
    }
    
    action_name = gtk_action_get_name (action);
    
    if (!action_name || strcmp (action_name, NAME))
    {
        TEST_FAIL ("Action name should be %s, not %s", NAME, action_name, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef NAME
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_action
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkAction*
 * Assertion: Looks up an action by following a path.
 * Params Values: a GtkUIManager, a path
 * Expected: the action whose proxy widget is found by following the path.  
 */
static void test_purpose_31()
{
    #define PATH "/ui/MainMenuBar/ToolItems/Clear"
    #define NAME "ClearAction"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    GtkAction *action;
    const gchar *action_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    action = gtk_ui_manager_get_action  (ui_manager, PATH);
    
    if (!GTK_IS_ACTION (action))
    {
        TEST_FAIL ("Did not find the action following the path %s", PATH, NULL);
    }
    
    action_name = gtk_action_get_name (action);
    
    if (!action_name || strcmp (action_name, NAME))
    {
        TEST_FAIL ("Action name should be %s, not %s", NAME, action_name, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef NAME
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_action
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkAction*
 * Assertion: Looks up an action by following a path.
 * Params Values: a GtkUIManager, a path
 * Expected: the action whose proxy widget is found by following the path.  
 */
static void test_purpose_32()
{
    #define PATH "/MainMenuBar/ToolItems/Clear"
    #define NAME "ClearAction"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    GtkAction *action;
    const gchar *action_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    action = gtk_ui_manager_get_action  (ui_manager, PATH);
    
    if (!GTK_IS_ACTION (action))
    {
        TEST_FAIL ("Did not find the action following the path %s", PATH, NULL);
    }
    
    action_name = gtk_action_get_name (action);
    
    if (!action_name || strcmp (action_name, NAME))
    {
        TEST_FAIL ("Action name should be %s, not %s", NAME, action_name, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef NAME
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_action
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkAction*
 * Assertion: Looks up an action by following a path.
 * Params Values: a GtkUIManager, a path
 * Expected: the action whose proxy widget is found by following the path.  
 */
static void test_purpose_33()
{
    #define PATH "/ui/MainMenuBar/ToolItems/Lookup"
    #define NAME "LookupAction"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    GtkAction *action;
    const gchar *action_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    action = gtk_ui_manager_get_action  (ui_manager, PATH);
    
    if (!GTK_IS_ACTION (action))
    {
        TEST_FAIL ("Did not find the action following the path %s", PATH, NULL);
    }
    
    action_name = gtk_action_get_name (action);
    
    if (!action_name || strcmp (action_name, NAME))
    {
        TEST_FAIL ("Action name should be %s, not %s", NAME, action_name, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef NAME
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_action
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkAction*
 * Assertion: Looks up an action by following a path.
 * Params Values: a GtkUIManager, a path
 * Expected: the action whose proxy widget is found by following the path.  
 */
static void test_purpose_34()
{
    #define PATH "/MainMenuBar/ToolItems/Lookup"
    #define NAME "LookupAction"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    GtkAction *action;
    const gchar *action_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    action = gtk_ui_manager_get_action  (ui_manager, PATH);
    
    if (!GTK_IS_ACTION (action))
    {
        TEST_FAIL ("Did not find the action following the path %s", PATH, NULL);
    }
    
    action_name = gtk_action_get_name (action);
    
    if (!action_name || strcmp (action_name, NAME))
    {
        TEST_FAIL ("Action name should be %s, not %s", NAME, action_name, NULL)
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef NAME
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_action
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkAction*
 * Assertion: Looks up an action by following a path.
 * Params Values: a GtkUIManager, a path
 * Expected: NULL if no widget was found.  
 */
static void test_purpose_35()
{
    #define PATH "/foo/bar"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    GtkAction *action;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    action = gtk_ui_manager_get_action  (ui_manager, PATH);
    
    if (action != NULL)
    {
        TEST_FAIL ("Action should be NULL", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_action
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkAction*
 * Assertion: Looks up an action by following a path.
 * Params Values: a GtkUIManager, a path
 * Expected: NULL if no widget was found.  
 */
static void test_purpose_36()
{
    #define PATH "/123456"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    GtkAction *action;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    action = gtk_ui_manager_get_action  (ui_manager, PATH);
    
    if (action != NULL)
    {
        TEST_FAIL ("Action should be NULL", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_get_action
 * Params: GtkUIManager *self, const gchar *path
 * Returns: GtkAction*
 * Assertion: Looks up an action by following a path.
 * Params Values: a GtkUIManager, a path
 * Expected: NULL if no widget was found.  
 */
static void test_purpose_37()
{
    #define PATH "/~!@#$%^&*()_+"
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    GtkAction *action;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    action = gtk_ui_manager_get_action  (ui_manager, PATH);
    
    if (action != NULL)
    {
        TEST_FAIL ("Action should be NULL", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_add_ui
 * Params: GtkUIManager *self, guint merge_id, const gchar *path, const gchar *name, const gchar *action, GtkUIManagerItemType type, gboolean top
 * Returns: void
 * Assertion: Adds a UI element to the current contents of self. If type is GTK_UI_MANAGER_AUTO, GTK+ inserts a menuitem, toolitem or separator if such an element can be inserted at the place determined by path. Otherwise type must indicate an element that can be inserted at the place determined by path.
 * Params Values: a GtkUIManager; the merge id for the merged UI; a path; the name for the added UI element; the name of the action to be proxied, or NULL to add a separator; the type of UI element to add; if TRUE, the UI element is added before its siblings, otherwise it is added after its siblings.
 * Expected: void  
 */
static void test_purpose_38()
{
    #define PATH "/ui/menubar/FileMenu"
    #define TYPE GTK_UI_MANAGER_MENUITEM
    #define TOP TRUE
    #define GTK_IS_TYPE GTK_IS_MENU_ITEM
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    guint new_merge_id;
    GtkActionGroup *new_action_group;
    GtkActionEntry newEntry[] = {
        {"BarAction", GTK_STOCK_CDROM, "_Bar", "<control>B", "tooltip for BAR", G_CALLBACK (bar_action)}
    };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    new_action_group = gtk_action_group_new ("MyNewActions");
    
    gtk_action_group_add_actions (new_action_group, newEntry, G_N_ELEMENTS (newEntry), NULL);
    gtk_ui_manager_insert_action_group(ui_manager, new_action_group, 0 );
    new_merge_id = gtk_ui_manager_new_merge_id(ui_manager);
    
    gtk_ui_manager_add_ui(ui_manager, new_merge_id, PATH, "Bar", "BarAction", TYPE, TOP);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH "/Bar");
    
    if (widget == NULL)
    {
        TEST_FAIL ("Widget found by following the path %s should not be NULL", PATH "/Bar", NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL ("Widget found by following the path %s is not of the appropriate type", PATH "/Bar", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef TYPE
    #undef TOP
    #undef GTK_IS_TYPE
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_add_ui
 * Params: GtkUIManager *self, guint merge_id, const gchar *path, const gchar *name, const gchar *action, GtkUIManagerItemType type, gboolean top
 * Returns: void
 * Assertion: Adds a UI element to the current contents of self. If type is GTK_UI_MANAGER_AUTO, GTK+ inserts a menuitem, toolitem or separator if such an element can be inserted at the place determined by path. Otherwise type must indicate an element that can be inserted at the place determined by path.
 * Params Values: a GtkUIManager; the merge id for the merged UI; a path; the name for the added UI element; the name of the action to be proxied, or NULL to add a separator; the type of UI element to add; if TRUE, the UI element is added before its siblings, otherwise it is added after its siblings.
 * Expected: void  
 */
static void test_purpose_39()
{
    #define PATH "/menubar/FileMenu"
    #define TYPE GTK_UI_MANAGER_MENUITEM
    #define TOP FALSE
    #define GTK_IS_TYPE GTK_IS_MENU_ITEM
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    guint new_merge_id;
    GtkActionGroup *new_action_group;
    GtkActionEntry newEntry[] = {
        {"BarAction", GTK_STOCK_CDROM, "_Bar", "<control>B", "tooltip for BAR", G_CALLBACK (bar_action)}
    };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    new_action_group = gtk_action_group_new ("MyNewActions");
    
    gtk_action_group_add_actions (new_action_group, newEntry, G_N_ELEMENTS (newEntry), NULL);
    gtk_ui_manager_insert_action_group(ui_manager, new_action_group, 0 );
    new_merge_id = gtk_ui_manager_new_merge_id(ui_manager);
    
    gtk_ui_manager_add_ui(ui_manager, new_merge_id, PATH, "Bar", "BarAction", TYPE, TOP);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH "/Bar");
    
    if (widget == NULL)
    {
        TEST_FAIL ("Widget found by following the path %s should not be NULL", PATH "/Bar", NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL ("Widget found by following the path %s is not of the appropriate type", PATH "/Bar", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef TYPE
    #undef TOP
    #undef GTK_IS_TYPE
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_add_ui
 * Params: GtkUIManager *self, guint merge_id, const gchar *path, const gchar *name, const gchar *action, GtkUIManagerItemType type, gboolean top
 * Returns: void
 * Assertion: Adds a UI element to the current contents of self. If type is GTK_UI_MANAGER_AUTO, GTK+ inserts a menuitem, toolitem or separator if such an element can be inserted at the place determined by path. Otherwise type must indicate an element that can be inserted at the place determined by path.
 * Params Values: a GtkUIManager; the merge id for the merged UI; a path; the name for the added UI element; the name of the action to be proxied, or NULL to add a separator; the type of UI element to add; if TRUE, the UI element is added before its siblings, otherwise it is added after its siblings.
 * Expected: void  
 */
static void test_purpose_40()
{
    #define PATH "/ui/menubar/FileMenu"
    #define TYPE GTK_UI_MANAGER_AUTO
    #define TOP TRUE
    #define GTK_IS_TYPE GTK_IS_MENU_ITEM
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    guint new_merge_id;
    GtkActionGroup *new_action_group;
    GtkActionEntry newEntry[] = {
        {"BarAction", GTK_STOCK_CDROM, "_Bar", "<control>B", "tooltip for BAR", G_CALLBACK (bar_action)}
    };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    new_action_group = gtk_action_group_new ("MyNewActions");
    
    gtk_action_group_add_actions (new_action_group, newEntry, G_N_ELEMENTS (newEntry), NULL);
    gtk_ui_manager_insert_action_group(ui_manager, new_action_group, 0 );
    new_merge_id = gtk_ui_manager_new_merge_id(ui_manager);
    
    gtk_ui_manager_add_ui(ui_manager, new_merge_id, PATH, "Bar", "BarAction", TYPE, TOP);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH "/Bar");
    
    if (widget == NULL)
    {
        TEST_FAIL ("Widget found by following the path %s should not be NULL", PATH "/Bar", NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL ("Widget found by following the path %s is not of the appropriate type", PATH "/Bar", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef TYPE
    #undef TOP
    #undef GTK_IS_TYPE
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_add_ui
 * Params: GtkUIManager *self, guint merge_id, const gchar *path, const gchar *name, const gchar *action, GtkUIManagerItemType type, gboolean top
 * Returns: void
 * Assertion: Adds a UI element to the current contents of self. If type is GTK_UI_MANAGER_AUTO, GTK+ inserts a menuitem, toolitem or separator if such an element can be inserted at the place determined by path. Otherwise type must indicate an element that can be inserted at the place determined by path.
 * Params Values: a GtkUIManager; the merge id for the merged UI; a path; the name for the added UI element; the name of the action to be proxied, or NULL to add a separator; the type of UI element to add; if TRUE, the UI element is added before its siblings, otherwise it is added after its siblings.
 * Expected: void  
 */
static void test_purpose_41()
{
    #define PATH "/menubar/FileMenu"
    #define TYPE GTK_UI_MANAGER_AUTO
    #define TOP FALSE
    #define GTK_IS_TYPE GTK_IS_MENU_ITEM
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    guint new_merge_id;
    GtkActionGroup *new_action_group;
    GtkActionEntry newEntry[] = {
        {"BarAction", GTK_STOCK_CDROM, "_Bar", "<control>B", "tooltip for BAR", G_CALLBACK (bar_action)}
    };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    new_action_group = gtk_action_group_new ("MyNewActions");
    
    gtk_action_group_add_actions (new_action_group, newEntry, G_N_ELEMENTS (newEntry), NULL);
    gtk_ui_manager_insert_action_group(ui_manager, new_action_group, 0 );
    new_merge_id = gtk_ui_manager_new_merge_id(ui_manager);
    
    gtk_ui_manager_add_ui(ui_manager, new_merge_id, PATH, "Bar", "BarAction", TYPE, TOP);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH "/Bar");
    
    if (widget == NULL)
    {
        TEST_FAIL ("Widget found by following the path %s should not be NULL", PATH "/Bar", NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL ("Widget found by following the path %s is not of the appropriate type", PATH "/Bar", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef TYPE
    #undef TOP
    #undef GTK_IS_TYPE
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_add_ui
 * Params: GtkUIManager *self, guint merge_id, const gchar *path, const gchar *name, const gchar *action, GtkUIManagerItemType type, gboolean top
 * Returns: void
 * Assertion: Adds a UI element to the current contents of self. If type is GTK_UI_MANAGER_AUTO, GTK+ inserts a menuitem, toolitem or separator if such an element can be inserted at the place determined by path. Otherwise type must indicate an element that can be inserted at the place determined by path.
 * Params Values: a GtkUIManager; the merge id for the merged UI; a path; the name for the added UI element; the name of the action to be proxied, or NULL to add a separator; the type of UI element to add; if TRUE, the UI element is added before its siblings, otherwise it is added after its siblings.
 * Expected: void  
 */
static void test_purpose_42()
{
    #define PATH "/ui/MainMenuBar/ToolItems"
    #define TYPE GTK_UI_MANAGER_TOOLITEM
    #define TOP TRUE
    #define GTK_IS_TYPE GTK_IS_TOOL_ITEM
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    guint new_merge_id;
    GtkActionGroup *new_action_group;
    GtkActionEntry newEntry[] = {
        {"BarAction", GTK_STOCK_CDROM, "_Bar", "<control>B", "tooltip for BAR", G_CALLBACK (bar_action)}
    };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    new_action_group = gtk_action_group_new ("MyNewActions");
    
    gtk_action_group_add_actions (new_action_group, newEntry, G_N_ELEMENTS (newEntry), NULL);
    gtk_ui_manager_insert_action_group(ui_manager, new_action_group, 0 );
    new_merge_id = gtk_ui_manager_new_merge_id(ui_manager);
    
    gtk_ui_manager_add_ui(ui_manager, new_merge_id, PATH, "Bar", "BarAction", TYPE, TOP);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH "/Bar");
    
    if (widget == NULL)
    {
        TEST_FAIL ("Widget found by following the path %s should not be NULL", PATH "/Bar", NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL ("Widget found by following the path %s is not of the appropriate type", PATH "/Bar", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef TYPE
    #undef TOP
    #undef GTK_IS_TYPE
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_add_ui
 * Params: GtkUIManager *self, guint merge_id, const gchar *path, const gchar *name, const gchar *action, GtkUIManagerItemType type, gboolean top
 * Returns: void
 * Assertion: Adds a UI element to the current contents of self. If type is GTK_UI_MANAGER_AUTO, GTK+ inserts a menuitem, toolitem or separator if such an element can be inserted at the place determined by path. Otherwise type must indicate an element that can be inserted at the place determined by path.
 * Params Values: a GtkUIManager; the merge id for the merged UI; a path; the name for the added UI element; the name of the action to be proxied, or NULL to add a separator; the type of UI element to add; if TRUE, the UI element is added before its siblings, otherwise it is added after its siblings.
 * Expected: void  
 */
static void test_purpose_43()
{
    #define PATH "/MainMenuBar/ToolItems"
    #define TYPE GTK_UI_MANAGER_TOOLITEM
    #define TOP FALSE
    #define GTK_IS_TYPE GTK_IS_TOOL_ITEM
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    guint new_merge_id;
    GtkActionGroup *new_action_group;
    GtkActionEntry newEntry[] = {
        {"BarAction", GTK_STOCK_CDROM, "_Bar", "<control>B", "tooltip for BAR", G_CALLBACK (bar_action)}
    };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    new_action_group = gtk_action_group_new ("MyNewActions");
    
    gtk_action_group_add_actions (new_action_group, newEntry, G_N_ELEMENTS (newEntry), NULL);
    gtk_ui_manager_insert_action_group(ui_manager, new_action_group, 0 );
    new_merge_id = gtk_ui_manager_new_merge_id(ui_manager);
    
    gtk_ui_manager_add_ui(ui_manager, new_merge_id, PATH, "Bar", "BarAction", TYPE, TOP);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH "/Bar");
    
    if (widget == NULL)
    {
        TEST_FAIL ("Widget found by following the path %s should not be NULL", PATH "/Bar", NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL ("Widget found by following the path %s is not of the appropriate type", PATH "/Bar", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef TYPE
    #undef TOP
    #undef GTK_IS_TYPE
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_add_ui
 * Params: GtkUIManager *self, guint merge_id, const gchar *path, const gchar *name, const gchar *action, GtkUIManagerItemType type, gboolean top
 * Returns: void
 * Assertion: Adds a UI element to the current contents of self. If type is GTK_UI_MANAGER_AUTO, GTK+ inserts a menuitem, toolitem or separator if such an element can be inserted at the place determined by path. Otherwise type must indicate an element that can be inserted at the place determined by path.
 * Params Values: a GtkUIManager; the merge id for the merged UI; a path; the name for the added UI element; the name of the action to be proxied, or NULL to add a separator; the type of UI element to add; if TRUE, the UI element is added before its siblings, otherwise it is added after its siblings.
 * Expected: void  
 */
static void test_purpose_44()
{
    #define PATH "/ui/MainMenuBar/ToolItems"
    #define TYPE GTK_UI_MANAGER_AUTO
    #define TOP TRUE
    #define GTK_IS_TYPE GTK_IS_TOOL_ITEM
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    guint new_merge_id;
    GtkActionGroup *new_action_group;
    GtkActionEntry newEntry[] = {
        {"BarAction", GTK_STOCK_CDROM, "_Bar", "<control>B", "tooltip for BAR", G_CALLBACK (bar_action)}
    };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    new_action_group = gtk_action_group_new ("MyNewActions");
    
    gtk_action_group_add_actions (new_action_group, newEntry, G_N_ELEMENTS (newEntry), NULL);
    gtk_ui_manager_insert_action_group(ui_manager, new_action_group, 0 );
    new_merge_id = gtk_ui_manager_new_merge_id(ui_manager);
    
    gtk_ui_manager_add_ui(ui_manager, new_merge_id, PATH, "Bar", "BarAction", TYPE, TOP);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH "/Bar");
    
    if (widget == NULL)
    {
        TEST_FAIL ("Widget found by following the path %s should not be NULL", PATH "/Bar", NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL ("Widget found by following the path %s is not of the appropriate type", PATH "/Bar", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef TYPE
    #undef TOP
    #undef GTK_IS_TYPE
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_add_ui
 * Params: GtkUIManager *self, guint merge_id, const gchar *path, const gchar *name, const gchar *action, GtkUIManagerItemType type, gboolean top
 * Returns: void
 * Assertion: Adds a UI element to the current contents of self. If type is GTK_UI_MANAGER_AUTO, GTK+ inserts a menuitem, toolitem or separator if such an element can be inserted at the place determined by path. Otherwise type must indicate an element that can be inserted at the place determined by path.
 * Params Values: a GtkUIManager; the merge id for the merged UI; a path; the name for the added UI element; the name of the action to be proxied, or NULL to add a separator; the type of UI element to add; if TRUE, the UI element is added before its siblings, otherwise it is added after its siblings.
 * Expected: void  
 */
static void test_purpose_45()
{
    #define PATH "/MainMenuBar/ToolItems"
    #define TYPE GTK_UI_MANAGER_AUTO
    #define TOP FALSE
    #define GTK_IS_TYPE GTK_IS_TOOL_ITEM
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    guint new_merge_id;
    GtkActionGroup *new_action_group;
    GtkActionEntry newEntry[] = {
        {"BarAction", GTK_STOCK_CDROM, "_Bar", "<control>B", "tooltip for BAR", G_CALLBACK (bar_action)}
    };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    new_action_group = gtk_action_group_new ("MyNewActions");
    
    gtk_action_group_add_actions (new_action_group, newEntry, G_N_ELEMENTS (newEntry), NULL);
    gtk_ui_manager_insert_action_group(ui_manager, new_action_group, 0 );
    new_merge_id = gtk_ui_manager_new_merge_id(ui_manager);
    
    gtk_ui_manager_add_ui(ui_manager, new_merge_id, PATH, "Bar", "BarAction", TYPE, TOP);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH "/Bar");
    
    if (widget == NULL)
    {
        TEST_FAIL ("Widget found by following the path %s should not be NULL", PATH "/Bar", NULL);
    }
    
    if (!GTK_IS_TYPE (widget))
    {
        TEST_FAIL ("Widget found by following the path %s is not of the appropriate type", PATH "/Bar", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef TYPE
    #undef TOP
    #undef GTK_IS_TYPE
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_remove_ui
 * Params: GtkUIManager *self, guint merge_id
 * Returns: void
 * Assertion: Unmerges the part of selfs content identified by merge_id.
 * Params Values: a GtkUIManager object, a merge id as returned by gtk_ui_manager_add_ui_from_string().
 * Expected: void  
 */
static void test_purpose_46()
{
    #define PATH "/ui/menubar/FileMenu"
    #define TYPE GTK_UI_MANAGER_MENUITEM
    #define TOP TRUE
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    guint merge_id;
    guint new_merge_id;
    GtkActionGroup *new_action_group;
    GtkActionEntry newEntry[] = {
        {"BarAction", GTK_STOCK_CDROM, "_Bar", "<control>B", "tooltip for BAR", G_CALLBACK (bar_action)}
    };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    merge_id = gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    new_action_group = gtk_action_group_new ("MyNewActions");
    
    gtk_action_group_add_actions (new_action_group, newEntry, G_N_ELEMENTS (newEntry), NULL);
    gtk_ui_manager_insert_action_group(ui_manager, new_action_group, 0 );
    new_merge_id = gtk_ui_manager_new_merge_id(ui_manager);
    
    gtk_ui_manager_add_ui(ui_manager, new_merge_id, PATH, "Bar", "BarAction", TYPE, TOP);
    
    gtk_ui_manager_remove_ui (ui_manager, new_merge_id);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH "/Bar");
    
    if (widget != NULL)
    {
        TEST_FAIL ("Widget should be NULL", NULL);
    }
    
    gtk_ui_manager_remove_ui (ui_manager, merge_id);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (widget != NULL)
    {
        TEST_FAIL ("Widget should be NULL", NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef TYPE
    #undef TOP
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_remove_ui
 * Params: GtkUIManager *self, guint merge_id
 * Returns: void
 * Assertion: Unmerges the part of selfs content identified by merge_id.
 * Params Values: a GtkUIManager object, a merge id as returned by gtk_ui_manager_add_ui_from_string().
 * Expected: void  
 */
static void test_purpose_47()
{
    #define PATH "/menubar/FileMenu"
    #define TYPE GTK_UI_MANAGER_MENUITEM
    #define TOP FALSE
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    guint merge_id;
    guint new_merge_id;
    GtkActionGroup *new_action_group;
    GtkActionEntry newEntry[] = {
        {"BarAction", GTK_STOCK_CDROM, "_Bar", "<control>B", "tooltip for BAR", G_CALLBACK (bar_action)}
    };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    merge_id = gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    new_action_group = gtk_action_group_new ("MyNewActions");
    
    gtk_action_group_add_actions (new_action_group, newEntry, G_N_ELEMENTS (newEntry), NULL);
    gtk_ui_manager_insert_action_group(ui_manager, new_action_group, 0 );
    new_merge_id = gtk_ui_manager_new_merge_id(ui_manager);
    
    gtk_ui_manager_add_ui(ui_manager, new_merge_id, PATH, "Bar", "BarAction", TYPE, TOP);
    
    gtk_ui_manager_remove_ui (ui_manager, new_merge_id);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH "/Bar");
    
    if (widget != NULL)
    {
        TEST_FAIL ("Widget should be NULL", NULL);
    }
    
    gtk_ui_manager_remove_ui (ui_manager, merge_id);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (widget != NULL)
    {
        TEST_FAIL ("Widget should be NULL", NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef TYPE
    #undef TOP
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_remove_ui
 * Params: GtkUIManager *self, guint merge_id
 * Returns: void
 * Assertion: Unmerges the part of selfs content identified by merge_id.
 * Params Values: a GtkUIManager object, a merge id as returned by gtk_ui_manager_add_ui_from_string().
 * Expected: void  
 */
static void test_purpose_48()
{
    #define PATH "/ui/menubar/FileMenu"
    #define TYPE GTK_UI_MANAGER_AUTO
    #define TOP TRUE
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    guint merge_id;
    guint new_merge_id;
    GtkActionGroup *new_action_group;
    GtkActionEntry newEntry[] = {
        {"BarAction", GTK_STOCK_CDROM, "_Bar", "<control>B", "tooltip for BAR", G_CALLBACK (bar_action)}
    };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    merge_id = gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    new_action_group = gtk_action_group_new ("MyNewActions");
    
    gtk_action_group_add_actions (new_action_group, newEntry, G_N_ELEMENTS (newEntry), NULL);
    gtk_ui_manager_insert_action_group(ui_manager, new_action_group, 0 );
    new_merge_id = gtk_ui_manager_new_merge_id(ui_manager);
    
    gtk_ui_manager_add_ui(ui_manager, new_merge_id, PATH, "Bar", "BarAction", TYPE, TOP);
    
    gtk_ui_manager_remove_ui (ui_manager, new_merge_id);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH "/Bar");
    
    if (widget != NULL)
    {
        TEST_FAIL ("Widget should be NULL", NULL);
    }
    
    gtk_ui_manager_remove_ui (ui_manager, merge_id);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (widget != NULL)
    {
        TEST_FAIL ("Widget should be NULL", NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef TYPE
    #undef TOP
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_remove_ui
 * Params: GtkUIManager *self, guint merge_id
 * Returns: void
 * Assertion: Unmerges the part of selfs content identified by merge_id.
 * Params Values: a GtkUIManager object, a merge id as returned by gtk_ui_manager_add_ui_from_string().
 * Expected: void  
 */
static void test_purpose_49()
{
    #define PATH "/menubar/FileMenu"
    #define TYPE GTK_UI_MANAGER_AUTO
    #define TOP FALSE
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    guint merge_id;
    guint new_merge_id;
    GtkActionGroup *new_action_group;
    GtkActionEntry newEntry[] = {
        {"BarAction", GTK_STOCK_CDROM, "_Bar", "<control>B", "tooltip for BAR", G_CALLBACK (bar_action)}
    };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    merge_id = gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    new_action_group = gtk_action_group_new ("MyNewActions");
    
    gtk_action_group_add_actions (new_action_group, newEntry, G_N_ELEMENTS (newEntry), NULL);
    gtk_ui_manager_insert_action_group(ui_manager, new_action_group, 0 );
    new_merge_id = gtk_ui_manager_new_merge_id(ui_manager);
    
    gtk_ui_manager_add_ui(ui_manager, new_merge_id, PATH, "Bar", "BarAction", TYPE, TOP);
    
    gtk_ui_manager_remove_ui (ui_manager, new_merge_id);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH "/Bar");
    
    if (widget != NULL)
    {
        TEST_FAIL ("Widget should be NULL", NULL);
    }
    
    gtk_ui_manager_remove_ui (ui_manager, merge_id);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (widget != NULL)
    {
        TEST_FAIL ("Widget should be NULL", NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef TYPE
    #undef TOP
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_remove_ui
 * Params: GtkUIManager *self, guint merge_id
 * Returns: void
 * Assertion: Unmerges the part of selfs content identified by merge_id.
 * Params Values: a GtkUIManager object, a merge id as returned by gtk_ui_manager_add_ui_from_string().
 * Expected: void  
 */
static void test_purpose_50()
{
    #define PATH "/ui/MainMenuBar/ToolItems"
    #define TYPE GTK_UI_MANAGER_TOOLITEM
    #define TOP TRUE
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    guint merge_id;
    guint new_merge_id;
    GtkActionGroup *new_action_group;
    GtkActionEntry newEntry[] = {
        {"BarAction", GTK_STOCK_CDROM, "_Bar", "<control>B", "tooltip for BAR", G_CALLBACK (bar_action)}
    };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    merge_id = gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    new_action_group = gtk_action_group_new ("MyNewActions");
    
    gtk_action_group_add_actions (new_action_group, newEntry, G_N_ELEMENTS (newEntry), NULL);
    gtk_ui_manager_insert_action_group(ui_manager, new_action_group, 0 );
    new_merge_id = gtk_ui_manager_new_merge_id(ui_manager);
    
    gtk_ui_manager_add_ui(ui_manager, new_merge_id, PATH, "Bar", "BarAction", TYPE, TOP);
    
    gtk_ui_manager_remove_ui (ui_manager, new_merge_id);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH "/Bar");
    
    if (widget != NULL)
    {
        TEST_FAIL ("Widget should be NULL", NULL);
    }
    
    gtk_ui_manager_remove_ui (ui_manager, merge_id);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (widget != NULL)
    {
        TEST_FAIL ("Widget should be NULL", NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef TYPE
    #undef TOP
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_remove_ui
 * Params: GtkUIManager *self, guint merge_id
 * Returns: void
 * Assertion: Unmerges the part of selfs content identified by merge_id.
 * Params Values: a GtkUIManager object, a merge id as returned by gtk_ui_manager_add_ui_from_string().
 * Expected: void  
 */
static void test_purpose_51()
{
    #define PATH "/MainMenuBar/ToolItems"
    #define TYPE GTK_UI_MANAGER_TOOLITEM
    #define TOP FALSE
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    guint merge_id;
    guint new_merge_id;
    GtkActionGroup *new_action_group;
    GtkActionEntry newEntry[] = {
        {"BarAction", GTK_STOCK_CDROM, "_Bar", "<control>B", "tooltip for BAR", G_CALLBACK (bar_action)}
    };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    merge_id = gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    new_action_group = gtk_action_group_new ("MyNewActions");
    
    gtk_action_group_add_actions (new_action_group, newEntry, G_N_ELEMENTS (newEntry), NULL);
    gtk_ui_manager_insert_action_group(ui_manager, new_action_group, 0 );
    new_merge_id = gtk_ui_manager_new_merge_id(ui_manager);
    
    gtk_ui_manager_add_ui(ui_manager, new_merge_id, PATH, "Bar", "BarAction", TYPE, TOP);
    
    gtk_ui_manager_remove_ui (ui_manager, new_merge_id);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH "/Bar");
    
    if (widget != NULL)
    {
        TEST_FAIL ("Widget should be NULL", NULL);
    }
    
    gtk_ui_manager_remove_ui (ui_manager, merge_id);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (widget != NULL)
    {
        TEST_FAIL ("Widget should be NULL", NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef TYPE
    #undef TOP
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_remove_ui
 * Params: GtkUIManager *self, guint merge_id
 * Returns: void
 * Assertion: Unmerges the part of selfs content identified by merge_id.
 * Params Values: a GtkUIManager object, a merge id as returned by gtk_ui_manager_add_ui_from_string().
 * Expected: void  
 */
static void test_purpose_52()
{
    #define PATH "/ui/MainMenuBar/ToolItems"
    #define TYPE GTK_UI_MANAGER_AUTO
    #define TOP TRUE
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    guint merge_id;
    guint new_merge_id;
    GtkActionGroup *new_action_group;
    GtkActionEntry newEntry[] = {
        {"BarAction", GTK_STOCK_CDROM, "_Bar", "<control>B", "tooltip for BAR", G_CALLBACK (bar_action)}
    };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    merge_id = gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    new_action_group = gtk_action_group_new ("MyNewActions");
    
    gtk_action_group_add_actions (new_action_group, newEntry, G_N_ELEMENTS (newEntry), NULL);
    gtk_ui_manager_insert_action_group(ui_manager, new_action_group, 0 );
    new_merge_id = gtk_ui_manager_new_merge_id(ui_manager);
    
    gtk_ui_manager_add_ui(ui_manager, new_merge_id, PATH, "Bar", "BarAction", TYPE, TOP);
    
    gtk_ui_manager_remove_ui (ui_manager, new_merge_id);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH "/Bar");
    
    if (widget != NULL)
    {
        TEST_FAIL ("Widget should be NULL", NULL);
    }
    
    gtk_ui_manager_remove_ui (ui_manager, merge_id);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (widget != NULL)
    {
        TEST_FAIL ("Widget should be NULL", NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef TYPE
    #undef TOP
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_ui_manager_remove_ui
 * Params: GtkUIManager *self, guint merge_id
 * Returns: void
 * Assertion: Unmerges the part of selfs content identified by merge_id.
 * Params Values: a GtkUIManager object, a merge id as returned by gtk_ui_manager_add_ui_from_string().
 * Expected: void  
 */
static void test_purpose_53()
{
    #define PATH "/MainMenuBar/ToolItems"
    #define TYPE GTK_UI_MANAGER_AUTO
    #define TOP FALSE
    #define UI_FILE_NAME "/gtkvts/src/tests/functions/Widgets/MyUI.xml"
    
    GtkWidget *widget;
    GtkWidget *box;
    GtkActionGroup *action_group;
    GtkUIManager *ui_manager;
    GError *error;
    gchar *filename;
    gchar *tet_root;
    guint merge_id;
    guint new_merge_id;
    GtkActionGroup *new_action_group;
    GtkActionEntry newEntry[] = {
        {"BarAction", GTK_STOCK_CDROM, "_Bar", "<control>B", "tooltip for BAR", G_CALLBACK (bar_action)}
    };
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    box = gtk_vbox_new (FALSE, 0);
    action_group = gtk_action_group_new ("MyActions");
    
    ui_manager = gtk_ui_manager_new ();
    
    if (!ui_manager)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    if (!GTK_IS_UI_MANAGER (ui_manager))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_action_group_add_actions (action_group, entries, n_entries, NULL);
    gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
    
    filename = calloc (1, 1024);
    
    if (!filename)
    {
        TEST_FAIL ("No memory available", NULL);
        return;
    }
    
    tet_root = getenv ("TET_ROOT");
    
    if (!tet_root)
    {
        TEST_FAIL ("Environment variable TET_ROOT not set", NULL);
        return;
    }
    
    filename = strcat (filename, tet_root);
    filename = strcat (filename, UI_FILE_NAME);
    
    error = NULL;
    merge_id = gtk_ui_manager_add_ui_from_file (ui_manager, filename, &error);
    
    if (error)
    {
        g_message ("building menus failed: %s", error->message);
        g_error_free (error);
    }
    
    g_signal_connect (ui_manager, "add-widget", G_CALLBACK (menu_add_widget), box);
    
    new_action_group = gtk_action_group_new ("MyNewActions");
    
    gtk_action_group_add_actions (new_action_group, newEntry, G_N_ELEMENTS (newEntry), NULL);
    gtk_ui_manager_insert_action_group(ui_manager, new_action_group, 0 );
    new_merge_id = gtk_ui_manager_new_merge_id(ui_manager);
    
    gtk_ui_manager_add_ui(ui_manager, new_merge_id, PATH, "Bar", "BarAction", TYPE, TOP);
    
    gtk_ui_manager_remove_ui (ui_manager, new_merge_id);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH "/Bar");
    
    if (widget != NULL)
    {
        TEST_FAIL ("Widget should be NULL", NULL);
    }
    
    gtk_ui_manager_remove_ui (ui_manager, merge_id);
    
    widget = gtk_ui_manager_get_widget (ui_manager, PATH);
    
    if (widget != NULL)
    {
        TEST_FAIL ("Widget should be NULL", NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (box);
    /******* -------------  *******/
    
    gtk_widget_destroy (gtk_widget_get_toplevel (box));
    
    free (filename);
    
    #undef PATH
    #undef TYPE
    #undef TOP
    #undef UI_FILE_NAME
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkUIManager ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {NULL,0}
};
