/*
 * Singly_Linked_Lists methods tests
 * Testing Singly_Linked_Lists methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

static gint nums[] = {0, 1, 2, 3, 4, 5, 6, 7, 8, 9};    /* the initial list data */
static gint data_size = sizeof(nums);

static GSList*
my_init_list(gint *g_data, GSList* list)
{
    int i = 0;
    for (i = 0; i < data_size / sizeof(gint); i++)
        list = g_slist_append(list, g_data + i);
    return list;
}

static gint
my_list_compare_one (gconstpointer a, gconstpointer b)
{
    gint one = *((const gint*)a);
    gint two = *((const gint*)b);
    return one-two;
}

static gint
my_list_compare_two (gconstpointer a, gconstpointer b)
{
    gint one = *((const gint*)a);
    gint two = *((const gint*)b);
    return two-one;
}

static void
g_user_func(gpointer data, gpointer user_data)
{
    *(gint *)data += *(gint *)user_data;
}


/*
 * Name: g_slist_append
 * Params: GSList *list, gpointer data
 * Returns: GSList*
 * Assertion: Adds a new element on to the end of the list. 
 *            The return value is the new start of the list, which may have changed, so make sure you store the new value
 *            list : a GSList.
 *            data : the data for the new element.
 *            Returns : the new start of the GSList.
 * Params Values: NULL, 100
 * Expected: 100  
 */
static void test_purpose_1()
{
    #define LIST NULL
    #define DATA 100
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GSList *list = NULL, *gslist = NULL;
    gint data = 0;
    
    list = g_slist_alloc();
    if (list == NULL){
        TEST_FAIL("g_slist_append: Can't alloc one node", NULL);
    }
    
    data = DATA;
    gslist = g_slist_append(LIST, &data);
    list = g_slist_last(gslist);
    /* Check if the data has been added into the end of LIST */
    if (*(gint *)list->data != 100){
        TEST_FAIL("g_slist_append: Should be 100, now is %d", *(gint *)list->data);
    }
    
    #undef LIST
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_slist_append
 * Params: GSList *list, gpointer data
 * Returns: GSList*
 * Assertion: Adds a new element on to the end of the list. 
 *            The return value is the new start of the list, which may have changed, so make sure you store the new value
 *            list : a GSList.
 *            data : the data for the new element.
 *            Returns : the new start of the GSList.
 * Params Values: list, 100
 * Expected: 100  
 */
static void test_purpose_2()
{
    #define LIST list
    #define DATA 100
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GSList *list = NULL, *gslist = NULL;
    gint data = 0;
    
    list = g_slist_alloc();
    if (list == NULL){
        TEST_FAIL("g_slist_append: Can't alloc one node", NULL);
    }
    
    data = DATA;
    gslist = g_slist_append(LIST, &data);
    list = g_slist_last(gslist);
    /* Check if the data has been added into the end of LIST */
    if (*(gint *)list->data != 100){
        TEST_FAIL("g_slist_append: Should be 100, now is %d", *(gint *)list->data);
    }
    
    #undef LIST
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_slist_prepend
 * Params: GSList *list, gpointer data
 * Returns: GSList*
 * Assertion: Adds a new element on to the start of the list.
 *            The return value is the new start of the list, which may have changed, so make sure you store the new value
 *            list : a GSList.
 *            data : the data for the new element.
 *            Returns : the new start of the GSList.
 * Params Values: NULL, 100
 * Expected: 100  
 */
static void test_purpose_3()
{
    #define LIST NULL
    #define DATA 100
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GSList *list = NULL, *gslist = NULL;
    gint data = 0;
    
    list = g_slist_alloc();
    if (list == NULL){
        TEST_FAIL("g_slist_prepend: Can't alloc one node", NULL);
    }
    
    data = DATA;
    gslist = g_slist_prepend(LIST, &data);
    /* Check if the data has been added into the start of LIST */
    if (*(gint *)gslist->data != 100){
        TEST_FAIL("g_slist_prepend: Should be 100, now is %d", *(gint *)gslist->data);
    }
    
    #undef LIST
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_slist_prepend
 * Params: GSList *list, gpointer data
 * Returns: GSList*
 * Assertion: Adds a new element on to the start of the list.
 *            The return value is the new start of the list, which may have changed, so make sure you store the new value
 *            list : a GSList.
 *            data : the data for the new element.
 *            Returns : the new start of the GSList.
 * Params Values: list, 100
 * Expected: 100  
 */
static void test_purpose_4()
{
    #define LIST list
    #define DATA 100
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    GSList *list = NULL, *gslist = NULL;
    gint data = 0;
    
    list = g_slist_alloc();
    if (list == NULL){
        TEST_FAIL("g_slist_prepend: Can't alloc one node", NULL);
    }
    
    data = DATA;
    gslist = g_slist_prepend(LIST, &data);
    /* Check if the data has been added into the start of LIST */
    if (*(gint *)gslist->data != 100){
        TEST_FAIL("g_slist_prepend: Should be 100, now is %d", *(gint *)gslist->data);
    }
    
    #undef LIST
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_slist_insert
 * Params: GSList *list, gpointer data, gint position
 * Returns: GSList*
 * Assertion: Inserts a new element into the list at the given position.
 *            list : a GSList.
 *            data : the data for the new element.
 *            position : the position to insert the element. If this is negative, or is larger than the number of elements in the list, the new element is added on to the end of the list.
 *            Returns : the new start of the GSList.
 * Params Values: list, 10, 3
 * Expected: 10  
 */
static void test_purpose_5()
{
    #define LIST list
    #define DATA 10
    #define POS  3
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    GSList *list = NULL;
    gint* g_data = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    list = my_init_list(g_data, list);
    
    list = g_slist_insert(LIST, GINT_TO_POINTER(DATA), POS);
    
    /* Check if when the position is negative, or is larger than the number of elements in the list, 
       the new element is added on to the end of the list. 
    */   
    if ((POS > 10) || (POS < 0)){
        gint dt = GPOINTER_TO_INT(g_slist_last(list)->data);
        if (DATA != dt){
            TEST_FAIL("g_slist_insert: The data should be %d, now is %d", DATA, dt);
        }
    }
    
    /* Check if the data has been inserted in the position */
    else{
        gint dt = GPOINTER_TO_INT(g_slist_nth_data(list, POS));
        if (DATA != dt){
            TEST_FAIL("g_slist_insert: The data should be %d, now is %d", DATA, dt);
        }
    }
    g_free(g_data);
    
    #undef LIST
    #undef DATA
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_slist_insert
 * Params: GSList *list, gpointer data, gint position
 * Returns: GSList*
 * Assertion: Inserts a new element into the list at the given position.
 *            list : a GSList.
 *            data : the data for the new element.
 *            position : the position to insert the element. If this is negative, or is larger than the number of elements in the list, the new element is added on to the end of the list.
 *            Returns : the new start of the GSList.
 * Params Values: list, 10, -1
 * Expected: 10  
 */
static void test_purpose_6()
{
    #define LIST list
    #define DATA 10
    #define POS  -1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    GSList *list = NULL;
    gint* g_data = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    list = my_init_list(g_data, list);
    
    list = g_slist_insert(LIST, GINT_TO_POINTER(DATA), POS);
    
    /* Check if when the position is negative, or is larger than the number of elements in the list, 
       the new element is added on to the end of the list. 
    */   
    if ((POS > 10) || (POS < 0)){
        gint dt = GPOINTER_TO_INT(g_slist_last(list)->data);
        if (DATA != dt){
            TEST_FAIL("g_slist_insert: The data should be %d, now is %d", DATA, dt);
        }
    }
    
    /* Check if the data has been inserted in the position */
    else{
        gint dt = GPOINTER_TO_INT(g_slist_nth_data(list, POS));
        if (DATA != dt){
            TEST_FAIL("g_slist_insert: The data should be %d, now is %d", DATA, dt);
        }
    }
    g_free(g_data);
    
    #undef LIST
    #undef DATA
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_slist_insert
 * Params: GSList *list, gpointer data, gint position
 * Returns: GSList*
 * Assertion: Inserts a new element into the list at the given position.
 *            list : a GSList.
 *            data : the data for the new element.
 *            position : the position to insert the element. If this is negative, or is larger than the number of elements in the list, the new element is added on to the end of the list.
 *            Returns : the new start of the GSList.
 * Params Values: list , 10, 100
 * Expected: 10  
 */
static void test_purpose_7()
{
    #define LIST list 
    #define DATA 10
    #define POS  100
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    GSList *list = NULL;
    gint* g_data = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    list = my_init_list(g_data, list);
    
    list = g_slist_insert(LIST, GINT_TO_POINTER(DATA), POS);
    
    /* Check if when the position is negative, or is larger than the number of elements in the list, 
       the new element is added on to the end of the list. 
    */   
    if ((POS > 10) || (POS < 0)){
        gint dt = GPOINTER_TO_INT(g_slist_last(list)->data);
        if (DATA != dt){
            TEST_FAIL("g_slist_insert: The data should be %d, now is %d", DATA, dt);
        }
    }
    
    /* Check if the data has been inserted in the position */
    else{
        gint dt = GPOINTER_TO_INT(g_slist_nth_data(list, POS));
        if (DATA != dt){
            TEST_FAIL("g_slist_insert: The data should be %d, now is %d", DATA, dt);
        }
    }
    g_free(g_data);
    
    #undef LIST
    #undef DATA
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_slist_insert_sorted
 * Params: GSList *list, gpointer data, GCompareFunc func
 * Returns: GSList*
 * Assertion: Inserts a new element into the list, using the given comparison function to determine its position.
 *            list : a GSList.
 *            data : the data for the new element.
 *            func : the function to compare elements in the list. It should return a number > 0 if the first parameter comes after the second parameter in the sort order.
 *            Returns : the new start of the GSList.
 * Params Values: list, 3, my_list_compare_one
 * Expected: {1, 2, 3, 5, 6}  
 */
static void test_purpose_8()
{
    #define LIST list
    #define DATA 3
    #define FUNC my_list_compare_one
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    GSList *list = NULL;
    gint gnums[4] = {1, 2, 5, 6};
    gint data = DATA;
    
    for (i = 0; i < 4; i++)
        list = g_slist_append(list, &gnums[i]);
    
    /* From small to large */
    if (data == 3){
        list = g_slist_insert_sorted(LIST, &data, FUNC);
        if (*(gint *)g_slist_nth_data(list, 2) != data)
            TEST_FAIL("g_slist_insert_sorted: should be %d, now is %d", data, *(gint *)g_slist_nth_data(list, 2))
    }
    /* From large to small */
    else{
        list = g_slist_reverse(list);
        list = g_slist_insert_sorted(LIST, &data, FUNC);
        if (*(gint *)g_slist_nth_data(list, 2) != data)
            TEST_FAIL("g_slist_insert_sorted: should be %d, now is %d", data, *(gint *)g_slist_nth_data(list, 2))
    }
    #undef LIST
    #undef DATA
    #undef FUNC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_slist_insert_sorted
 * Params: GSList *list, gpointer data, GCompareFunc func
 * Returns: GSList*
 * Assertion: Inserts a new element into the list, using the given comparison function to determine its position.
 *            list : a GSList.
 *            data : the data for the new element.
 *            func : the function to compare elements in the list. It should return a number > 0 if the first parameter comes after the second parameter in the sort order.
 *            Returns : the new start of the GSList.
 * Params Values: list, 4, my_list_compare_two
 * Expected: {6, 5, 4, 2, 1}  
 */
static void test_purpose_9()
{
    #define LIST list
    #define DATA 4
    #define FUNC my_list_compare_two
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    GSList *list = NULL;
    gint gnums[4] = {1, 2, 5, 6};
    gint data = DATA;
    
    for (i = 0; i < 4; i++)
        list = g_slist_append(list, &gnums[i]);
    
    /* From small to large */
    if (data == 3){
        list = g_slist_insert_sorted(LIST, &data, FUNC);
        if (*(gint *)g_slist_nth_data(list, 2) != data)
            TEST_FAIL("g_slist_insert_sorted: should be %d, now is %d", data, *(gint *)g_slist_nth_data(list, 2))
    }
    /* From large to small */
    else{
        list = g_slist_reverse(list);
        list = g_slist_insert_sorted(LIST, &data, FUNC);
        if (*(gint *)g_slist_nth_data(list, 2) != data)
            TEST_FAIL("g_slist_insert_sorted: should be %d, now is %d", data, *(gint *)g_slist_nth_data(list, 2))
    }
    #undef LIST
    #undef DATA
    #undef FUNC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_slist_remove
 * Params: GSList *list, gconstpointer data
 * Returns: GSList*
 * Assertion: Removes an element from a GSList. If two elements contain the same data, only the first is removed. If none of the elements contain the data, the GSList is unchanged.
 *            list : a GSList.
 *            data : the data of the element to remove.
 *            Returns : the new start of the GSList.
 * Params Values: list, 3
 * Expected: {0, 1, 2, 4, 5, 6, 7, 8, 9}  
 */
static void test_purpose_10()
{
    #define LIST list
    #define DATA 3
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    GSList *list = NULL, *gslist = NULL;
    gint *g_data = NULL;
    gint data = DATA;
    gint len = 0;
    
    g_data = (gint *)g_memdup(nums, data_size);
    list = my_init_list(g_data, list);
    len = g_slist_length(list);
    list = g_slist_append(list, &data);
    
    gslist = g_slist_remove(LIST, g_data + DATA);
    
    /* check if the data has been removed */
    if (*(gint *)g_slist_nth_data(gslist, data) == DATA){
        TEST_FAIL("g_slist_remove: does not remove the data %d", DATA);
    }
    /* check if the same data exists */
    else{
        if (*(gint *)g_slist_last(gslist)->data != DATA){
            TEST_FAIL("g_slist_remove: remove error", NULL);
        }
    }
    g_free(g_data);
    #undef LIST
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_slist_delete_link
 * Params: GSList *list, GSList *link_
 * Returns: GSList*
 * Assertion: Deletes a node of list. Returns the new list head.
 *            list : a GSList.
 *            link_ : node to delete.
 *            Returns : new head of list.
 * Params Values: list, 1
 * Expected: {0, 2, 3, ... 9}  
 */
static void test_purpose_11()
{
    #define LIST list
    #define LINK 1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    gint *g_data = NULL;
    GSList *list = NULL, *link = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    list = my_init_list(g_data, list);
    
    link = g_slist_find(LIST, g_data + LINK);
    list = g_slist_delete_link(LIST, link);
    
    /* check if the length decreases and the data does not exist */
    if (*(gint *)g_slist_nth_data(list, LINK) == *(g_data + LINK)){
        TEST_FAIL("g_slist_delete_link: Delete link %d failed", LINK);
    }
    g_free(g_data);
    #undef LIST
    #undef LINK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: g_slist_remove_link
 * Params: GSList *list, GSList *link_
 * Returns: GSList*
 * Assertion: Removes an element from a GSList, without freeing the element. The removed element's next link is set to NULL, so that it becomes a self-contained list with one element.
 *            list : a GSList.
 *            link_ : an element in the GSList.
 *            Returns : the new start of the GSList, without the element.
 * Params Values: list, 1
 * Expected: Remove the link 1  
 */
static void test_purpose_12()
{
    #define LIST list
    #define LINK 1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    gint *g_data = NULL;
    
    GSList *list = NULL, *link = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    list = my_init_list(g_data, list);
    
    link = g_slist_find(LIST, g_data + LINK);
    list = g_slist_remove_link(LIST, link);
    g_slist_free_1(link);
    
    
    /* check if the length decreases and the data does not exist */
    if (*(gint *)g_slist_nth_data(list, LINK) != *(g_data + LINK + 1)){
        TEST_FAIL("g_slist_remove_link: Remove link%d failed", LINK);
    }
    g_free(g_data);
    
    #undef LIST
    #undef LINK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  g_slist_foreach
 * Params: GSList *list, GFunc func, gpointer user_data
 * Returns: void
 * Assertion: Calls a function for each element of a GSList.
 *            list : a GSList.
 *            func : the function to call with each element's data.
 *            user_data : user data to pass to the function.
 * Params Values: list, g_user_func, 1
 * Expected: {1, 2, 3, 4, ... , 10}  
 */
static void test_purpose_13()
{
    #define LIST        list
    #define GFUNC       g_user_func
    #define USER_DATA   1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i=0;
    gint data;
    GSList *list = NULL;
    gint *g_data = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    list = my_init_list(g_data, list);
    
    data = USER_DATA;
    g_slist_foreach(LIST, GFUNC, &data);
    
    /* check if each data can be handled by FUNC */
    for (i = 0; i < g_slist_length(LIST); i++){
        if (*(gint *)g_slist_nth_data(LIST, i) != (i + USER_DATA)){
            TEST_FAIL("g_slist_foreach: for each error", NULL);
        }
    }
    g_free(g_data);
    #undef LIST
    #undef GFUNC
    #undef USER_DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   g_slist_nth_data
 * Params: GSList *list, guint n
 * Returns: gpointer
 * Assertion: Gets the data of the element at the given position.
 *            list : a GSList.
 *            n : the position of the element.
 *            Returns : the element's data, or NULL if the position is off the end of the GSList.
 * Params Values: list, 3
 * Expected: 3  
 */
static void test_purpose_14()
{
    #define LIST list
    #define POS  3
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    GSList * list = NULL;
    gint *g_data = NULL;
    gpointer data = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    for (i = 0; i < 9; i++){
        list = g_slist_append(list, g_data + i);
    }
    
    data = g_slist_nth_data(LIST, POS);
    /* check if the data can be got */
    if (POS < 9){
        if (*(gint *)data != POS){
            TEST_FAIL("g_slist_nth_data: shoud be %d, now is %d", POS, *(gint *)data);
        }
    }
    /* check if data is NULL when the position is off the end of the GSList */
    else{
        if (data != NULL){
            TEST_FAIL("g_slist_nth_data: should be NULL, now is %d", *(gint *)data);
        }
    }
    g_free(g_data);
    
    #undef LIST
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   g_slist_nth_data
 * Params: GSList *list, guint n
 * Returns: gpointer
 * Assertion: Gets the data of the element at the given position.
 *            list : a GSList.
 *            n : the position of the element.
 *            Returns : the element's data, or NULL if the position is off the end of the GSList.
 * Params Values: list, 9
 * Expected: NULL  
 */
static void test_purpose_15()
{
    #define LIST list
    #define POS  9
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    GSList * list = NULL;
    gint *g_data = NULL;
    gpointer data = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    for (i = 0; i < 9; i++){
        list = g_slist_append(list, g_data + i);
    }
    
    data = g_slist_nth_data(LIST, POS);
    /* check if the data can be got */
    if (POS < 9){
        if (*(gint *)data != POS){
            TEST_FAIL("g_slist_nth_data: shoud be %d, now is %d", POS, *(gint *)data);
        }
    }
    /* check if data is NULL when the position is off the end of the GSList */
    else{
        if (data != NULL){
            TEST_FAIL("g_slist_nth_data: should be NULL, now is %d", *(gint *)data);
        }
    }
    g_free(g_data);
    
    #undef LIST
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   g_slist_index
 * Params: GSList *list, gconstpointer data
 * Returns: gint
 * Assertion: Gets the position of the element containing the given data (starting from 0).
 *            list : a GSList.
 *            data : the data to find.
 *            Returns : the index of the element containing the data, or -1 if the data is not found.
 * Params Values: list, 3
 * Expected: 3  
 */
static void test_purpose_16()
{
    #define LIST list
    #define DATA 3
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    gint *g_data = NULL;
    GSList *list = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    for (i = 0; i < 9; i++){
        list = g_slist_append(list, g_data + i);
    }
    
    i = g_slist_index(LIST, g_data + DATA);
    
    /* check if the return is -1 when the data is not found */
    if (i == -1){
        if (DATA < 9){
            TEST_FAIL("g_slist_index: should be %d, now is %d", DATA, i);
        }
    }
    /* check if the index is right */
    else{
        if (i != DATA){
            TEST_FAIL("g_slist_index: should be %d, now is %d", DATA, i);
        }
    }
    g_free(g_data);
    
    #undef LIST
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   g_slist_index
 * Params: GSList *list, gconstpointer data
 * Returns: gint
 * Assertion: Gets the position of the element containing the given data (starting from 0).
 *            list : a GSList.
 *            data : the data to find.
 *            Returns : the index of the element containing the data, or -1 if the data is not found.
 * Params Values: list, 9
 * Expected: -1  
 */
static void test_purpose_17()
{
    #define LIST list
    #define DATA 9
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    gint *g_data = NULL;
    GSList *list = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    for (i = 0; i < 9; i++){
        list = g_slist_append(list, g_data + i);
    }
    
    i = g_slist_index(LIST, g_data + DATA);
    
    /* check if the return is -1 when the data is not found */
    if (i == -1){
        if (DATA < 9){
            TEST_FAIL("g_slist_index: should be %d, now is %d", DATA, i);
        }
    }
    /* check if the index is right */
    else{
        if (i != DATA){
            TEST_FAIL("g_slist_index: should be %d, now is %d", DATA, i);
        }
    }
    g_free(g_data);
    
    #undef LIST
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   g_slist_reverse
 * Params: GSList *list
 * Returns: GSList*
 * Assertion: Reverses a GSList.
 *            list : a GSList.
 *            Returns : the start of the reversed GSList.
 * Params Values: list
 * Expected: {9, 8, 7, ... , 1, 0}  
 */
static void test_purpose_18()
{
    #define LIST list
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    gint *g_data = NULL;
    GSList *list = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    list = my_init_list(g_data, list);
    
    list = g_slist_reverse(LIST);
    
    /* check each data in list */
    for (i = 0; i < data_size / sizeof(gint); i++){
        if (*(gint *)list->data != nums[data_size/sizeof(gint)-1-i]){
            TEST_FAIL("g_slist_reverse: reverse error", NULL);
            break;
        }
        list = list->next;
    }
    g_free(g_data);
    
    #undef LIST
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   g_slist_length
 * Params: GSList *list
 * Returns: guint
 * Assertion: Gets the number of elements in a GSList.
 *            list : a GSList.
 *            Returns : the number of elements in the GSList.
 * Params Values: list                              
 * Expected: 10  
 */
static void test_purpose_19()
{
    #define LIST list
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    guint len = 0;
    GSList *list = NULL;
    gint *g_data = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    list = my_init_list(g_data, list);
    
    
    len = g_slist_length(LIST);
    
    if (len != (data_size/sizeof(gint))){
        TEST_FAIL("g_slist_length: get length error", NULL);
    }
    #undef LIST
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   g_slist_find
 * Params: GSList *list, gconstpointer data
 * Returns: GSList*
 * Assertion: Finds the element in a GSList which contains the given data.
 *            list : a GSList.
 *            data : the element data to find.
 *            Returns : the found GSList element, or NULL if it is not found.
 * Params Values: list, 1
 * Expected: 1  
 */
static void test_purpose_20()
{
    #define LIST list
    #define DATA 1
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    gint *g_data = NULL;
    GSList *list = NULL, *gslist = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    for (i = 0; i < data_size/sizeof(gint)-1; i++){
        list = g_slist_append(list, &nums[i]);
    }
    
    gslist = g_slist_find(LIST, &nums[DATA]);
    
    /*check if the data is NULL when it is not found */
    if (gslist == NULL){
       if (DATA < *(g_data + data_size/sizeof(gint) - 1)){
           TEST_FAIL("g_slist_find: find error", NULL);
       } 
    }
    /* check if the data is right */
    else{
       if (*(gint *)gslist->data != *(g_data + DATA)){
           TEST_FAIL("g_slist_find: find error", NULL);
       }
    }
    #undef LIST
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   g_slist_find
 * Params: GSList *list, gconstpointer data
 * Returns: GSList*
 * Assertion: Finds the element in a GSList which contains the given data.
 *            list : a GSList.
 *            data : the element data to find.
 *            Returns : the found GSList element, or NULL if it is not found.
 * Params Values: list, 9
 * Expected: NULL  
 */
static void test_purpose_21()
{
    #define LIST list
    #define DATA 9
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    gint *g_data = NULL;
    GSList *list = NULL, *gslist = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    for (i = 0; i < data_size/sizeof(gint)-1; i++){
        list = g_slist_append(list, &nums[i]);
    }
    
    gslist = g_slist_find(LIST, &nums[DATA]);
    
    /*check if the data is NULL when it is not found */
    if (gslist == NULL){
       if (DATA < *(g_data + data_size/sizeof(gint) - 1)){
           TEST_FAIL("g_slist_find: find error", NULL);
       } 
    }
    /* check if the data is right */
    else{
       if (*(gint *)gslist->data != *(g_data + DATA)){
           TEST_FAIL("g_slist_find: find error", NULL);
       }
    }
    #undef LIST
    #undef DATA
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   g_slist_sort
 * Params: GSList *list, GCompareFunc compare_func
 * Returns: GSList*
 * Assertion: Sorts a GSList using the given comparison function.
 *            list : a GSList.
 *            compare_func : qsort()-style comparison function.
 *            Returns : the start of the sorted GList.
 * Params Values: list, my_list_compare_one
 * Expected: {1, 2, 3, 4}  
 */
static void test_purpose_22()
{
    #define LIST list
    #define FUNC my_list_compare_one
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    GSList *list = NULL, *tmp = NULL;
    gint gnums[4] = {3, 2, 1, 4};
    
    
    for (i = 0; i < 4; i++)
        list = g_slist_append(list, &gnums[i]);
    
    list = g_slist_sort(LIST, FUNC);
    tmp = list;
    
    /* check if the data is from little to large */
    if (*(gint *)tmp->data == 1){
        for (i = 1; i < 4; i++){
            tmp = tmp->next;
            if (*(gint *)tmp->data != (i + 1)){
                TEST_FAIL("g_slist_sort: sort error", NULL);
            }
        }
    }
    /*check if the data is from large to little */
    else if (*(gint *)tmp->data == 4){
        for (i = 1; i < 4; i++){
            tmp = tmp->next;
            if (*(gint *)tmp->data != (4 - i)){
                TEST_FAIL("g_slist_sort: sort error", NULL);
            }
        }
    }
    else{
        TEST_FAIL("g_slist_sort: sort error", NULL);
    }
    #undef LIST
    #undef FUNC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   g_slist_sort
 * Params: GSList *list, GCompareFunc compare_func
 * Returns: GSList*
 * Assertion: Sorts a GSList using the given comparison function.
 *            list : a GSList.
 *            compare_func : qsort()-style comparison function.
 *            Returns : the start of the sorted GList.
 * Params Values: list, my_list_compare_two
 * Expected: {4, 3, 2, 1}  
 */
static void test_purpose_23()
{
    #define LIST list
    #define FUNC my_list_compare_two
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    GSList *list = NULL, *tmp = NULL;
    gint gnums[4] = {3, 2, 1, 4};
    
    
    for (i = 0; i < 4; i++)
        list = g_slist_append(list, &gnums[i]);
    
    list = g_slist_sort(LIST, FUNC);
    tmp = list;
    
    /* check if the data is from little to large */
    if (*(gint *)tmp->data == 1){
        for (i = 1; i < 4; i++){
            tmp = tmp->next;
            if (*(gint *)tmp->data != (i + 1)){
                TEST_FAIL("g_slist_sort: sort error", NULL);
            }
        }
    }
    /*check if the data is from large to little */
    else if (*(gint *)tmp->data == 4){
        for (i = 1; i < 4; i++){
            tmp = tmp->next;
            if (*(gint *)tmp->data != (4 - i)){
                TEST_FAIL("g_slist_sort: sort error", NULL);
            }
        }
    }
    else{
        TEST_FAIL("g_slist_sort: sort error", NULL);
    }
    #undef LIST
    #undef FUNC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   g_slist_last
 * Params: GSList *list
 * Returns: GSList*
 * Assertion: Gets the last element in a GSList.
 *            list : a GSList.
 *            Returns : the last element in the GSList, or NULL if the GSList has no elements.
 * Params Values: list
 * Expected: 9  
 */
static void test_purpose_24()
{
    #define LIST list
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint *g_data = NULL;
    GSList *list = NULL, *gslist = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    list = my_init_list(g_data, list);
    
    gslist = g_slist_last(LIST);
    /* check the last data */
    if (*(gint *)gslist->data != *(g_data + data_size/sizeof(gint) - 1)){
        TEST_FAIL("g_slist_last: error", NULL);
    }
    g_free(g_data);
    #undef LIST
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   g_slist_nth
 * Params: GSList *list, guint n
 * Returns: gpointer
 * Assertion: Gets the element at the given position in a GSList.
 *            list : a GSList.
 *            n : the position of the element, counting from 0.
 *            Returns : the element, or NULL if the position is off the end of the GSList.
 * Params Values: list, 3
 * Expected: 3  
 */
static void test_purpose_25()
{
    #define LIST  list
    #define POS   3
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    gint *g_data = NULL;
    GSList *list = NULL, *gslist = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    for (i = 0; i < 9; i++){
        list = g_slist_append(list, g_data + i);
    }
    
    gslist = g_slist_nth(LIST, POS);
    
    if (gslist != NULL){
        if (*(gint *)gslist->data != *(g_data + POS)){
            TEST_FAIL("g_slist_nth: error", NULL);
        }
    }
    else{
        if (POS < 9){
            TEST_FAIL("g_slist_nth: error", NULL);
        }
    }
    g_free(g_data);
    #undef LIST
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   g_slist_nth
 * Params: GSList *list, guint n
 * Returns: gpointer
 * Assertion: Gets the element at the given position in a GSList.
 *            list : a GSList.
 *            n : the position of the element, counting from 0.
 *            Returns : the element, or NULL if the position is off the end of the GSList.
 * Params Values: list, 9
 * Expected: NULL  
 */
static void test_purpose_26()
{
    #define LIST  list
    #define POS   9
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    gint *g_data = NULL;
    GSList *list = NULL, *gslist = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    for (i = 0; i < 9; i++){
        list = g_slist_append(list, g_data + i);
    }
    
    gslist = g_slist_nth(LIST, POS);
    
    if (gslist != NULL){
        if (*(gint *)gslist->data != *(g_data + POS)){
            TEST_FAIL("g_slist_nth: error", NULL);
        }
    }
    else{
        if (POS < 9){
            TEST_FAIL("g_slist_nth: error", NULL);
        }
    }
    g_free(g_data);
    #undef LIST
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   g_slist_concat
 * Params: GSList *list1, GSList *list2
 * Returns: GSList*
 * Assertion: Adds the second GSList onto the end of the first GSList. Note that the elements of the second GSList are not copied. They are used directly.
 *            list1 : a GSList.
 *            list2 : the GSList to add to the end of the first GSList.
 *            Returns : the start of the new GSList.
 * Params Values: list1, list2
 * Expected: {1, 2, 3, 4}  
 */
static void test_purpose_27()
{
    #define LIST1 list1
    #define LIST2 list2
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    GSList *list1 = NULL, *list2 = NULL, *tmp = NULL;
    gint nums1[] = {1, 2};
    gint nums2[] = {3, 4};
    
    for (i = 0; i < 2; i++){
        list1 = g_slist_append(list1, &nums1[i]);
        list2 = g_slist_append(list2, &nums2[i]);
    }
    
    list1 = g_slist_concat(LIST1, LIST2);
    tmp = list1;
    for (i = 0; i < 4; i++){
        if (*(gint *)tmp->data != (i + 1)){
            TEST_FAIL("g_slist_concat: error", NULL);
        }
        tmp = tmp->next;
    }
    #undef LIST1
    #undef LIST2
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   g_slist_find_custom
 * Params: GSList *list, gconstpointer data, GCompareFunc func
 * Returns: GSList*
 * Assertion: Finds an element in a GSList, using a supplied function to find the desired element. It iterates over the list, calling the given function which should return 0 when the desired element is found. The function takes two gconstpointer arguments, the GSList element's data and the given user data.
 *            list : a GSList.
 *            data : user data passed to the function.
 *            func : the function to call for each element. It should return 0 when the desired element is found.
 *            Returns : the found GSList element, or NULL if it is not found.
 * Params Values: list, 3, my_list_compare_one
 * Expected: 3  
 */
static void test_purpose_28()
{
    #define LIST list
    #define DATA 3
    #define FUNC my_list_compare_one
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    GSList *list = NULL, *gslist = NULL;
    gint *g_data = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    for (i = 0; i < 9; i++){
        list = g_slist_append(list, g_data + i);
    }
    gslist = g_slist_find_custom(LIST, g_data + DATA, FUNC);
    
    if (gslist != NULL){
        if (*(gint *)gslist->data != *(g_data + DATA)){
            TEST_FAIL("g_slist_find_custom: error", NULL);
        }
    }
    else{
        if (DATA < 9){
            TEST_FAIL("g_slist_find_custom: error", NULL);
        }
    }
    g_free(g_data);
    #undef LIST
    #undef DATA
    #undef FUNC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   g_slist_find_custom
 * Params: GSList *list, gconstpointer data, GCompareFunc func
 * Returns: GSList*
 * Assertion: Finds an element in a GSList, using a supplied function to find the desired element. It iterates over the list, calling the given function which should return 0 when the desired element is found. The function takes two gconstpointer arguments, the GSList element's data and the given user data.
 *            list : a GSList.
 *            data : user data passed to the function.
 *            func : the function to call for each element. It should return 0 when the desired element is found.
 *            Returns : the found GSList element, or NULL if it is not found.
 * Params Values: list, 3, my_list_compare_two
 * Expected: 3  
 */
static void test_purpose_29()
{
    #define LIST list
    #define DATA 3
    #define FUNC my_list_compare_two
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    GSList *list = NULL, *gslist = NULL;
    gint *g_data = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    for (i = 0; i < 9; i++){
        list = g_slist_append(list, g_data + i);
    }
    gslist = g_slist_find_custom(LIST, g_data + DATA, FUNC);
    
    if (gslist != NULL){
        if (*(gint *)gslist->data != *(g_data + DATA)){
            TEST_FAIL("g_slist_find_custom: error", NULL);
        }
    }
    else{
        if (DATA < 9){
            TEST_FAIL("g_slist_find_custom: error", NULL);
        }
    }
    g_free(g_data);
    #undef LIST
    #undef DATA
    #undef FUNC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   g_slist_find_custom
 * Params: GSList *list, gconstpointer data, GCompareFunc func
 * Returns: GSList*
 * Assertion: Finds an element in a GSList, using a supplied function to find the desired element. It iterates over the list, calling the given function which should return 0 when the desired element is found. The function takes two gconstpointer arguments, the GSList element's data and the given user data.
 *            list : a GSList.
 *            data : user data passed to the function.
 *            func : the function to call for each element. It should return 0 when the desired element is found.
 *            Returns : the found GSList element, or NULL if it is not found.
 * Params Values: list, 9, my_list_compare_one
 * Expected: NULL  
 */
static void test_purpose_30()
{
    #define LIST list
    #define DATA 9
    #define FUNC my_list_compare_one
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    GSList *list = NULL, *gslist = NULL;
    gint *g_data = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    for (i = 0; i < 9; i++){
        list = g_slist_append(list, g_data + i);
    }
    gslist = g_slist_find_custom(LIST, g_data + DATA, FUNC);
    
    if (gslist != NULL){
        if (*(gint *)gslist->data != *(g_data + DATA)){
            TEST_FAIL("g_slist_find_custom: error", NULL);
        }
    }
    else{
        if (DATA < 9){
            TEST_FAIL("g_slist_find_custom: error", NULL);
        }
    }
    g_free(g_data);
    #undef LIST
    #undef DATA
    #undef FUNC
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   g_slist_copy
 * Params: GSList *list
 * Returns: GSList*
 * Assertion: Copies a GSList.
 * 
 * Note that this is a "shallow" copy. If the list elements consist of pointers to data, the pointers are copied but the actual data isn't.
 *           list : a GSList.
 *           Returns : a copy of list.
 * Params Values: list
 * Expected: {0, 1, 2}  
 */
static void test_purpose_31()
{
    #define LIST list
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    GSList *list = NULL, *gslist = NULL, *tmp = NULL;
    gint gnums[] = {0, 1, 2};
    
    for (i = 0; i < 3; i++){
        list = g_slist_append(list, &gnums[i]);
    }
    gslist = g_slist_copy(LIST);
    tmp = gslist;
    for (i = 0; i < 3; i++){
        if (*(gint *)tmp->data != i){
            TEST_FAIL("g_slist_copy: should be %d, now is %d", i, *(gint *)tmp->data);
        }
        tmp = tmp->next;
    }
    gnums[0] = 100;
    /* check if the 'shallow' copy */
    if (*(gint *)gslist->data != 100){
        TEST_FAIL("g_slist_copy: error", NULL);
    }
    
    #undef LIST
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   g_slist_position
 * Params: GSList *list, GSList *llink
 * Returns: gint
 * Assertion: Gets the position of the given element in the GSList (starting from 0).
 *            list : a GSList.
 *            llink : an element in the GSList.
 *            Returns : the position of the element in the GSList, or -1 if the element is not found.
 * Params Values: list, 2
 * Expected: 2  
 */
static void test_purpose_32()
{
    #define LIST list
    #define LINK 2
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    gint *g_data = NULL;
    GSList *list = NULL, *link = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    
    for (i = 0; i < 9; i++){
        list = g_slist_append(list, g_data + i);
    }
    link = g_slist_find(LIST, g_data + LINK);
    i = g_slist_position(LIST, link);
    if (i != -1){
        if (i != *(g_data + LINK)){
            TEST_FAIL("g_slist_position: error", NULL);
        }
    }
    else{
        if (LINK < 9){
            TEST_FAIL("g_slist_position: error", NULL);
        }
    }
    
    #undef LIST
    #undef LINK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:   g_slist_position
 * Params: GSList *list, GSList *llink
 * Returns: gint
 * Assertion: Gets the position of the given element in the GSList (starting from 0).
 *            list : a GSList.
 *            llink : an element in the GSList.
 *            Returns : the position of the element in the GSList, or -1 if the element is not found.
 * Params Values: list, 9
 * Expected: -1  
 */
static void test_purpose_33()
{
    #define LIST list
    #define LINK 9
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    gint i = 0;
    gint *g_data = NULL;
    GSList *list = NULL, *link = NULL;
    
    g_data = (gint *)g_memdup(nums, data_size);
    
    for (i = 0; i < 9; i++){
        list = g_slist_append(list, g_data + i);
    }
    link = g_slist_find(LIST, g_data + LINK);
    i = g_slist_position(LIST, link);
    if (i != -1){
        if (i != *(g_data + LINK)){
            TEST_FAIL("g_slist_position: error", NULL);
        }
    }
    else{
        if (LINK < 9){
            TEST_FAIL("g_slist_position: error", NULL);
        }
    }
    
    #undef LIST
    #undef LINK
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for Singly_Linked_Lists ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {NULL,0}
};
