/*
 * pango_layout methods tests
 * Testing pango_layout methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*Structure definition.*/

typedef struct _PangoLayoutLinePrivate PangoLayoutLinePrivate;

struct _PangoLayoutLinePrivate
{
  PangoLayoutLine line;
  guint ref_count;
};

struct _PangoContext
{
  GObject parent_instance;

  PangoLanguage *language;
  PangoDirection base_dir;
  PangoFontDescription *font_desc;

  PangoMatrix *matrix;

  PangoFontMap *font_map;
};


struct _PangoLayout
{
  GObject parent_instance;

  /* If you add fields to PangoLayout, be sure to update both
   * the _copy function
   */

  PangoContext *context;
  PangoAttrList *attrs;
  PangoFontDescription *font_desc;

  gchar *text;
  int length;                   /* length of text in bytes */
  int width;                    /* wrap width, in device units */
  int indent;                   /* amount by which first line should be shorter
*/
  int spacing;                  /* spacing between lines */

  guint justify : 1;
  guint alignment : 2;


  guint single_paragraph : 1;
  guint auto_dir : 1;

  guint wrap : 2;               /* PangoWrapMode */
  guint ellipsize : 2;          /* PangoEllipsizeMode */

  gint n_chars;                 /* Total number of characters in layout */
  PangoLogAttr *log_attrs;      /* Logical attributes for layout's text */

  int tab_width;                /* Cached width of a tab. -1 == not yet calculat
ed */

  PangoTabArray *tabs;

  GSList *lines;
};


int struc_cmp (char *str1,char *str2)
{
    int i,l;
    if ((l = sizeof(str1)) != sizeof(str2))
        return 0;
    for (i = 0;i < l;i++)
        if (str1[1] != str2[i])
            return 0;    
    return 1;
}


/*
 * Name: pango_layout_set_text
 * Params: PangoLayout *layout, const char *text, int length
 * Returns: void
 * Assertion: Sets the text of the layout.
 * Params Values: layout,"my layout text!",-1   
 * Expected: text of the layout is "my layout text!"
 *   
 */
static void test_purpose_1()
{
    #define LAYOUT layout
    #define TEXT "my layout text!"
    #define LENGTH -1  
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    const char *text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set text of the new created layout.*/
    pango_layout_set_text(LAYOUT,TEXT,LENGTH);
    
    /*Get text of the layout.*/
    text = pango_layout_get_text(LAYOUT);
    
    /*Check that the text is correct.*/
    if(strcmp(text,TEXT))
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    
    #undef LAYOUT
    #undef TEXT
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_set_text
 * Params: PangoLayout *layout, const char *text, int length
 * Returns: void
 * Assertion: Sets the text of the layout.
 * Params Values: layout," ",1 
 * Expected: text of the layout is " "
 *   
 */
static void test_purpose_2()
{
    #define LAYOUT layout
    #define TEXT " "
    #define LENGTH 1
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    const char *text;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set text of the new created layout.*/
    pango_layout_set_text(LAYOUT,TEXT,LENGTH);
    
    /*Get text of the layout.*/
    text = pango_layout_get_text(LAYOUT);
    
    /*Check that the text is correct.*/
    if(strcmp(text,TEXT))
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    
    #undef LAYOUT
    #undef TEXT
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_set_width
 * Params: PangoLayout *layout, int width
 * Returns: void
 * Assertion: Sets the width to which the lines of the PangoLayout should be wrapped.
 * Params Values: layout,10
 * Expected: width of the lines to be wrapped is 10 
 *   
 */
static void test_purpose_3()
{
    #define LAYOUT layout
    #define WIDTH 10
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    int width;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new (context_new);
    
    /*Set the width of lines to be wrapped.*/
    pango_layout_set_width(LAYOUT,WIDTH);
    
    /*Get the width.*/
    width = pango_layout_get_width(LAYOUT);
    
    /*Check that the width is correct.*/
    if (width != WIDTH)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_set_width
 * Params: PangoLayout *layout, int width
 * Returns: void
 * Assertion: Sets the width to which the lines of the PangoLayout should be wrapped.
 * Params Values: layout,0
 * Expected: width of the lines to be wrapped is 0
 *   
 */
static void test_purpose_4()
{
    #define LAYOUT layout
    #define WIDTH 0
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    int width;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new (context_new);
    
    /*Set the width of lines to be wrapped.*/
    pango_layout_set_width(LAYOUT,WIDTH);
    
    /*Get the width.*/
    width = pango_layout_get_width(LAYOUT);
    
    /*Check that the width is correct.*/
    if (width != WIDTH)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_set_width
 * Params: PangoLayout *layout, int width
 * Returns: void
 * Assertion: Sets the width to which the lines of the PangoLayout should be wrapped.
 * Params Values: layout,-1
 * Expected: wrap mod is off
 *   
 */
static void test_purpose_5()
{
    #define LAYOUT layout
    #define WIDTH -1
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    int width;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new (context_new);
    
    /*Set the width of lines to be wrapped.*/
    pango_layout_set_width(LAYOUT,WIDTH);
    
    /*Get the width.*/
    width = pango_layout_get_width(LAYOUT);
    
    /*Check that the width is correct.*/
    if (width != WIDTH)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_new
 * Params: PangoContext *context
 * Returns: a new PangoLayout, with a reference count of one.
 * Assertion: Create a new PangoLayout object with attributes initialized to default values for a particular PangoContext.
 * Params Values: context_new
 * Expected: a new layout with reference count of 1
 *   
 */
static void test_purpose_6()
{
    #define CONTEXT  context_new
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout = NULL;
    GObject layout_obj;
    int ref_num;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(CONTEXT);
    
    /*Check that the layout is created.*/
    if (layout == NULL)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    /*Get the reference number of the layout.*/
    layout_obj = layout->parent_instance;
    ref_num = layout_obj.ref_count;
    /*g_printf("The reference number of the layout is %d.\n",ref_num);*/
    
    /*Check that the refernce number is 1.*/
    if (ref_num != 1)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef CONTEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_set_wrap
 * Params: PangoLayout *layout, PangoWrapMode wrap
 * Returns: void
 * Assertion: Sets the wrap mode; the wrap mode only has an effect if a width is set on the layout with pango_layout_set_width(). To turn off wrapping, set the width to -1.
 * Params Values: layout,PANGO_WRAP_WORD 
 * Expected: wrap mod of layout is PANGO_WRAP_WORD
 *   
 */
static void test_purpose_7()
{
    #define LAYOUT  layout
    #define WRAP_MODE PANGO_WRAP_WORD
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    PangoWrapMode wrap;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set wrap mod of the layout.*/
    pango_layout_set_wrap(LAYOUT,WRAP_MODE);
    
    /*Get the wrap mod.*/
    wrap = pango_layout_get_wrap(LAYOUT);
    
    /*Check that the wrap mod is correct.*/
    if (wrap != WRAP_MODE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef WRAP_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_set_wrap
 * Params: PangoLayout *layout, PangoWrapMode wrap
 * Returns: void
 * Assertion: Sets the wrap mode; the wrap mode only has an effect if a width is set on the layout with pango_layout_set_width(). To turn off wrapping, set the width to -1.
 * Params Values: layout,PANGO_WRAP_CHAR 
 * Expected: wrap mod of layout is PANGO_WRAP_CHAR
 *   
 */
static void test_purpose_8()
{
    #define LAYOUT  layout
    #define WRAP_MODE PANGO_WRAP_CHAR
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    PangoWrapMode wrap;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set wrap mod of the layout.*/
    pango_layout_set_wrap(LAYOUT,WRAP_MODE);
    
    /*Get the wrap mod.*/
    wrap = pango_layout_get_wrap(LAYOUT);
    
    /*Check that the wrap mod is correct.*/
    if (wrap != WRAP_MODE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef WRAP_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_set_wrap
 * Params: PangoLayout *layout, PangoWrapMode wrap
 * Returns: void
 * Assertion: Sets the wrap mode; the wrap mode only has an effect if a width is set on the layout with pango_layout_set_width(). To turn off wrapping, set the width to -1.
 * Params Values: layout,PANGO_WRAP_WORD_CHAR 
 * Expected: wrap mod of layout is PANGO_WRAP_WORD_CHAR
 *   
 */
static void test_purpose_9()
{
    #define LAYOUT  layout
    #define WRAP_MODE PANGO_WRAP_WORD_CHAR
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    PangoWrapMode wrap;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set wrap mod of the layout.*/
    pango_layout_set_wrap(LAYOUT,WRAP_MODE);
    
    /*Get the wrap mod.*/
    wrap = pango_layout_get_wrap(LAYOUT);
    
    /*Check that the wrap mod is correct.*/
    if (wrap != WRAP_MODE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef WRAP_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_set_markup
 * Params: PangoLayout *layout, const char *markup, int length
 * Returns: void
 * Assertion: Same as pango_layout_set_markup_with_accel(), but the markup text isn't scanned for accelerators.
 * Params Values: layout,"\"<span foreground=\"blue\" size=\"x-large\">\"Blue text</span> is <i>cool</i>!\"",-1 
 * Expected: text and attr list attribute parse from text "\"<span foreground=\"blue\" size=\"x-large\">\"Blue text</span> is <i>cool</i>!\""
 *   
 */
static void test_purpose_10()
{
    #define LAYOUT  layout
    #define MARKUP "\"<span foreground=\"blue\" size=\"x-large\">\"Blue text</span> is <i>cool</i>!\""
    #define LENGTH -1 
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    gchar *text = NULL;
    const char *ltext;
    gboolean markup_parse;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set text and attr list of the layout from markup text.*/
    pango_layout_set_markup(LAYOUT,MARKUP,LENGTH);
    
    /*Parse markup text.*/
    markup_parse = pango_parse_markup(MARKUP,-1,0,NULL,&text,NULL,NULL);
    
    /*Check that the text is correctly set.*/
    /* LSB bug 2700 PangoLayout is opaque, avoid trying to access 
       layout->text directly. Use pango_layout_get_text() */
    ltext = pango_layout_get_text(layout);
    if (ltext != NULL)
    {
      if (strcmp(text,ltext))
      {
        TEST_FAIL(get_wrong_type_msg(),NULL);
      }
    }
    else
    {
      TEST_FAIL("layout->text is NULL", NULL);
    }
    
    g_object_unref(font_ft2_map);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef MARKUP
    #undef LENGTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_get_context
 * Params: PangoLayout *layout
 * Returns: The PangoContext for the layout. This does not have an additional refcount added, so if you want to keep a copy of this around, you must reference it yourself.
 * Assertion: Retrieves the PangoContext used for this layout.
 * Params Values: layout 
 * Expected: context of layout
 *   
 */
static void test_purpose_11()
{
    #define LAYOUT layout
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    PangoContext *context;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new context.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    
    /*Set the language tag of the context.*/
    pango_context_set_language(context_new,pango_language_from_string("en"));
    
    /*Create a new layout from context_new.*/
    layout = pango_layout_new(context_new);
    
    /*Get context of the layout.*/
    context = pango_layout_get_context(LAYOUT);
    
    /*g_printf("The language used for the context got is %s.\n",context->language);*/
    
    /*Check that the language of the context gotten from the layout is the same as language tag of the previously created context.*/
    if(struc_cmp((char *)context_new,(char *)context))
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_get_size
 * Params: PangoLayout *layout, int *width, int *height
 * Returns: void
 * Assertion: Determines the logical width and height of a PangoLayout in Pango units. (device units divided by PANGO_SCALE). This is simply a convenience function around pango_layout_get_extents().
 * Params Values:layout,width,height 
 * Expected: the value of width and height is equal to the corresponding value of logical_rect
 *   
 */
static void test_purpose_12()
{
    #define LAYOUT layout
    #define WIDTH width
    #define HEIGHT height
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    PangoRectangle logical_rect;
    int *width,*height;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    width = g_new0(int,1);
    height = g_new0(int,1);
    
    /*Create a new context from the ft2 font map.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    
    /*Create a new PangoLayout.*/
    layout = pango_layout_new(context_new);
    
    /*Set the width of the layout.*/
    /* LSB bug 2947 PangoLayout is opaque, avoid trying to access 
       layout->width directly. Use pango_layout_set_width() */
    pango_layout_set_width(LAYOUT,2*PANGO_SCALE);
    
    /*Get the size of the layout.*/
    pango_layout_get_size(LAYOUT,WIDTH,HEIGHT);
    
    /*Get the logical rectangle of the layout.*/
    pango_layout_get_extents(layout, NULL, &logical_rect);
    
    /*Verify the width and height of the layout is correct.*/
    if (*width != logical_rect.width || *height != logical_rect.height)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    /*g_printf("Size of the layout is width = %d,height = %d.\n",*width,*height);*/
    /*g_printf("Width in the layout structure is %d.\n",layout->width/PANGO_SCALE);*/
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    g_free(width);
    g_free(height);
    
    #undef LAYOUT
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_iter_free
 * Params: PangoLayoutIter *iter
 * Returns: void
 * Assertion: Frees an iterator that's no longer in use.
 * Params Values: iter 
 * Expected: decrease the reference count number of line in iter  by 1
 *   
 */
static void test_purpose_13()
{
    #define ITER iter 
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    PangoLayoutLine *line;
    PangoLayoutLinePrivate *private;
    PangoLayoutIter *iter = NULL;
    guint ref_num;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set text of the layout.*/
    pango_layout_set_text(layout,"my layout text.\nJust for testing!",-1);
    
    /*Get iterator the layout.*/
    iter = pango_layout_get_iter(layout);
    
    /*Get line from the iterator.*/
    line = pango_layout_iter_get_line(iter);
    
    /*Get reference count of the line.*/
    private = (PangoLayoutLinePrivate *)line;
    ref_num = private->ref_count;
    
    /*Decrease the reference count number by 1.*/
    pango_layout_iter_free(ITER);
    
    line = pango_layout_iter_get_line(iter);
    private = (PangoLayoutLinePrivate *)line;
    
    //g_printf("Reference count num of line after iter_free is %d.\n",private->ref_count);
    /* After layout_iter_free, the reference count of line is minus 1. */
    if (ref_num != private->ref_count + 1)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef ITER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_get_text
 * Params: PangoLayout *layout
 * Returns: the text in the layout
 * Assertion: Gets the text in the layout. The returned text should not be freed or modified.
 * Params Values: layout,"my layout text!"  
 * Expected: text of the layout is "my layout text!" 
 *   
 */
static void test_purpose_14()
{
    #define LAYOUT layout
    #define TEXT "my layout text!" 
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    const char *text;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set text of the layout.*/
    pango_layout_set_text(LAYOUT,TEXT,-1);
    
    /*Get text of the layout.*/
    text = pango_layout_get_text(LAYOUT);
    
    /*Check that the text is correct.*/
    if(strcmp(text,TEXT))
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_get_text
 * Params: PangoLayout *layout
 * Returns: the text in the layout
 * Assertion: Gets the text in the layout. The returned text should not be freed or modified.
 * Params Values: layout," " 
 * Expected: text of the layout is " "
 *   
 */
static void test_purpose_15()
{
    #define LAYOUT layout
    #define TEXT " "
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    const char *text;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set text of the layout.*/
    pango_layout_set_text(LAYOUT,TEXT,-1);
    
    /*Get text of the layout.*/
    text = pango_layout_get_text(LAYOUT);
    
    /*Check that the text is correct.*/
    if(strcmp(text,TEXT))
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_get_text
 * Params: PangoLayout *layout
 * Returns: the text in the layout
 * Assertion: Gets the text in the layout. The returned text should not be freed or modified.
 * Params Values: layout,"" 
 * Expected: text of the layout is ""
 *   
 */
static void test_purpose_16()
{
    #define LAYOUT layout
    #define TEXT ""
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    const char *text;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set text of the layout.*/
    pango_layout_set_text(LAYOUT,TEXT,-1);
    
    /*Get text of the layout.*/
    text = pango_layout_get_text(LAYOUT);
    
    /*Check that the text is correct.*/
    if(strcmp(text,TEXT))
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_get_iter
 * Params: PangoLayout *layout
 * Returns: a new PangoLayoutIter.
 * Assertion: Returns an iterator to iterate over the visual extents of the layout.
 * Params Values: layout
 * Expected: iterator of the layout
 *   
 */
static void test_purpose_17()
{
    #define LAYOUT layout
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    PangoLayoutLine *line;
    gint length;
    PangoLayoutIter *iter = NULL;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set text of the layout.*/
    pango_layout_set_text(layout,"my layout text.\nJust for testing!",-1);
    
    /*Get iterator of the layout.*/
    iter = pango_layout_get_iter(LAYOUT);
    
    /*Get line from the iterator.*/
    line = pango_layout_iter_get_line(iter);
    length = line->length;
    
    /*Check that the line got from the iterator is correct,so the iterator itself is correct.*/
    if (length != strlen("my layout text."))
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    pango_layout_iter_free(iter);
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_set_spacing
 * Params: PangoLayout *layout, int spacing
 * Returns: void
 * Assertion: Sets the amount of spacing between the lines of the layout.
 * Params Values: layout,0
 * Expected: the spacing amount between lines of the layout is 0
 *   
 */
static void test_purpose_18()
{
    #define LAYOUT layout
    #define SPACE 0
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    int space;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set the spacing amount between lines of the layout.*/
    pango_layout_set_spacing(LAYOUT,SPACE);
    
    /*Get the spacing amount of the layout.*/
    space = pango_layout_get_spacing(LAYOUT);
    
    /*Chech that the spacing amount is correct.*/
    if (space != SPACE)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef SPACE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_set_spacing
 * Params: PangoLayout *layout, int spacing
 * Returns: void
 * Assertion: Sets the amount of spacing between the lines of the layout.
 * Params Values: layout,2
 * Expected: the spacing amount between lines of the layout is 2
 *   
 */
static void test_purpose_19()
{
    #define LAYOUT layout
    #define SPACE 2
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    int space;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set the spacing amount between lines of the layout.*/
    pango_layout_set_spacing(LAYOUT,SPACE);
    
    /*Get the spacing amount of the layout.*/
    space = pango_layout_get_spacing(LAYOUT);
    
    /*Chech that the spacing amount is correct.*/
    if (space != SPACE)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef SPACE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_set_spacing
 * Params: PangoLayout *layout, int spacing
 * Returns: void
 * Assertion: Sets the amount of spacing between the lines of the layout.
 * Params Values: layout,-1
 * Expected: the spacing amount between lines of the layout is -1
 *   
 */
static void test_purpose_20()
{
    #define LAYOUT layout
    #define SPACE -1
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    int space;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set the spacing amount between lines of the layout.*/
    pango_layout_set_spacing(LAYOUT,SPACE);
    
    /*Get the spacing amount of the layout.*/
    space = pango_layout_get_spacing(LAYOUT);
    
    /*Chech that the spacing amount is correct.*/
    if (space != SPACE)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef SPACE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_set_justify
 * Params: PangoLayout *layout, gboolean justify
 * Returns: void
 * Assertion: Sets whether or not each complete line should be stretched to fill the entire width of the layout. This stretching is typically done by adding whitespace, but for some scripts (such as Arabic), the justification is done by extending the characters. 
 * Params Values: layout,FALSE  
 * Expected: Justify of layout is FALSE 
 *   
 */
static void test_purpose_21()
{
    #define LAYOUT layout
    #define JUSTIFY FALSE 
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    gboolean justify;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set justify of the new created layout.*/
    pango_layout_set_justify(LAYOUT,JUSTIFY);
    
    /*Get justify of the layout.*/
    justify = pango_layout_get_justify(LAYOUT);
    
    /*Check that the justify of the layout is correct.*/
    if (justify != JUSTIFY)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef JUSTIFY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_set_justify
 * Params: PangoLayout *layout, gboolean justify
 * Returns: void
 * Assertion: Sets whether or not each complete line should be stretched to fill the entire width of the layout. This stretching is typically done by adding whitespace, but for some scripts (such as Arabic), the justification is done by extending the characters. 
 * Params Values: layout,TRUE 
 * Expected: Justify of layout is TRUE
 *   
 */
static void test_purpose_22()
{
    #define LAYOUT layout
    #define JUSTIFY TRUE
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    gboolean justify;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set justify of the new created layout.*/
    pango_layout_set_justify(LAYOUT,JUSTIFY);
    
    /*Get justify of the layout.*/
    justify = pango_layout_get_justify(LAYOUT);
    
    /*Check that the justify of the layout is correct.*/
    if (justify != JUSTIFY)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef JUSTIFY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_xy_to_index
 * Params: PangoLayout *layout, int x, int y, int *index_, int *trailing
 * Returns: TRUE if the coordinates were inside text
 * Assertion: Converts from X and Y position within a layout to the byte index to the character at that logical position. 
 * If the Y position is not inside the layout, the closest position is chosen (the position will be clamped inside the layout). 
 * If the X position is not within the layout, then the start or the end of the line is chosen as described for pango_layout_x_to_index(). 
 * If either the X or Y positions were not inside the layout, then the function returns FALSE; on an exact hit, it returns TRUE.
 * Params Values: layout,30*PANGO_SCALE,40*PANGO_SCALE,index,trailing
 * Expected: the index at location (30*PANGO_SCALE,40*PANGO_SCALE) of the layout
 *   
 */
static void test_purpose_23()
{
    #define LAYOUT layout
    #define X 30*PANGO_SCALE
    #define Y 40*PANGO_SCALE
    #define INDEX index
    #define TRAILING trailing
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    int *index,*trailing;
    PangoRectangle pos;
    gboolean rlt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    index = g_new0(int,1);
    trailing = g_new0(int,1);
    *index = -1;
    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set text of the layout.*/
    pango_layout_set_text(layout,"my layout text.\nJust for testing!",-1);
    
    /*Get the index at location of (X,Y) in the layout.*/
    rlt = pango_layout_xy_to_index(LAYOUT,X,Y,INDEX,TRAILING);
    /*
    if(rlt)
        g_printf("Click is inside layout:-)\n");
    else
        g_printf("Click is outside layout:-(\n");
    */
    /*g_printf("The index at location (X,Y) is %d.\n",*index);*/
    
    /*Convert index to x.*/
    /*pango_layout_index_to_pos(layout,*index,&pos);
    g_printf("X index of the pos is %d,X == %d.\n",pos.x,X);
    */
    
    /*Check whether the value of index is changed.*/
    if (*index == -1)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    g_free(index);
    g_free(trailing);
    
    #undef LAYOUT
    #undef X
    #undef Y
    #undef INDEX
    #undef TRAIL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_xy_to_index
 * Params: PangoLayout *layout, int x, int y, int *index_, int *trailing
 * Returns: TRUE if the coordinates were inside text
 * Assertion: Converts from X and Y position within a layout to the byte index to the character at that logical position. 
 * If the Y position is not inside the layout, the closest position is chosen (the position will be clamped inside the layout). 
 * If the X position is not within the layout, then the start or the end of the line is chosen as described for pango_layout_x_to_index(). 
 * If either the X or Y positions were not inside the layout, then the function returns FALSE; on an exact hit, it returns TRUE.
 * Params Values: layout,0,0,index,trailing
 * Expected: the index at location (0,0) of the layout
 *   
 */
static void test_purpose_24()
{
    #define LAYOUT layout
    #define X 0
    #define Y 0
    #define INDEX index
    #define TRAILING trailing
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    int *index,*trailing;
    PangoRectangle pos;
    gboolean rlt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    index = g_new0(int,1);
    trailing = g_new0(int,1);
    *index = -1;
    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set text of the layout.*/
    pango_layout_set_text(layout,"my layout text.\nJust for testing!",-1);
    
    /*Get the index at location of (X,Y) in the layout.*/
    rlt = pango_layout_xy_to_index(LAYOUT,X,Y,INDEX,TRAILING);
    /*
    if(rlt)
        g_printf("Click is inside layout:-)\n");
    else
        g_printf("Click is outside layout:-(\n");
    */
    /*g_printf("The index at location (X,Y) is %d.\n",*index);*/
    
    /*Convert index to x.*/
    /*pango_layout_index_to_pos(layout,*index,&pos);
    g_printf("X index of the pos is %d,X == %d.\n",pos.x,X);
    */
    
    /*Check whether the value of index is changed.*/
    if (*index == -1)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    g_free(index);
    g_free(trailing);
    
    #undef LAYOUT
    #undef X
    #undef Y
    #undef INDEX
    #undef TRAIL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_xy_to_index
 * Params: PangoLayout *layout, int x, int y, int *index_, int *trailing
 * Returns: TRUE if the coordinates were inside text
 * Assertion: Converts from X and Y position within a layout to the byte index to the character at that logical position. 
 * If the Y position is not inside the layout, the closest position is chosen (the position will be clamped inside the layout). 
 * If the X position is not within the layout, then the start or the end of the line is chosen as described for pango_layout_x_to_index(). 
 * If either the X or Y positions were not inside the layout, then the function returns FALSE; on an exact hit, it returns TRUE.
 * Params Values: layout,10*PANGO_SCALE,15*PANGO_SCALE,index,trailing
 * Expected: the index at location (10*PANGO_SCALE,15*PANGO_SCALE) of the layout
 *   
 */
static void test_purpose_25()
{
    #define LAYOUT layout
    #define X 10*PANGO_SCALE
    #define Y 15*PANGO_SCALE
    #define INDEX index
    #define TRAILING trailing
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    int *index,*trailing;
    PangoRectangle pos;
    gboolean rlt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    index = g_new0(int,1);
    trailing = g_new0(int,1);
    *index = -1;
    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set text of the layout.*/
    pango_layout_set_text(layout,"my layout text.\nJust for testing!",-1);
    
    /*Get the index at location of (X,Y) in the layout.*/
    rlt = pango_layout_xy_to_index(LAYOUT,X,Y,INDEX,TRAILING);
    /*
    if(rlt)
        g_printf("Click is inside layout:-)\n");
    else
        g_printf("Click is outside layout:-(\n");
    */
    /*g_printf("The index at location (X,Y) is %d.\n",*index);*/
    
    /*Convert index to x.*/
    /*pango_layout_index_to_pos(layout,*index,&pos);
    g_printf("X index of the pos is %d,X == %d.\n",pos.x,X);
    */
    
    /*Check whether the value of index is changed.*/
    if (*index == -1)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    g_free(index);
    g_free(trailing);
    
    #undef LAYOUT
    #undef X
    #undef Y
    #undef INDEX
    #undef TRAIL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_xy_to_index
 * Params: PangoLayout *layout, int x, int y, int *index_, int *trailing
 * Returns: TRUE if the coordinates were inside text
 * Assertion: Converts from X and Y position within a layout to the byte index to the character at that logical position. 
 * If the Y position is not inside the layout, the closest position is chosen (the position will be clamped inside the layout). 
 * If the X position is not within the layout, then the start or the end of the line is chosen as described for pango_layout_x_to_index(). 
 * If either the X or Y positions were not inside the layout, then the function returns FALSE; on an exact hit, it returns TRUE.
 * Params Values: layout,100*PANGO_SCALE,125*PANGO_SCALE,index,trailing
 * Expected: the index at location (100*PANGO_SCALE,125*PANGO_SCALE) of the layout
 *   
 */
static void test_purpose_26()
{
    #define LAYOUT layout
    #define X 100*PANGO_SCALE
    #define Y 125*PANGO_SCALE
    #define INDEX index
    #define TRAILING trailing
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    int *index,*trailing;
    PangoRectangle pos;
    gboolean rlt;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    index = g_new0(int,1);
    trailing = g_new0(int,1);
    *index = -1;
    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set text of the layout.*/
    pango_layout_set_text(layout,"my layout text.\nJust for testing!",-1);
    
    /*Get the index at location of (X,Y) in the layout.*/
    rlt = pango_layout_xy_to_index(LAYOUT,X,Y,INDEX,TRAILING);
    /*
    if(rlt)
        g_printf("Click is inside layout:-)\n");
    else
        g_printf("Click is outside layout:-(\n");
    */
    /*g_printf("The index at location (X,Y) is %d.\n",*index);*/
    
    /*Convert index to x.*/
    /*pango_layout_index_to_pos(layout,*index,&pos);
    g_printf("X index of the pos is %d,X == %d.\n",pos.x,X);
    */
    
    /*Check whether the value of index is changed.*/
    if (*index == -1)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    g_free(index);
    g_free(trailing);
    
    #undef LAYOUT
    #undef X
    #undef Y
    #undef INDEX
    #undef TRAIL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_index_to_pos
 * Params: PangoLayout *layout, int index_, PangoRectangle *pos
 * Returns: void
 * Assertion: Converts from an index within a PangoLayout to the onscreen position corresponding to the grapheme at that index, which is represented as rectangle. 
 * Note that pos->x is always the leading edge of the grapheme and pos->x + pos->width the trailing edge of the grapheme.If the directionality of the grapheme is right-to-left, then pos->width will be negative.
 * Params Values: 22,pos ,<%3%> 
 * Expected: the positoin value of index 22
 *   
 */
static void test_purpose_27()
{
    #define LAYOUT layout
    #define INDEX 22
    #define POS pos 
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    PangoRectangle *pos;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    pos = g_new0(PangoRectangle,1);
    pos->x = -1;
    pos->y = -1;
    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set text of the new created layout.*/
    pango_layout_set_text(layout,"my layout text.\nJust for testing!",-1);
    
    /*Convert index to position.*/
    pango_layout_index_to_pos(LAYOUT,INDEX,POS);
    
    /*
    *g_printf("The X position of the index is %d.\n",pos->x);
    *g_printf("The Y position of the index is %d.\n",pos->y);
    */
    
    /*Check whether the position value is set.*/
    if (pos->x == -1 || pos->y == -1)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    g_free(pos);
    
    #undef LAYOUT
    #undef INDEX
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_index_to_pos
 * Params: PangoLayout *layout, int index_, PangoRectangle *pos
 * Returns: void
 * Assertion: Converts from an index within a PangoLayout to the onscreen position corresponding to the grapheme at that index, which is represented as rectangle. 
 * Note that pos->x is always the leading edge of the grapheme and pos->x + pos->width the trailing edge of the grapheme.If the directionality of the grapheme is right-to-left, then pos->width will be negative.
 * Params Values: 0 ,pos ,<%3%> 
 * Expected: the positoin value of index 0 
 *   
 */
static void test_purpose_28()
{
    #define LAYOUT layout
    #define INDEX 0 
    #define POS pos 
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    PangoRectangle *pos;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    pos = g_new0(PangoRectangle,1);
    pos->x = -1;
    pos->y = -1;
    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set text of the new created layout.*/
    pango_layout_set_text(layout,"my layout text.\nJust for testing!",-1);
    
    /*Convert index to position.*/
    pango_layout_index_to_pos(LAYOUT,INDEX,POS);
    
    /*
    *g_printf("The X position of the index is %d.\n",pos->x);
    *g_printf("The Y position of the index is %d.\n",pos->y);
    */
    
    /*Check whether the position value is set.*/
    if (pos->x == -1 || pos->y == -1)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    g_free(pos);
    
    #undef LAYOUT
    #undef INDEX
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_index_to_pos
 * Params: PangoLayout *layout, int index_, PangoRectangle *pos
 * Returns: void
 * Assertion: Converts from an index within a PangoLayout to the onscreen position corresponding to the grapheme at that index, which is represented as rectangle. 
 * Note that pos->x is always the leading edge of the grapheme and pos->x + pos->width the trailing edge of the grapheme.If the directionality of the grapheme is right-to-left, then pos->width will be negative.
 * Params Values: 1 ,pos ,<%3%> 
 * Expected: the positoin value of index 1 
 *   
 */
static void test_purpose_29()
{
    #define LAYOUT layout
    #define INDEX 1 
    #define POS pos 
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    PangoRectangle *pos;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    pos = g_new0(PangoRectangle,1);
    pos->x = -1;
    pos->y = -1;
    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set text of the new created layout.*/
    pango_layout_set_text(layout,"my layout text.\nJust for testing!",-1);
    
    /*Convert index to position.*/
    pango_layout_index_to_pos(LAYOUT,INDEX,POS);
    
    /*
    *g_printf("The X position of the index is %d.\n",pos->x);
    *g_printf("The Y position of the index is %d.\n",pos->y);
    */
    
    /*Check whether the position value is set.*/
    if (pos->x == -1 || pos->y == -1)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    g_free(pos);
    
    #undef LAYOUT
    #undef INDEX
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_index_to_pos
 * Params: PangoLayout *layout, int index_, PangoRectangle *pos
 * Returns: void
 * Assertion: Converts from an index within a PangoLayout to the onscreen position corresponding to the grapheme at that index, which is represented as rectangle. 
 * Note that pos->x is always the leading edge of the grapheme and pos->x + pos->width the trailing edge of the grapheme.If the directionality of the grapheme is right-to-left, then pos->width will be negative.
 * Params Values: 32,pos ,<%3%> 
 * Expected: the positoin value of index 32
 *   
 */
static void test_purpose_30()
{
    #define LAYOUT layout
    #define INDEX 32
    #define POS pos 
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    PangoRectangle *pos;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    pos = g_new0(PangoRectangle,1);
    pos->x = -1;
    pos->y = -1;
    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set text of the new created layout.*/
    pango_layout_set_text(layout,"my layout text.\nJust for testing!",-1);
    
    /*Convert index to position.*/
    pango_layout_index_to_pos(LAYOUT,INDEX,POS);
    
    /*
    *g_printf("The X position of the index is %d.\n",pos->x);
    *g_printf("The Y position of the index is %d.\n",pos->y);
    */
    
    /*Check whether the position value is set.*/
    if (pos->x == -1 || pos->y == -1)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    g_free(pos);
    
    #undef LAYOUT
    #undef INDEX
    #undef POS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_line_get_extents
 * Params: PangoLayoutLine *line, PangoRectangle *ink_rect, PangoRectangle *logical_rect
 * Returns: void
 * Assertion: Computes the logical and ink extents of a layout line. 
 * See the documentation for pango_font_get_glyph_extents() for details about the interpretation of the rectangles.
 * Params Values: layout,ink_rect,logical_rect 
 * Expected: ink and logical externts of the layout is not -1   
 *   
 */
static void test_purpose_31()
{
    #define LINE layout
    #define INK_RECT ink_rect
    #define LOGICAL_RECT logical_rect
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    PangoLayoutLine *line;
    PangoRectangle *ink_rect;
    PangoRectangle *logical_rect;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    ink_rect = g_new0(PangoRectangle,1);
    ink_rect->width = -1;
    logical_rect = g_new0(PangoRectangle,1);
    logical_rect->width = -1;
    
    /*
    *g_printf("The initial width value of ink rectangle is %d.\n",ink_rect->width);
    */
    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new (context_new);
    
    /*Set text in the layout.*/
    pango_layout_set_text(layout,"my layout text.\nJust for testing!",-1);
    
    /*Get line from the layout.*/
    line = pango_layout_get_line(layout,0);
    
    /*Get the ink and logical rectangle value of the layout.*/
    pango_layout_get_extents(LINE,INK_RECT,LOGICAL_RECT);
    
    if (INK_RECT != NULL)
    {
    /*The ink externts of the layout is not -1.*/
        if (ink_rect->width == -1)
        {
            TEST_FAIL(get_wrong_type_msg(),NULL);
        }
    }
    
    if (LOGICAL_RECT != NULL)
    {
    /*The logical externts of the layout is not -1.*/
        if (logical_rect->width == -1)
        {
            TEST_FAIL(get_wrong_type_msg(),NULL);
        }
    }
    
    /*g_printf("After get externts,the width value of ink rectangle is %d.\n",ink_rect->width);*/
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    g_free(ink_rect);
    g_free(logical_rect);
    
    #undef LINE
    #undef INK_RECT
    #undef LOGICAL_RECT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_line_get_extents
 * Params: PangoLayoutLine *line, PangoRectangle *ink_rect, PangoRectangle *logical_rect
 * Returns: void
 * Assertion: Computes the logical and ink extents of a layout line. 
 * See the documentation for pango_font_get_glyph_extents() for details about the interpretation of the rectangles.
 * Params Values: layout,ink_rect,NULL 
 * Expected: ink externts of the layout is not -1   
 *   
 */
static void test_purpose_32()
{
    #define LINE layout
    #define INK_RECT ink_rect
    #define LOGICAL_RECT NULL
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    PangoLayoutLine *line;
    PangoRectangle *ink_rect;
    PangoRectangle *logical_rect;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    ink_rect = g_new0(PangoRectangle,1);
    ink_rect->width = -1;
    logical_rect = g_new0(PangoRectangle,1);
    logical_rect->width = -1;
    
    /*
    *g_printf("The initial width value of ink rectangle is %d.\n",ink_rect->width);
    */
    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new (context_new);
    
    /*Set text in the layout.*/
    pango_layout_set_text(layout,"my layout text.\nJust for testing!",-1);
    
    /*Get line from the layout.*/
    line = pango_layout_get_line(layout,0);
    
    /*Get the ink and logical rectangle value of the layout.*/
    pango_layout_get_extents(LINE,INK_RECT,LOGICAL_RECT);
    
    if (INK_RECT != NULL)
    {
    /*The ink externts of the layout is not -1.*/
        if (ink_rect->width == -1)
        {
            TEST_FAIL(get_wrong_type_msg(),NULL);
        }
    }
    
    if (LOGICAL_RECT != NULL)
    {
    /*The logical externts of the layout is not -1.*/
        if (logical_rect->width == -1)
        {
            TEST_FAIL(get_wrong_type_msg(),NULL);
        }
    }
    
    /*g_printf("After get externts,the width value of ink rectangle is %d.\n",ink_rect->width);*/
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    g_free(ink_rect);
    g_free(logical_rect);
    
    #undef LINE
    #undef INK_RECT
    #undef LOGICAL_RECT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_line_get_extents
 * Params: PangoLayoutLine *line, PangoRectangle *ink_rect, PangoRectangle *logical_rect
 * Returns: void
 * Assertion: Computes the logical and ink extents of a layout line. 
 * See the documentation for pango_font_get_glyph_extents() for details about the interpretation of the rectangles.
 * Params Values: layout,NULL,logical_rect 
 * Expected: logical externts of the layout is not -1   
 *   
 */
static void test_purpose_33()
{
    #define LINE layout
    #define INK_RECT NULL
    #define LOGICAL_RECT logical_rect
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    PangoLayoutLine *line;
    PangoRectangle *ink_rect;
    PangoRectangle *logical_rect;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    ink_rect = g_new0(PangoRectangle,1);
    ink_rect->width = -1;
    logical_rect = g_new0(PangoRectangle,1);
    logical_rect->width = -1;
    
    /*
    *g_printf("The initial width value of ink rectangle is %d.\n",ink_rect->width);
    */
    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new (context_new);
    
    /*Set text in the layout.*/
    pango_layout_set_text(layout,"my layout text.\nJust for testing!",-1);
    
    /*Get line from the layout.*/
    line = pango_layout_get_line(layout,0);
    
    /*Get the ink and logical rectangle value of the layout.*/
    pango_layout_get_extents(LINE,INK_RECT,LOGICAL_RECT);
    
    if (INK_RECT != NULL)
    {
    /*The ink externts of the layout is not -1.*/
        if (ink_rect->width == -1)
        {
            TEST_FAIL(get_wrong_type_msg(),NULL);
        }
    }
    
    if (LOGICAL_RECT != NULL)
    {
    /*The logical externts of the layout is not -1.*/
        if (logical_rect->width == -1)
        {
            TEST_FAIL(get_wrong_type_msg(),NULL);
        }
    }
    
    /*g_printf("After get externts,the width value of ink rectangle is %d.\n",ink_rect->width);*/
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    g_free(ink_rect);
    g_free(logical_rect);
    
    #undef LINE
    #undef INK_RECT
    #undef LOGICAL_RECT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_line_get_extents
 * Params: PangoLayoutLine *line, PangoRectangle *ink_rect, PangoRectangle *logical_rect
 * Returns: void
 * Assertion: Computes the logical and ink extents of a layout line. 
 * See the documentation for pango_font_get_glyph_extents() for details about the interpretation of the rectangles.
 * Params Values: layout,NULL,NULL 
 * Expected: ink and logical externts of the layout is not stored   
 *   
 */
static void test_purpose_34()
{
    #define LINE layout
    #define INK_RECT NULL
    #define LOGICAL_RECT NULL
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    PangoLayoutLine *line;
    PangoRectangle *ink_rect;
    PangoRectangle *logical_rect;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    ink_rect = g_new0(PangoRectangle,1);
    ink_rect->width = -1;
    logical_rect = g_new0(PangoRectangle,1);
    logical_rect->width = -1;
    
    /*
    *g_printf("The initial width value of ink rectangle is %d.\n",ink_rect->width);
    */
    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new (context_new);
    
    /*Set text in the layout.*/
    pango_layout_set_text(layout,"my layout text.\nJust for testing!",-1);
    
    /*Get line from the layout.*/
    line = pango_layout_get_line(layout,0);
    
    /*Get the ink and logical rectangle value of the layout.*/
    pango_layout_get_extents(LINE,INK_RECT,LOGICAL_RECT);
    
    if (INK_RECT != NULL)
    {
    /*The ink externts of the layout is not -1.*/
        if (ink_rect->width == -1)
        {
            TEST_FAIL(get_wrong_type_msg(),NULL);
        }
    }
    
    if (LOGICAL_RECT != NULL)
    {
    /*The logical externts of the layout is not -1.*/
        if (logical_rect->width == -1)
        {
            TEST_FAIL(get_wrong_type_msg(),NULL);
        }
    }
    
    /*g_printf("After get externts,the width value of ink rectangle is %d.\n",ink_rect->width);*/
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    g_free(ink_rect);
    g_free(logical_rect);
    
    #undef LINE
    #undef INK_RECT
    #undef LOGICAL_RECT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_get_width
 * Params: PangoLayout *layout
 * Returns: the width
 * Assertion: Gets the width to which the lines of the PangoLayout should be wrapped.
 * Params Values: layout
 * Expected: 10 
 *   
 */
static void test_purpose_35()
{
    #define LAYOUT layout
    #define WIDTH 10 
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    int width;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new (context_new);
    
    /*Set the width of the new created layout.*/
    pango_layout_set_width(LAYOUT,WIDTH);
    
    /*Get the width.*/
    width = pango_layout_get_width(LAYOUT);
    
    /*Check that the width is correct.*/
    if (width != WIDTH)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_get_width
 * Params: PangoLayout *layout
 * Returns: the width
 * Assertion: Gets the width to which the lines of the PangoLayout should be wrapped.
 * Params Values: layout
 * Expected: 0
 *   
 */
static void test_purpose_36()
{
    #define LAYOUT layout
    #define WIDTH 0
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    int width;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new (context_new);
    
    /*Set the width of the new created layout.*/
    pango_layout_set_width(LAYOUT,WIDTH);
    
    /*Get the width.*/
    width = pango_layout_get_width(LAYOUT);
    
    /*Check that the width is correct.*/
    if (width != WIDTH)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_get_width
 * Params: PangoLayout *layout
 * Returns: the width
 * Assertion: Gets the width to which the lines of the PangoLayout should be wrapped.
 * Params Values: layout
 * Expected: -1
 *   
 */
static void test_purpose_37()
{
    #define LAYOUT layout
    #define WIDTH -1
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    int width;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new (context_new);
    
    /*Set the width of the new created layout.*/
    pango_layout_set_width(LAYOUT,WIDTH);
    
    /*Get the width.*/
    width = pango_layout_get_width(LAYOUT);
    
    /*Check that the width is correct.*/
    if (width != WIDTH)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef WIDTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_get_lines
 * Params: PangoLayout *layout
 * Returns: a GSList containing the lines in the layout. 
 * This points to internal data of the PangoLayout and must be used with care. 
 * It will become invalid on any change to the layout's text or properties.
 * Assertion: Returns the lines of the layout as a list.
 * Params Values: layout 
 * Expected: lines in the layout
 *   
 */
static void test_purpose_38()
{
    #define LAYOUT layout 
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    int line_cnt;
    GSList *line_list;
    PangoLayoutLine *line;
    gint length;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new (context_new);
    
    /*Set text of the new created layout.*/
    pango_layout_set_text(layout,"my layout text.\nJust for testing!",-1);
    
    line_cnt = pango_layout_get_line_count(layout);
    /*g_printf("Line count num is %d.\n",line_cnt);*/
    
    /*Get lines in the layout.*/
    line_list = pango_layout_get_lines(LAYOUT);
    
    /*Get the first line.*/
    line = line_list->data;
    
    length = line->length;
    /*g_printf("Length of the line gotten is %d.\n",length);*/
    /*The first line is "my layout text.",check whether it's correct.Here just check the length of the line structure.*/
    if (length != strlen("my layout text."))
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    /*Get the second line of the line list.*/
    line_list = line_list->next;
    line = line_list->data;
    
    length = line->length;
    /*The second line is "Just for testing!",check whether it's correct.Here just check the length of the line structure.*/
    if (length != strlen("Just for testing!"))
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_set_indent
 * Params: PangoLayout *layout, int indent
 * Returns: void
 * Assertion: Sets the width in pango units to indent each paragraph. 
 * A negative value of indent will produce a hanging indent. 
 * That is, the first line will have the full width, and subsequent lines will be indented by the absolute value of indent.
 * Params Values: layout,0 
 * Expected: indent of layout is 0
 *   
 */
static void test_purpose_39()
{
    #define LAYOUT layout
    #define INDENT 0
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    int indent;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set indent of the new created layout.*/
    pango_layout_set_indent(LAYOUT,INDENT);
    
    /*Get indent of the layout.*/
    indent = pango_layout_get_indent(LAYOUT);
    
    /*Check that the indent is correct.*/
    if (indent != INDENT)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef INDENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_set_indent
 * Params: PangoLayout *layout, int indent
 * Returns: void
 * Assertion: Sets the width in pango units to indent each paragraph. 
 * A negative value of indent will produce a hanging indent. 
 * That is, the first line will have the full width, and subsequent lines will be indented by the absolute value of indent.
 * Params Values: layout,10 
 * Expected: indent of layout is 10
 *   
 */
static void test_purpose_40()
{
    #define LAYOUT layout
    #define INDENT 10
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    int indent;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set indent of the new created layout.*/
    pango_layout_set_indent(LAYOUT,INDENT);
    
    /*Get indent of the layout.*/
    indent = pango_layout_get_indent(LAYOUT);
    
    /*Check that the indent is correct.*/
    if (indent != INDENT)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef INDENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_set_indent
 * Params: PangoLayout *layout, int indent
 * Returns: void
 * Assertion: Sets the width in pango units to indent each paragraph. 
 * A negative value of indent will produce a hanging indent. 
 * That is, the first line will have the full width, and subsequent lines will be indented by the absolute value of indent.
 * Params Values: layout,-1 
 * Expected: indent of layout is -1
 *   
 */
static void test_purpose_41()
{
    #define LAYOUT layout
    #define INDENT -1
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    int indent;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new(context_new);
    
    /*Set indent of the new created layout.*/
    pango_layout_set_indent(LAYOUT,INDENT);
    
    /*Get indent of the layout.*/
    indent = pango_layout_get_indent(LAYOUT);
    
    /*Check that the indent is correct.*/
    if (indent != INDENT)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef INDENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_get_wrap
 * Params: PangoLayout *layout
 * Returns: Active wrap mode.
 * Assertion: Gets the wrap mode for the layout.
 * Params Values: layout 
 * Expected: PANGO_WRAP_WORD
 *   
 */
static void test_purpose_42()
{
    #define LAYOUT  layout
    #define WRAP_MODE PANGO_WRAP_WORD
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    PangoWrapMode wrap;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new (context_new);
    
    /*Set wrap mod of the new created layout.*/
    pango_layout_set_wrap(LAYOUT,WRAP_MODE);
    
    /*Get the wrap mod.*/
    wrap = pango_layout_get_wrap(LAYOUT);
    
    /*Check that the wrap mod is correct.*/
    if (wrap != WRAP_MODE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef WRAP_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_get_wrap
 * Params: PangoLayout *layout
 * Returns: Active wrap mode.
 * Assertion: Gets the wrap mode for the layout.
 * Params Values: layout 
 * Expected: PANGO_WRAP_CHAR
 *   
 */
static void test_purpose_43()
{
    #define LAYOUT  layout
    #define WRAP_MODE PANGO_WRAP_CHAR
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    PangoWrapMode wrap;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new (context_new);
    
    /*Set wrap mod of the new created layout.*/
    pango_layout_set_wrap(LAYOUT,WRAP_MODE);
    
    /*Get the wrap mod.*/
    wrap = pango_layout_get_wrap(LAYOUT);
    
    /*Check that the wrap mod is correct.*/
    if (wrap != WRAP_MODE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef WRAP_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_get_wrap
 * Params: PangoLayout *layout
 * Returns: Active wrap mode.
 * Assertion: Gets the wrap mode for the layout.
 * Params Values: layout 
 * Expected: PANGO_WRAP_WORD_CHAR
 *   
 */
static void test_purpose_44()
{
    #define LAYOUT  layout
    #define WRAP_MODE PANGO_WRAP_WORD_CHAR
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    PangoWrapMode wrap;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new (context_new);
    
    /*Set wrap mod of the new created layout.*/
    pango_layout_set_wrap(LAYOUT,WRAP_MODE);
    
    /*Get the wrap mod.*/
    wrap = pango_layout_get_wrap(LAYOUT);
    
    /*Check that the wrap mod is correct.*/
    if (wrap != WRAP_MODE)
    {
        TEST_FAIL(get_not_created_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef WRAP_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: pango_layout_get_line
 * Params: PangoLayout *layout, int line
 * Returns: the requested PangoLayoutLine, or NULL if the index is out of range.
 *  This layout line can be ref'ed and retained, but will become invalid if changes are made to the PangoLayout.
 * Assertion: Retrieves a particular line from a PangoLayout.
 * Params Values: layout,0  
 * Expected: length of the got line is length("my layout text.")
 *   
 */
static void test_purpose_45()
{
    #define LAYOUT layout
    #define LINE_NUM 0 
    
    PangoContext *context_new;
    PangoFontMap* font_ft2_map;
    PangoLayout *layout;
    int line_cnt;
    PangoLayoutLine *line;
    gint length;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    
    /*To create a new layout.*/
    font_ft2_map = pango_ft2_font_map_new();
    context_new = pango_ft2_font_map_create_context((PangoFT2FontMap *)font_ft2_map);
    layout = pango_layout_new (context_new);
    
    /*Set text of the new created layout.*/
    pango_layout_set_text(layout,"my layout text.\nJust for testing!",-1);
    line_cnt = pango_layout_get_line_count(layout);
    /*g_printf("Line count num is %d.\n",line_cnt);*/
    
    /*Check the line count number is correct.*/
    if (line_cnt != 2)
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    /*Get line at index LINE_NUM.*/
    line = pango_layout_get_line(LAYOUT,LINE_NUM);
    length = line->length;
    /*g_printf("Length of the line gotten is %d.\n",length);*/
    
    /*Check that length of the line is correct.*/
    if (length != strlen("my layout text."))
    {
        TEST_FAIL(get_wrong_type_msg(),NULL);
    }
    
    g_object_unref(context_new);
    g_object_unref(font_ft2_map);
    g_object_unref(layout);
    
    #undef LAYOUT
    #undef LINE_NUM
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for pango_layout ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {NULL,0}
};
