/*
 * GtkButton methods tests
 * Testing GtkButton methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
gint global_counter;
gint global_key;
gint global_mods;

void global_changed_signal   (GtkButton *button, gpointer user_data)
{
    global_counter++;
}

void global_key_press   (GtkWidget *widget, gpointer user_data)
{
    robot_key_press_event (widget, global_key, global_mods);
}


/*
 * Name: gtk_button_new
 * Params: void
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton widget.
 * Params Values: void
 * Expected: GtkButton*  
 */
static void test_purpose_1()
{
    GtkWidget *widget;
    GtkWidget *window;
    GtkReliefStyle relief;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new
 * Params: void
 * Returns: GtkWidget*
 * Assertion:  To add a child widget to the button, use gtk_container_add(). 
 * Params Values: void
 * Expected: GtkButton*  
 */
static void test_purpose_2()
{
    #define CHILD_WIDGET gtk_button_new ();
    
    GtkWidget *widget;
    GtkWidget *child_widget;
    GtkWidget *real_child_widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    child_widget = CHILD_WIDGET;
    widget = gtk_button_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child_widget);
    
    real_child_widget = gtk_bin_get_child (GTK_BIN (widget));
    if (real_child_widget != child_widget)
    {
        TEST_FAIL ("real_child_widget != child_widget", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  CHILD_WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new
 * Params: void
 * Returns: GtkWidget*
 * Assertion:  To add a child widget to the button, use gtk_container_add(). 
 * Params Values: void
 * Expected: GtkButton*  
 */
static void test_purpose_3()
{
    #define CHILD_WIDGET gtk_button_new_with_label ("button");
    
    GtkWidget *widget;
    GtkWidget *child_widget;
    GtkWidget *real_child_widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    child_widget = CHILD_WIDGET;
    widget = gtk_button_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child_widget);
    
    real_child_widget = gtk_bin_get_child (GTK_BIN (widget));
    if (real_child_widget != child_widget)
    {
        TEST_FAIL ("real_child_widget != child_widget", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  CHILD_WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new
 * Params: void
 * Returns: GtkWidget*
 * Assertion:  To add a child widget to the button, use gtk_container_add(). 
 * Params Values: void
 * Expected: GtkButton*  
 */
static void test_purpose_4()
{
    #define CHILD_WIDGET gtk_label_new ("label");
    
    GtkWidget *widget;
    GtkWidget *child_widget;
    GtkWidget *real_child_widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    child_widget = CHILD_WIDGET;
    widget = gtk_button_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (widget), child_widget);
    
    real_child_widget = gtk_bin_get_child (GTK_BIN (widget));
    if (real_child_widget != child_widget)
    {
        TEST_FAIL ("real_child_widget != child_widget", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  CHILD_WIDGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a GtkButton widget with a GtkLabel child containing the given text.
 * Params Values: NULL
 * Expected: GtkButton*  
 */
static void test_purpose_5()
{
    #define LABEL NULL
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label (LABEL);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a GtkButton widget with a GtkLabel child containing the given text.
 * Params Values: ""
 * Expected: GtkButton*  
 */
static void test_purpose_6()
{
    #define LABEL ""
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label (LABEL);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a GtkButton widget with a GtkLabel child containing the given text.
 * Params Values: " "
 * Expected: GtkButton*  
 */
static void test_purpose_7()
{
    #define LABEL " "
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label (LABEL);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a GtkButton widget with a GtkLabel child containing the given text.
 * Params Values: "   "
 * Expected: GtkButton*  
 */
static void test_purpose_8()
{
    #define LABEL "   "
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label (LABEL);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a GtkButton widget with a GtkLabel child containing the given text.
 * Params Values: "Label String"
 * Expected: GtkButton*  
 */
static void test_purpose_9()
{
    #define LABEL "Label String"
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label (LABEL);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a GtkButton widget with a GtkLabel child containing the given text.
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkButton*  
 */
static void test_purpose_10()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label (LABEL);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a GtkButton widget with a GtkLabel child containing the given text.
 * Params Values: "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: GtkButton*  
 */
static void test_purpose_11()
{
    #define LABEL "!@#$%^&*()_+|~=\";:'?<>`/"
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label (LABEL);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a GtkButton widget with a GtkLabel child containing the given text.
 * Params Values: "_a_b"
 * Expected: GtkButton*  
 */
static void test_purpose_12()
{
    #define LABEL "_a_b"
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label (LABEL);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a GtkButton widget with a GtkLabel child containing the given text.
 * Params Values: "\n\t\""
 * Expected: GtkButton*  
 */
static void test_purpose_13()
{
    #define LABEL "\n\t\""
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label (LABEL);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a GtkButton widget with a GtkLabel child containing the given text.
 * Params Values: "_\n\t\""
 * Expected: GtkButton*  
 */
static void test_purpose_14()
{
    #define LABEL "_\n\t\""
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label (LABEL);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a GtkButton widget with a GtkLabel child containing the given text.
 * Params Values: "\b"
 * Expected: GtkButton*  
 */
static void test_purpose_15()
{
    #define LABEL "\b"
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label (LABEL);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_label
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a GtkButton widget with a GtkLabel child containing the given text.
 * Params Values: "_\b"
 * Expected: GtkButton*  
 */
static void test_purpose_16()
{
    #define LABEL "_\b"
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label (LABEL);
    
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    #undef  LABEL 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing a label.
 * Params Values: NULL
 * Expected: GtkButton*  
 */
static void test_purpose_17()
{
    #define LABEL NULL
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing a label.
 * Params Values: ""
 * Expected: GtkButton*  
 */
static void test_purpose_18()
{
    #define LABEL ""
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing a label.
 * Params Values: " "
 * Expected: GtkButton*  
 */
static void test_purpose_19()
{
    #define LABEL " "
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing a label.
 * Params Values: "   "
 * Expected: GtkButton*  
 */
static void test_purpose_20()
{
    #define LABEL "   "
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing a label.
 * Params Values: "Label String"
 * Expected: GtkButton*  
 */
static void test_purpose_21()
{
    #define LABEL "Label String"
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing a label.
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkButton*  
 */
static void test_purpose_22()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing a label.
 * Params Values: "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: GtkButton*  
 */
static void test_purpose_23()
{
    #define LABEL "!@#$%^&*()_+|~=\";:'?<>`/"
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing a label.
 * Params Values: "_a_b"
 * Expected: GtkButton*  
 */
static void test_purpose_24()
{
    #define LABEL "_a_b"
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing a label.
 * Params Values: "\n\t\""
 * Expected: GtkButton*  
 */
static void test_purpose_25()
{
    #define LABEL "\n\t\""
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing a label.
 * Params Values: "_\n\t\""
 * Expected: GtkButton*  
 */
static void test_purpose_26()
{
    #define LABEL "_\n\t\""
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing a label.
 * Params Values: "\b"
 * Expected: GtkButton*  
 */
static void test_purpose_27()
{
    #define LABEL "\b"
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing a label.
 * Params Values: "_\b"
 * Expected: GtkButton*  
 */
static void test_purpose_28()
{
    #define LABEL "_\b"
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing a label.
 * Params Values: "_Text"
 * Expected: GtkButton*  
 */
static void test_purpose_29()
{
    #define LABEL "_Text"
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing a label.
 * Params Values: "__Text"
 * Expected: GtkButton*  
 */
static void test_purpose_30()
{
    #define LABEL "__Text"
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Pressing Alt and that key activates the button.
 * Params Values: "_a_b"
 * Expected: GtkButton*  
 */
static void test_purpose_31()
{
    #define LABEL "_a_b"
    #define KEY GDK_a
    #define MODS GDK_MOD1_MASK
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    global_key = KEY;
    global_mods = MODS;
    widget = gtk_button_new_with_mnemonic  (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    g_signal_connect (G_OBJECT (widget), "activate", GTK_SIGNAL_FUNC (global_changed_signal), NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_key_press);
    /******* -------------  *******/  
    
    if (!global_counter) 
    {
        TEST_FAIL ("'activate' signal not catched", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  KEY
    #undef  MODS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Pressing Alt and that key activates the button.
 * Params Values: "_Text"
 * Expected: GtkButton*  
 */
static void test_purpose_32()
{
    #define LABEL "_Text"
    #define KEY GDK_t
    #define MODS GDK_MOD1_MASK | GDK_LOCK_MASK
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    global_key = KEY;
    global_mods = MODS;
    widget = gtk_button_new_with_mnemonic  (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    g_signal_connect (G_OBJECT (widget), "activate", GTK_SIGNAL_FUNC (global_changed_signal), NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_key_press);
    /******* -------------  *******/  
    
    if (!global_counter) 
    {
        TEST_FAIL ("'activate' signal not catched", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  KEY
    #undef  MODS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Pressing Alt and that key activates the button.
 * Params Values: "T_ext"
 * Expected: GtkButton*  
 */
static void test_purpose_33()
{
    #define LABEL "T_ext"
    #define KEY GDK_e
    #define MODS GDK_MOD1_MASK
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    global_key = KEY;
    global_mods = MODS;
    widget = gtk_button_new_with_mnemonic  (LABEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    g_signal_connect (G_OBJECT (widget), "activate", GTK_SIGNAL_FUNC (global_changed_signal), NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE_AND_DO (widget, global_key_press);
    /******* -------------  *******/  
    
    if (!global_counter) 
    {
        TEST_FAIL ("'activate' signal not catched", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  KEY
    #undef  MODS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: ""
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: ""
 * Expected: GtkButton*  
 */
static void test_purpose_34()
{
    #define STOCK_ID ""
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: " "
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: " "
 * Expected: GtkButton*  
 */
static void test_purpose_35()
{
    #define STOCK_ID " "
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: "   "
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: "   "
 * Expected: GtkButton*  
 */
static void test_purpose_36()
{
    #define STOCK_ID "   "
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: "Label String"
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: "Label String"
 * Expected: GtkButton*  
 */
static void test_purpose_37()
{
    #define STOCK_ID "Label String"
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkButton*  
 */
static void test_purpose_38()
{
    #define STOCK_ID "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: GtkButton*  
 */
static void test_purpose_39()
{
    #define STOCK_ID "!@#$%^&*()_+|~=\";:'?<>`/"
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: "_a_b"
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: "_a_b"
 * Expected: GtkButton*  
 */
static void test_purpose_40()
{
    #define STOCK_ID "_a_b"
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: "\n\t\""
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: "\n\t\""
 * Expected: GtkButton*  
 */
static void test_purpose_41()
{
    #define STOCK_ID "\n\t\""
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: "_\n\t\""
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: "_\n\t\""
 * Expected: GtkButton*  
 */
static void test_purpose_42()
{
    #define STOCK_ID "_\n\t\""
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: "\b"
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: "\b"
 * Expected: GtkButton*  
 */
static void test_purpose_43()
{
    #define STOCK_ID "\b"
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: "_\b"
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: "_\b"
 * Expected: GtkButton*  
 */
static void test_purpose_44()
{
    #define STOCK_ID "_\b"
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: "_Underline Label"
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: "_Underline Label"
 * Expected: GtkButton*  
 */
static void test_purpose_45()
{
    #define STOCK_ID "_Underline Label"
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: GTK_STOCK_ADD
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: GTK_STOCK_ADD
 * Expected: GtkButton*  
 */
static void test_purpose_46()
{
    #define STOCK_ID GTK_STOCK_ADD
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: GTK_STOCK_APPLY
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: GTK_STOCK_APPLY
 * Expected: GtkButton*  
 */
static void test_purpose_47()
{
    #define STOCK_ID GTK_STOCK_APPLY
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: GTK_STOCK_BOLD
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: GTK_STOCK_BOLD
 * Expected: GtkButton*  
 */
static void test_purpose_48()
{
    #define STOCK_ID GTK_STOCK_BOLD
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: GTK_STOCK_CANCEL
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: GTK_STOCK_CANCEL
 * Expected: GtkButton*  
 */
static void test_purpose_49()
{
    #define STOCK_ID GTK_STOCK_CANCEL
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: GTK_STOCK_CDROM
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: GTK_STOCK_CDROM
 * Expected: GtkButton*  
 */
static void test_purpose_50()
{
    #define STOCK_ID GTK_STOCK_CDROM
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_CLEAR
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_CLEAR
 * Expected: GtkButton*  
 */
static void test_purpose_51()
{
    #define STOCK_ID 	     GTK_STOCK_CLEAR
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_CLOSE
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_CLOSE
 * Expected: GtkButton*  
 */
static void test_purpose_52()
{
    #define STOCK_ID 	     GTK_STOCK_CLOSE
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_CONVERT
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_CONVERT
 * Expected: GtkButton*  
 */
static void test_purpose_53()
{
    #define STOCK_ID 	     GTK_STOCK_CONVERT
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_COPY
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_COPY
 * Expected: GtkButton*  
 */
static void test_purpose_54()
{
    #define STOCK_ID 	     GTK_STOCK_COPY
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_CUT
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_CUT
 * Expected: GtkButton*  
 */
static void test_purpose_55()
{
    #define STOCK_ID 	     GTK_STOCK_CUT
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_DELETE
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_DELETE
 * Expected: GtkButton*  
 */
static void test_purpose_56()
{
    #define STOCK_ID 	     GTK_STOCK_DELETE
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_DIALOG_ERROR
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_DIALOG_ERROR
 * Expected: GtkButton*  
 */
static void test_purpose_57()
{
    #define STOCK_ID 	     GTK_STOCK_DIALOG_ERROR
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_DIALOG_INFO
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_DIALOG_INFO
 * Expected: GtkButton*  
 */
static void test_purpose_58()
{
    #define STOCK_ID 	     GTK_STOCK_DIALOG_INFO
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_DIALOG_QUESTION
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_DIALOG_QUESTION
 * Expected: GtkButton*  
 */
static void test_purpose_59()
{
    #define STOCK_ID 	     GTK_STOCK_DIALOG_QUESTION
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_DIALOG_WARNING
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_DIALOG_WARNING
 * Expected: GtkButton*  
 */
static void test_purpose_60()
{
    #define STOCK_ID 	     GTK_STOCK_DIALOG_WARNING
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_EXECUTE
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_EXECUTE
 * Expected: GtkButton*  
 */
static void test_purpose_61()
{
    #define STOCK_ID 	     GTK_STOCK_EXECUTE
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_FIND
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_FIND
 * Expected: GtkButton*  
 */
static void test_purpose_62()
{
    #define STOCK_ID 	     GTK_STOCK_FIND
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_FIND_AND_REPLACE
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_FIND_AND_REPLACE
 * Expected: GtkButton*  
 */
static void test_purpose_63()
{
    #define STOCK_ID 	     GTK_STOCK_FIND_AND_REPLACE
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_FLOPPY
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_FLOPPY
 * Expected: GtkButton*  
 */
static void test_purpose_64()
{
    #define STOCK_ID 	     GTK_STOCK_FLOPPY
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_GOTO_BOTTOM
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_GOTO_BOTTOM
 * Expected: GtkButton*  
 */
static void test_purpose_65()
{
    #define STOCK_ID 	     GTK_STOCK_GOTO_BOTTOM
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_GOTO_FIRST
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_GOTO_FIRST
 * Expected: GtkButton*  
 */
static void test_purpose_66()
{
    #define STOCK_ID 	     GTK_STOCK_GOTO_FIRST
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_GOTO_LAST
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_GOTO_LAST
 * Expected: GtkButton*  
 */
static void test_purpose_67()
{
    #define STOCK_ID 	     GTK_STOCK_GOTO_LAST
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_GOTO_TOP
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_GOTO_TOP
 * Expected: GtkButton*  
 */
static void test_purpose_68()
{
    #define STOCK_ID 	     GTK_STOCK_GOTO_TOP
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_GO_BACK
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_GO_BACK
 * Expected: GtkButton*  
 */
static void test_purpose_69()
{
    #define STOCK_ID 	     GTK_STOCK_GO_BACK
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_GO_DOWN
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_GO_DOWN
 * Expected: GtkButton*  
 */
static void test_purpose_70()
{
    #define STOCK_ID 	     GTK_STOCK_GO_DOWN
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_GO_FORWARD
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_GO_FORWARD
 * Expected: GtkButton*  
 */
static void test_purpose_71()
{
    #define STOCK_ID 	     GTK_STOCK_GO_FORWARD
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_GO_UP
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_GO_UP
 * Expected: GtkButton*  
 */
static void test_purpose_72()
{
    #define STOCK_ID 	     GTK_STOCK_GO_UP
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_HELP
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_HELP
 * Expected: GtkButton*  
 */
static void test_purpose_73()
{
    #define STOCK_ID 	     GTK_STOCK_HELP
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_HOME
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_HOME
 * Expected: GtkButton*  
 */
static void test_purpose_74()
{
    #define STOCK_ID 	     GTK_STOCK_HOME
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_INDEX
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_INDEX
 * Expected: GtkButton*  
 */
static void test_purpose_75()
{
    #define STOCK_ID 	     GTK_STOCK_INDEX
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_ITALIC
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_ITALIC
 * Expected: GtkButton*  
 */
static void test_purpose_76()
{
    #define STOCK_ID 	     GTK_STOCK_ITALIC
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_JUMP_TO
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_JUMP_TO
 * Expected: GtkButton*  
 */
static void test_purpose_77()
{
    #define STOCK_ID 	     GTK_STOCK_JUMP_TO
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_JUSTIFY_CENTER
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_JUSTIFY_CENTER
 * Expected: GtkButton*  
 */
static void test_purpose_78()
{
    #define STOCK_ID 	     GTK_STOCK_JUSTIFY_CENTER
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_JUSTIFY_FILL
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_JUSTIFY_FILL
 * Expected: GtkButton*  
 */
static void test_purpose_79()
{
    #define STOCK_ID 	     GTK_STOCK_JUSTIFY_FILL
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_JUSTIFY_LEFT
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_JUSTIFY_LEFT
 * Expected: GtkButton*  
 */
static void test_purpose_80()
{
    #define STOCK_ID 	     GTK_STOCK_JUSTIFY_LEFT
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_JUSTIFY_RIGHT
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_JUSTIFY_RIGHT
 * Expected: GtkButton*  
 */
static void test_purpose_81()
{
    #define STOCK_ID 	     GTK_STOCK_JUSTIFY_RIGHT
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_NEW
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_NEW
 * Expected: GtkButton*  
 */
static void test_purpose_82()
{
    #define STOCK_ID 	     GTK_STOCK_NEW
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_NO
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_NO
 * Expected: GtkButton*  
 */
static void test_purpose_83()
{
    #define STOCK_ID 	     GTK_STOCK_NO
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_OK
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_OK
 * Expected: GtkButton*  
 */
static void test_purpose_84()
{
    #define STOCK_ID 	     GTK_STOCK_OK
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_OPEN
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_OPEN
 * Expected: GtkButton*  
 */
static void test_purpose_85()
{
    #define STOCK_ID 	     GTK_STOCK_OPEN
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_PASTE
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_PASTE
 * Expected: GtkButton*  
 */
static void test_purpose_86()
{
    #define STOCK_ID 	     GTK_STOCK_PASTE
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_PREFERENCES
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_PREFERENCES
 * Expected: GtkButton*  
 */
static void test_purpose_87()
{
    #define STOCK_ID 	     GTK_STOCK_PREFERENCES
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_PRINT
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_PRINT
 * Expected: GtkButton*  
 */
static void test_purpose_88()
{
    #define STOCK_ID 	     GTK_STOCK_PRINT
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_PRINT_PREVIEW
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_PRINT_PREVIEW
 * Expected: GtkButton*  
 */
static void test_purpose_89()
{
    #define STOCK_ID 	     GTK_STOCK_PRINT_PREVIEW
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_PROPERTIES
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_PROPERTIES
 * Expected: GtkButton*  
 */
static void test_purpose_90()
{
    #define STOCK_ID 	     GTK_STOCK_PROPERTIES
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_QUIT
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_QUIT
 * Expected: GtkButton*  
 */
static void test_purpose_91()
{
    #define STOCK_ID 	     GTK_STOCK_QUIT
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_REDO
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_REDO
 * Expected: GtkButton*  
 */
static void test_purpose_92()
{
    #define STOCK_ID 	     GTK_STOCK_REDO
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_REFRESH
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_REFRESH
 * Expected: GtkButton*  
 */
static void test_purpose_93()
{
    #define STOCK_ID 	     GTK_STOCK_REFRESH
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_REMOVE
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_REMOVE
 * Expected: GtkButton*  
 */
static void test_purpose_94()
{
    #define STOCK_ID 	     GTK_STOCK_REMOVE
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_REVERT_TO_SAVED
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_REVERT_TO_SAVED
 * Expected: GtkButton*  
 */
static void test_purpose_95()
{
    #define STOCK_ID 	     GTK_STOCK_REVERT_TO_SAVED
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_SAVE
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_SAVE
 * Expected: GtkButton*  
 */
static void test_purpose_96()
{
    #define STOCK_ID 	     GTK_STOCK_SAVE
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_SAVE_AS
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_SAVE_AS
 * Expected: GtkButton*  
 */
static void test_purpose_97()
{
    #define STOCK_ID 	     GTK_STOCK_SAVE_AS
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_SELECT_COLOR
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_SELECT_COLOR
 * Expected: GtkButton*  
 */
static void test_purpose_98()
{
    #define STOCK_ID 	     GTK_STOCK_SELECT_COLOR
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_SELECT_FONT
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_SELECT_FONT
 * Expected: GtkButton*  
 */
static void test_purpose_99()
{
    #define STOCK_ID 	     GTK_STOCK_SELECT_FONT
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_SORT_ASCENDING
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_SORT_ASCENDING
 * Expected: GtkButton*  
 */
static void test_purpose_100()
{
    #define STOCK_ID 	     GTK_STOCK_SORT_ASCENDING
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_SORT_DESCENDING
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_SORT_DESCENDING
 * Expected: GtkButton*  
 */
static void test_purpose_101()
{
    #define STOCK_ID 	     GTK_STOCK_SORT_DESCENDING
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_SPELL_CHECK
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_SPELL_CHECK
 * Expected: GtkButton*  
 */
static void test_purpose_102()
{
    #define STOCK_ID 	     GTK_STOCK_SPELL_CHECK
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_STOP
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_STOP
 * Expected: GtkButton*  
 */
static void test_purpose_103()
{
    #define STOCK_ID 	     GTK_STOCK_STOP
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_STRIKETHROUGH
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_STRIKETHROUGH
 * Expected: GtkButton*  
 */
static void test_purpose_104()
{
    #define STOCK_ID 	     GTK_STOCK_STRIKETHROUGH
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_UNDELETE
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_UNDELETE
 * Expected: GtkButton*  
 */
static void test_purpose_105()
{
    #define STOCK_ID 	     GTK_STOCK_UNDELETE
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_UNDERLINE
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_UNDERLINE
 * Expected: GtkButton*  
 */
static void test_purpose_106()
{
    #define STOCK_ID 	     GTK_STOCK_UNDERLINE
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_UNDO
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_UNDO
 * Expected: GtkButton*  
 */
static void test_purpose_107()
{
    #define STOCK_ID 	     GTK_STOCK_UNDO
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: 	     GTK_STOCK_YES
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: 	     GTK_STOCK_YES
 * Expected: GtkButton*  
 */
static void test_purpose_108()
{
    #define STOCK_ID 	     GTK_STOCK_YES
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: GTK_STOCK_ZOOM_100
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: GTK_STOCK_ZOOM_100
 * Expected: GtkButton*  
 */
static void test_purpose_109()
{
    #define STOCK_ID GTK_STOCK_ZOOM_100
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: GTK_STOCK_ZOOM_FIT
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: GTK_STOCK_ZOOM_FIT
 * Expected: GtkButton*  
 */
static void test_purpose_110()
{
    #define STOCK_ID GTK_STOCK_ZOOM_FIT
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: GTK_STOCK_ZOOM_IN
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: GTK_STOCK_ZOOM_IN
 * Expected: GtkButton*  
 */
static void test_purpose_111()
{
    #define STOCK_ID GTK_STOCK_ZOOM_IN
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkButton containing the image and text from a stock item.
 * Params Values: GTK_STOCK_ZOOM_OUT
 * Expected: GtkButton*
 * 
 * Name: gtk_button_new_from_stock
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If stock_id is unknown, then it will be treated as a mnemonic label (as for gtk_button_new_with_mnemonic()).
 * Params Values: GTK_STOCK_ZOOM_OUT
 * Expected: GtkButton*  
 */
static void test_purpose_112()
{
    #define STOCK_ID GTK_STOCK_ZOOM_OUT
    
    gchararray label;
    GtkReliefStyle relief;
    GtkWidget *window;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_from_stock (STOCK_ID);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (STOCK_ID && label)
    {
        if (strcmp(label, STOCK_ID))
        {
            TEST_FAIL("label = %s, should be %s", label, STOCK_ID);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_relief
 * Params: GtkButton *button, GtkReliefStyle newstyle
 * Returns: void
 * Assertion: Sets the relief style of the edges of the given GtkButton widget.
 * Params Values: GtkButton *button, GTK_RELIEF_NORMAL
 * Expected: void  
 */
static void test_purpose_113()
{
    #define RELIEF GTK_RELIEF_NORMAL
    
    GtkReliefStyle relief;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_relief(GTK_BUTTON (widget), RELIEF);
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != RELIEF) 
    {
        TEST_FAIL("relief = %i %i", relief, RELIEF);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  RELIEF
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_relief
 * Params: GtkButton *button, GtkReliefStyle newstyle
 * Returns: void
 * Assertion: Sets the relief style of the edges of the given GtkButton widget.
 * Params Values: GtkButton *button, GTK_RELIEF_HALF
 * Expected: void  
 */
static void test_purpose_114()
{
    #define RELIEF GTK_RELIEF_HALF
    
    GtkReliefStyle relief;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_relief(GTK_BUTTON (widget), RELIEF);
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != RELIEF) 
    {
        TEST_FAIL("relief = %i %i", relief, RELIEF);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  RELIEF
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_relief
 * Params: GtkButton *button, GtkReliefStyle newstyle
 * Returns: void
 * Assertion: Sets the relief style of the edges of the given GtkButton widget.
 * Params Values: GtkButton *button, GTK_RELIEF_NONE
 * Expected: void  
 */
static void test_purpose_115()
{
    #define RELIEF GTK_RELIEF_NONE
    
    GtkReliefStyle relief;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_relief(GTK_BUTTON (widget), RELIEF);
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != RELIEF) 
    {
        TEST_FAIL("relief = %i %i", relief, RELIEF);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  RELIEF
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_relief
 * Params: GtkButton *button, GtkReliefStyle newstyle
 * Returns: void
 * Assertion: The default style is, as one can guess, GTK_RELIEF_NORMAL.
 * Params Values: GtkButton *button, <%0%>
 * Expected: void  
 */
static void test_purpose_116()
{
    GtkReliefStyle relief;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    relief = gtk_button_get_relief(GTK_BUTTON (widget));
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL("relief = %i, the default one is GTK_RELIEF_NORMAL", relief);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_relief
 * Params: GtkButton *button
 * Returns: GtkReliefStyle newstyle
 * Assertion: Returns the current relief style of the given GtkButton. 
 * Params Values: GtkButton *button
 * Expected: GTK_RELIEF_NORMAL  
 */
static void test_purpose_117()
{
    #define RELIEF GTK_RELIEF_NORMAL
    
    GtkReliefStyle relief;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    relief = RELIEF;
    g_object_set(GTK_OBJECT(widget), "relief", relief, NULL);
    relief = gtk_button_get_relief(GTK_BUTTON (widget));
    if (relief != RELIEF) 
    {
        TEST_FAIL("relief = %i %i", relief, RELIEF);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  RELIEF
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_relief
 * Params: GtkButton *button
 * Returns: GtkReliefStyle newstyle
 * Assertion: Returns the current relief style of the given GtkButton. 
 * Params Values: GtkButton *button
 * Expected: GTK_RELIEF_HALF  
 */
static void test_purpose_118()
{
    #define RELIEF GTK_RELIEF_HALF
    
    GtkReliefStyle relief;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    relief = RELIEF;
    g_object_set(GTK_OBJECT(widget), "relief", relief, NULL);
    relief = gtk_button_get_relief(GTK_BUTTON (widget));
    if (relief != RELIEF) 
    {
        TEST_FAIL("relief = %i %i", relief, RELIEF);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  RELIEF
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_relief
 * Params: GtkButton *button
 * Returns: GtkReliefStyle newstyle
 * Assertion: Returns the current relief style of the given GtkButton. 
 * Params Values: GtkButton *button
 * Expected: GTK_RELIEF_NONE  
 */
static void test_purpose_119()
{
    #define RELIEF GTK_RELIEF_NONE
    
    GtkReliefStyle relief;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    relief = RELIEF;
    g_object_set(GTK_OBJECT(widget), "relief", relief, NULL);
    relief = gtk_button_get_relief(GTK_BUTTON (widget));
    if (relief != RELIEF) 
    {
        TEST_FAIL("relief = %i %i", relief, RELIEF);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  RELIEF
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_pressed 
 * Params: GtkButton *button
 * Returns: void
 * Assertion: Emits a GtkButton::pressed signal to the given GtkButton. 
 * Params Values: a newly created GtkButton *button
 * Expected: void  
 */
static void test_purpose_120()
{
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    widget = gtk_button_new_with_label("Label");
    
    
    g_signal_connect (G_OBJECT (widget), "pressed", 
                        GTK_SIGNAL_FUNC (global_changed_signal), NULL);
    
    gtk_button_pressed (GTK_BUTTON (widget));
    
    if (global_counter == 0)
    {
        TEST_FAIL ("GtkButton widget should emit 'pressed' signal", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_released 
 * Params: GtkButton *button
 * Returns: void
 * Assertion: Emits a GtkButton::released signal to the given GtkButton. 
 * Params Values: a newly created GtkButton *button
 * Expected: void  
 */
static void test_purpose_121()
{
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    widget = gtk_button_new_with_label("Label");
    
    
    g_signal_connect (G_OBJECT (widget), "released", 
                        GTK_SIGNAL_FUNC (global_changed_signal), NULL);
    
    gtk_button_released (GTK_BUTTON (widget));
    
    if (global_counter == 0)
    {
        TEST_FAIL ("GtkButton widget should emit 'released' signal", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_clicked 
 * Params: GtkButton *button
 * Returns: void
 * Assertion: Emits a GtkButton::clicked signal to the given GtkButton. 
 * Params Values: a newly created GtkButton *button
 * Expected: void  
 */
static void test_purpose_122()
{
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    widget = gtk_button_new_with_label("Label");
    
    
    g_signal_connect (G_OBJECT (widget), "clicked", 
                        GTK_SIGNAL_FUNC (global_changed_signal), NULL);
    
    gtk_button_clicked (GTK_BUTTON (widget));
    
    if (global_counter == 0)
    {
        TEST_FAIL ("GtkButton widget should emit 'clicked' signal", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_enter 
 * Params: GtkButton *button
 * Returns: void
 * Assertion: Emits a GtkButton::enter signal to the given GtkButton. 
 * Params Values: a newly created GtkButton *button
 * Expected: void  
 */
static void test_purpose_123()
{
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    widget = gtk_button_new_with_label("Label");
    
    
    g_signal_connect (G_OBJECT (widget), "enter", 
                        GTK_SIGNAL_FUNC (global_changed_signal), NULL);
    
    gtk_button_enter (GTK_BUTTON (widget));
    
    if (global_counter == 0)
    {
        TEST_FAIL ("GtkButton widget should emit 'enter' signal", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_leave 
 * Params: GtkButton *button
 * Returns: void
 * Assertion: Emits a GtkButton::leave signal to the given GtkButton. 
 * Params Values: a newly created GtkButton *button
 * Expected: void  
 */
static void test_purpose_124()
{
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_counter = 0;
    widget = gtk_button_new_with_label("Label");
    
    
    g_signal_connect (G_OBJECT (widget), "leave", 
                        GTK_SIGNAL_FUNC (global_changed_signal), NULL);
    
    gtk_button_leave (GTK_BUTTON (widget));
    
    if (global_counter == 0)
    {
        TEST_FAIL ("GtkButton widget should emit 'leave' signal", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, NULL
 * Expected: void
 * 
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: This will also clear any previously set labels.
 * Params Values: GtkButton *button, NULL
 * Expected: void  
 */
static void test_purpose_125()
{
    #define LABEL NULL
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_label (GTK_BUTTON (widget), LABEL);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (LABEL)
    {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL but should be not", NULL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL("real_label is %s, should be %s", real_label, LABEL);
        }
    } else {
        if (real_label)
        {
            TEST_FAIL ("real_label is not NULL but should be", NULL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, ""
 * Expected: void
 * 
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: This will also clear any previously set labels.
 * Params Values: GtkButton *button, ""
 * Expected: void  
 */
static void test_purpose_126()
{
    #define LABEL ""
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_label (GTK_BUTTON (widget), LABEL);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (LABEL)
    {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL but should be not", NULL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL("real_label is %s, should be %s", real_label, LABEL);
        }
    } else {
        if (real_label)
        {
            TEST_FAIL ("real_label is not NULL but should be", NULL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, " "
 * Expected: void
 * 
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: This will also clear any previously set labels.
 * Params Values: GtkButton *button, " "
 * Expected: void  
 */
static void test_purpose_127()
{
    #define LABEL " "
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_label (GTK_BUTTON (widget), LABEL);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (LABEL)
    {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL but should be not", NULL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL("real_label is %s, should be %s", real_label, LABEL);
        }
    } else {
        if (real_label)
        {
            TEST_FAIL ("real_label is not NULL but should be", NULL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, "   "
 * Expected: void
 * 
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: This will also clear any previously set labels.
 * Params Values: GtkButton *button, "   "
 * Expected: void  
 */
static void test_purpose_128()
{
    #define LABEL "   "
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_label (GTK_BUTTON (widget), LABEL);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (LABEL)
    {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL but should be not", NULL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL("real_label is %s, should be %s", real_label, LABEL);
        }
    } else {
        if (real_label)
        {
            TEST_FAIL ("real_label is not NULL but should be", NULL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, "Label String"
 * Expected: void
 * 
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: This will also clear any previously set labels.
 * Params Values: GtkButton *button, "Label String"
 * Expected: void  
 */
static void test_purpose_129()
{
    #define LABEL "Label String"
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_label (GTK_BUTTON (widget), LABEL);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (LABEL)
    {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL but should be not", NULL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL("real_label is %s, should be %s", real_label, LABEL);
        }
    } else {
        if (real_label)
        {
            TEST_FAIL ("real_label is not NULL but should be", NULL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: void
 * 
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: This will also clear any previously set labels.
 * Params Values: GtkButton *button, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: void  
 */
static void test_purpose_130()
{
    #define LABEL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_label (GTK_BUTTON (widget), LABEL);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (LABEL)
    {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL but should be not", NULL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL("real_label is %s, should be %s", real_label, LABEL);
        }
    } else {
        if (real_label)
        {
            TEST_FAIL ("real_label is not NULL but should be", NULL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: void
 * 
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: This will also clear any previously set labels.
 * Params Values: GtkButton *button, "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: void  
 */
static void test_purpose_131()
{
    #define LABEL "!@#$%^&*()_+|~=\";:'?<>`/"
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_label (GTK_BUTTON (widget), LABEL);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (LABEL)
    {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL but should be not", NULL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL("real_label is %s, should be %s", real_label, LABEL);
        }
    } else {
        if (real_label)
        {
            TEST_FAIL ("real_label is not NULL but should be", NULL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, "_a_b"
 * Expected: void
 * 
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: This will also clear any previously set labels.
 * Params Values: GtkButton *button, "_a_b"
 * Expected: void  
 */
static void test_purpose_132()
{
    #define LABEL "_a_b"
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_label (GTK_BUTTON (widget), LABEL);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (LABEL)
    {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL but should be not", NULL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL("real_label is %s, should be %s", real_label, LABEL);
        }
    } else {
        if (real_label)
        {
            TEST_FAIL ("real_label is not NULL but should be", NULL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, "\n\t\""
 * Expected: void
 * 
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: This will also clear any previously set labels.
 * Params Values: GtkButton *button, "\n\t\""
 * Expected: void  
 */
static void test_purpose_133()
{
    #define LABEL "\n\t\""
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_label (GTK_BUTTON (widget), LABEL);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (LABEL)
    {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL but should be not", NULL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL("real_label is %s, should be %s", real_label, LABEL);
        }
    } else {
        if (real_label)
        {
            TEST_FAIL ("real_label is not NULL but should be", NULL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, "_\n\t\""
 * Expected: void
 * 
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: This will also clear any previously set labels.
 * Params Values: GtkButton *button, "_\n\t\""
 * Expected: void  
 */
static void test_purpose_134()
{
    #define LABEL "_\n\t\""
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_label (GTK_BUTTON (widget), LABEL);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (LABEL)
    {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL but should be not", NULL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL("real_label is %s, should be %s", real_label, LABEL);
        }
    } else {
        if (real_label)
        {
            TEST_FAIL ("real_label is not NULL but should be", NULL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, "\b"
 * Expected: void
 * 
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: This will also clear any previously set labels.
 * Params Values: GtkButton *button, "\b"
 * Expected: void  
 */
static void test_purpose_135()
{
    #define LABEL "\b"
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_label (GTK_BUTTON (widget), LABEL);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (LABEL)
    {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL but should be not", NULL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL("real_label is %s, should be %s", real_label, LABEL);
        }
    } else {
        if (real_label)
        {
            TEST_FAIL ("real_label is not NULL but should be", NULL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, "_\b"
 * Expected: void
 * 
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: This will also clear any previously set labels.
 * Params Values: GtkButton *button, "_\b"
 * Expected: void  
 */
static void test_purpose_136()
{
    #define LABEL "_\b"
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_label (GTK_BUTTON (widget), LABEL);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (LABEL)
    {
        if (!real_label)
        {
            TEST_FAIL ("real_label is NULL but should be not", NULL);
        } else if (strcmp (real_label, LABEL)) {
            TEST_FAIL("real_label is %s, should be %s", real_label, LABEL);
        }
    } else {
        if (real_label)
        {
            TEST_FAIL ("real_label is not NULL but should be", NULL);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, NULL
 * Expected: void  
 */
static void test_purpose_137()
{
    #define STOCK_ID NULL
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, ""
 * Expected: void  
 */
static void test_purpose_138()
{
    #define STOCK_ID ""
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, " "
 * Expected: void  
 */
static void test_purpose_139()
{
    #define STOCK_ID " "
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, "   "
 * Expected: void  
 */
static void test_purpose_140()
{
    #define STOCK_ID "   "
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, "Label String"
 * Expected: void  
 */
static void test_purpose_141()
{
    #define STOCK_ID "Label String"
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: void  
 */
static void test_purpose_142()
{
    #define STOCK_ID "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, "!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: void  
 */
static void test_purpose_143()
{
    #define STOCK_ID "!@#$%^&*()_+|~=\";:'?<>`/"
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, "_a_b"
 * Expected: void  
 */
static void test_purpose_144()
{
    #define STOCK_ID "_a_b"
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, "\n\t\""
 * Expected: void  
 */
static void test_purpose_145()
{
    #define STOCK_ID "\n\t\""
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, "_\n\t\""
 * Expected: void  
 */
static void test_purpose_146()
{
    #define STOCK_ID "_\n\t\""
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, "\b"
 * Expected: void  
 */
static void test_purpose_147()
{
    #define STOCK_ID "\b"
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, "_\b"
 * Expected: void  
 */
static void test_purpose_148()
{
    #define STOCK_ID "_\b"
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, "_Underline Label"
 * Expected: void  
 */
static void test_purpose_149()
{
    #define STOCK_ID "_Underline Label"
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, GTK_STOCK_ADD
 * Expected: void  
 */
static void test_purpose_150()
{
    #define STOCK_ID GTK_STOCK_ADD
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, GTK_STOCK_APPLY
 * Expected: void  
 */
static void test_purpose_151()
{
    #define STOCK_ID GTK_STOCK_APPLY
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, GTK_STOCK_BOLD
 * Expected: void  
 */
static void test_purpose_152()
{
    #define STOCK_ID GTK_STOCK_BOLD
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, GTK_STOCK_CANCEL
 * Expected: void  
 */
static void test_purpose_153()
{
    #define STOCK_ID GTK_STOCK_CANCEL
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, GTK_STOCK_CDROM
 * Expected: void  
 */
static void test_purpose_154()
{
    #define STOCK_ID GTK_STOCK_CDROM
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_CLEAR
 * Expected: void  
 */
static void test_purpose_155()
{
    #define STOCK_ID 	     GTK_STOCK_CLEAR
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_CLOSE
 * Expected: void  
 */
static void test_purpose_156()
{
    #define STOCK_ID 	     GTK_STOCK_CLOSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_CONVERT
 * Expected: void  
 */
static void test_purpose_157()
{
    #define STOCK_ID 	     GTK_STOCK_CONVERT
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_COPY
 * Expected: void  
 */
static void test_purpose_158()
{
    #define STOCK_ID 	     GTK_STOCK_COPY
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_CUT
 * Expected: void  
 */
static void test_purpose_159()
{
    #define STOCK_ID 	     GTK_STOCK_CUT
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_DELETE
 * Expected: void  
 */
static void test_purpose_160()
{
    #define STOCK_ID 	     GTK_STOCK_DELETE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_DIALOG_ERROR
 * Expected: void  
 */
static void test_purpose_161()
{
    #define STOCK_ID 	     GTK_STOCK_DIALOG_ERROR
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_DIALOG_INFO
 * Expected: void  
 */
static void test_purpose_162()
{
    #define STOCK_ID 	     GTK_STOCK_DIALOG_INFO
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_DIALOG_QUESTION
 * Expected: void  
 */
static void test_purpose_163()
{
    #define STOCK_ID 	     GTK_STOCK_DIALOG_QUESTION
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_DIALOG_WARNING
 * Expected: void  
 */
static void test_purpose_164()
{
    #define STOCK_ID 	     GTK_STOCK_DIALOG_WARNING
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_EXECUTE
 * Expected: void  
 */
static void test_purpose_165()
{
    #define STOCK_ID 	     GTK_STOCK_EXECUTE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_FIND
 * Expected: void  
 */
static void test_purpose_166()
{
    #define STOCK_ID 	     GTK_STOCK_FIND
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_FIND_AND_REPLACE
 * Expected: void  
 */
static void test_purpose_167()
{
    #define STOCK_ID 	     GTK_STOCK_FIND_AND_REPLACE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_FLOPPY
 * Expected: void  
 */
static void test_purpose_168()
{
    #define STOCK_ID 	     GTK_STOCK_FLOPPY
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_GOTO_BOTTOM
 * Expected: void  
 */
static void test_purpose_169()
{
    #define STOCK_ID 	     GTK_STOCK_GOTO_BOTTOM
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_GOTO_FIRST
 * Expected: void  
 */
static void test_purpose_170()
{
    #define STOCK_ID 	     GTK_STOCK_GOTO_FIRST
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_GOTO_LAST
 * Expected: void  
 */
static void test_purpose_171()
{
    #define STOCK_ID 	     GTK_STOCK_GOTO_LAST
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_GOTO_TOP
 * Expected: void  
 */
static void test_purpose_172()
{
    #define STOCK_ID 	     GTK_STOCK_GOTO_TOP
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_GO_BACK
 * Expected: void  
 */
static void test_purpose_173()
{
    #define STOCK_ID 	     GTK_STOCK_GO_BACK
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_GO_DOWN
 * Expected: void  
 */
static void test_purpose_174()
{
    #define STOCK_ID 	     GTK_STOCK_GO_DOWN
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_GO_FORWARD
 * Expected: void  
 */
static void test_purpose_175()
{
    #define STOCK_ID 	     GTK_STOCK_GO_FORWARD
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_GO_UP
 * Expected: void  
 */
static void test_purpose_176()
{
    #define STOCK_ID 	     GTK_STOCK_GO_UP
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_HELP
 * Expected: void  
 */
static void test_purpose_177()
{
    #define STOCK_ID 	     GTK_STOCK_HELP
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_HOME
 * Expected: void  
 */
static void test_purpose_178()
{
    #define STOCK_ID 	     GTK_STOCK_HOME
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_INDEX
 * Expected: void  
 */
static void test_purpose_179()
{
    #define STOCK_ID 	     GTK_STOCK_INDEX
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_ITALIC
 * Expected: void  
 */
static void test_purpose_180()
{
    #define STOCK_ID 	     GTK_STOCK_ITALIC
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_JUMP_TO
 * Expected: void  
 */
static void test_purpose_181()
{
    #define STOCK_ID 	     GTK_STOCK_JUMP_TO
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_JUSTIFY_CENTER
 * Expected: void  
 */
static void test_purpose_182()
{
    #define STOCK_ID 	     GTK_STOCK_JUSTIFY_CENTER
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_JUSTIFY_FILL
 * Expected: void  
 */
static void test_purpose_183()
{
    #define STOCK_ID 	     GTK_STOCK_JUSTIFY_FILL
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_JUSTIFY_LEFT
 * Expected: void  
 */
static void test_purpose_184()
{
    #define STOCK_ID 	     GTK_STOCK_JUSTIFY_LEFT
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_JUSTIFY_RIGHT
 * Expected: void  
 */
static void test_purpose_185()
{
    #define STOCK_ID 	     GTK_STOCK_JUSTIFY_RIGHT
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_NEW
 * Expected: void  
 */
static void test_purpose_186()
{
    #define STOCK_ID 	     GTK_STOCK_NEW
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_NO
 * Expected: void  
 */
static void test_purpose_187()
{
    #define STOCK_ID 	     GTK_STOCK_NO
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_OK
 * Expected: void  
 */
static void test_purpose_188()
{
    #define STOCK_ID 	     GTK_STOCK_OK
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_OPEN
 * Expected: void  
 */
static void test_purpose_189()
{
    #define STOCK_ID 	     GTK_STOCK_OPEN
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_PASTE
 * Expected: void  
 */
static void test_purpose_190()
{
    #define STOCK_ID 	     GTK_STOCK_PASTE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_PREFERENCES
 * Expected: void  
 */
static void test_purpose_191()
{
    #define STOCK_ID 	     GTK_STOCK_PREFERENCES
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_PRINT
 * Expected: void  
 */
static void test_purpose_192()
{
    #define STOCK_ID 	     GTK_STOCK_PRINT
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_PRINT_PREVIEW
 * Expected: void  
 */
static void test_purpose_193()
{
    #define STOCK_ID 	     GTK_STOCK_PRINT_PREVIEW
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_PROPERTIES
 * Expected: void  
 */
static void test_purpose_194()
{
    #define STOCK_ID 	     GTK_STOCK_PROPERTIES
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_QUIT
 * Expected: void  
 */
static void test_purpose_195()
{
    #define STOCK_ID 	     GTK_STOCK_QUIT
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_REDO
 * Expected: void  
 */
static void test_purpose_196()
{
    #define STOCK_ID 	     GTK_STOCK_REDO
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_REFRESH
 * Expected: void  
 */
static void test_purpose_197()
{
    #define STOCK_ID 	     GTK_STOCK_REFRESH
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_REMOVE
 * Expected: void  
 */
static void test_purpose_198()
{
    #define STOCK_ID 	     GTK_STOCK_REMOVE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_REVERT_TO_SAVED
 * Expected: void  
 */
static void test_purpose_199()
{
    #define STOCK_ID 	     GTK_STOCK_REVERT_TO_SAVED
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_SAVE
 * Expected: void  
 */
static void test_purpose_200()
{
    #define STOCK_ID 	     GTK_STOCK_SAVE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_SAVE_AS
 * Expected: void  
 */
static void test_purpose_201()
{
    #define STOCK_ID 	     GTK_STOCK_SAVE_AS
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_SELECT_COLOR
 * Expected: void  
 */
static void test_purpose_202()
{
    #define STOCK_ID 	     GTK_STOCK_SELECT_COLOR
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_SELECT_FONT
 * Expected: void  
 */
static void test_purpose_203()
{
    #define STOCK_ID 	     GTK_STOCK_SELECT_FONT
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_SORT_ASCENDING
 * Expected: void  
 */
static void test_purpose_204()
{
    #define STOCK_ID 	     GTK_STOCK_SORT_ASCENDING
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_SORT_DESCENDING
 * Expected: void  
 */
static void test_purpose_205()
{
    #define STOCK_ID 	     GTK_STOCK_SORT_DESCENDING
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_SPELL_CHECK
 * Expected: void  
 */
static void test_purpose_206()
{
    #define STOCK_ID 	     GTK_STOCK_SPELL_CHECK
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_STOP
 * Expected: void  
 */
static void test_purpose_207()
{
    #define STOCK_ID 	     GTK_STOCK_STOP
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_STRIKETHROUGH
 * Expected: void  
 */
static void test_purpose_208()
{
    #define STOCK_ID 	     GTK_STOCK_STRIKETHROUGH
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_UNDELETE
 * Expected: void  
 */
static void test_purpose_209()
{
    #define STOCK_ID 	     GTK_STOCK_UNDELETE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_UNDERLINE
 * Expected: void  
 */
static void test_purpose_210()
{
    #define STOCK_ID 	     GTK_STOCK_UNDERLINE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_UNDO
 * Expected: void  
 */
static void test_purpose_211()
{
    #define STOCK_ID 	     GTK_STOCK_UNDO
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, 	     GTK_STOCK_YES
 * Expected: void  
 */
static void test_purpose_212()
{
    #define STOCK_ID 	     GTK_STOCK_YES
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, GTK_STOCK_ZOOM_100
 * Expected: void  
 */
static void test_purpose_213()
{
    #define STOCK_ID GTK_STOCK_ZOOM_100
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, GTK_STOCK_ZOOM_FIT
 * Expected: void  
 */
static void test_purpose_214()
{
    #define STOCK_ID GTK_STOCK_ZOOM_FIT
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, GTK_STOCK_ZOOM_IN
 * Expected: void  
 */
static void test_purpose_215()
{
    #define STOCK_ID GTK_STOCK_ZOOM_IN
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_label
 * Params: GtkButton *button, const gchar *label
 * Returns: void
 * Assertion: Sets the text of the label of the button to str.
 * Params Values: GtkButton *button, GTK_STOCK_ZOOM_OUT
 * Expected: void  
 */
static void test_purpose_216()
{
    #define STOCK_ID GTK_STOCK_ZOOM_OUT
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), TRUE);
    gtk_button_set_label (GTK_BUTTON (widget), STOCK_ID);
    g_object_get(GTK_OBJECT(widget), "label", &real_label, NULL);
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: NULL  
 */
static void test_purpose_217()
{
    #define STOCK_ID NULL
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: ""  
 */
static void test_purpose_218()
{
    #define STOCK_ID ""
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: " "  
 */
static void test_purpose_219()
{
    #define STOCK_ID " "
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: "   "  
 */
static void test_purpose_220()
{
    #define STOCK_ID "   "
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: "Label String"  
 */
static void test_purpose_221()
{
    #define STOCK_ID "Label String"
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"  
 */
static void test_purpose_222()
{
    #define STOCK_ID "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: "!@#$%^&*()_+|~=\";:'?<>`/"  
 */
static void test_purpose_223()
{
    #define STOCK_ID "!@#$%^&*()_+|~=\";:'?<>`/"
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: "_a_b"  
 */
static void test_purpose_224()
{
    #define STOCK_ID "_a_b"
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: "\n\t\""  
 */
static void test_purpose_225()
{
    #define STOCK_ID "\n\t\""
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: "_\n\t\""  
 */
static void test_purpose_226()
{
    #define STOCK_ID "_\n\t\""
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: "\b"  
 */
static void test_purpose_227()
{
    #define STOCK_ID "\b"
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: "_\b"  
 */
static void test_purpose_228()
{
    #define STOCK_ID "_\b"
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: "_Underline Label"  
 */
static void test_purpose_229()
{
    #define STOCK_ID "_Underline Label"
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: GTK_STOCK_ADD  
 */
static void test_purpose_230()
{
    #define STOCK_ID GTK_STOCK_ADD
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: GTK_STOCK_APPLY  
 */
static void test_purpose_231()
{
    #define STOCK_ID GTK_STOCK_APPLY
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: GTK_STOCK_BOLD  
 */
static void test_purpose_232()
{
    #define STOCK_ID GTK_STOCK_BOLD
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: GTK_STOCK_CANCEL  
 */
static void test_purpose_233()
{
    #define STOCK_ID GTK_STOCK_CANCEL
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: GTK_STOCK_CDROM  
 */
static void test_purpose_234()
{
    #define STOCK_ID GTK_STOCK_CDROM
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_CLEAR  
 */
static void test_purpose_235()
{
    #define STOCK_ID 	     GTK_STOCK_CLEAR
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_CLOSE  
 */
static void test_purpose_236()
{
    #define STOCK_ID 	     GTK_STOCK_CLOSE
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_CONVERT  
 */
static void test_purpose_237()
{
    #define STOCK_ID 	     GTK_STOCK_CONVERT
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_COPY  
 */
static void test_purpose_238()
{
    #define STOCK_ID 	     GTK_STOCK_COPY
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_CUT  
 */
static void test_purpose_239()
{
    #define STOCK_ID 	     GTK_STOCK_CUT
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_DELETE  
 */
static void test_purpose_240()
{
    #define STOCK_ID 	     GTK_STOCK_DELETE
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_DIALOG_ERROR  
 */
static void test_purpose_241()
{
    #define STOCK_ID 	     GTK_STOCK_DIALOG_ERROR
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_DIALOG_INFO  
 */
static void test_purpose_242()
{
    #define STOCK_ID 	     GTK_STOCK_DIALOG_INFO
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_DIALOG_QUESTION  
 */
static void test_purpose_243()
{
    #define STOCK_ID 	     GTK_STOCK_DIALOG_QUESTION
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_DIALOG_WARNING  
 */
static void test_purpose_244()
{
    #define STOCK_ID 	     GTK_STOCK_DIALOG_WARNING
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_EXECUTE  
 */
static void test_purpose_245()
{
    #define STOCK_ID 	     GTK_STOCK_EXECUTE
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_FIND  
 */
static void test_purpose_246()
{
    #define STOCK_ID 	     GTK_STOCK_FIND
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_FIND_AND_REPLACE  
 */
static void test_purpose_247()
{
    #define STOCK_ID 	     GTK_STOCK_FIND_AND_REPLACE
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_FLOPPY  
 */
static void test_purpose_248()
{
    #define STOCK_ID 	     GTK_STOCK_FLOPPY
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_GOTO_BOTTOM  
 */
static void test_purpose_249()
{
    #define STOCK_ID 	     GTK_STOCK_GOTO_BOTTOM
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_GOTO_FIRST  
 */
static void test_purpose_250()
{
    #define STOCK_ID 	     GTK_STOCK_GOTO_FIRST
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_GOTO_LAST  
 */
static void test_purpose_251()
{
    #define STOCK_ID 	     GTK_STOCK_GOTO_LAST
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_GOTO_TOP  
 */
static void test_purpose_252()
{
    #define STOCK_ID 	     GTK_STOCK_GOTO_TOP
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_GO_BACK  
 */
static void test_purpose_253()
{
    #define STOCK_ID 	     GTK_STOCK_GO_BACK
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_GO_DOWN  
 */
static void test_purpose_254()
{
    #define STOCK_ID 	     GTK_STOCK_GO_DOWN
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_GO_FORWARD  
 */
static void test_purpose_255()
{
    #define STOCK_ID 	     GTK_STOCK_GO_FORWARD
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_GO_UP  
 */
static void test_purpose_256()
{
    #define STOCK_ID 	     GTK_STOCK_GO_UP
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_HELP  
 */
static void test_purpose_257()
{
    #define STOCK_ID 	     GTK_STOCK_HELP
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_HOME  
 */
static void test_purpose_258()
{
    #define STOCK_ID 	     GTK_STOCK_HOME
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_INDEX  
 */
static void test_purpose_259()
{
    #define STOCK_ID 	     GTK_STOCK_INDEX
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_ITALIC  
 */
static void test_purpose_260()
{
    #define STOCK_ID 	     GTK_STOCK_ITALIC
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_JUMP_TO  
 */
static void test_purpose_261()
{
    #define STOCK_ID 	     GTK_STOCK_JUMP_TO
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_JUSTIFY_CENTER  
 */
static void test_purpose_262()
{
    #define STOCK_ID 	     GTK_STOCK_JUSTIFY_CENTER
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_JUSTIFY_FILL  
 */
static void test_purpose_263()
{
    #define STOCK_ID 	     GTK_STOCK_JUSTIFY_FILL
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_JUSTIFY_LEFT  
 */
static void test_purpose_264()
{
    #define STOCK_ID 	     GTK_STOCK_JUSTIFY_LEFT
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_JUSTIFY_RIGHT  
 */
static void test_purpose_265()
{
    #define STOCK_ID 	     GTK_STOCK_JUSTIFY_RIGHT
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_NEW  
 */
static void test_purpose_266()
{
    #define STOCK_ID 	     GTK_STOCK_NEW
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_NO  
 */
static void test_purpose_267()
{
    #define STOCK_ID 	     GTK_STOCK_NO
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_OK  
 */
static void test_purpose_268()
{
    #define STOCK_ID 	     GTK_STOCK_OK
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_OPEN  
 */
static void test_purpose_269()
{
    #define STOCK_ID 	     GTK_STOCK_OPEN
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_PASTE  
 */
static void test_purpose_270()
{
    #define STOCK_ID 	     GTK_STOCK_PASTE
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_PREFERENCES  
 */
static void test_purpose_271()
{
    #define STOCK_ID 	     GTK_STOCK_PREFERENCES
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_PRINT  
 */
static void test_purpose_272()
{
    #define STOCK_ID 	     GTK_STOCK_PRINT
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_PRINT_PREVIEW  
 */
static void test_purpose_273()
{
    #define STOCK_ID 	     GTK_STOCK_PRINT_PREVIEW
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_PROPERTIES  
 */
static void test_purpose_274()
{
    #define STOCK_ID 	     GTK_STOCK_PROPERTIES
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_QUIT  
 */
static void test_purpose_275()
{
    #define STOCK_ID 	     GTK_STOCK_QUIT
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_REDO  
 */
static void test_purpose_276()
{
    #define STOCK_ID 	     GTK_STOCK_REDO
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_REFRESH  
 */
static void test_purpose_277()
{
    #define STOCK_ID 	     GTK_STOCK_REFRESH
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_REMOVE  
 */
static void test_purpose_278()
{
    #define STOCK_ID 	     GTK_STOCK_REMOVE
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_REVERT_TO_SAVED  
 */
static void test_purpose_279()
{
    #define STOCK_ID 	     GTK_STOCK_REVERT_TO_SAVED
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_SAVE  
 */
static void test_purpose_280()
{
    #define STOCK_ID 	     GTK_STOCK_SAVE
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_SAVE_AS  
 */
static void test_purpose_281()
{
    #define STOCK_ID 	     GTK_STOCK_SAVE_AS
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_SELECT_COLOR  
 */
static void test_purpose_282()
{
    #define STOCK_ID 	     GTK_STOCK_SELECT_COLOR
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_SELECT_FONT  
 */
static void test_purpose_283()
{
    #define STOCK_ID 	     GTK_STOCK_SELECT_FONT
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_SORT_ASCENDING  
 */
static void test_purpose_284()
{
    #define STOCK_ID 	     GTK_STOCK_SORT_ASCENDING
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_SORT_DESCENDING  
 */
static void test_purpose_285()
{
    #define STOCK_ID 	     GTK_STOCK_SORT_DESCENDING
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_SPELL_CHECK  
 */
static void test_purpose_286()
{
    #define STOCK_ID 	     GTK_STOCK_SPELL_CHECK
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_STOP  
 */
static void test_purpose_287()
{
    #define STOCK_ID 	     GTK_STOCK_STOP
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_STRIKETHROUGH  
 */
static void test_purpose_288()
{
    #define STOCK_ID 	     GTK_STOCK_STRIKETHROUGH
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_UNDELETE  
 */
static void test_purpose_289()
{
    #define STOCK_ID 	     GTK_STOCK_UNDELETE
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_UNDERLINE  
 */
static void test_purpose_290()
{
    #define STOCK_ID 	     GTK_STOCK_UNDERLINE
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_UNDO  
 */
static void test_purpose_291()
{
    #define STOCK_ID 	     GTK_STOCK_UNDO
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_YES  
 */
static void test_purpose_292()
{
    #define STOCK_ID 	     GTK_STOCK_YES
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: GTK_STOCK_ZOOM_100  
 */
static void test_purpose_293()
{
    #define STOCK_ID GTK_STOCK_ZOOM_100
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: GTK_STOCK_ZOOM_FIT  
 */
static void test_purpose_294()
{
    #define STOCK_ID GTK_STOCK_ZOOM_FIT
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: GTK_STOCK_ZOOM_IN  
 */
static void test_purpose_295()
{
    #define STOCK_ID GTK_STOCK_ZOOM_IN
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: GTK_STOCK_ZOOM_OUT  
 */
static void test_purpose_296()
{
    #define STOCK_ID GTK_STOCK_ZOOM_OUT
    #define USE_STOCK TRUE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: NULL  
 */
static void test_purpose_297()
{
    #define STOCK_ID NULL
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: ""  
 */
static void test_purpose_298()
{
    #define STOCK_ID ""
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: " "  
 */
static void test_purpose_299()
{
    #define STOCK_ID " "
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: "   "  
 */
static void test_purpose_300()
{
    #define STOCK_ID "   "
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: "Label String"  
 */
static void test_purpose_301()
{
    #define STOCK_ID "Label String"
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"  
 */
static void test_purpose_302()
{
    #define STOCK_ID "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: "!@#$%^&*()_+|~=\";:'?<>`/"  
 */
static void test_purpose_303()
{
    #define STOCK_ID "!@#$%^&*()_+|~=\";:'?<>`/"
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: "_a_b"  
 */
static void test_purpose_304()
{
    #define STOCK_ID "_a_b"
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: "\n\t\""  
 */
static void test_purpose_305()
{
    #define STOCK_ID "\n\t\""
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: "_\n\t\""  
 */
static void test_purpose_306()
{
    #define STOCK_ID "_\n\t\""
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: "\b"  
 */
static void test_purpose_307()
{
    #define STOCK_ID "\b"
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: "_\b"  
 */
static void test_purpose_308()
{
    #define STOCK_ID "_\b"
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: "_Underline Label"  
 */
static void test_purpose_309()
{
    #define STOCK_ID "_Underline Label"
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: GTK_STOCK_ADD  
 */
static void test_purpose_310()
{
    #define STOCK_ID GTK_STOCK_ADD
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: GTK_STOCK_APPLY  
 */
static void test_purpose_311()
{
    #define STOCK_ID GTK_STOCK_APPLY
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: GTK_STOCK_BOLD  
 */
static void test_purpose_312()
{
    #define STOCK_ID GTK_STOCK_BOLD
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: GTK_STOCK_CANCEL  
 */
static void test_purpose_313()
{
    #define STOCK_ID GTK_STOCK_CANCEL
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: GTK_STOCK_CDROM  
 */
static void test_purpose_314()
{
    #define STOCK_ID GTK_STOCK_CDROM
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_CLEAR  
 */
static void test_purpose_315()
{
    #define STOCK_ID 	     GTK_STOCK_CLEAR
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_CLOSE  
 */
static void test_purpose_316()
{
    #define STOCK_ID 	     GTK_STOCK_CLOSE
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_CONVERT  
 */
static void test_purpose_317()
{
    #define STOCK_ID 	     GTK_STOCK_CONVERT
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_COPY  
 */
static void test_purpose_318()
{
    #define STOCK_ID 	     GTK_STOCK_COPY
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_CUT  
 */
static void test_purpose_319()
{
    #define STOCK_ID 	     GTK_STOCK_CUT
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_DELETE  
 */
static void test_purpose_320()
{
    #define STOCK_ID 	     GTK_STOCK_DELETE
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_DIALOG_ERROR  
 */
static void test_purpose_321()
{
    #define STOCK_ID 	     GTK_STOCK_DIALOG_ERROR
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_DIALOG_INFO  
 */
static void test_purpose_322()
{
    #define STOCK_ID 	     GTK_STOCK_DIALOG_INFO
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_DIALOG_QUESTION  
 */
static void test_purpose_323()
{
    #define STOCK_ID 	     GTK_STOCK_DIALOG_QUESTION
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_DIALOG_WARNING  
 */
static void test_purpose_324()
{
    #define STOCK_ID 	     GTK_STOCK_DIALOG_WARNING
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_EXECUTE  
 */
static void test_purpose_325()
{
    #define STOCK_ID 	     GTK_STOCK_EXECUTE
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_FIND  
 */
static void test_purpose_326()
{
    #define STOCK_ID 	     GTK_STOCK_FIND
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_FIND_AND_REPLACE  
 */
static void test_purpose_327()
{
    #define STOCK_ID 	     GTK_STOCK_FIND_AND_REPLACE
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_FLOPPY  
 */
static void test_purpose_328()
{
    #define STOCK_ID 	     GTK_STOCK_FLOPPY
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_GOTO_BOTTOM  
 */
static void test_purpose_329()
{
    #define STOCK_ID 	     GTK_STOCK_GOTO_BOTTOM
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_GOTO_FIRST  
 */
static void test_purpose_330()
{
    #define STOCK_ID 	     GTK_STOCK_GOTO_FIRST
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_GOTO_LAST  
 */
static void test_purpose_331()
{
    #define STOCK_ID 	     GTK_STOCK_GOTO_LAST
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_GOTO_TOP  
 */
static void test_purpose_332()
{
    #define STOCK_ID 	     GTK_STOCK_GOTO_TOP
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_GO_BACK  
 */
static void test_purpose_333()
{
    #define STOCK_ID 	     GTK_STOCK_GO_BACK
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_GO_DOWN  
 */
static void test_purpose_334()
{
    #define STOCK_ID 	     GTK_STOCK_GO_DOWN
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_GO_FORWARD  
 */
static void test_purpose_335()
{
    #define STOCK_ID 	     GTK_STOCK_GO_FORWARD
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_GO_UP  
 */
static void test_purpose_336()
{
    #define STOCK_ID 	     GTK_STOCK_GO_UP
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_HELP  
 */
static void test_purpose_337()
{
    #define STOCK_ID 	     GTK_STOCK_HELP
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_HOME  
 */
static void test_purpose_338()
{
    #define STOCK_ID 	     GTK_STOCK_HOME
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_INDEX  
 */
static void test_purpose_339()
{
    #define STOCK_ID 	     GTK_STOCK_INDEX
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_ITALIC  
 */
static void test_purpose_340()
{
    #define STOCK_ID 	     GTK_STOCK_ITALIC
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_JUMP_TO  
 */
static void test_purpose_341()
{
    #define STOCK_ID 	     GTK_STOCK_JUMP_TO
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_JUSTIFY_CENTER  
 */
static void test_purpose_342()
{
    #define STOCK_ID 	     GTK_STOCK_JUSTIFY_CENTER
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_JUSTIFY_FILL  
 */
static void test_purpose_343()
{
    #define STOCK_ID 	     GTK_STOCK_JUSTIFY_FILL
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_JUSTIFY_LEFT  
 */
static void test_purpose_344()
{
    #define STOCK_ID 	     GTK_STOCK_JUSTIFY_LEFT
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_JUSTIFY_RIGHT  
 */
static void test_purpose_345()
{
    #define STOCK_ID 	     GTK_STOCK_JUSTIFY_RIGHT
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_NEW  
 */
static void test_purpose_346()
{
    #define STOCK_ID 	     GTK_STOCK_NEW
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_NO  
 */
static void test_purpose_347()
{
    #define STOCK_ID 	     GTK_STOCK_NO
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_OK  
 */
static void test_purpose_348()
{
    #define STOCK_ID 	     GTK_STOCK_OK
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_OPEN  
 */
static void test_purpose_349()
{
    #define STOCK_ID 	     GTK_STOCK_OPEN
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_PASTE  
 */
static void test_purpose_350()
{
    #define STOCK_ID 	     GTK_STOCK_PASTE
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_PREFERENCES  
 */
static void test_purpose_351()
{
    #define STOCK_ID 	     GTK_STOCK_PREFERENCES
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_PRINT  
 */
static void test_purpose_352()
{
    #define STOCK_ID 	     GTK_STOCK_PRINT
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_PRINT_PREVIEW  
 */
static void test_purpose_353()
{
    #define STOCK_ID 	     GTK_STOCK_PRINT_PREVIEW
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_PROPERTIES  
 */
static void test_purpose_354()
{
    #define STOCK_ID 	     GTK_STOCK_PROPERTIES
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_QUIT  
 */
static void test_purpose_355()
{
    #define STOCK_ID 	     GTK_STOCK_QUIT
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_REDO  
 */
static void test_purpose_356()
{
    #define STOCK_ID 	     GTK_STOCK_REDO
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_REFRESH  
 */
static void test_purpose_357()
{
    #define STOCK_ID 	     GTK_STOCK_REFRESH
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_REMOVE  
 */
static void test_purpose_358()
{
    #define STOCK_ID 	     GTK_STOCK_REMOVE
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_REVERT_TO_SAVED  
 */
static void test_purpose_359()
{
    #define STOCK_ID 	     GTK_STOCK_REVERT_TO_SAVED
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_SAVE  
 */
static void test_purpose_360()
{
    #define STOCK_ID 	     GTK_STOCK_SAVE
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_SAVE_AS  
 */
static void test_purpose_361()
{
    #define STOCK_ID 	     GTK_STOCK_SAVE_AS
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_SELECT_COLOR  
 */
static void test_purpose_362()
{
    #define STOCK_ID 	     GTK_STOCK_SELECT_COLOR
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_SELECT_FONT  
 */
static void test_purpose_363()
{
    #define STOCK_ID 	     GTK_STOCK_SELECT_FONT
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_SORT_ASCENDING  
 */
static void test_purpose_364()
{
    #define STOCK_ID 	     GTK_STOCK_SORT_ASCENDING
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_SORT_DESCENDING  
 */
static void test_purpose_365()
{
    #define STOCK_ID 	     GTK_STOCK_SORT_DESCENDING
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_SPELL_CHECK  
 */
static void test_purpose_366()
{
    #define STOCK_ID 	     GTK_STOCK_SPELL_CHECK
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_STOP  
 */
static void test_purpose_367()
{
    #define STOCK_ID 	     GTK_STOCK_STOP
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_STRIKETHROUGH  
 */
static void test_purpose_368()
{
    #define STOCK_ID 	     GTK_STOCK_STRIKETHROUGH
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_UNDELETE  
 */
static void test_purpose_369()
{
    #define STOCK_ID 	     GTK_STOCK_UNDELETE
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_UNDERLINE  
 */
static void test_purpose_370()
{
    #define STOCK_ID 	     GTK_STOCK_UNDERLINE
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_UNDO  
 */
static void test_purpose_371()
{
    #define STOCK_ID 	     GTK_STOCK_UNDO
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: 	     GTK_STOCK_YES  
 */
static void test_purpose_372()
{
    #define STOCK_ID 	     GTK_STOCK_YES
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: GTK_STOCK_ZOOM_100  
 */
static void test_purpose_373()
{
    #define STOCK_ID GTK_STOCK_ZOOM_100
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: GTK_STOCK_ZOOM_FIT  
 */
static void test_purpose_374()
{
    #define STOCK_ID GTK_STOCK_ZOOM_FIT
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: GTK_STOCK_ZOOM_IN  
 */
static void test_purpose_375()
{
    #define STOCK_ID GTK_STOCK_ZOOM_IN
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: Fetches the text from the label of the button, as set by gtk_button_set_label().
 * Params Values: GtkButton *button
 * Expected: GTK_STOCK_ZOOM_OUT  
 */
static void test_purpose_376()
{
    #define STOCK_ID GTK_STOCK_ZOOM_OUT
    #define USE_STOCK FALSE
    
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label ("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_set(GTK_OBJECT(widget), "label", STOCK_ID, NULL);
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (STOCK_ID && real_label)
    {
        if (strcmp(real_label, STOCK_ID))
        {
            TEST_FAIL("real_label = %s, should be %s", real_label, STOCK_ID);
        }
    } else {
        if (real_label && (strlen(real_label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", real_label, strlen(real_label));
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  STOCK_ID
    #undef  USE_STOCK
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_label
 * Params: GtkButton *button
 * Returns: const gchar *label
 * Assertion: If the label text has not been set the return value will be NULL.
 * Params Values: GtkButton *button
 * Expected: NULL  
 */
static void test_purpose_377()
{
    const gchar* real_label;
    GtkWidget *widget;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    real_label = gtk_button_get_label (GTK_BUTTON (widget));
    
    if (real_label)
    {
        TEST_FAIL("real_label is not NULL", NULL);
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_use_stock
 * Params: GtkButton *button, gboolean use_stock
 * Returns: void
 * Assertion: If true, the label set on the button is used as a stock id to select the stock item for the button.
 * Params Values: GtkButton *button, TRUE
 * Expected: void  
 */
static void test_purpose_378()
{
    #define USE_STOCK TRUE
    
    GtkWidget *widget;
    gboolean real_use_stock;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_get (GTK_OBJECT(widget), "use-stock", &real_use_stock, NULL);
    if (real_use_stock != USE_STOCK) 
    {
        TEST_FAIL("real_use_stock = %d, shold be %d", real_use_stock, USE_STOCK);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  USE_STOCK
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_use_stock
 * Params: GtkButton *button, gboolean use_stock
 * Returns: void
 * Assertion: If true, the label set on the button is used as a stock id to select the stock item for the button.
 * Params Values: GtkButton *button, FALSE
 * Expected: void  
 */
static void test_purpose_379()
{
    #define USE_STOCK FALSE
    
    GtkWidget *widget;
    gboolean real_use_stock;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_stock (GTK_BUTTON (widget), USE_STOCK);
    g_object_get (GTK_OBJECT(widget), "use-stock", &real_use_stock, NULL);
    if (real_use_stock != USE_STOCK) 
    {
        TEST_FAIL("real_use_stock = %d, shold be %d", real_use_stock, USE_STOCK);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  USE_STOCK
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_use_stock
 * Params: GtkButton *button
 * Returns: gboolean use_stock
 * Assertion: Returns whether the button label is a stock item.
 * Params Values: GtkButton *button
 * Expected: TRUE  
 */
static void test_purpose_380()
{
    #define USE_STOCK TRUE
    
    GtkWidget *widget;
    gboolean real_use_stock;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT(widget), "use-stock", USE_STOCK, NULL);
    real_use_stock = gtk_button_get_use_stock (GTK_BUTTON (widget));
    if (real_use_stock != USE_STOCK) 
    {
        TEST_FAIL("real_use_stock = %d, shold be %d", real_use_stock, USE_STOCK);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  USE_STOCK
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_use_stock
 * Params: GtkButton *button
 * Returns: gboolean use_stock
 * Assertion: Returns whether the button label is a stock item.
 * Params Values: GtkButton *button
 * Expected: FALSE  
 */
static void test_purpose_381()
{
    #define USE_STOCK FALSE
    
    GtkWidget *widget;
    gboolean real_use_stock;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT(widget), "use-stock", USE_STOCK, NULL);
    real_use_stock = gtk_button_get_use_stock (GTK_BUTTON (widget));
    if (real_use_stock != USE_STOCK) 
    {
        TEST_FAIL("real_use_stock = %d, shold be %d", real_use_stock, USE_STOCK);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  USE_STOCK
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_use_underline
 * Params: GtkButton *button, gboolean use_underline
 * Returns: void
 * Assertion: If true, an underline in the text of the button label indicates the next character should be used for the mnemonic accelerator key.
 * Params Values: GtkButton *button, TRUE
 * Expected: void  
 */
static void test_purpose_382()
{
    #define USE_UNDERLINE TRUE
    
    GtkWidget *widget;
    gboolean real_use_underline;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_underline (GTK_BUTTON (widget), USE_UNDERLINE);
    g_object_get (GTK_OBJECT(widget), "use-underline", &real_use_underline, NULL);
    if (real_use_underline != USE_UNDERLINE) 
    {
        TEST_FAIL("real_use_underline = %d, shold be %d", real_use_underline, USE_UNDERLINE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  USE_UNDERLINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_set_use_underline
 * Params: GtkButton *button, gboolean use_underline
 * Returns: void
 * Assertion: If true, an underline in the text of the button label indicates the next character should be used for the mnemonic accelerator key.
 * Params Values: GtkButton *button, FALSE
 * Expected: void  
 */
static void test_purpose_383()
{
    #define USE_UNDERLINE FALSE
    
    GtkWidget *widget;
    gboolean real_use_underline;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    gtk_button_set_use_underline (GTK_BUTTON (widget), USE_UNDERLINE);
    g_object_get (GTK_OBJECT(widget), "use-underline", &real_use_underline, NULL);
    if (real_use_underline != USE_UNDERLINE) 
    {
        TEST_FAIL("real_use_underline = %d, shold be %d", real_use_underline, USE_UNDERLINE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  USE_UNDERLINE
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_use_underline
 * Params: GtkButton *button
 * Returns: gboolean use_underline
 * Assertion: Returns whether an embedded underline in the button label indicates a mnemonic.
 * Params Values: GtkButton *button
 * Expected: TRUE  
 */
static void test_purpose_384()
{
    #define USE_UNDERLINE TRUE
    
    GtkWidget *widget;
    gboolean real_use_underline;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT(widget), "use-underline", USE_UNDERLINE, NULL);
    real_use_underline = gtk_button_get_use_underline (GTK_BUTTON (widget));
    if (real_use_underline != USE_UNDERLINE) 
    {
        TEST_FAIL("real_use_underline = %d, shold be %d", real_use_underline, USE_UNDERLINE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef USE_UNDERLINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_get_use_underline
 * Params: GtkButton *button
 * Returns: gboolean use_underline
 * Assertion: Returns whether an embedded underline in the button label indicates a mnemonic.
 * Params Values: GtkButton *button
 * Expected: FALSE  
 */
static void test_purpose_385()
{
    #define USE_UNDERLINE FALSE
    
    GtkWidget *widget;
    gboolean real_use_underline;
    GtkWidget *window;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_label("Label");
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_set (GTK_OBJECT(widget), "use-underline", USE_UNDERLINE, NULL);
    real_use_underline = gtk_button_get_use_underline (GTK_BUTTON (widget));
    if (real_use_underline != USE_UNDERLINE) 
    {
        TEST_FAIL("real_use_underline = %d, shold be %d", real_use_underline, USE_UNDERLINE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef USE_UNDERLINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores).
 * Params Values: "__"
 * Expected: GtkButton*  
 */
static void test_purpose_386()
{
    #define LABEL "__"
    #define CORRECT_LABEL "_"
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores).
 * Params Values: " __"
 * Expected: GtkButton*  
 */
static void test_purpose_387()
{
    #define LABEL " __"
    #define CORRECT_LABEL " _"
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores).
 * Params Values: "  __"
 * Expected: GtkButton*  
 */
static void test_purpose_388()
{
    #define LABEL "  __"
    #define CORRECT_LABEL "  _"
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores).
 * Params Values: "__Label String"
 * Expected: GtkButton*  
 */
static void test_purpose_389()
{
    #define LABEL "__Label String"
    #define CORRECT_LABEL "_Label String"
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores).
 * Params Values: "__abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: GtkButton*  
 */
static void test_purpose_390()
{
    #define LABEL "__abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    #define CORRECT_LABEL "_abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores).
 * Params Values: "__!@#$%^&*()_+|~=\";:'?<>`/"
 * Expected: GtkButton*  
 */
static void test_purpose_391()
{
    #define LABEL "__!@#$%^&*()_+|~=\";:'?<>`/"
    #define CORRECT_LABEL "_!@#$%^&*()+|~=\";:'?<>`/"
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores).
 * Params Values: "__a_b"
 * Expected: GtkButton*  
 */
static void test_purpose_392()
{
    #define LABEL "__a_b"
    #define CORRECT_LABEL "_ab"
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores).
 * Params Values: "\n\t\""
 * Expected: GtkButton*  
 */
static void test_purpose_393()
{
    #define LABEL "\n\t\""
    #define CORRECT_LABEL "\n\t\""
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores).
 * Params Values: "__\n\t\""
 * Expected: GtkButton*  
 */
static void test_purpose_394()
{
    #define LABEL "__\n\t\""
    #define CORRECT_LABEL "_\n\t\""
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores).
 * Params Values: "__\b"
 * Expected: GtkButton*  
 */
static void test_purpose_395()
{
    #define LABEL "__\b"
    #define CORRECT_LABEL "_\b"
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: If you need a literal underscore character in a label, use '__' (two underscores).
 * Params Values: "_a"
 * Expected: GtkButton*  
 */
static void test_purpose_396()
{
    #define LABEL "_a"
    #define CORRECT_LABEL "a"
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    G_CONST_RETURN gchar* real_label;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (LABEL)
    {
        real_label = gtk_label_get_text (GTK_LABEL (child));
        if (strcmp (real_label, CORRECT_LABEL)) {
            TEST_FAIL ("real_label is '%s', should be '%s'", real_label, CORRECT_LABEL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_LABEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_File"
 * Expected: GtkButton*  
 */
static void test_purpose_397()
{
    #define LABEL "_File"
    #define CORRECT_KEYVAL 'f'
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_file"
 * Expected: GtkButton*  
 */
static void test_purpose_398()
{
    #define LABEL "_file"
    #define CORRECT_KEYVAL 'f'
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_fil_e"
 * Expected: GtkButton*  
 */
static void test_purpose_399()
{
    #define LABEL "_fil_e"
    #define CORRECT_KEYVAL 'f'
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "__fil_e"
 * Expected: GtkButton*  
 */
static void test_purpose_400()
{
    #define LABEL "__fil_e"
    #define CORRECT_KEYVAL 'e'
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_fil_f"
 * Expected: GtkButton*  
 */
static void test_purpose_401()
{
    #define LABEL "_fil_f"
    #define CORRECT_KEYVAL 'f'
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "___fil_e"
 * Expected: GtkButton*  
 */
static void test_purpose_402()
{
    #define LABEL "___fil_e"
    #define CORRECT_KEYVAL 'f'
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_f__ile"
 * Expected: GtkButton*  
 */
static void test_purpose_403()
{
    #define LABEL "_f__ile"
    #define CORRECT_KEYVAL 'f'
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_@ile"
 * Expected: GtkButton*  
 */
static void test_purpose_404()
{
    #define LABEL "_@ile"
    #define CORRECT_KEYVAL '@'
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_#ile"
 * Expected: GtkButton*  
 */
static void test_purpose_405()
{
    #define LABEL "_#ile"
    #define CORRECT_KEYVAL '#'
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_/ile"
 * Expected: GtkButton*  
 */
static void test_purpose_406()
{
    #define LABEL "_/ile"
    #define CORRECT_KEYVAL '/'
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_\\le"
 * Expected: GtkButton*  
 */
static void test_purpose_407()
{
    #define LABEL "_\\le"
    #define CORRECT_KEYVAL '\\'
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_ le"
 * Expected: GtkButton*  
 */
static void test_purpose_408()
{
    #define LABEL "_ le"
    #define CORRECT_KEYVAL ' '
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_fi_le"
 * Expected: GtkButton*  
 */
static void test_purpose_409()
{
    #define LABEL "_fi_le"
    #define CORRECT_KEYVAL 'f'
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "__le"
 * Expected: GtkButton*  
 */
static void test_purpose_410()
{
    #define LABEL "__le"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "l__e"
 * Expected: GtkButton*  
 */
static void test_purpose_411()
{
    #define LABEL "l__e"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "___le"
 * Expected: GtkButton*  
 */
static void test_purpose_412()
{
    #define LABEL "___le"
    #define CORRECT_KEYVAL 'l'
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "____le"
 * Expected: GtkButton*  
 */
static void test_purpose_413()
{
    #define LABEL "____le"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "__"
 * Expected: GtkButton*  
 */
static void test_purpose_414()
{
    #define LABEL "__"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "_\0"
 * Expected: GtkButton*  
 */
static void test_purpose_415()
{
    #define LABEL "_\0"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_button_new_with_mnemonic
 * Params: const gchar *label
 * Returns: GtkWidget*
 * Assertion: The first underlined character represents a keyboard accelerator called a mnemonic.
 * Params Values: "Fil\0_e"
 * Expected: GtkButton*  
 */
static void test_purpose_416()
{
    #define LABEL "Fil\0_e"
    #define CORRECT_KEYVAL GDK_VoidSymbol
    
    gchararray  label;
    GtkReliefStyle relief;
    GtkWidget *child;
    GtkWidget *widget;
    guint mnemonic_keyval;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_button_new_with_mnemonic  (LABEL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
        
    if (!GTK_IS_BUTTON (widget))
    {
        TEST_FAIL (get_wrong_type_msg(), NULL); 
        return;
    }
    
    g_object_get(GTK_OBJECT(widget), "label", &label, NULL);
    
    if (LABEL && label)
    {
        if (strcmp(label, LABEL))
        {
            TEST_FAIL("label = %s %s", label, LABEL);
        }
    }
    else
    {
        if (label && (strlen(label) > 0))
        {
            TEST_FAIL("label = %s, strlen = %i", label, strlen(label));
        }
    }
    
    g_object_get(GTK_OBJECT(widget), "relief", &relief, NULL);
    if (relief != GTK_RELIEF_NORMAL) 
    {
        TEST_FAIL ("relief is %d, should be %d", relief, GTK_RELIEF_NORMAL);
    }
    
    child = gtk_bin_get_child (GTK_BIN (widget));
    if (LABEL)
    {
        if (!GTK_IS_LABEL (child))
        {
            TEST_FAIL ("check menu item child should be of type GtkLabel", NULL);
            return;
        }
    } else {
        if (child)
        {
            TEST_FAIL ("check menu item child should be NULL", NULL);
        }
    }
    
    if (child)
    {
        mnemonic_keyval = gtk_label_get_mnemonic_keyval(GTK_LABEL (child));
        if (mnemonic_keyval != CORRECT_KEYVAL)
        {
            TEST_FAIL("mnemonic_keyval = '%c', should be '%c'\n", 
                      mnemonic_keyval, CORRECT_KEYVAL);
        }
    }
    
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef  LABEL
    #undef  CORRECT_KEYVAL
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkButton ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {test_purpose_79, 1},
    {test_purpose_80, 1},
    {test_purpose_81, 1},
    {test_purpose_82, 1},
    {test_purpose_83, 1},
    {test_purpose_84, 1},
    {test_purpose_85, 1},
    {test_purpose_86, 1},
    {test_purpose_87, 1},
    {test_purpose_88, 1},
    {test_purpose_89, 1},
    {test_purpose_90, 1},
    {test_purpose_91, 1},
    {test_purpose_92, 1},
    {test_purpose_93, 1},
    {test_purpose_94, 1},
    {test_purpose_95, 1},
    {test_purpose_96, 1},
    {test_purpose_97, 1},
    {test_purpose_98, 1},
    {test_purpose_99, 1},
    {test_purpose_100, 1},
    {test_purpose_101, 1},
    {test_purpose_102, 1},
    {test_purpose_103, 1},
    {test_purpose_104, 1},
    {test_purpose_105, 1},
    {test_purpose_106, 1},
    {test_purpose_107, 1},
    {test_purpose_108, 1},
    {test_purpose_109, 1},
    {test_purpose_110, 1},
    {test_purpose_111, 1},
    {test_purpose_112, 1},
    {test_purpose_113, 1},
    {test_purpose_114, 1},
    {test_purpose_115, 1},
    {test_purpose_116, 1},
    {test_purpose_117, 1},
    {test_purpose_118, 1},
    {test_purpose_119, 1},
    {test_purpose_120, 1},
    {test_purpose_121, 1},
    {test_purpose_122, 1},
    {test_purpose_123, 1},
    {test_purpose_124, 1},
    {test_purpose_125, 1},
    {test_purpose_126, 1},
    {test_purpose_127, 1},
    {test_purpose_128, 1},
    {test_purpose_129, 1},
    {test_purpose_130, 1},
    {test_purpose_131, 1},
    {test_purpose_132, 1},
    {test_purpose_133, 1},
    {test_purpose_134, 1},
    {test_purpose_135, 1},
    {test_purpose_136, 1},
    {test_purpose_137, 1},
    {test_purpose_138, 1},
    {test_purpose_139, 1},
    {test_purpose_140, 1},
    {test_purpose_141, 1},
    {test_purpose_142, 1},
    {test_purpose_143, 1},
    {test_purpose_144, 1},
    {test_purpose_145, 1},
    {test_purpose_146, 1},
    {test_purpose_147, 1},
    {test_purpose_148, 1},
    {test_purpose_149, 1},
    {test_purpose_150, 1},
    {test_purpose_151, 1},
    {test_purpose_152, 1},
    {test_purpose_153, 1},
    {test_purpose_154, 1},
    {test_purpose_155, 1},
    {test_purpose_156, 1},
    {test_purpose_157, 1},
    {test_purpose_158, 1},
    {test_purpose_159, 1},
    {test_purpose_160, 1},
    {test_purpose_161, 1},
    {test_purpose_162, 1},
    {test_purpose_163, 1},
    {test_purpose_164, 1},
    {test_purpose_165, 1},
    {test_purpose_166, 1},
    {test_purpose_167, 1},
    {test_purpose_168, 1},
    {test_purpose_169, 1},
    {test_purpose_170, 1},
    {test_purpose_171, 1},
    {test_purpose_172, 1},
    {test_purpose_173, 1},
    {test_purpose_174, 1},
    {test_purpose_175, 1},
    {test_purpose_176, 1},
    {test_purpose_177, 1},
    {test_purpose_178, 1},
    {test_purpose_179, 1},
    {test_purpose_180, 1},
    {test_purpose_181, 1},
    {test_purpose_182, 1},
    {test_purpose_183, 1},
    {test_purpose_184, 1},
    {test_purpose_185, 1},
    {test_purpose_186, 1},
    {test_purpose_187, 1},
    {test_purpose_188, 1},
    {test_purpose_189, 1},
    {test_purpose_190, 1},
    {test_purpose_191, 1},
    {test_purpose_192, 1},
    {test_purpose_193, 1},
    {test_purpose_194, 1},
    {test_purpose_195, 1},
    {test_purpose_196, 1},
    {test_purpose_197, 1},
    {test_purpose_198, 1},
    {test_purpose_199, 1},
    {test_purpose_200, 1},
    {test_purpose_201, 1},
    {test_purpose_202, 1},
    {test_purpose_203, 1},
    {test_purpose_204, 1},
    {test_purpose_205, 1},
    {test_purpose_206, 1},
    {test_purpose_207, 1},
    {test_purpose_208, 1},
    {test_purpose_209, 1},
    {test_purpose_210, 1},
    {test_purpose_211, 1},
    {test_purpose_212, 1},
    {test_purpose_213, 1},
    {test_purpose_214, 1},
    {test_purpose_215, 1},
    {test_purpose_216, 1},
    {test_purpose_217, 1},
    {test_purpose_218, 1},
    {test_purpose_219, 1},
    {test_purpose_220, 1},
    {test_purpose_221, 1},
    {test_purpose_222, 1},
    {test_purpose_223, 1},
    {test_purpose_224, 1},
    {test_purpose_225, 1},
    {test_purpose_226, 1},
    {test_purpose_227, 1},
    {test_purpose_228, 1},
    {test_purpose_229, 1},
    {test_purpose_230, 1},
    {test_purpose_231, 1},
    {test_purpose_232, 1},
    {test_purpose_233, 1},
    {test_purpose_234, 1},
    {test_purpose_235, 1},
    {test_purpose_236, 1},
    {test_purpose_237, 1},
    {test_purpose_238, 1},
    {test_purpose_239, 1},
    {test_purpose_240, 1},
    {test_purpose_241, 1},
    {test_purpose_242, 1},
    {test_purpose_243, 1},
    {test_purpose_244, 1},
    {test_purpose_245, 1},
    {test_purpose_246, 1},
    {test_purpose_247, 1},
    {test_purpose_248, 1},
    {test_purpose_249, 1},
    {test_purpose_250, 1},
    {test_purpose_251, 1},
    {test_purpose_252, 1},
    {test_purpose_253, 1},
    {test_purpose_254, 1},
    {test_purpose_255, 1},
    {test_purpose_256, 1},
    {test_purpose_257, 1},
    {test_purpose_258, 1},
    {test_purpose_259, 1},
    {test_purpose_260, 1},
    {test_purpose_261, 1},
    {test_purpose_262, 1},
    {test_purpose_263, 1},
    {test_purpose_264, 1},
    {test_purpose_265, 1},
    {test_purpose_266, 1},
    {test_purpose_267, 1},
    {test_purpose_268, 1},
    {test_purpose_269, 1},
    {test_purpose_270, 1},
    {test_purpose_271, 1},
    {test_purpose_272, 1},
    {test_purpose_273, 1},
    {test_purpose_274, 1},
    {test_purpose_275, 1},
    {test_purpose_276, 1},
    {test_purpose_277, 1},
    {test_purpose_278, 1},
    {test_purpose_279, 1},
    {test_purpose_280, 1},
    {test_purpose_281, 1},
    {test_purpose_282, 1},
    {test_purpose_283, 1},
    {test_purpose_284, 1},
    {test_purpose_285, 1},
    {test_purpose_286, 1},
    {test_purpose_287, 1},
    {test_purpose_288, 1},
    {test_purpose_289, 1},
    {test_purpose_290, 1},
    {test_purpose_291, 1},
    {test_purpose_292, 1},
    {test_purpose_293, 1},
    {test_purpose_294, 1},
    {test_purpose_295, 1},
    {test_purpose_296, 1},
    {test_purpose_297, 1},
    {test_purpose_298, 1},
    {test_purpose_299, 1},
    {test_purpose_300, 1},
    {test_purpose_301, 1},
    {test_purpose_302, 1},
    {test_purpose_303, 1},
    {test_purpose_304, 1},
    {test_purpose_305, 1},
    {test_purpose_306, 1},
    {test_purpose_307, 1},
    {test_purpose_308, 1},
    {test_purpose_309, 1},
    {test_purpose_310, 1},
    {test_purpose_311, 1},
    {test_purpose_312, 1},
    {test_purpose_313, 1},
    {test_purpose_314, 1},
    {test_purpose_315, 1},
    {test_purpose_316, 1},
    {test_purpose_317, 1},
    {test_purpose_318, 1},
    {test_purpose_319, 1},
    {test_purpose_320, 1},
    {test_purpose_321, 1},
    {test_purpose_322, 1},
    {test_purpose_323, 1},
    {test_purpose_324, 1},
    {test_purpose_325, 1},
    {test_purpose_326, 1},
    {test_purpose_327, 1},
    {test_purpose_328, 1},
    {test_purpose_329, 1},
    {test_purpose_330, 1},
    {test_purpose_331, 1},
    {test_purpose_332, 1},
    {test_purpose_333, 1},
    {test_purpose_334, 1},
    {test_purpose_335, 1},
    {test_purpose_336, 1},
    {test_purpose_337, 1},
    {test_purpose_338, 1},
    {test_purpose_339, 1},
    {test_purpose_340, 1},
    {test_purpose_341, 1},
    {test_purpose_342, 1},
    {test_purpose_343, 1},
    {test_purpose_344, 1},
    {test_purpose_345, 1},
    {test_purpose_346, 1},
    {test_purpose_347, 1},
    {test_purpose_348, 1},
    {test_purpose_349, 1},
    {test_purpose_350, 1},
    {test_purpose_351, 1},
    {test_purpose_352, 1},
    {test_purpose_353, 1},
    {test_purpose_354, 1},
    {test_purpose_355, 1},
    {test_purpose_356, 1},
    {test_purpose_357, 1},
    {test_purpose_358, 1},
    {test_purpose_359, 1},
    {test_purpose_360, 1},
    {test_purpose_361, 1},
    {test_purpose_362, 1},
    {test_purpose_363, 1},
    {test_purpose_364, 1},
    {test_purpose_365, 1},
    {test_purpose_366, 1},
    {test_purpose_367, 1},
    {test_purpose_368, 1},
    {test_purpose_369, 1},
    {test_purpose_370, 1},
    {test_purpose_371, 1},
    {test_purpose_372, 1},
    {test_purpose_373, 1},
    {test_purpose_374, 1},
    {test_purpose_375, 1},
    {test_purpose_376, 1},
    {test_purpose_377, 1},
    {test_purpose_378, 1},
    {test_purpose_379, 1},
    {test_purpose_380, 1},
    {test_purpose_381, 1},
    {test_purpose_382, 1},
    {test_purpose_383, 1},
    {test_purpose_384, 1},
    {test_purpose_385, 1},
    {test_purpose_386, 1},
    {test_purpose_387, 1},
    {test_purpose_388, 1},
    {test_purpose_389, 1},
    {test_purpose_390, 1},
    {test_purpose_391, 1},
    {test_purpose_392, 1},
    {test_purpose_393, 1},
    {test_purpose_394, 1},
    {test_purpose_395, 1},
    {test_purpose_396, 1},
    {test_purpose_397, 1},
    {test_purpose_398, 1},
    {test_purpose_399, 1},
    {test_purpose_400, 1},
    {test_purpose_401, 1},
    {test_purpose_402, 1},
    {test_purpose_403, 1},
    {test_purpose_404, 1},
    {test_purpose_405, 1},
    {test_purpose_406, 1},
    {test_purpose_407, 1},
    {test_purpose_408, 1},
    {test_purpose_409, 1},
    {test_purpose_410, 1},
    {test_purpose_411, 1},
    {test_purpose_412, 1},
    {test_purpose_413, 1},
    {test_purpose_414, 1},
    {test_purpose_415, 1},
    {test_purpose_416, 1},
    {NULL,0}
};
