/*
 * GtkTextView methods tests
 * Testing GtkTextView methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

/*
 * Name: gtk_text_view_new
 * Params: void
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkTextView. 
 * Params Values: void
 * Expected: GtkTextView*  
 */
static void test_purpose_1()
{
    gint height_lines;
    gint width_columns;
    gint pixels_above_lines;
    gint pixels_below_lines;
    gint pixels_inside_wrap;
    gboolean editable;
    GtkWrapMode wrap_mode;
    gint left_margin;
    gint right_margin;
    gint indent;
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /* ???????????
    g_object_get(GTK_OBJECT(widget), "height-lines", &height_lines, NULL);
    if (height_lines != 0) 
    {
        TEST_FAIL ("height_lines = %i", height_lines);
    }
    
    g_object_get(GTK_OBJECT(widget), "width-columns", &width_columns, NULL);
    if (width_columns != 0) 
    {
        TEST_FAIL ("width_columns = %i", width_columns);
    }
    */
    
    g_object_get(GTK_OBJECT(widget), "pixels-above-lines", 
                   &pixels_above_lines, NULL);
    if (pixels_above_lines != 0) 
    {
        TEST_FAIL ("pixels_above_lines = %i", pixels_above_lines);
    }
    
    g_object_get(GTK_OBJECT(widget), "pixels-below-lines", 
                   &pixels_below_lines, NULL);
    if (pixels_below_lines != 0) 
    {
        TEST_FAIL ("pixels_below_lines =%i", pixels_below_lines);
    }
    
    g_object_get(GTK_OBJECT(widget), "pixels-inside-wrap", 
                   &pixels_inside_wrap, NULL);
    if (pixels_inside_wrap != 0) 
    {
        TEST_FAIL ("pixels_inside_wrap = %i", pixels_inside_wrap);
    }
    
    g_object_get(GTK_OBJECT(widget), "editable", &editable, NULL);
    if (editable != TRUE) 
    {
        TEST_FAIL ("editable = %i", editable);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap-mode", &wrap_mode, NULL);
    if (wrap_mode != GTK_WRAP_NONE) 
    {
        TEST_FAIL ("wrap_mode = %i", wrap_mode);
    }
    
    g_object_get(GTK_OBJECT(widget), "left-margin", &left_margin, NULL);
    if (left_margin != 0) 
    {
        TEST_FAIL ("left_margin = %i", left_margin);
    }
    
    g_object_get(GTK_OBJECT(widget), "right-margin", &right_margin, NULL);
    if (right_margin != 0) 
    {
        TEST_FAIL ("right_margin = %i", right_margin);
    }
    
    g_object_get(GTK_OBJECT(widget), "indent", &indent, NULL);
    if (indent != 0) 
    {
        TEST_FAIL ("indent = %i", indent);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_new
 * Params: void
 * Returns: GtkWidget*
 * Assertion: If you don't call gtk_text_view_set_buffer() before using the text view, an empty default buffer will be created for you.'
 * Params Values: void
 * Expected: GtkTextView*  
 */
static void test_purpose_2()
{
    GtkWidget* widget;
    GtkTextBuffer* buffer;
    gint line_count;
    gint char_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    line_count = gtk_text_buffer_get_line_count (buffer);
    if (line_count != 1)
    {
        TEST_FAIL ("line_count = %d, should be 1", line_count);
    }
    char_count = gtk_text_buffer_get_char_count (buffer);
    if (char_count != 0)
    {
        TEST_FAIL ("char_count = %d, should be 0", char_count);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_new_with_buffer
 * Params: GtkTextBuffer *buffer
 * Returns: GtkWidget*
 * Assertion: Creates a new GtkTextView widget displaying the buffer buffer.
 * Params Values: void
 * Expected: GtkTextView*  
 */
static void test_purpose_3()
{
    gint height_lines;
    gint width_columns;
    gint pixels_above_lines;
    gint pixels_below_lines;
    gint pixels_inside_wrap;
    gboolean editable;
    GtkWrapMode wrap_mode;
    gint left_margin;
    gint right_margin;
    gint indent;
    /*  PangoTabArray tabs; */
    
    GtkWidget *widget;
    GtkTextBuffer *buffer;
    GtkTextBuffer *real_buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    buffer = gtk_text_buffer_new (NULL);
    
    widget = gtk_text_view_new_with_buffer (gtk_text_buffer_new 
                                            (gtk_text_tag_table_new()));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    real_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    
    if (gtk_text_buffer_get_line_count (real_buffer) 
        != gtk_text_buffer_get_line_count (buffer))
    {
        TEST_FAIL ("real_buffer line count is %d, buffer line count is %d",
                   gtk_text_buffer_get_line_count (real_buffer),
                   gtk_text_buffer_get_line_count (buffer));
    }
    
    
    /*
    g_object_get(GTK_OBJECT(widget), "height-lines", &height_lines, NULL);
    if (height_lines != 0) 
    {
        TEST_FAIL ("height_lines = %i", height_lines);
    }
    
    g_object_get(GTK_OBJECT(widget), "width-columns", &width_columns, NULL);
    if (width_columns != 0) 
    {
        TEST_FAIL ("width_columns = %i", width_columns);
    }
    */
    
    g_object_get(GTK_OBJECT(widget), "pixels-above-lines", 
                   &pixels_above_lines, NULL);
    if (pixels_above_lines != 0) 
    {
        TEST_FAIL ("pixels_above_lines = %i", pixels_above_lines);
    }
    
    g_object_get(GTK_OBJECT(widget), "pixels-below-lines", 
                   &pixels_below_lines, NULL);
    if (pixels_below_lines != 0) 
    {
        TEST_FAIL ("pixels_below_lines =%i", pixels_below_lines);
    }
    
    g_object_get(GTK_OBJECT(widget), "pixels-inside-wrap", 
                   &pixels_inside_wrap, NULL);
    if (pixels_inside_wrap != 0) 
    {
        TEST_FAIL ("pixels_inside_wrap = %i", pixels_inside_wrap);
    }
    
    g_object_get(GTK_OBJECT(widget), "editable", &editable, NULL);
    if (editable != TRUE) 
    {
        TEST_FAIL ("editable = %i", editable);
    }
    
    g_object_get(GTK_OBJECT(widget), "wrap-mode", &wrap_mode, NULL);
    if (wrap_mode != GTK_WRAP_NONE) 
    {
        TEST_FAIL ("wrap_mode = %i", wrap_mode);
    }
    
    g_object_get(GTK_OBJECT(widget), "left-margin", &left_margin, NULL);
    if (left_margin != 0) 
    {
        TEST_FAIL ("left_margin = %i", left_margin);
    }
    
    g_object_get(GTK_OBJECT(widget), "right-margin", &right_margin, NULL);
    if (right_margin != 0) 
    {
        TEST_FAIL ("right_margin = %i", right_margin);
    }
    
    g_object_get(GTK_OBJECT(widget), "indent", &indent, NULL);
    if (indent != 0) 
    {
        TEST_FAIL ("indent = %i", indent);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_new_with_buffer
 * Params: GtkTextBuffer *buffer
 * Returns: GtkWidget*
 * Assertion: buffer may be NULL to create a default buffer, in which case this function is equivalent to gtk_text_view_new().
 * Params Values: void
 * Expected: GtkTextView*  
 */
static void test_purpose_4()
{
    GtkWidget* widget;
    GtkTextBuffer* buffer;
    gint line_count;
    gint char_count;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new_with_buffer (NULL);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    line_count = gtk_text_buffer_get_line_count (buffer);
    if (line_count != 1)
    {
        TEST_FAIL ("line_count = %d, should be 1", line_count);
    }
    char_count = gtk_text_buffer_get_char_count (buffer);
    if (char_count != 0)
    {
        TEST_FAIL ("char_count = %d, should be 0", char_count);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_new_with_buffer
 * Params: GtkTextBuffer *buffer
 * Returns: GtkWidget*
 * Assertion: The text view adds its own reference count to the buffer; it does not take over an existing reference.
 * Params Values: void
 * Expected: GtkTextView*  
 */
static void test_purpose_5()
{
    #define VIEW_NUM 1
    
    GtkWidget* widget;
    GtkWidget* widgets[VIEW_NUM];
    GtkTextBuffer* buffer;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new_with_buffer (gtk_text_buffer_new 
                                            (gtk_text_tag_table_new()));
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < VIEW_NUM; i++)
    {
        widgets[i] = gtk_text_view_new ();
        if (!widgets[i])
        {
            TEST_FAIL (get_not_created_msg (), NULL); 
            return;
        }
        if (!GTK_IS_TEXT_VIEW (widgets[i]))
        {
            TEST_FAIL (get_wrong_type_msg (), NULL); 
            return;
        }
        gtk_text_view_set_buffer (GTK_TEXT_VIEW (widgets[i]), buffer);
    }
    
    if ((G_OBJECT (buffer))->ref_count != VIEW_NUM + 2)
    {
        TEST_FAIL ("buffer ref_count = %d, should be %d", 
                   (G_OBJECT (buffer))->ref_count, VIEW_NUM + 2);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef VIEW_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_new_with_buffer
 * Params: GtkTextBuffer *buffer
 * Returns: GtkWidget*
 * Assertion: The text view adds its own reference count to the buffer; it does not take over an existing reference.
 * Params Values: void
 * Expected: GtkTextView*  
 */
static void test_purpose_6()
{
    #define VIEW_NUM 49
    
    GtkWidget* widget;
    GtkWidget* widgets[VIEW_NUM];
    GtkTextBuffer* buffer;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new_with_buffer (gtk_text_buffer_new 
                                            (gtk_text_tag_table_new()));
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < VIEW_NUM; i++)
    {
        widgets[i] = gtk_text_view_new ();
        if (!widgets[i])
        {
            TEST_FAIL (get_not_created_msg (), NULL); 
            return;
        }
        if (!GTK_IS_TEXT_VIEW (widgets[i]))
        {
            TEST_FAIL (get_wrong_type_msg (), NULL); 
            return;
        }
        gtk_text_view_set_buffer (GTK_TEXT_VIEW (widgets[i]), buffer);
    }
    
    if ((G_OBJECT (buffer))->ref_count != VIEW_NUM + 2)
    {
        TEST_FAIL ("buffer ref_count = %d, should be %d", 
                   (G_OBJECT (buffer))->ref_count, VIEW_NUM + 2);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef VIEW_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_new_with_buffer
 * Params: GtkTextBuffer *buffer
 * Returns: GtkWidget*
 * Assertion: The text view adds its own reference count to the buffer; it does not take over an existing reference.
 * Params Values: void
 * Expected: GtkTextView*  
 */
static void test_purpose_7()
{
    #define VIEW_NUM 149
    
    GtkWidget* widget;
    GtkWidget* widgets[VIEW_NUM];
    GtkTextBuffer* buffer;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new_with_buffer (gtk_text_buffer_new 
                                            (gtk_text_tag_table_new()));
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < VIEW_NUM; i++)
    {
        widgets[i] = gtk_text_view_new ();
        if (!widgets[i])
        {
            TEST_FAIL (get_not_created_msg (), NULL); 
            return;
        }
        if (!GTK_IS_TEXT_VIEW (widgets[i]))
        {
            TEST_FAIL (get_wrong_type_msg (), NULL); 
            return;
        }
        gtk_text_view_set_buffer (GTK_TEXT_VIEW (widgets[i]), buffer);
    }
    
    if ((G_OBJECT (buffer))->ref_count != VIEW_NUM + 2)
    {
        TEST_FAIL ("buffer ref_count = %d, should be %d", 
                   (G_OBJECT (buffer))->ref_count, VIEW_NUM + 2);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef VIEW_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_buffer
 * Params: GtkTextView *text_view, GtkTextBuffer *buffer
 * Returns: void
 * Assertion: Sets buffer as the buffer being displayed by text_view.
 * Params Values: newly created GtkTextView*, newly created GtkTextBuffer*
 * Expected: void
 * 
 * Name: gtk_text_view_get_buffer
 * Params: GtkTextView *text_view
 * Returns: GtkTextBuffer*
 * Assertion: Returns the GtkTextBuffer being displayed by this text view.
 * Params Values: newly created GtkTextView*
 * Expected:  GtkTextBuffer* that was set by gtk_text_view_set_buffer ()  
 */
static void test_purpose_8()
{
    GtkWidget *widget;
    GtkTextBuffer *text_buffer;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    text_buffer = gtk_text_buffer_new (gtk_text_tag_table_new());
    
    gtk_text_view_set_buffer (GTK_TEXT_VIEW (widget), text_buffer);
    
    if (gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget)) != text_buffer)
    {
        TEST_FAIL("Text buffer is differ from that was set by gtk_text_view_set_buffer()", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_buffer
 * Params: GtkTextView *text_view, GtkTextBuffer *buffer
 * Returns: void
 * Assertion: The previous buffer displayed by the text view is unreferenced, and a reference is added to buffer.
 * Params Values: newly created GtkTextView*, newly created GtkTextBuffer*
 * Expected: void  
 */
static void test_purpose_9()
{
    GtkWidget *widget;
    GtkTextBuffer *text_buffer1;
    GtkTextBuffer *text_buffer2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    text_buffer1 = gtk_text_buffer_new (gtk_text_tag_table_new());
    text_buffer2 = gtk_text_buffer_new (gtk_text_tag_table_new());
    gtk_text_view_set_buffer (GTK_TEXT_VIEW (widget), text_buffer1);
    gtk_text_view_set_buffer (GTK_TEXT_VIEW (widget), text_buffer2);
    
    if ((G_OBJECT (text_buffer1))->ref_count != 1)
    {
        TEST_FAIL ("text_buffer1->ref_count = %d, should be 1", 
                   (G_OBJECT (text_buffer1))->ref_count);
    }
    if ((G_OBJECT (text_buffer2))->ref_count != 2)
    {
        TEST_FAIL ("text_buffer2->ref_count = %d, should be 2", 
                   (G_OBJECT (text_buffer2))->ref_count);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_buffer
 * Params: GtkTextView *text_view
 * Returns: GtkTextBuffer*
 * Assertion: The reference count on the buffer is not incremented; the caller of this function won't own a new reference.'
 * Params Values: newly created GtkTextView*
 * Expected:  GtkTextBuffer* that was set by gtk_text_view_set_buffer ()  
 */
static void test_purpose_10()
{
    GtkWidget *widget;
    GtkTextBuffer *text_buffer1;
    GtkTextBuffer *text_buffer2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    text_buffer1 = gtk_text_buffer_new (gtk_text_tag_table_new());
    gtk_text_view_set_buffer (GTK_TEXT_VIEW (widget), text_buffer1);
    text_buffer2 = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    text_buffer2 = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    text_buffer2 = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    
    if ((G_OBJECT (text_buffer2))->ref_count != 2)
    {
        TEST_FAIL ("text_buffer2->ref_count = %d, should be 2", 
                   (G_OBJECT (text_buffer2))->ref_count);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_wrap_mode
 * Params: GtkTextView *text_view, GtkWrapMode *wrap_mode
 * Returns: void
 * Assertion: Sets the line wrapping for the view.
 * Params Values: newly created GtkTextView*, GTK_WRAP_NONE
 * Expected: void
 * 
 * Name: gtk_text_view_get_wrap_mode
 * Params: GtkTextView *text_view
 * Returns: GtkWrapMode
 * Assertion: Gets the line wrapping for the view.
 * Params Values: newly created GtkTextView*
 * Expected: GTK_WRAP_NONE  
 */
static void test_purpose_11()
{
    #define WRAP_MODE  GTK_WRAP_NONE
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), WRAP_MODE);
    
    if (gtk_text_view_get_wrap_mode (GTK_TEXT_VIEW (widget)) != WRAP_MODE)
    {
        TEST_FAIL("wrap-mode = %i, should be %i\n", gtk_text_view_get_wrap_mode (GTK_TEXT_VIEW (widget)), WRAP_MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WRAP_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_wrap_mode
 * Params: GtkTextView *text_view, GtkWrapMode *wrap_mode
 * Returns: void
 * Assertion: Sets the line wrapping for the view.
 * Params Values: newly created GtkTextView*, GTK_WRAP_CHAR
 * Expected: void
 * 
 * Name: gtk_text_view_get_wrap_mode
 * Params: GtkTextView *text_view
 * Returns: GtkWrapMode
 * Assertion: Gets the line wrapping for the view.
 * Params Values: newly created GtkTextView*
 * Expected: GTK_WRAP_CHAR  
 */
static void test_purpose_12()
{
    #define WRAP_MODE  GTK_WRAP_CHAR
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), WRAP_MODE);
    
    if (gtk_text_view_get_wrap_mode (GTK_TEXT_VIEW (widget)) != WRAP_MODE)
    {
        TEST_FAIL("wrap-mode = %i, should be %i\n", gtk_text_view_get_wrap_mode (GTK_TEXT_VIEW (widget)), WRAP_MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WRAP_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_wrap_mode
 * Params: GtkTextView *text_view, GtkWrapMode *wrap_mode
 * Returns: void
 * Assertion: Sets the line wrapping for the view.
 * Params Values: newly created GtkTextView*, GTK_WRAP_WORD
 * Expected: void
 * 
 * Name: gtk_text_view_get_wrap_mode
 * Params: GtkTextView *text_view
 * Returns: GtkWrapMode
 * Assertion: Gets the line wrapping for the view.
 * Params Values: newly created GtkTextView*
 * Expected: GTK_WRAP_WORD  
 */
static void test_purpose_13()
{
    #define WRAP_MODE  GTK_WRAP_WORD
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), WRAP_MODE);
    
    if (gtk_text_view_get_wrap_mode (GTK_TEXT_VIEW (widget)) != WRAP_MODE)
    {
        TEST_FAIL("wrap-mode = %i, should be %i\n", gtk_text_view_get_wrap_mode (GTK_TEXT_VIEW (widget)), WRAP_MODE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WRAP_MODE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_editable
 * Params: GtkTextView *text_view, gboolean *editable
 * Returns: void
 * Assertion: Sets the default editability of the GtkTextView.
 * Params Values: newly created GtkTextView*, TRUE
 * Expected: void
 * 
 * Name: gtk_text_view_get_editable
 * Params: GtkTextView *text_view
 * Returns: gboolean
 * Assertion: Returns the default editability of the GtkTextView.
 * Params Values: newly created GtkTextView*
 * Expected: TRUE  
 */
static void test_purpose_14()
{
    #define EDITABLE  TRUE
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_editable (GTK_TEXT_VIEW (widget), EDITABLE);
    
    if (gtk_text_view_get_editable (GTK_TEXT_VIEW (widget)) != EDITABLE)
    {
        TEST_FAIL("editable = %i, should be %i\n", gtk_text_view_get_editable (GTK_TEXT_VIEW (widget)), EDITABLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef EDITABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_editable
 * Params: GtkTextView *text_view, gboolean *editable
 * Returns: void
 * Assertion: Sets the default editability of the GtkTextView.
 * Params Values: newly created GtkTextView*, FALSE
 * Expected: void
 * 
 * Name: gtk_text_view_get_editable
 * Params: GtkTextView *text_view
 * Returns: gboolean
 * Assertion: Returns the default editability of the GtkTextView.
 * Params Values: newly created GtkTextView*
 * Expected: FALSE  
 */
static void test_purpose_15()
{
    #define EDITABLE  FALSE
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_editable (GTK_TEXT_VIEW (widget), EDITABLE);
    
    if (gtk_text_view_get_editable (GTK_TEXT_VIEW (widget)) != EDITABLE)
    {
        TEST_FAIL("editable = %i, should be %i\n", gtk_text_view_get_editable (GTK_TEXT_VIEW (widget)), EDITABLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef EDITABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_cursor_visible
 * Params: GtkTextView *text_view, gboolean *cursor_visible
 * Returns: void
 * Assertion: Toggles whether the insertion point is displayed.
 * Params Values: newly created GtkTextView*, TRUE
 * Expected: void
 * 
 * Name: gtk_text_view_get_cursor_visible
 * Params: GtkTextView *text_view
 * Returns: gboolean
 * Assertion: Find out whether the cursor is being displayed.
 * Params Values: newly created GtkTextView*
 * Expected: TRUE  
 */
static void test_purpose_16()
{
    #define CURSOR_VISIBLE  TRUE
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (widget), CURSOR_VISIBLE);
    
    if (gtk_text_view_get_cursor_visible (GTK_TEXT_VIEW (widget)) != CURSOR_VISIBLE)
    {
        TEST_FAIL("cursor_visible = %i, should be %i\n", gtk_text_view_get_cursor_visible (GTK_TEXT_VIEW (widget)), CURSOR_VISIBLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CURSOR_VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_cursor_visible
 * Params: GtkTextView *text_view, gboolean *cursor_visible
 * Returns: void
 * Assertion: Toggles whether the insertion point is displayed.
 * Params Values: newly created GtkTextView*, FALSE
 * Expected: void
 * 
 * Name: gtk_text_view_get_cursor_visible
 * Params: GtkTextView *text_view
 * Returns: gboolean
 * Assertion: Find out whether the cursor is being displayed.
 * Params Values: newly created GtkTextView*
 * Expected: FALSE  
 */
static void test_purpose_17()
{
    #define CURSOR_VISIBLE  FALSE
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (widget), CURSOR_VISIBLE);
    
    if (gtk_text_view_get_cursor_visible (GTK_TEXT_VIEW (widget)) != CURSOR_VISIBLE)
    {
        TEST_FAIL("cursor_visible = %i, should be %i\n", gtk_text_view_get_cursor_visible (GTK_TEXT_VIEW (widget)), CURSOR_VISIBLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CURSOR_VISIBLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_pixels_above_lines
 * Params: GtkTextView *text_view, gint *pixels_above_lines
 * Returns: void
 * Assertion: Sets the default number of blank pixels above paragraphs in text_view.
 * Params Values: newly created GtkTextView*, 0
 * Expected: void
 * 
 * Name: gtk_text_view_get_pixels_above_lines
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the default number of pixels to put above paragraphs.
 * Params Values: newly created GtkTextView*
 * Expected: 0  
 */
static void test_purpose_18()
{
    #define PIXELS_ABOVE_LINES  0
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_pixels_above_lines (GTK_TEXT_VIEW (widget), PIXELS_ABOVE_LINES);
    
    if (gtk_text_view_get_pixels_above_lines (GTK_TEXT_VIEW (widget)) != PIXELS_ABOVE_LINES)
    {
        TEST_FAIL("pixels_above_lines = %i, should be %i\n", gtk_text_view_get_pixels_above_lines (GTK_TEXT_VIEW (widget)), PIXELS_ABOVE_LINES);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PIXELS_ABOVE_LINES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_pixels_above_lines
 * Params: GtkTextView *text_view, gint *pixels_above_lines
 * Returns: void
 * Assertion: Sets the default number of blank pixels above paragraphs in text_view.
 * Params Values: newly created GtkTextView*, 1
 * Expected: void
 * 
 * Name: gtk_text_view_get_pixels_above_lines
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the default number of pixels to put above paragraphs.
 * Params Values: newly created GtkTextView*
 * Expected: 1  
 */
static void test_purpose_19()
{
    #define PIXELS_ABOVE_LINES  1
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_pixels_above_lines (GTK_TEXT_VIEW (widget), PIXELS_ABOVE_LINES);
    
    if (gtk_text_view_get_pixels_above_lines (GTK_TEXT_VIEW (widget)) != PIXELS_ABOVE_LINES)
    {
        TEST_FAIL("pixels_above_lines = %i, should be %i\n", gtk_text_view_get_pixels_above_lines (GTK_TEXT_VIEW (widget)), PIXELS_ABOVE_LINES);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PIXELS_ABOVE_LINES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_pixels_above_lines
 * Params: GtkTextView *text_view, gint *pixels_above_lines
 * Returns: void
 * Assertion: Sets the default number of blank pixels above paragraphs in text_view.
 * Params Values: newly created GtkTextView*, G_MAXINT
 * Expected: void
 * 
 * Name: gtk_text_view_get_pixels_above_lines
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the default number of pixels to put above paragraphs.
 * Params Values: newly created GtkTextView*
 * Expected: G_MAXINT  
 */
static void test_purpose_20()
{
    #define PIXELS_ABOVE_LINES  G_MAXINT
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_pixels_above_lines (GTK_TEXT_VIEW (widget), PIXELS_ABOVE_LINES);
    
    if (gtk_text_view_get_pixels_above_lines (GTK_TEXT_VIEW (widget)) != PIXELS_ABOVE_LINES)
    {
        TEST_FAIL("pixels_above_lines = %i, should be %i\n", gtk_text_view_get_pixels_above_lines (GTK_TEXT_VIEW (widget)), PIXELS_ABOVE_LINES);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PIXELS_ABOVE_LINES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_pixels_below_lines
 * Params: GtkTextView *text_view, gint *pixels_below_lines
 * Returns: void
 * Assertion: Sets the default number of pixels of blank space to put below paragraphs in text_view.
 * Params Values: newly created GtkTextView*, 0
 * Expected: void
 * 
 * Name: gtk_text_view_get_pixels_below_lines
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the value set by gtk_text_view_set_pixels_below_lines().
 * Params Values: newly created GtkTextView*
 * Expected: 0  
 */
static void test_purpose_21()
{
    #define PIXELS_BELOW_LINES  0
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_pixels_below_lines (GTK_TEXT_VIEW (widget), PIXELS_BELOW_LINES);
    
    if (gtk_text_view_get_pixels_below_lines (GTK_TEXT_VIEW (widget)) != PIXELS_BELOW_LINES)
    {
        TEST_FAIL("pixels_below_lines = %i, should be %i\n", gtk_text_view_get_pixels_below_lines (GTK_TEXT_VIEW (widget)), PIXELS_BELOW_LINES);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PIXELS_BELOW_LINES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_pixels_below_lines
 * Params: GtkTextView *text_view, gint *pixels_below_lines
 * Returns: void
 * Assertion: Sets the default number of pixels of blank space to put below paragraphs in text_view.
 * Params Values: newly created GtkTextView*, 1
 * Expected: void
 * 
 * Name: gtk_text_view_get_pixels_below_lines
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the value set by gtk_text_view_set_pixels_below_lines().
 * Params Values: newly created GtkTextView*
 * Expected: 1  
 */
static void test_purpose_22()
{
    #define PIXELS_BELOW_LINES  1
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_pixels_below_lines (GTK_TEXT_VIEW (widget), PIXELS_BELOW_LINES);
    
    if (gtk_text_view_get_pixels_below_lines (GTK_TEXT_VIEW (widget)) != PIXELS_BELOW_LINES)
    {
        TEST_FAIL("pixels_below_lines = %i, should be %i\n", gtk_text_view_get_pixels_below_lines (GTK_TEXT_VIEW (widget)), PIXELS_BELOW_LINES);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PIXELS_BELOW_LINES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_pixels_below_lines
 * Params: GtkTextView *text_view, gint *pixels_below_lines
 * Returns: void
 * Assertion: Sets the default number of pixels of blank space to put below paragraphs in text_view.
 * Params Values: newly created GtkTextView*, G_MAXINT
 * Expected: void
 * 
 * Name: gtk_text_view_get_pixels_below_lines
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the value set by gtk_text_view_set_pixels_below_lines().
 * Params Values: newly created GtkTextView*
 * Expected: G_MAXINT  
 */
static void test_purpose_23()
{
    #define PIXELS_BELOW_LINES  G_MAXINT
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_pixels_below_lines (GTK_TEXT_VIEW (widget), PIXELS_BELOW_LINES);
    
    if (gtk_text_view_get_pixels_below_lines (GTK_TEXT_VIEW (widget)) != PIXELS_BELOW_LINES)
    {
        TEST_FAIL("pixels_below_lines = %i, should be %i\n", gtk_text_view_get_pixels_below_lines (GTK_TEXT_VIEW (widget)), PIXELS_BELOW_LINES);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PIXELS_BELOW_LINES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_pixels_inside_wrap
 * Params: GtkTextView *text_view, gint *pixels_inside_wrap
 * Returns: void
 * Assertion: Sets the default number of pixels of blank space to leave between display/wrapped lines within a paragraph.
 * Params Values: newly created GtkTextView*, 0
 * Expected: void
 * 
 * Name: gtk_text_view_get_pixels_inside_wrap
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the value set by gtk_text_view_set_pixels_inside_wrap().
 * Params Values: newly created GtkTextView*
 * Expected: 0  
 */
static void test_purpose_24()
{
    #define PIXELS_INSIDE_WRAP  0
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_pixels_inside_wrap (GTK_TEXT_VIEW (widget), PIXELS_INSIDE_WRAP);
    
    if (gtk_text_view_get_pixels_inside_wrap (GTK_TEXT_VIEW (widget)) != PIXELS_INSIDE_WRAP)
    {
        TEST_FAIL("pixels_inside_wrap = %i, should be %i\n", gtk_text_view_get_pixels_inside_wrap (GTK_TEXT_VIEW (widget)), PIXELS_INSIDE_WRAP);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PIXELS_INSIDE_WRAP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_pixels_inside_wrap
 * Params: GtkTextView *text_view, gint *pixels_inside_wrap
 * Returns: void
 * Assertion: Sets the default number of pixels of blank space to leave between display/wrapped lines within a paragraph.
 * Params Values: newly created GtkTextView*, 1
 * Expected: void
 * 
 * Name: gtk_text_view_get_pixels_inside_wrap
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the value set by gtk_text_view_set_pixels_inside_wrap().
 * Params Values: newly created GtkTextView*
 * Expected: 1  
 */
static void test_purpose_25()
{
    #define PIXELS_INSIDE_WRAP  1
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_pixels_inside_wrap (GTK_TEXT_VIEW (widget), PIXELS_INSIDE_WRAP);
    
    if (gtk_text_view_get_pixels_inside_wrap (GTK_TEXT_VIEW (widget)) != PIXELS_INSIDE_WRAP)
    {
        TEST_FAIL("pixels_inside_wrap = %i, should be %i\n", gtk_text_view_get_pixels_inside_wrap (GTK_TEXT_VIEW (widget)), PIXELS_INSIDE_WRAP);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PIXELS_INSIDE_WRAP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_pixels_inside_wrap
 * Params: GtkTextView *text_view, gint *pixels_inside_wrap
 * Returns: void
 * Assertion: Sets the default number of pixels of blank space to leave between display/wrapped lines within a paragraph.
 * Params Values: newly created GtkTextView*, G_MAXINT
 * Expected: void
 * 
 * Name: gtk_text_view_get_pixels_inside_wrap
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the value set by gtk_text_view_set_pixels_inside_wrap().
 * Params Values: newly created GtkTextView*
 * Expected: G_MAXINT  
 */
static void test_purpose_26()
{
    #define PIXELS_INSIDE_WRAP  G_MAXINT
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_pixels_inside_wrap (GTK_TEXT_VIEW (widget), PIXELS_INSIDE_WRAP);
    
    if (gtk_text_view_get_pixels_inside_wrap (GTK_TEXT_VIEW (widget)) != PIXELS_INSIDE_WRAP)
    {
        TEST_FAIL("pixels_inside_wrap = %i, should be %i\n", gtk_text_view_get_pixels_inside_wrap (GTK_TEXT_VIEW (widget)), PIXELS_INSIDE_WRAP);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef PIXELS_INSIDE_WRAP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_justification
 * Params: GtkTextView *text_view, GtkJustification *justification
 * Returns: void
 * Assertion: Sets the default justification of text in text_view.
 * Params Values: newly created GtkTextView*, GTK_JUSTIFY_LEFT
 * Expected: void
 * 
 * Name: gtk_text_view_get_justification
 * Params: GtkTextView *text_view
 * Returns: GtkJustification
 * Assertion: Gets the default justification of paragraphs in text_view. 
 * Params Values: newly created GtkTextView*
 * Expected: GTK_JUSTIFY_LEFT  
 */
static void test_purpose_27()
{
    #define JUSTIFICATION  GTK_JUSTIFY_LEFT
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_justification (GTK_TEXT_VIEW (widget), JUSTIFICATION);
    
    if (gtk_text_view_get_justification (GTK_TEXT_VIEW (widget)) != JUSTIFICATION)
    {
        TEST_FAIL("justification = %i, should be %i\n", gtk_text_view_get_justification (GTK_TEXT_VIEW (widget)), JUSTIFICATION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef JUSTIFICATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_justification
 * Params: GtkTextView *text_view, GtkJustification *justification
 * Returns: void
 * Assertion: Sets the default justification of text in text_view.
 * Params Values: newly created GtkTextView*, GTK_JUSTIFY_RIGHT
 * Expected: void
 * 
 * Name: gtk_text_view_get_justification
 * Params: GtkTextView *text_view
 * Returns: GtkJustification
 * Assertion: Gets the default justification of paragraphs in text_view. 
 * Params Values: newly created GtkTextView*
 * Expected: GTK_JUSTIFY_RIGHT  
 */
static void test_purpose_28()
{
    #define JUSTIFICATION  GTK_JUSTIFY_RIGHT
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_justification (GTK_TEXT_VIEW (widget), JUSTIFICATION);
    
    if (gtk_text_view_get_justification (GTK_TEXT_VIEW (widget)) != JUSTIFICATION)
    {
        TEST_FAIL("justification = %i, should be %i\n", gtk_text_view_get_justification (GTK_TEXT_VIEW (widget)), JUSTIFICATION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef JUSTIFICATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_justification
 * Params: GtkTextView *text_view, GtkJustification *justification
 * Returns: void
 * Assertion: Sets the default justification of text in text_view.
 * Params Values: newly created GtkTextView*, GTK_JUSTIFY_CENTER
 * Expected: void
 * 
 * Name: gtk_text_view_get_justification
 * Params: GtkTextView *text_view
 * Returns: GtkJustification
 * Assertion: Gets the default justification of paragraphs in text_view. 
 * Params Values: newly created GtkTextView*
 * Expected: GTK_JUSTIFY_CENTER  
 */
static void test_purpose_29()
{
    #define JUSTIFICATION  GTK_JUSTIFY_CENTER
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_justification (GTK_TEXT_VIEW (widget), JUSTIFICATION);
    
    if (gtk_text_view_get_justification (GTK_TEXT_VIEW (widget)) != JUSTIFICATION)
    {
        TEST_FAIL("justification = %i, should be %i\n", gtk_text_view_get_justification (GTK_TEXT_VIEW (widget)), JUSTIFICATION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef JUSTIFICATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_justification
 * Params: GtkTextView *text_view, GtkJustification *justification
 * Returns: void
 * Assertion: Sets the default justification of text in text_view.
 * Params Values: newly created GtkTextView*, GTK_JUSTIFY_FILL
 * Expected: void
 * 
 * Name: gtk_text_view_get_justification
 * Params: GtkTextView *text_view
 * Returns: GtkJustification
 * Assertion: Gets the default justification of paragraphs in text_view. 
 * Params Values: newly created GtkTextView*
 * Expected: GTK_JUSTIFY_FILL  
 */
static void test_purpose_30()
{
    #define JUSTIFICATION  GTK_JUSTIFY_FILL
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_justification (GTK_TEXT_VIEW (widget), JUSTIFICATION);
    
    if (gtk_text_view_get_justification (GTK_TEXT_VIEW (widget)) != JUSTIFICATION)
    {
        TEST_FAIL("justification = %i, should be %i\n", gtk_text_view_get_justification (GTK_TEXT_VIEW (widget)), JUSTIFICATION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef JUSTIFICATION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_left_margin
 * Params: GtkTextView *text_view, gint *left_margin
 * Returns: void
 * Assertion: Sets the default left margin for text in text_view.
 * Params Values: newly created GtkTextView*, 0
 * Expected: void
 * 
 * Name: gtk_text_view_get_left_margin
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the default left margin size of paragraphs in the text_view.
 * Params Values: newly created GtkTextView*
 * Expected: 0  
 */
static void test_purpose_31()
{
    #define LEFT_MARGIN  0
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_left_margin (GTK_TEXT_VIEW (widget), LEFT_MARGIN);
    
    if (gtk_text_view_get_left_margin (GTK_TEXT_VIEW (widget)) != LEFT_MARGIN)
    {
        TEST_FAIL("left_margin = %i, should be %i\n", gtk_text_view_get_left_margin (GTK_TEXT_VIEW (widget)), LEFT_MARGIN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LEFT_MARGIN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_left_margin
 * Params: GtkTextView *text_view, gint *left_margin
 * Returns: void
 * Assertion: Sets the default left margin for text in text_view.
 * Params Values: newly created GtkTextView*, 1
 * Expected: void
 * 
 * Name: gtk_text_view_get_left_margin
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the default left margin size of paragraphs in the text_view.
 * Params Values: newly created GtkTextView*
 * Expected: 1  
 */
static void test_purpose_32()
{
    #define LEFT_MARGIN  1
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_left_margin (GTK_TEXT_VIEW (widget), LEFT_MARGIN);
    
    if (gtk_text_view_get_left_margin (GTK_TEXT_VIEW (widget)) != LEFT_MARGIN)
    {
        TEST_FAIL("left_margin = %i, should be %i\n", gtk_text_view_get_left_margin (GTK_TEXT_VIEW (widget)), LEFT_MARGIN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LEFT_MARGIN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_left_margin
 * Params: GtkTextView *text_view, gint *left_margin
 * Returns: void
 * Assertion: Sets the default left margin for text in text_view.
 * Params Values: newly created GtkTextView*, G_MAXINT
 * Expected: void
 * 
 * Name: gtk_text_view_get_left_margin
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the default left margin size of paragraphs in the text_view.
 * Params Values: newly created GtkTextView*
 * Expected: G_MAXINT  
 */
static void test_purpose_33()
{
    #define LEFT_MARGIN  G_MAXINT
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_left_margin (GTK_TEXT_VIEW (widget), LEFT_MARGIN);
    
    if (gtk_text_view_get_left_margin (GTK_TEXT_VIEW (widget)) != LEFT_MARGIN)
    {
        TEST_FAIL("left_margin = %i, should be %i\n", gtk_text_view_get_left_margin (GTK_TEXT_VIEW (widget)), LEFT_MARGIN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef LEFT_MARGIN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_right_margin
 * Params: GtkTextView *text_view, gint *right_margin
 * Returns: void
 * Assertion: Sets the default right margin for text in the text view.
 * Params Values: newly created GtkTextView*, 0
 * Expected: void
 * 
 * Name: gtk_text_view_get_right_margin
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the default right margin for text in text_view.
 * Params Values: newly created GtkTextView*
 * Expected: 0  
 */
static void test_purpose_34()
{
    #define RIGHT_MARGIN  0
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_right_margin (GTK_TEXT_VIEW (widget), RIGHT_MARGIN);
    
    if (gtk_text_view_get_right_margin (GTK_TEXT_VIEW (widget)) != RIGHT_MARGIN)
    {
        TEST_FAIL("right_margin = %i, should be %i\n", gtk_text_view_get_right_margin (GTK_TEXT_VIEW (widget)), RIGHT_MARGIN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RIGHT_MARGIN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_right_margin
 * Params: GtkTextView *text_view, gint *right_margin
 * Returns: void
 * Assertion: Sets the default right margin for text in the text view.
 * Params Values: newly created GtkTextView*, 1
 * Expected: void
 * 
 * Name: gtk_text_view_get_right_margin
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the default right margin for text in text_view.
 * Params Values: newly created GtkTextView*
 * Expected: 1  
 */
static void test_purpose_35()
{
    #define RIGHT_MARGIN  1
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_right_margin (GTK_TEXT_VIEW (widget), RIGHT_MARGIN);
    
    if (gtk_text_view_get_right_margin (GTK_TEXT_VIEW (widget)) != RIGHT_MARGIN)
    {
        TEST_FAIL("right_margin = %i, should be %i\n", gtk_text_view_get_right_margin (GTK_TEXT_VIEW (widget)), RIGHT_MARGIN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RIGHT_MARGIN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_right_margin
 * Params: GtkTextView *text_view, gint *right_margin
 * Returns: void
 * Assertion: Sets the default right margin for text in the text view.
 * Params Values: newly created GtkTextView*, G_MAXINT
 * Expected: void
 * 
 * Name: gtk_text_view_get_right_margin
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the default right margin for text in text_view.
 * Params Values: newly created GtkTextView*
 * Expected: G_MAXINT  
 */
static void test_purpose_36()
{
    #define RIGHT_MARGIN  G_MAXINT
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_right_margin (GTK_TEXT_VIEW (widget), RIGHT_MARGIN);
    
    if (gtk_text_view_get_right_margin (GTK_TEXT_VIEW (widget)) != RIGHT_MARGIN)
    {
        TEST_FAIL("right_margin = %i, should be %i\n", gtk_text_view_get_right_margin (GTK_TEXT_VIEW (widget)), RIGHT_MARGIN);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef RIGHT_MARGIN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_indent
 * Params: GtkTextView *text_view, gint *indent
 * Returns: void
 * Assertion: Sets the default indentation for paragraphs in text_view.
 * Params Values: newly created GtkTextView*, G_MININT
 * Expected: void
 * 
 * Name: gtk_text_view_get_indent
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the default indentation of paragraphs in text_view.
 * Params Values: newly created GtkTextView*
 * Expected: G_MININT
 * 
 * Name: gtk_text_view_get_indent
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: The indentation may be negative.
 * Params Values: newly created GtkTextView*
 * Expected: G_MININT  
 */
static void test_purpose_37()
{
    #define INDENT  G_MININT
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_indent (GTK_TEXT_VIEW (widget), INDENT);
    
    if (gtk_text_view_get_indent (GTK_TEXT_VIEW (widget)) != INDENT)
    {
        TEST_FAIL("indent = %i, should be %i\n", gtk_text_view_get_indent (GTK_TEXT_VIEW (widget)), INDENT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef INDENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_indent
 * Params: GtkTextView *text_view, gint *indent
 * Returns: void
 * Assertion: Sets the default indentation for paragraphs in text_view.
 * Params Values: newly created GtkTextView*, -1000
 * Expected: void
 * 
 * Name: gtk_text_view_get_indent
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the default indentation of paragraphs in text_view.
 * Params Values: newly created GtkTextView*
 * Expected: -1000
 * 
 * Name: gtk_text_view_get_indent
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: The indentation may be negative.
 * Params Values: newly created GtkTextView*
 * Expected: -1000  
 */
static void test_purpose_38()
{
    #define INDENT  -1000
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_indent (GTK_TEXT_VIEW (widget), INDENT);
    
    if (gtk_text_view_get_indent (GTK_TEXT_VIEW (widget)) != INDENT)
    {
        TEST_FAIL("indent = %i, should be %i\n", gtk_text_view_get_indent (GTK_TEXT_VIEW (widget)), INDENT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef INDENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_indent
 * Params: GtkTextView *text_view, gint *indent
 * Returns: void
 * Assertion: Sets the default indentation for paragraphs in text_view.
 * Params Values: newly created GtkTextView*, -1
 * Expected: void
 * 
 * Name: gtk_text_view_get_indent
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the default indentation of paragraphs in text_view.
 * Params Values: newly created GtkTextView*
 * Expected: -1
 * 
 * Name: gtk_text_view_get_indent
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: The indentation may be negative.
 * Params Values: newly created GtkTextView*
 * Expected: -1  
 */
static void test_purpose_39()
{
    #define INDENT  -1
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_indent (GTK_TEXT_VIEW (widget), INDENT);
    
    if (gtk_text_view_get_indent (GTK_TEXT_VIEW (widget)) != INDENT)
    {
        TEST_FAIL("indent = %i, should be %i\n", gtk_text_view_get_indent (GTK_TEXT_VIEW (widget)), INDENT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef INDENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_indent
 * Params: GtkTextView *text_view, gint *indent
 * Returns: void
 * Assertion: Sets the default indentation for paragraphs in text_view.
 * Params Values: newly created GtkTextView*, 0
 * Expected: void
 * 
 * Name: gtk_text_view_get_indent
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the default indentation of paragraphs in text_view.
 * Params Values: newly created GtkTextView*
 * Expected: 0
 * 
 * Name: gtk_text_view_get_indent
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: The indentation may be negative.
 * Params Values: newly created GtkTextView*
 * Expected: 0  
 */
static void test_purpose_40()
{
    #define INDENT  0
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_indent (GTK_TEXT_VIEW (widget), INDENT);
    
    if (gtk_text_view_get_indent (GTK_TEXT_VIEW (widget)) != INDENT)
    {
        TEST_FAIL("indent = %i, should be %i\n", gtk_text_view_get_indent (GTK_TEXT_VIEW (widget)), INDENT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef INDENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_indent
 * Params: GtkTextView *text_view, gint *indent
 * Returns: void
 * Assertion: Sets the default indentation for paragraphs in text_view.
 * Params Values: newly created GtkTextView*, 1
 * Expected: void
 * 
 * Name: gtk_text_view_get_indent
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the default indentation of paragraphs in text_view.
 * Params Values: newly created GtkTextView*
 * Expected: 1
 * 
 * Name: gtk_text_view_get_indent
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: The indentation may be negative.
 * Params Values: newly created GtkTextView*
 * Expected: 1  
 */
static void test_purpose_41()
{
    #define INDENT  1
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_indent (GTK_TEXT_VIEW (widget), INDENT);
    
    if (gtk_text_view_get_indent (GTK_TEXT_VIEW (widget)) != INDENT)
    {
        TEST_FAIL("indent = %i, should be %i\n", gtk_text_view_get_indent (GTK_TEXT_VIEW (widget)), INDENT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef INDENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_indent
 * Params: GtkTextView *text_view, gint *indent
 * Returns: void
 * Assertion: Sets the default indentation for paragraphs in text_view.
 * Params Values: newly created GtkTextView*, 1000
 * Expected: void
 * 
 * Name: gtk_text_view_get_indent
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the default indentation of paragraphs in text_view.
 * Params Values: newly created GtkTextView*
 * Expected: 1000
 * 
 * Name: gtk_text_view_get_indent
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: The indentation may be negative.
 * Params Values: newly created GtkTextView*
 * Expected: 1000  
 */
static void test_purpose_42()
{
    #define INDENT  1000
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_indent (GTK_TEXT_VIEW (widget), INDENT);
    
    if (gtk_text_view_get_indent (GTK_TEXT_VIEW (widget)) != INDENT)
    {
        TEST_FAIL("indent = %i, should be %i\n", gtk_text_view_get_indent (GTK_TEXT_VIEW (widget)), INDENT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef INDENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_indent
 * Params: GtkTextView *text_view, gint *indent
 * Returns: void
 * Assertion: Sets the default indentation for paragraphs in text_view.
 * Params Values: newly created GtkTextView*, G_MAXINT
 * Expected: void
 * 
 * Name: gtk_text_view_get_indent
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: Gets the default indentation of paragraphs in text_view.
 * Params Values: newly created GtkTextView*
 * Expected: G_MAXINT
 * 
 * Name: gtk_text_view_get_indent
 * Params: GtkTextView *text_view
 * Returns: gint
 * Assertion: The indentation may be negative.
 * Params Values: newly created GtkTextView*
 * Expected: G_MAXINT  
 */
static void test_purpose_43()
{
    #define INDENT  G_MAXINT
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_indent (GTK_TEXT_VIEW (widget), INDENT);
    
    if (gtk_text_view_get_indent (GTK_TEXT_VIEW (widget)) != INDENT)
    {
        TEST_FAIL("indent = %i, should be %i\n", gtk_text_view_get_indent (GTK_TEXT_VIEW (widget)), INDENT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef INDENT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_tabs
 * Params: GtkTextView *text_view, PangoTabArray *tabs
 * Returns: void
 * Assertion: Sets the default tab stops for paragraphs in text_view.
 * Params Values: newly created GtkTextView*, newly created PangoTabArray*
 * Expected: void
 * 
 * Name: gtk_text_view_get_tabs
 * Params: GtkTextView *text_view
 * Returns: PangoTabArray*
 * Assertion: Gets the default tabs for text_view.
 * Params Values: newly created GtkTextView*
 * Expected:  PangoTabArray* that was set by gtk_text_view_set_tabs ()  
 */
static void test_purpose_44()
{
    #define COUNT 1
    #define PIXELS TRUE
    #define DATA PANGO_TAB_LEFT, 1
    
    GtkWidget *widget;
    PangoTabArray *tabs;
    gint i;
    PangoTabAlign alignment, alignment1;
    gint location, location1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    tabs = pango_tab_array_new_with_positions (COUNT, PIXELS, DATA);
    if (tabs == NULL)
    {
        TEST_FAIL ("tabs not created", NULL);
        return;
    }
    
    gtk_text_view_set_tabs (GTK_TEXT_VIEW (widget), tabs);
    
    if (pango_tab_array_get_size (tabs) != pango_tab_array_get_size (gtk_text_view_get_tabs (GTK_TEXT_VIEW (widget))))
    {
        TEST_FAIL("tab array size invalid", NULL);
        return;
    }
    
    for (i = 0; i < pango_tab_array_get_size (tabs); i++)
    {
        pango_tab_array_get_tab (tabs, i, &alignment, &location);
        pango_tab_array_get_tab (gtk_text_view_get_tabs (GTK_TEXT_VIEW (widget)), i, &alignment1, &location1);
        
        if (location != location1)
        {
            TEST_FAIL("locations of tab[%i] not equal", NULL);
        }
        if (alignment != alignment1)
        {
            TEST_FAIL("alignments of tab[%i] not equal", NULL);
        }
        
    }
    
    
    
    /*
    if (gtk_text_view_get_tabs (GTK_TEXT_VIEW (widget)) != tabs)
    {
        TEST_FAIL("tabs is differ from that was set by gtk_text_view_set_tabs()", NULL);
    }
    */
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef COUNT
    #undef PIXELS 
    #undef DATA 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_tabs
 * Params: GtkTextView *text_view, PangoTabArray *tabs
 * Returns: void
 * Assertion: Sets the default tab stops for paragraphs in text_view.
 * Params Values: newly created GtkTextView*, newly created PangoTabArray*
 * Expected: void
 * 
 * Name: gtk_text_view_get_tabs
 * Params: GtkTextView *text_view
 * Returns: PangoTabArray*
 * Assertion: Gets the default tabs for text_view.
 * Params Values: newly created GtkTextView*
 * Expected:  PangoTabArray* that was set by gtk_text_view_set_tabs ()  
 */
static void test_purpose_45()
{
    #define COUNT 3
    #define PIXELS TRUE
    #define DATA PANGO_TAB_LEFT, 1, PANGO_TAB_LEFT, 20, PANGO_TAB_LEFT, 30
    
    GtkWidget *widget;
    PangoTabArray *tabs;
    gint i;
    PangoTabAlign alignment, alignment1;
    gint location, location1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    tabs = pango_tab_array_new_with_positions (COUNT, PIXELS, DATA);
    if (tabs == NULL)
    {
        TEST_FAIL ("tabs not created", NULL);
        return;
    }
    
    gtk_text_view_set_tabs (GTK_TEXT_VIEW (widget), tabs);
    
    if (pango_tab_array_get_size (tabs) != pango_tab_array_get_size (gtk_text_view_get_tabs (GTK_TEXT_VIEW (widget))))
    {
        TEST_FAIL("tab array size invalid", NULL);
        return;
    }
    
    for (i = 0; i < pango_tab_array_get_size (tabs); i++)
    {
        pango_tab_array_get_tab (tabs, i, &alignment, &location);
        pango_tab_array_get_tab (gtk_text_view_get_tabs (GTK_TEXT_VIEW (widget)), i, &alignment1, &location1);
        
        if (location != location1)
        {
            TEST_FAIL("locations of tab[%i] not equal", NULL);
        }
        if (alignment != alignment1)
        {
            TEST_FAIL("alignments of tab[%i] not equal", NULL);
        }
        
    }
    
    
    
    /*
    if (gtk_text_view_get_tabs (GTK_TEXT_VIEW (widget)) != tabs)
    {
        TEST_FAIL("tabs is differ from that was set by gtk_text_view_set_tabs()", NULL);
    }
    */
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef COUNT
    #undef PIXELS 
    #undef DATA 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_set_tabs
 * Params: GtkTextView *text_view, PangoTabArray *tabs
 * Returns: void
 * Assertion: Sets the default tab stops for paragraphs in text_view.
 * Params Values: newly created GtkTextView*, newly created PangoTabArray*
 * Expected: void
 * 
 * Name: gtk_text_view_get_tabs
 * Params: GtkTextView *text_view
 * Returns: PangoTabArray*
 * Assertion: Gets the default tabs for text_view.
 * Params Values: newly created GtkTextView*
 * Expected:  PangoTabArray* that was set by gtk_text_view_set_tabs ()  
 */
static void test_purpose_46()
{
    #define COUNT 5
    #define PIXELS TRUE
    #define DATA PANGO_TAB_LEFT, 1, PANGO_TAB_LEFT, 2, PANGO_TAB_LEFT, 3, PANGO_TAB_LEFT, 4, PANGO_TAB_LEFT, 5
    
    GtkWidget *widget;
    PangoTabArray *tabs;
    gint i;
    PangoTabAlign alignment, alignment1;
    gint location, location1;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    tabs = pango_tab_array_new_with_positions (COUNT, PIXELS, DATA);
    if (tabs == NULL)
    {
        TEST_FAIL ("tabs not created", NULL);
        return;
    }
    
    gtk_text_view_set_tabs (GTK_TEXT_VIEW (widget), tabs);
    
    if (pango_tab_array_get_size (tabs) != pango_tab_array_get_size (gtk_text_view_get_tabs (GTK_TEXT_VIEW (widget))))
    {
        TEST_FAIL("tab array size invalid", NULL);
        return;
    }
    
    for (i = 0; i < pango_tab_array_get_size (tabs); i++)
    {
        pango_tab_array_get_tab (tabs, i, &alignment, &location);
        pango_tab_array_get_tab (gtk_text_view_get_tabs (GTK_TEXT_VIEW (widget)), i, &alignment1, &location1);
        
        if (location != location1)
        {
            TEST_FAIL("locations of tab[%i] not equal", NULL);
        }
        if (alignment != alignment1)
        {
            TEST_FAIL("alignments of tab[%i] not equal", NULL);
        }
        
    }
    
    
    
    /*
    if (gtk_text_view_get_tabs (GTK_TEXT_VIEW (widget)) != tabs)
    {
        TEST_FAIL("tabs is differ from that was set by gtk_text_view_set_tabs()", NULL);
    }
    */
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef COUNT
    #undef PIXELS 
    #undef DATA 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_tabs
 * Params: GtkTextView *text_view
 * Returns: PangoTabArray*
 * Assertion: The returned array will be NULL if "standard" (8-space) tabs are used. 
 * Params Values: newly created GtkTextView*
 * Expected:  PangoTabArray* that was set by gtk_text_view_set_tabs ()  
 */
static void test_purpose_47()
{
    GtkWidget *widget;
    PangoTabArray *tabs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new ();
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_VIEW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_text_view_get_tabs (GTK_TEXT_VIEW (widget)))
    {
        TEST_FAIL ("'tabs' should be NULL", NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_window_to_buffer_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint window_x,gint window_y,gint* buffer_x,gint* buffer_y
 * Returns: void
 * Assertion: Converts coordinates on the window identified by win to buffer coordinates, storing the result in (buffer_x,buffer_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_WIDGET, 1, 1
 * Expected: void  
 */
static void test_purpose_48()
{
    #define TYPE GTK_TEXT_WINDOW_WIDGET
    #define X 1
    #define Y 1
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_window_to_buffer_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint window_x,gint window_y,gint* buffer_x,gint* buffer_y
 * Returns: void
 * Assertion: Converts coordinates on the window identified by win to buffer coordinates, storing the result in (buffer_x,buffer_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TEXT, 1, 1
 * Expected: void  
 */
static void test_purpose_49()
{
    #define TYPE GTK_TEXT_WINDOW_TEXT
    #define X 1
    #define Y 1
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_window_to_buffer_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint window_x,gint window_y,gint* buffer_x,gint* buffer_y
 * Returns: void
 * Assertion: Converts coordinates on the window identified by win to buffer coordinates, storing the result in (buffer_x,buffer_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_LEFT, 1, 1
 * Expected: void  
 */
static void test_purpose_50()
{
    #define TYPE GTK_TEXT_WINDOW_LEFT
    #define X 1
    #define Y 1
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_window_to_buffer_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint window_x,gint window_y,gint* buffer_x,gint* buffer_y
 * Returns: void
 * Assertion: Converts coordinates on the window identified by win to buffer coordinates, storing the result in (buffer_x,buffer_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_RIGHT, 1, 1
 * Expected: void  
 */
static void test_purpose_51()
{
    #define TYPE GTK_TEXT_WINDOW_RIGHT
    #define X 1
    #define Y 1
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_window_to_buffer_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint window_x,gint window_y,gint* buffer_x,gint* buffer_y
 * Returns: void
 * Assertion: Converts coordinates on the window identified by win to buffer coordinates, storing the result in (buffer_x,buffer_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TOP, 1, 1
 * Expected: void  
 */
static void test_purpose_52()
{
    #define TYPE GTK_TEXT_WINDOW_TOP
    #define X 1
    #define Y 1
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_window_to_buffer_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint window_x,gint window_y,gint* buffer_x,gint* buffer_y
 * Returns: void
 * Assertion: Converts coordinates on the window identified by win to buffer coordinates, storing the result in (buffer_x,buffer_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM, 1, 1
 * Expected: void  
 */
static void test_purpose_53()
{
    #define TYPE GTK_TEXT_WINDOW_BOTTOM
    #define X 1
    #define Y 1
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_window_to_buffer_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint window_x,gint window_y,gint* buffer_x,gint* buffer_y
 * Returns: void
 * Assertion: Converts coordinates on the window identified by win to buffer coordinates, storing the result in (buffer_x,buffer_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_WIDGET, 10, 10
 * Expected: void  
 */
static void test_purpose_54()
{
    #define TYPE GTK_TEXT_WINDOW_WIDGET
    #define X 10
    #define Y 10
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_window_to_buffer_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint window_x,gint window_y,gint* buffer_x,gint* buffer_y
 * Returns: void
 * Assertion: Converts coordinates on the window identified by win to buffer coordinates, storing the result in (buffer_x,buffer_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TEXT, 10, 10
 * Expected: void  
 */
static void test_purpose_55()
{
    #define TYPE GTK_TEXT_WINDOW_TEXT
    #define X 10
    #define Y 10
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_window_to_buffer_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint window_x,gint window_y,gint* buffer_x,gint* buffer_y
 * Returns: void
 * Assertion: Converts coordinates on the window identified by win to buffer coordinates, storing the result in (buffer_x,buffer_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_LEFT, 10, 10
 * Expected: void  
 */
static void test_purpose_56()
{
    #define TYPE GTK_TEXT_WINDOW_LEFT
    #define X 10
    #define Y 10
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_window_to_buffer_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint window_x,gint window_y,gint* buffer_x,gint* buffer_y
 * Returns: void
 * Assertion: Converts coordinates on the window identified by win to buffer coordinates, storing the result in (buffer_x,buffer_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_RIGHT, 10, 10
 * Expected: void  
 */
static void test_purpose_57()
{
    #define TYPE GTK_TEXT_WINDOW_RIGHT
    #define X 10
    #define Y 10
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_window_to_buffer_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint window_x,gint window_y,gint* buffer_x,gint* buffer_y
 * Returns: void
 * Assertion: Converts coordinates on the window identified by win to buffer coordinates, storing the result in (buffer_x,buffer_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TOP, 10, 10
 * Expected: void  
 */
static void test_purpose_58()
{
    #define TYPE GTK_TEXT_WINDOW_TOP
    #define X 10
    #define Y 10
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_window_to_buffer_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint window_x,gint window_y,gint* buffer_x,gint* buffer_y
 * Returns: void
 * Assertion: Converts coordinates on the window identified by win to buffer coordinates, storing the result in (buffer_x,buffer_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM, 10, 10
 * Expected: void  
 */
static void test_purpose_59()
{
    #define TYPE GTK_TEXT_WINDOW_BOTTOM
    #define X 10
    #define Y 10
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_window_to_buffer_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint window_x,gint window_y,gint* buffer_x,gint* buffer_y
 * Returns: void
 * Assertion: Converts coordinates on the window identified by win to buffer coordinates, storing the result in (buffer_x,buffer_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_WIDGET, 5000, 5000
 * Expected: void  
 */
static void test_purpose_60()
{
    #define TYPE GTK_TEXT_WINDOW_WIDGET
    #define X 5000
    #define Y 5000
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_window_to_buffer_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint window_x,gint window_y,gint* buffer_x,gint* buffer_y
 * Returns: void
 * Assertion: Converts coordinates on the window identified by win to buffer coordinates, storing the result in (buffer_x,buffer_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TEXT, 5000, 5000
 * Expected: void  
 */
static void test_purpose_61()
{
    #define TYPE GTK_TEXT_WINDOW_TEXT
    #define X 5000
    #define Y 5000
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_window_to_buffer_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint window_x,gint window_y,gint* buffer_x,gint* buffer_y
 * Returns: void
 * Assertion: Converts coordinates on the window identified by win to buffer coordinates, storing the result in (buffer_x,buffer_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_LEFT, 5000, 5000
 * Expected: void  
 */
static void test_purpose_62()
{
    #define TYPE GTK_TEXT_WINDOW_LEFT
    #define X 5000
    #define Y 5000
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_window_to_buffer_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint window_x,gint window_y,gint* buffer_x,gint* buffer_y
 * Returns: void
 * Assertion: Converts coordinates on the window identified by win to buffer coordinates, storing the result in (buffer_x,buffer_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_RIGHT, 5000, 5000
 * Expected: void  
 */
static void test_purpose_63()
{
    #define TYPE GTK_TEXT_WINDOW_RIGHT
    #define X 5000
    #define Y 5000
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_window_to_buffer_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint window_x,gint window_y,gint* buffer_x,gint* buffer_y
 * Returns: void
 * Assertion: Converts coordinates on the window identified by win to buffer coordinates, storing the result in (buffer_x,buffer_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TOP, 5000, 5000
 * Expected: void  
 */
static void test_purpose_64()
{
    #define TYPE GTK_TEXT_WINDOW_TOP
    #define X 5000
    #define Y 5000
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_window_to_buffer_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint window_x,gint window_y,gint* buffer_x,gint* buffer_y
 * Returns: void
 * Assertion: Converts coordinates on the window identified by win to buffer coordinates, storing the result in (buffer_x,buffer_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM, 5000, 5000
 * Expected: void  
 */
static void test_purpose_65()
{
    #define TYPE GTK_TEXT_WINDOW_BOTTOM
    #define X 5000
    #define Y 5000
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_window_to_buffer_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint window_x,gint window_y,gint* buffer_x,gint* buffer_y
 * Returns: void
 * Assertion: Converts coordinates on the window identified by win to buffer coordinates, storing the result in (buffer_x,buffer_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM, 10000, 500
 * Expected: void  
 */
static void test_purpose_66()
{
    #define TYPE GTK_TEXT_WINDOW_BOTTOM
    #define X 10000
    #define Y 500
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_buffer_to_window_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint buffer_x,gint buffer_y,gint *window_x,gint *window_y 
 * Returns: void
 * Assertion: Converts coordinate (buffer_x, buffer_y) to coordinates for the window win, and stores the result in (window_x, window_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_WIDGET, 1, 1
 * Expected: void  
 */
static void test_purpose_67()
{
    #define TYPE GTK_TEXT_WINDOW_WIDGET
    #define X 1
    #define Y 1
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_buffer_to_window_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint buffer_x,gint buffer_y,gint *window_x,gint *window_y 
 * Returns: void
 * Assertion: Converts coordinate (buffer_x, buffer_y) to coordinates for the window win, and stores the result in (window_x, window_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TEXT, 1, 1
 * Expected: void  
 */
static void test_purpose_68()
{
    #define TYPE GTK_TEXT_WINDOW_TEXT
    #define X 1
    #define Y 1
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_buffer_to_window_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint buffer_x,gint buffer_y,gint *window_x,gint *window_y 
 * Returns: void
 * Assertion: Converts coordinate (buffer_x, buffer_y) to coordinates for the window win, and stores the result in (window_x, window_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_LEFT, 1, 1
 * Expected: void  
 */
static void test_purpose_69()
{
    #define TYPE GTK_TEXT_WINDOW_LEFT
    #define X 1
    #define Y 1
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_buffer_to_window_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint buffer_x,gint buffer_y,gint *window_x,gint *window_y 
 * Returns: void
 * Assertion: Converts coordinate (buffer_x, buffer_y) to coordinates for the window win, and stores the result in (window_x, window_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_RIGHT, 1, 1
 * Expected: void  
 */
static void test_purpose_70()
{
    #define TYPE GTK_TEXT_WINDOW_RIGHT
    #define X 1
    #define Y 1
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_buffer_to_window_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint buffer_x,gint buffer_y,gint *window_x,gint *window_y 
 * Returns: void
 * Assertion: Converts coordinate (buffer_x, buffer_y) to coordinates for the window win, and stores the result in (window_x, window_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TOP, 1, 1
 * Expected: void  
 */
static void test_purpose_71()
{
    #define TYPE GTK_TEXT_WINDOW_TOP
    #define X 1
    #define Y 1
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_buffer_to_window_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint buffer_x,gint buffer_y,gint *window_x,gint *window_y 
 * Returns: void
 * Assertion: Converts coordinate (buffer_x, buffer_y) to coordinates for the window win, and stores the result in (window_x, window_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM, 1, 1
 * Expected: void  
 */
static void test_purpose_72()
{
    #define TYPE GTK_TEXT_WINDOW_BOTTOM
    #define X 1
    #define Y 1
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_buffer_to_window_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint buffer_x,gint buffer_y,gint *window_x,gint *window_y 
 * Returns: void
 * Assertion: Converts coordinate (buffer_x, buffer_y) to coordinates for the window win, and stores the result in (window_x, window_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_WIDGET, 10, 10
 * Expected: void  
 */
static void test_purpose_73()
{
    #define TYPE GTK_TEXT_WINDOW_WIDGET
    #define X 10
    #define Y 10
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_buffer_to_window_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint buffer_x,gint buffer_y,gint *window_x,gint *window_y 
 * Returns: void
 * Assertion: Converts coordinate (buffer_x, buffer_y) to coordinates for the window win, and stores the result in (window_x, window_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TEXT, 10, 10
 * Expected: void  
 */
static void test_purpose_74()
{
    #define TYPE GTK_TEXT_WINDOW_TEXT
    #define X 10
    #define Y 10
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_buffer_to_window_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint buffer_x,gint buffer_y,gint *window_x,gint *window_y 
 * Returns: void
 * Assertion: Converts coordinate (buffer_x, buffer_y) to coordinates for the window win, and stores the result in (window_x, window_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_LEFT, 10, 10
 * Expected: void  
 */
static void test_purpose_75()
{
    #define TYPE GTK_TEXT_WINDOW_LEFT
    #define X 10
    #define Y 10
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_buffer_to_window_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint buffer_x,gint buffer_y,gint *window_x,gint *window_y 
 * Returns: void
 * Assertion: Converts coordinate (buffer_x, buffer_y) to coordinates for the window win, and stores the result in (window_x, window_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_RIGHT, 10, 10
 * Expected: void  
 */
static void test_purpose_76()
{
    #define TYPE GTK_TEXT_WINDOW_RIGHT
    #define X 10
    #define Y 10
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_buffer_to_window_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint buffer_x,gint buffer_y,gint *window_x,gint *window_y 
 * Returns: void
 * Assertion: Converts coordinate (buffer_x, buffer_y) to coordinates for the window win, and stores the result in (window_x, window_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TOP, 10, 10
 * Expected: void  
 */
static void test_purpose_77()
{
    #define TYPE GTK_TEXT_WINDOW_TOP
    #define X 10
    #define Y 10
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_buffer_to_window_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint buffer_x,gint buffer_y,gint *window_x,gint *window_y 
 * Returns: void
 * Assertion: Converts coordinate (buffer_x, buffer_y) to coordinates for the window win, and stores the result in (window_x, window_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM, 10, 10
 * Expected: void  
 */
static void test_purpose_78()
{
    #define TYPE GTK_TEXT_WINDOW_BOTTOM
    #define X 10
    #define Y 10
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_buffer_to_window_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint buffer_x,gint buffer_y,gint *window_x,gint *window_y 
 * Returns: void
 * Assertion: Converts coordinate (buffer_x, buffer_y) to coordinates for the window win, and stores the result in (window_x, window_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_WIDGET, 5000, 5000
 * Expected: void  
 */
static void test_purpose_79()
{
    #define TYPE GTK_TEXT_WINDOW_WIDGET
    #define X 5000
    #define Y 5000
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_buffer_to_window_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint buffer_x,gint buffer_y,gint *window_x,gint *window_y 
 * Returns: void
 * Assertion: Converts coordinate (buffer_x, buffer_y) to coordinates for the window win, and stores the result in (window_x, window_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TEXT, 5000, 5000
 * Expected: void  
 */
static void test_purpose_80()
{
    #define TYPE GTK_TEXT_WINDOW_TEXT
    #define X 5000
    #define Y 5000
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_buffer_to_window_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint buffer_x,gint buffer_y,gint *window_x,gint *window_y 
 * Returns: void
 * Assertion: Converts coordinate (buffer_x, buffer_y) to coordinates for the window win, and stores the result in (window_x, window_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_LEFT, 5000, 5000
 * Expected: void  
 */
static void test_purpose_81()
{
    #define TYPE GTK_TEXT_WINDOW_LEFT
    #define X 5000
    #define Y 5000
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_buffer_to_window_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint buffer_x,gint buffer_y,gint *window_x,gint *window_y 
 * Returns: void
 * Assertion: Converts coordinate (buffer_x, buffer_y) to coordinates for the window win, and stores the result in (window_x, window_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_RIGHT, 5000, 5000
 * Expected: void  
 */
static void test_purpose_82()
{
    #define TYPE GTK_TEXT_WINDOW_RIGHT
    #define X 5000
    #define Y 5000
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_buffer_to_window_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint buffer_x,gint buffer_y,gint *window_x,gint *window_y 
 * Returns: void
 * Assertion: Converts coordinate (buffer_x, buffer_y) to coordinates for the window win, and stores the result in (window_x, window_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TOP, 5000, 5000
 * Expected: void  
 */
static void test_purpose_83()
{
    #define TYPE GTK_TEXT_WINDOW_TOP
    #define X 5000
    #define Y 5000
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_buffer_to_window_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint buffer_x,gint buffer_y,gint *window_x,gint *window_y 
 * Returns: void
 * Assertion: Converts coordinate (buffer_x, buffer_y) to coordinates for the window win, and stores the result in (window_x, window_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM, 5000, 5000
 * Expected: void  
 */
static void test_purpose_84()
{
    #define TYPE GTK_TEXT_WINDOW_BOTTOM
    #define X 5000
    #define Y 5000
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_buffer_to_window_coords
 * Params: GtkTextView *text_view,GtkTextWindowType win,gint buffer_x,gint buffer_y,gint *window_x,gint *window_y 
 * Returns: void
 * Assertion: Converts coordinate (buffer_x, buffer_y) to coordinates for the window win, and stores the result in (window_x, window_y).
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM, 10000, 500
 * Expected: void  
 */
static void test_purpose_85()
{
    #define TYPE GTK_TEXT_WINDOW_BOTTOM
    #define X 10000
    #define Y 500
    
    GtkWidget *widget;
    gint x;
    gint y;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    
    if (TYPE == GTK_TEXT_WINDOW_LEFT || TYPE == GTK_TEXT_WINDOW_RIGHT
        || TYPE == GTK_TEXT_WINDOW_TOP || TYPE == GTK_TEXT_WINDOW_BOTTOM)
    {
        gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 10);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_buffer_to_window_coords (GTK_TEXT_VIEW (widget), 
                                           TYPE, X, Y, &x, &y);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE 
    #undef X 
    #undef Y 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_move_mark_onscreen
 * Params: GtkTextView *text_view, GtkTextMark *mark,
 * Returns: void
 * Assertion: Moves a mark within the buffer so that it's located within the currently-visible text area.'
 * Params Values: a newly created GtkTextView*, GtkTextMark*
 * Expected: void  
 */
static void test_purpose_86()
{
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkTextMark *mark;
    GtkWidget *widget;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define ITER_POS 0
    #define CORRECT_RES FALSE
    
    widget = gtk_text_view_new  ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_widget_set_size_request (widget, 100, 20);
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS);
    gtk_text_buffer_create_mark (buffer, "Text", &iter, FALSE);
    mark = gtk_text_buffer_get_mark (buffer, "Text");
    
    result = gtk_text_view_move_mark_onscreen (GTK_TEXT_VIEW (widget), GTK_TEXT_MARK (mark));
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_move_mark_onscreen
 * Params: GtkTextView *text_view, GtkTextMark *mark,
 * Returns: void
 * Assertion: Moves a mark within the buffer so that it's located within the currently-visible text area.'
 * Params Values: a newly created GtkTextView*, GtkTextMark*
 * Expected: void  
 */
static void test_purpose_87()
{
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkTextMark *mark;
    GtkWidget *widget;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define ITER_POS 35
    #define CORRECT_RES TRUE
    
    widget = gtk_text_view_new  ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_widget_set_size_request (widget, 100, 20);
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS);
    gtk_text_buffer_create_mark (buffer, "Text", &iter, FALSE);
    mark = gtk_text_buffer_get_mark (buffer, "Text");
    
    result = gtk_text_view_move_mark_onscreen (GTK_TEXT_VIEW (widget), GTK_TEXT_MARK (mark));
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_place_cursor_onscreen 
 * Params: GtkTextView *text_view
 * Returns: gboolean
 * Assertion: Moves the cursor to the currently visible region of the buffer, it it isn't there already.'
 * Params Values: a newly created GtkTextView*
 * Expected: void  
 */
static void test_purpose_88()
{
    GtkTextIter start;
    GtkTextIter end;
    GtkTextBuffer* buffer;
    GtkTextMark *mark;
    GtkWidget *scrolled_window;
    GtkWidget *widget;
    gboolean onscreen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, "Text",4);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    onscreen = gtk_text_view_place_cursor_onscreen (GTK_TEXT_VIEW (widget));
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward by one display (wrapped) line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_89()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define NUMBER 0
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gboolean result;
    gint line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_line(buffer, &iter,NUMBER);
    
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_WORD);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line (GTK_TEXT_VIEW (widget), &iter);
    if (result == CORRECT_RES)
    {
        if (result)
        {
            line = gtk_text_iter_get_line (&iter);
            if(line != NUMBER + 1)
            {
                TEST_FAIL ("Number of line is '%d',should be '%d'", line, NUMBER + 1);
            }
        }
    } else {
        TEST_FAIL ("gtk_text_view_forward_display_line() returned %d, should return %d",
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef NUMBER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward by one display (wrapped) line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_90()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define NUMBER 3
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gboolean result;
    gint line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_line(buffer, &iter,NUMBER);
    
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_WORD);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line (GTK_TEXT_VIEW (widget), &iter);
    if (result == CORRECT_RES)
    {
        if (result)
        {
            line = gtk_text_iter_get_line (&iter);
            if(line != NUMBER + 1)
            {
                TEST_FAIL ("Number of line is '%d',should be '%d'", line, NUMBER + 1);
            }
        }
    } else {
        TEST_FAIL ("gtk_text_view_forward_display_line() returned %d, should return %d",
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef NUMBER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward by one display (wrapped) line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_91()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define NUMBER 5
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gboolean result;
    gint line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_line(buffer, &iter,NUMBER);
    
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_WORD);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line (GTK_TEXT_VIEW (widget), &iter);
    if (result == CORRECT_RES)
    {
        if (result)
        {
            line = gtk_text_iter_get_line (&iter);
            if(line != NUMBER + 1)
            {
                TEST_FAIL ("Number of line is '%d',should be '%d'", line, NUMBER + 1);
            }
        }
    } else {
        TEST_FAIL ("gtk_text_view_forward_display_line() returned %d, should return %d",
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef NUMBER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward by one display (wrapped) line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_92()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define NUMBER 6
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gboolean result;
    gint line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_line(buffer, &iter,NUMBER);
    
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_WORD);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line (GTK_TEXT_VIEW (widget), &iter);
    if (result == CORRECT_RES)
    {
        if (result)
        {
            line = gtk_text_iter_get_line (&iter);
            if(line != NUMBER + 1)
            {
                TEST_FAIL ("Number of line is '%d',should be '%d'", line, NUMBER + 1);
            }
        }
    } else {
        TEST_FAIL ("gtk_text_view_forward_display_line() returned %d, should return %d",
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef NUMBER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward by one display (wrapped) line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_93()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define NUMBER 0
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gboolean result;
    gint line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_line(buffer, &iter,NUMBER);
    
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_WORD);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line (GTK_TEXT_VIEW (widget), &iter);
    if (result == CORRECT_RES)
    {
        if (result)
        {
            line = gtk_text_iter_get_line (&iter);
            if(line != NUMBER + 1)
            {
                TEST_FAIL ("Number of line is '%d',should be '%d'", line, NUMBER + 1);
            }
        }
    } else {
        TEST_FAIL ("gtk_text_view_forward_display_line() returned %d, should return %d",
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef NUMBER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward by one display (wrapped) line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_94()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define NUMBER 1
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gboolean result;
    gint line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_line(buffer, &iter,NUMBER);
    
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_WORD);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line (GTK_TEXT_VIEW (widget), &iter);
    if (result == CORRECT_RES)
    {
        if (result)
        {
            line = gtk_text_iter_get_line (&iter);
            if(line != NUMBER + 1)
            {
                TEST_FAIL ("Number of line is '%d',should be '%d'", line, NUMBER + 1);
            }
        }
    } else {
        TEST_FAIL ("gtk_text_view_forward_display_line() returned %d, should return %d",
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef NUMBER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward by one display (wrapped) line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_95()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define NUMBER 2
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gboolean result;
    gint line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_line(buffer, &iter,NUMBER);
    
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_WORD);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line (GTK_TEXT_VIEW (widget), &iter);
    if (result == CORRECT_RES)
    {
        if (result)
        {
            line = gtk_text_iter_get_line (&iter);
            if(line != NUMBER + 1)
            {
                TEST_FAIL ("Number of line is '%d',should be '%d'", line, NUMBER + 1);
            }
        }
    } else {
        TEST_FAIL ("gtk_text_view_forward_display_line() returned %d, should return %d",
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef NUMBER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward by one display (wrapped) line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_96()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define NUMBER 4
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gboolean result;
    gint line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_line(buffer, &iter,NUMBER);
    
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_WORD);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line (GTK_TEXT_VIEW (widget), &iter);
    if (result == CORRECT_RES)
    {
        if (result)
        {
            line = gtk_text_iter_get_line (&iter);
            if(line != NUMBER + 1)
            {
                TEST_FAIL ("Number of line is '%d',should be '%d'", line, NUMBER + 1);
            }
        }
    } else {
        TEST_FAIL ("gtk_text_view_forward_display_line() returned %d, should return %d",
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef NUMBER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward by one display (wrapped) line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_97()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define NUMBER 8
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gboolean result;
    gint line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_line(buffer, &iter,NUMBER);
    
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_WORD);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line (GTK_TEXT_VIEW (widget), &iter);
    if (result == CORRECT_RES)
    {
        if (result)
        {
            line = gtk_text_iter_get_line (&iter);
            if(line != NUMBER + 1)
            {
                TEST_FAIL ("Number of line is '%d',should be '%d'", line, NUMBER + 1);
            }
        }
    } else {
        TEST_FAIL ("gtk_text_view_forward_display_line() returned %d, should return %d",
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef NUMBER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_backward_display_line
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter backward by one display (wrapped) line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_98()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define NUMBER 0
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gboolean result;
    gint line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_line (buffer, &iter, NUMBER);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_backward_display_line (GTK_TEXT_VIEW (widget), &iter);
    if (result == CORRECT_RES)
    {
        if (result)
        {
            line = gtk_text_iter_get_line (&iter);
            if(line != NUMBER - 1)
            {
                TEST_FAIL ("Number of line is '%d',should be '%d'", line, NUMBER - 1);
            }
        }
    } else {
        TEST_FAIL ("gtk_text_view_forward_display_line() returned %d, should return %d",
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef NUMBER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_backward_display_line
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter backward by one display (wrapped) line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_99()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define NUMBER 1
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gboolean result;
    gint line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_line (buffer, &iter, NUMBER);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_backward_display_line (GTK_TEXT_VIEW (widget), &iter);
    if (result == CORRECT_RES)
    {
        if (result)
        {
            line = gtk_text_iter_get_line (&iter);
            if(line != NUMBER - 1)
            {
                TEST_FAIL ("Number of line is '%d',should be '%d'", line, NUMBER - 1);
            }
        }
    } else {
        TEST_FAIL ("gtk_text_view_forward_display_line() returned %d, should return %d",
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef NUMBER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_backward_display_line
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter backward by one display (wrapped) line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_100()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define NUMBER 3
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gboolean result;
    gint line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_line (buffer, &iter, NUMBER);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_backward_display_line (GTK_TEXT_VIEW (widget), &iter);
    if (result == CORRECT_RES)
    {
        if (result)
        {
            line = gtk_text_iter_get_line (&iter);
            if(line != NUMBER - 1)
            {
                TEST_FAIL ("Number of line is '%d',should be '%d'", line, NUMBER - 1);
            }
        }
    } else {
        TEST_FAIL ("gtk_text_view_forward_display_line() returned %d, should return %d",
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef NUMBER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_backward_display_line
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter backward by one display (wrapped) line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_101()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define NUMBER 5
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gboolean result;
    gint line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_line (buffer, &iter, NUMBER);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_backward_display_line (GTK_TEXT_VIEW (widget), &iter);
    if (result == CORRECT_RES)
    {
        if (result)
        {
            line = gtk_text_iter_get_line (&iter);
            if(line != NUMBER - 1)
            {
                TEST_FAIL ("Number of line is '%d',should be '%d'", line, NUMBER - 1);
            }
        }
    } else {
        TEST_FAIL ("gtk_text_view_forward_display_line() returned %d, should return %d",
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef NUMBER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_backward_display_line
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter backward by one display (wrapped) line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_102()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define NUMBER 6
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gboolean result;
    gint line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_line (buffer, &iter, NUMBER);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_backward_display_line (GTK_TEXT_VIEW (widget), &iter);
    if (result == CORRECT_RES)
    {
        if (result)
        {
            line = gtk_text_iter_get_line (&iter);
            if(line != NUMBER - 1)
            {
                TEST_FAIL ("Number of line is '%d',should be '%d'", line, NUMBER - 1);
            }
        }
    } else {
        TEST_FAIL ("gtk_text_view_forward_display_line() returned %d, should return %d",
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef NUMBER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_backward_display_line
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter backward by one display (wrapped) line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_103()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define NUMBER 0
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gboolean result;
    gint line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_line (buffer, &iter, NUMBER);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_backward_display_line (GTK_TEXT_VIEW (widget), &iter);
    if (result == CORRECT_RES)
    {
        if (result)
        {
            line = gtk_text_iter_get_line (&iter);
            if(line != NUMBER - 1)
            {
                TEST_FAIL ("Number of line is '%d',should be '%d'", line, NUMBER - 1);
            }
        }
    } else {
        TEST_FAIL ("gtk_text_view_forward_display_line() returned %d, should return %d",
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef NUMBER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_backward_display_line
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter backward by one display (wrapped) line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_104()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define NUMBER 1
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gboolean result;
    gint line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_line (buffer, &iter, NUMBER);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_backward_display_line (GTK_TEXT_VIEW (widget), &iter);
    if (result == CORRECT_RES)
    {
        if (result)
        {
            line = gtk_text_iter_get_line (&iter);
            if(line != NUMBER - 1)
            {
                TEST_FAIL ("Number of line is '%d',should be '%d'", line, NUMBER - 1);
            }
        }
    } else {
        TEST_FAIL ("gtk_text_view_forward_display_line() returned %d, should return %d",
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef NUMBER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_backward_display_line
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter backward by one display (wrapped) line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_105()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define NUMBER 2
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gboolean result;
    gint line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_line (buffer, &iter, NUMBER);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_backward_display_line (GTK_TEXT_VIEW (widget), &iter);
    if (result == CORRECT_RES)
    {
        if (result)
        {
            line = gtk_text_iter_get_line (&iter);
            if(line != NUMBER - 1)
            {
                TEST_FAIL ("Number of line is '%d',should be '%d'", line, NUMBER - 1);
            }
        }
    } else {
        TEST_FAIL ("gtk_text_view_forward_display_line() returned %d, should return %d",
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef NUMBER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_backward_display_line
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter backward by one display (wrapped) line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_106()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define NUMBER 4
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gboolean result;
    gint line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_line (buffer, &iter, NUMBER);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_backward_display_line (GTK_TEXT_VIEW (widget), &iter);
    if (result == CORRECT_RES)
    {
        if (result)
        {
            line = gtk_text_iter_get_line (&iter);
            if(line != NUMBER - 1)
            {
                TEST_FAIL ("Number of line is '%d',should be '%d'", line, NUMBER - 1);
            }
        }
    } else {
        TEST_FAIL ("gtk_text_view_forward_display_line() returned %d, should return %d",
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef NUMBER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_backward_display_line
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter backward by one display (wrapped) line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_107()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define NUMBER 6
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gboolean result;
    gint line;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_line (buffer, &iter, NUMBER);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_backward_display_line (GTK_TEXT_VIEW (widget), &iter);
    if (result == CORRECT_RES)
    {
        if (result)
        {
            line = gtk_text_iter_get_line (&iter);
            if(line != NUMBER - 1)
            {
                TEST_FAIL ("Number of line is '%d',should be '%d'", line, NUMBER - 1);
            }
        }
    } else {
        TEST_FAIL ("gtk_text_view_forward_display_line() returned %d, should return %d",
                   result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef NUMBER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line_end 
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward to the next display line end.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_108()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define ITER_POS_BEFORE 0
    #define ITER_POS_AFTER 6
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gint offs;
    char* str = TEST_LINE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_widget_set_size_request (widget, 100, 20);
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line_end (GTK_TEXT_VIEW (widget), &iter);
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    offs = gtk_text_iter_get_offset(&iter);
    if (offs != ITER_POS_AFTER)
    {
        TEST_FAIL ("offs = %d, should be %d", offs, ITER_POS_AFTER);
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef ITER_POS_AFTER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line_end 
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward to the next display line end.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_109()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define ITER_POS_BEFORE 3
    #define ITER_POS_AFTER 6
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gint offs;
    char* str = TEST_LINE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_widget_set_size_request (widget, 100, 20);
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line_end (GTK_TEXT_VIEW (widget), &iter);
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    offs = gtk_text_iter_get_offset(&iter);
    if (offs != ITER_POS_AFTER)
    {
        TEST_FAIL ("offs = %d, should be %d", offs, ITER_POS_AFTER);
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef ITER_POS_AFTER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line_end 
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward to the next display line end.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_110()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define ITER_POS_BEFORE 6
    #define ITER_POS_AFTER 6
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gint offs;
    char* str = TEST_LINE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_widget_set_size_request (widget, 100, 20);
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line_end (GTK_TEXT_VIEW (widget), &iter);
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    offs = gtk_text_iter_get_offset(&iter);
    if (offs != ITER_POS_AFTER)
    {
        TEST_FAIL ("offs = %d, should be %d", offs, ITER_POS_AFTER);
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef ITER_POS_AFTER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line_end 
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward to the next display line end.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_111()
{
    #define TEST_LINE "Line 0\r\n Line 1"
    #define ITER_POS_BEFORE 6
    #define ITER_POS_AFTER 6
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gint offs;
    char* str = TEST_LINE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_widget_set_size_request (widget, 100, 20);
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line_end (GTK_TEXT_VIEW (widget), &iter);
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    offs = gtk_text_iter_get_offset(&iter);
    if (offs != ITER_POS_AFTER)
    {
        TEST_FAIL ("offs = %d, should be %d", offs, ITER_POS_AFTER);
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef ITER_POS_AFTER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line_end 
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward to the next display line end.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_112()
{
    #define TEST_LINE "Line 0\r\n Line 1"
    #define ITER_POS_BEFORE 7
    #define ITER_POS_AFTER 6
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gint offs;
    char* str = TEST_LINE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_widget_set_size_request (widget, 100, 20);
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line_end (GTK_TEXT_VIEW (widget), &iter);
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    offs = gtk_text_iter_get_offset(&iter);
    if (offs != ITER_POS_AFTER)
    {
        TEST_FAIL ("offs = %d, should be %d", offs, ITER_POS_AFTER);
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef ITER_POS_AFTER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line_end 
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward to the next display line end.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_113()
{
    #define TEST_LINE "Line 0"
    #define ITER_POS_BEFORE 0
    #define ITER_POS_AFTER 6
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gint offs;
    char* str = TEST_LINE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_widget_set_size_request (widget, 100, 20);
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line_end (GTK_TEXT_VIEW (widget), &iter);
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    offs = gtk_text_iter_get_offset(&iter);
    if (offs != ITER_POS_AFTER)
    {
        TEST_FAIL ("offs = %d, should be %d", offs, ITER_POS_AFTER);
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef ITER_POS_AFTER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line_end 
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward to the next display line end.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_114()
{
    #define TEST_LINE "Line 0"
    #define ITER_POS_BEFORE 5
    #define ITER_POS_AFTER 6
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gint offs;
    char* str = TEST_LINE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_widget_set_size_request (widget, 100, 20);
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line_end (GTK_TEXT_VIEW (widget), &iter);
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    offs = gtk_text_iter_get_offset(&iter);
    if (offs != ITER_POS_AFTER)
    {
        TEST_FAIL ("offs = %d, should be %d", offs, ITER_POS_AFTER);
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef ITER_POS_AFTER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line_end 
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward to the next display line end.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_115()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define ITER_POS_BEFORE 0
    #define ITER_POS_AFTER 0
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gint offs;
    char* str = TEST_LINE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_widget_set_size_request (widget, 100, 20);
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line_end (GTK_TEXT_VIEW (widget), &iter);
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    offs = gtk_text_iter_get_offset(&iter);
    if (offs != ITER_POS_AFTER)
    {
        TEST_FAIL ("offs = %d, should be %d", offs, ITER_POS_AFTER);
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef ITER_POS_AFTER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line_end 
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward to the next display line end.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_116()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define ITER_POS_BEFORE 1
    #define ITER_POS_AFTER 1
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gint offs;
    char* str = TEST_LINE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_widget_set_size_request (widget, 100, 20);
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line_end (GTK_TEXT_VIEW (widget), &iter);
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    offs = gtk_text_iter_get_offset(&iter);
    if (offs != ITER_POS_AFTER)
    {
        TEST_FAIL ("offs = %d, should be %d", offs, ITER_POS_AFTER);
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef ITER_POS_AFTER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line_end 
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward to the next display line end.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_117()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define ITER_POS_BEFORE 2
    #define ITER_POS_AFTER 1
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gint offs;
    char* str = TEST_LINE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_widget_set_size_request (widget, 100, 20);
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line_end (GTK_TEXT_VIEW (widget), &iter);
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    offs = gtk_text_iter_get_offset(&iter);
    if (offs != ITER_POS_AFTER)
    {
        TEST_FAIL ("offs = %d, should be %d", offs, ITER_POS_AFTER);
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef ITER_POS_AFTER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line_end 
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward to the next display line end.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_118()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define ITER_POS_BEFORE 4
    #define ITER_POS_AFTER 4
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gint offs;
    char* str = TEST_LINE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_widget_set_size_request (widget, 100, 20);
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line_end (GTK_TEXT_VIEW (widget), &iter);
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    offs = gtk_text_iter_get_offset(&iter);
    if (offs != ITER_POS_AFTER)
    {
        TEST_FAIL ("offs = %d, should be %d", offs, ITER_POS_AFTER);
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef ITER_POS_AFTER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_forward_display_line_end 
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter forward to the next display line end.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_119()
{
    #define TEST_LINE "\r\r\n\n\r\r\r\n\r\n"
    #define ITER_POS_BEFORE 8
    #define ITER_POS_AFTER 8
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gint offs;
    char* str = TEST_LINE;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_widget_set_size_request (widget, 100, 20);
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_forward_display_line_end (GTK_TEXT_VIEW (widget), &iter);
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    offs = gtk_text_iter_get_offset(&iter);
    if (offs != ITER_POS_AFTER)
    {
        TEST_FAIL ("offs = %d, should be %d", offs, ITER_POS_AFTER);
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef ITER_POS_AFTER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_backward_display_line_start 
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter backward to the next display line start.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_120()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define ITER_POS_BEFORE 0
    #define ITER_POS_AFTER 0
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gint offs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_backward_display_line_start (GTK_TEXT_VIEW (widget), &iter);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    offs = gtk_text_iter_get_offset(&iter);
    if (offs != ITER_POS_AFTER)
    {
        TEST_FAIL ("offs = %d, should be %d", offs, ITER_POS_AFTER);
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef ITER_POS_AFTER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_backward_display_line_start 
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter backward to the next display line start.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_121()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define ITER_POS_BEFORE 1
    #define ITER_POS_AFTER 0
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gint offs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_backward_display_line_start (GTK_TEXT_VIEW (widget), &iter);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    offs = gtk_text_iter_get_offset(&iter);
    if (offs != ITER_POS_AFTER)
    {
        TEST_FAIL ("offs = %d, should be %d", offs, ITER_POS_AFTER);
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef ITER_POS_AFTER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_backward_display_line_start 
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter backward to the next display line start.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_122()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define ITER_POS_BEFORE 7
    #define ITER_POS_AFTER 7
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gint offs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_backward_display_line_start (GTK_TEXT_VIEW (widget), &iter);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    offs = gtk_text_iter_get_offset(&iter);
    if (offs != ITER_POS_AFTER)
    {
        TEST_FAIL ("offs = %d, should be %d", offs, ITER_POS_AFTER);
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef ITER_POS_AFTER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_backward_display_line_start 
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter backward to the next display line start.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_123()
{
    #define TEST_LINE "Line 0\r\n Line 1"
    #define ITER_POS_BEFORE 7
    #define ITER_POS_AFTER 0
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gint offs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_backward_display_line_start (GTK_TEXT_VIEW (widget), &iter);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    offs = gtk_text_iter_get_offset(&iter);
    if (offs != ITER_POS_AFTER)
    {
        TEST_FAIL ("offs = %d, should be %d", offs, ITER_POS_AFTER);
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef ITER_POS_AFTER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_backward_display_line_start 
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter backward to the next display line start.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_124()
{
    #define TEST_LINE "Line 0"
    #define ITER_POS_BEFORE 0
    #define ITER_POS_AFTER 0
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gint offs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_backward_display_line_start (GTK_TEXT_VIEW (widget), &iter);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    offs = gtk_text_iter_get_offset(&iter);
    if (offs != ITER_POS_AFTER)
    {
        TEST_FAIL ("offs = %d, should be %d", offs, ITER_POS_AFTER);
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef ITER_POS_AFTER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_backward_display_line_start 
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter backward to the next display line start.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_125()
{
    #define TEST_LINE ""
    #define ITER_POS_BEFORE 0
    #define ITER_POS_AFTER 0
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gint offs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_backward_display_line_start (GTK_TEXT_VIEW (widget), &iter);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    offs = gtk_text_iter_get_offset(&iter);
    if (offs != ITER_POS_AFTER)
    {
        TEST_FAIL ("offs = %d, should be %d", offs, ITER_POS_AFTER);
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef ITER_POS_AFTER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_backward_display_line_start 
 * Params: GtkTextView *text_view,GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Moves the given iter backward to the next display line start.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_126()
{
    #define TEST_LINE ""
    #define ITER_POS_BEFORE 1
    #define ITER_POS_AFTER 0
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gint offs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_backward_display_line_start (GTK_TEXT_VIEW (widget), &iter);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    offs = gtk_text_iter_get_offset(&iter);
    if (offs != ITER_POS_AFTER)
    {
        TEST_FAIL ("offs = %d, should be %d", offs, ITER_POS_AFTER);
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef ITER_POS_AFTER
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_starts_display_line
 * Params: GtkTextView *text_view,const GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Determines whether iter is at the start of a display line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_127()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define ITER_POS_BEFORE 0
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gboolean res   ;
    gint line;
    gint offs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_starts_display_line(GTK_TEXT_VIEW (widget),&iter);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_starts_display_line
 * Params: GtkTextView *text_view,const GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Determines whether iter is at the start of a display line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_128()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define ITER_POS_BEFORE 1
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gboolean res   ;
    gint line;
    gint offs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_starts_display_line(GTK_TEXT_VIEW (widget),&iter);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_starts_display_line
 * Params: GtkTextView *text_view,const GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Determines whether iter is at the start of a display line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_129()
{
    #define TEST_LINE "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define ITER_POS_BEFORE 7
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gboolean res   ;
    gint line;
    gint offs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_starts_display_line(GTK_TEXT_VIEW (widget),&iter);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_starts_display_line
 * Params: GtkTextView *text_view,const GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Determines whether iter is at the start of a display line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_130()
{
    #define TEST_LINE "Line 0\r\n Line 1"
    #define ITER_POS_BEFORE 7
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gboolean res   ;
    gint line;
    gint offs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_starts_display_line(GTK_TEXT_VIEW (widget),&iter);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_starts_display_line
 * Params: GtkTextView *text_view,const GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Determines whether iter is at the start of a display line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_131()
{
    #define TEST_LINE "Line 0\r\r\n Line 1"
    #define ITER_POS_BEFORE 7
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gboolean res   ;
    gint line;
    gint offs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_starts_display_line(GTK_TEXT_VIEW (widget),&iter);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_starts_display_line
 * Params: GtkTextView *text_view,const GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Determines whether iter is at the start of a display line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_132()
{
    #define TEST_LINE "Line 0"
    #define ITER_POS_BEFORE 0
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gboolean res   ;
    gint line;
    gint offs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_starts_display_line(GTK_TEXT_VIEW (widget),&iter);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_starts_display_line
 * Params: GtkTextView *text_view,const GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Determines whether iter is at the start of a display line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_133()
{
    #define TEST_LINE ""
    #define ITER_POS_BEFORE 0
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gboolean res   ;
    gint line;
    gint offs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_starts_display_line(GTK_TEXT_VIEW (widget),&iter);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_starts_display_line
 * Params: GtkTextView *text_view,const GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Determines whether iter is at the start of a display line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: TRUE  
 */
static void test_purpose_134()
{
    #define TEST_LINE " "
    #define ITER_POS_BEFORE 0
    #define CORRECT_RES TRUE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gboolean res   ;
    gint line;
    gint offs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_starts_display_line(GTK_TEXT_VIEW (widget),&iter);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_starts_display_line
 * Params: GtkTextView *text_view,const GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Determines whether iter is at the start of a display line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_135()
{
    #define TEST_LINE " "
    #define ITER_POS_BEFORE 1
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gboolean res   ;
    gint line;
    gint offs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_starts_display_line(GTK_TEXT_VIEW (widget),&iter);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_starts_display_line
 * Params: GtkTextView *text_view,const GtkTextIter *iter
 * Returns: gboolean
 * Assertion: Determines whether iter is at the start of a display line.
 * Params Values: a newly created GtkTextView*,GtkTextIter*
 * Expected: FALSE  
 */
static void test_purpose_136()
{
    #define TEST_LINE " "
    #define ITER_POS_BEFORE 5
    #define CORRECT_RES FALSE
    
    GtkTextIter iter;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    gboolean result;
    gboolean res   ;
    gint line;
    gint offs;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen (TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, ITER_POS_BEFORE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_starts_display_line(GTK_TEXT_VIEW (widget),&iter);
    
    if (result != CORRECT_RES)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RES);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef ITER_POS_BEFORE
    #undef CORRECT_RES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type
 * Returns: gint
 * Assertion: Gets the width of the specified border window.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_LEFT
 * Expected: 0
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Sets the width of GTK_TEXT_WINDOW_LEFT or GTK_TEXT_WINDOW_RIGHT, or the height of GTK_TEXT_WINDOW_TOP or GTK_TEXT_WINDOW_BOTTOM.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_LEFT, 0
 * Expected: void
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Automatically destroys the corresponding window if the size is set to 0, and creates the window if the size is set to non-zero.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_LEFT, 0
 * Expected: void  
 */
static void test_purpose_137()
{
    #define TYPE GTK_TEXT_WINDOW_LEFT
    #define SIZE 0
    
    GtkWidget *widget;
    gint size;
    gint real_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    size = SIZE;
    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, size);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (size == 0)
    {
        if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for border window size = 0", NULL);
        }
    } else {
        if (!gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned NULL for border window size = %d", size);
        }
    
        real_size = gtk_text_view_get_border_window_size (GTK_TEXT_VIEW (widget), 
                                                          TYPE);
        if (real_size != size)
        {
            TEST_FAIL ("real_size = %d, should be %d", real_size, size);
        }
    
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type
 * Returns: gint
 * Assertion: Gets the width of the specified border window.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_RIGHT
 * Expected: 0
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Sets the width of GTK_TEXT_WINDOW_LEFT or GTK_TEXT_WINDOW_RIGHT, or the height of GTK_TEXT_WINDOW_TOP or GTK_TEXT_WINDOW_BOTTOM.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_RIGHT, 0
 * Expected: void
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Automatically destroys the corresponding window if the size is set to 0, and creates the window if the size is set to non-zero.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_RIGHT, 0
 * Expected: void  
 */
static void test_purpose_138()
{
    #define TYPE GTK_TEXT_WINDOW_RIGHT
    #define SIZE 0
    
    GtkWidget *widget;
    gint size;
    gint real_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    size = SIZE;
    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, size);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (size == 0)
    {
        if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for border window size = 0", NULL);
        }
    } else {
        if (!gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned NULL for border window size = %d", size);
        }
    
        real_size = gtk_text_view_get_border_window_size (GTK_TEXT_VIEW (widget), 
                                                          TYPE);
        if (real_size != size)
        {
            TEST_FAIL ("real_size = %d, should be %d", real_size, size);
        }
    
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type
 * Returns: gint
 * Assertion: Gets the width of the specified border window.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TOP
 * Expected: 0
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Sets the width of GTK_TEXT_WINDOW_LEFT or GTK_TEXT_WINDOW_RIGHT, or the height of GTK_TEXT_WINDOW_TOP or GTK_TEXT_WINDOW_BOTTOM.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TOP, 0
 * Expected: void
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Automatically destroys the corresponding window if the size is set to 0, and creates the window if the size is set to non-zero.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TOP, 0
 * Expected: void  
 */
static void test_purpose_139()
{
    #define TYPE GTK_TEXT_WINDOW_TOP
    #define SIZE 0
    
    GtkWidget *widget;
    gint size;
    gint real_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    size = SIZE;
    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, size);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (size == 0)
    {
        if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for border window size = 0", NULL);
        }
    } else {
        if (!gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned NULL for border window size = %d", size);
        }
    
        real_size = gtk_text_view_get_border_window_size (GTK_TEXT_VIEW (widget), 
                                                          TYPE);
        if (real_size != size)
        {
            TEST_FAIL ("real_size = %d, should be %d", real_size, size);
        }
    
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type
 * Returns: gint
 * Assertion: Gets the width of the specified border window.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM
 * Expected: 0
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Sets the width of GTK_TEXT_WINDOW_LEFT or GTK_TEXT_WINDOW_RIGHT, or the height of GTK_TEXT_WINDOW_TOP or GTK_TEXT_WINDOW_BOTTOM.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM, 0
 * Expected: void
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Automatically destroys the corresponding window if the size is set to 0, and creates the window if the size is set to non-zero.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM, 0
 * Expected: void  
 */
static void test_purpose_140()
{
    #define TYPE GTK_TEXT_WINDOW_BOTTOM
    #define SIZE 0
    
    GtkWidget *widget;
    gint size;
    gint real_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    size = SIZE;
    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, size);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (size == 0)
    {
        if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for border window size = 0", NULL);
        }
    } else {
        if (!gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned NULL for border window size = %d", size);
        }
    
        real_size = gtk_text_view_get_border_window_size (GTK_TEXT_VIEW (widget), 
                                                          TYPE);
        if (real_size != size)
        {
            TEST_FAIL ("real_size = %d, should be %d", real_size, size);
        }
    
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type
 * Returns: gint
 * Assertion: Gets the width of the specified border window.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_LEFT
 * Expected: 1
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Sets the width of GTK_TEXT_WINDOW_LEFT or GTK_TEXT_WINDOW_RIGHT, or the height of GTK_TEXT_WINDOW_TOP or GTK_TEXT_WINDOW_BOTTOM.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_LEFT, 1
 * Expected: void
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Automatically destroys the corresponding window if the size is set to 0, and creates the window if the size is set to non-zero.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_LEFT, 1
 * Expected: void  
 */
static void test_purpose_141()
{
    #define TYPE GTK_TEXT_WINDOW_LEFT
    #define SIZE 1
    
    GtkWidget *widget;
    gint size;
    gint real_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    size = SIZE;
    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, size);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (size == 0)
    {
        if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for border window size = 0", NULL);
        }
    } else {
        if (!gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned NULL for border window size = %d", size);
        }
    
        real_size = gtk_text_view_get_border_window_size (GTK_TEXT_VIEW (widget), 
                                                          TYPE);
        if (real_size != size)
        {
            TEST_FAIL ("real_size = %d, should be %d", real_size, size);
        }
    
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type
 * Returns: gint
 * Assertion: Gets the width of the specified border window.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_RIGHT
 * Expected: 1
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Sets the width of GTK_TEXT_WINDOW_LEFT or GTK_TEXT_WINDOW_RIGHT, or the height of GTK_TEXT_WINDOW_TOP or GTK_TEXT_WINDOW_BOTTOM.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_RIGHT, 1
 * Expected: void
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Automatically destroys the corresponding window if the size is set to 0, and creates the window if the size is set to non-zero.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_RIGHT, 1
 * Expected: void  
 */
static void test_purpose_142()
{
    #define TYPE GTK_TEXT_WINDOW_RIGHT
    #define SIZE 1
    
    GtkWidget *widget;
    gint size;
    gint real_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    size = SIZE;
    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, size);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (size == 0)
    {
        if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for border window size = 0", NULL);
        }
    } else {
        if (!gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned NULL for border window size = %d", size);
        }
    
        real_size = gtk_text_view_get_border_window_size (GTK_TEXT_VIEW (widget), 
                                                          TYPE);
        if (real_size != size)
        {
            TEST_FAIL ("real_size = %d, should be %d", real_size, size);
        }
    
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type
 * Returns: gint
 * Assertion: Gets the width of the specified border window.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TOP
 * Expected: 1
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Sets the width of GTK_TEXT_WINDOW_LEFT or GTK_TEXT_WINDOW_RIGHT, or the height of GTK_TEXT_WINDOW_TOP or GTK_TEXT_WINDOW_BOTTOM.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TOP, 1
 * Expected: void
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Automatically destroys the corresponding window if the size is set to 0, and creates the window if the size is set to non-zero.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TOP, 1
 * Expected: void  
 */
static void test_purpose_143()
{
    #define TYPE GTK_TEXT_WINDOW_TOP
    #define SIZE 1
    
    GtkWidget *widget;
    gint size;
    gint real_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    size = SIZE;
    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, size);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (size == 0)
    {
        if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for border window size = 0", NULL);
        }
    } else {
        if (!gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned NULL for border window size = %d", size);
        }
    
        real_size = gtk_text_view_get_border_window_size (GTK_TEXT_VIEW (widget), 
                                                          TYPE);
        if (real_size != size)
        {
            TEST_FAIL ("real_size = %d, should be %d", real_size, size);
        }
    
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type
 * Returns: gint
 * Assertion: Gets the width of the specified border window.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM
 * Expected: 1
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Sets the width of GTK_TEXT_WINDOW_LEFT or GTK_TEXT_WINDOW_RIGHT, or the height of GTK_TEXT_WINDOW_TOP or GTK_TEXT_WINDOW_BOTTOM.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM, 1
 * Expected: void
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Automatically destroys the corresponding window if the size is set to 0, and creates the window if the size is set to non-zero.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM, 1
 * Expected: void  
 */
static void test_purpose_144()
{
    #define TYPE GTK_TEXT_WINDOW_BOTTOM
    #define SIZE 1
    
    GtkWidget *widget;
    gint size;
    gint real_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    size = SIZE;
    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, size);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (size == 0)
    {
        if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for border window size = 0", NULL);
        }
    } else {
        if (!gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned NULL for border window size = %d", size);
        }
    
        real_size = gtk_text_view_get_border_window_size (GTK_TEXT_VIEW (widget), 
                                                          TYPE);
        if (real_size != size)
        {
            TEST_FAIL ("real_size = %d, should be %d", real_size, size);
        }
    
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type
 * Returns: gint
 * Assertion: Gets the width of the specified border window.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_LEFT
 * Expected: 49
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Sets the width of GTK_TEXT_WINDOW_LEFT or GTK_TEXT_WINDOW_RIGHT, or the height of GTK_TEXT_WINDOW_TOP or GTK_TEXT_WINDOW_BOTTOM.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_LEFT, 49
 * Expected: void
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Automatically destroys the corresponding window if the size is set to 0, and creates the window if the size is set to non-zero.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_LEFT, 49
 * Expected: void  
 */
static void test_purpose_145()
{
    #define TYPE GTK_TEXT_WINDOW_LEFT
    #define SIZE 49
    
    GtkWidget *widget;
    gint size;
    gint real_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    size = SIZE;
    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, size);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (size == 0)
    {
        if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for border window size = 0", NULL);
        }
    } else {
        if (!gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned NULL for border window size = %d", size);
        }
    
        real_size = gtk_text_view_get_border_window_size (GTK_TEXT_VIEW (widget), 
                                                          TYPE);
        if (real_size != size)
        {
            TEST_FAIL ("real_size = %d, should be %d", real_size, size);
        }
    
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type
 * Returns: gint
 * Assertion: Gets the width of the specified border window.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_RIGHT
 * Expected: 49
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Sets the width of GTK_TEXT_WINDOW_LEFT or GTK_TEXT_WINDOW_RIGHT, or the height of GTK_TEXT_WINDOW_TOP or GTK_TEXT_WINDOW_BOTTOM.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_RIGHT, 49
 * Expected: void
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Automatically destroys the corresponding window if the size is set to 0, and creates the window if the size is set to non-zero.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_RIGHT, 49
 * Expected: void  
 */
static void test_purpose_146()
{
    #define TYPE GTK_TEXT_WINDOW_RIGHT
    #define SIZE 49
    
    GtkWidget *widget;
    gint size;
    gint real_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    size = SIZE;
    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, size);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (size == 0)
    {
        if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for border window size = 0", NULL);
        }
    } else {
        if (!gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned NULL for border window size = %d", size);
        }
    
        real_size = gtk_text_view_get_border_window_size (GTK_TEXT_VIEW (widget), 
                                                          TYPE);
        if (real_size != size)
        {
            TEST_FAIL ("real_size = %d, should be %d", real_size, size);
        }
    
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type
 * Returns: gint
 * Assertion: Gets the width of the specified border window.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TOP
 * Expected: 49
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Sets the width of GTK_TEXT_WINDOW_LEFT or GTK_TEXT_WINDOW_RIGHT, or the height of GTK_TEXT_WINDOW_TOP or GTK_TEXT_WINDOW_BOTTOM.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TOP, 49
 * Expected: void
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Automatically destroys the corresponding window if the size is set to 0, and creates the window if the size is set to non-zero.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TOP, 49
 * Expected: void  
 */
static void test_purpose_147()
{
    #define TYPE GTK_TEXT_WINDOW_TOP
    #define SIZE 49
    
    GtkWidget *widget;
    gint size;
    gint real_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    size = SIZE;
    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, size);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (size == 0)
    {
        if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for border window size = 0", NULL);
        }
    } else {
        if (!gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned NULL for border window size = %d", size);
        }
    
        real_size = gtk_text_view_get_border_window_size (GTK_TEXT_VIEW (widget), 
                                                          TYPE);
        if (real_size != size)
        {
            TEST_FAIL ("real_size = %d, should be %d", real_size, size);
        }
    
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type
 * Returns: gint
 * Assertion: Gets the width of the specified border window.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM
 * Expected: 49
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Sets the width of GTK_TEXT_WINDOW_LEFT or GTK_TEXT_WINDOW_RIGHT, or the height of GTK_TEXT_WINDOW_TOP or GTK_TEXT_WINDOW_BOTTOM.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM, 49
 * Expected: void
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Automatically destroys the corresponding window if the size is set to 0, and creates the window if the size is set to non-zero.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM, 49
 * Expected: void  
 */
static void test_purpose_148()
{
    #define TYPE GTK_TEXT_WINDOW_BOTTOM
    #define SIZE 49
    
    GtkWidget *widget;
    gint size;
    gint real_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    size = SIZE;
    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, size);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (size == 0)
    {
        if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for border window size = 0", NULL);
        }
    } else {
        if (!gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned NULL for border window size = %d", size);
        }
    
        real_size = gtk_text_view_get_border_window_size (GTK_TEXT_VIEW (widget), 
                                                          TYPE);
        if (real_size != size)
        {
            TEST_FAIL ("real_size = %d, should be %d", real_size, size);
        }
    
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type
 * Returns: gint
 * Assertion: Gets the width of the specified border window.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_LEFT
 * Expected: 1000
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Sets the width of GTK_TEXT_WINDOW_LEFT or GTK_TEXT_WINDOW_RIGHT, or the height of GTK_TEXT_WINDOW_TOP or GTK_TEXT_WINDOW_BOTTOM.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_LEFT, 1000
 * Expected: void
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Automatically destroys the corresponding window if the size is set to 0, and creates the window if the size is set to non-zero.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_LEFT, 1000
 * Expected: void  
 */
static void test_purpose_149()
{
    #define TYPE GTK_TEXT_WINDOW_LEFT
    #define SIZE 1000
    
    GtkWidget *widget;
    gint size;
    gint real_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    size = SIZE;
    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, size);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (size == 0)
    {
        if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for border window size = 0", NULL);
        }
    } else {
        if (!gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned NULL for border window size = %d", size);
        }
    
        real_size = gtk_text_view_get_border_window_size (GTK_TEXT_VIEW (widget), 
                                                          TYPE);
        if (real_size != size)
        {
            TEST_FAIL ("real_size = %d, should be %d", real_size, size);
        }
    
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type
 * Returns: gint
 * Assertion: Gets the width of the specified border window.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TOP
 * Expected: 8953
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Sets the width of GTK_TEXT_WINDOW_LEFT or GTK_TEXT_WINDOW_RIGHT, or the height of GTK_TEXT_WINDOW_TOP or GTK_TEXT_WINDOW_BOTTOM.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TOP, 8953
 * Expected: void
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Automatically destroys the corresponding window if the size is set to 0, and creates the window if the size is set to non-zero.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TOP, 8953
 * Expected: void  
 */
static void test_purpose_150()
{
    #define TYPE GTK_TEXT_WINDOW_TOP
    #define SIZE 8953
    
    GtkWidget *widget;
    gint size;
    gint real_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    size = SIZE;
    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, size);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (size == 0)
    {
        if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for border window size = 0", NULL);
        }
    } else {
        if (!gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned NULL for border window size = %d", size);
        }
    
        real_size = gtk_text_view_get_border_window_size (GTK_TEXT_VIEW (widget), 
                                                          TYPE);
        if (real_size != size)
        {
            TEST_FAIL ("real_size = %d, should be %d", real_size, size);
        }
    
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type
 * Returns: gint
 * Assertion: Gets the width of the specified border window.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM
 * Expected: 1225
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Sets the width of GTK_TEXT_WINDOW_LEFT or GTK_TEXT_WINDOW_RIGHT, or the height of GTK_TEXT_WINDOW_TOP or GTK_TEXT_WINDOW_BOTTOM.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM, 1225
 * Expected: void
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Automatically destroys the corresponding window if the size is set to 0, and creates the window if the size is set to non-zero.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM, 1225
 * Expected: void  
 */
static void test_purpose_151()
{
    #define TYPE GTK_TEXT_WINDOW_BOTTOM
    #define SIZE 1225
    
    GtkWidget *widget;
    gint size;
    gint real_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    size = SIZE;
    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, size);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (size == 0)
    {
        if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for border window size = 0", NULL);
        }
    } else {
        if (!gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned NULL for border window size = %d", size);
        }
    
        real_size = gtk_text_view_get_border_window_size (GTK_TEXT_VIEW (widget), 
                                                          TYPE);
        if (real_size != size)
        {
            TEST_FAIL ("real_size = %d, should be %d", real_size, size);
        }
    
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type
 * Returns: gint
 * Assertion: Gets the width of the specified border window.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_RIGHT
 * Expected: 9688
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Sets the width of GTK_TEXT_WINDOW_LEFT or GTK_TEXT_WINDOW_RIGHT, or the height of GTK_TEXT_WINDOW_TOP or GTK_TEXT_WINDOW_BOTTOM.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_RIGHT, 9688
 * Expected: void
 * 
 * Name: gtk_text_view_set_border_window_size
 * Params: GtkTextView *text_view, GtkTextWindowType type, gint size
 * Returns: void
 * Assertion: Automatically destroys the corresponding window if the size is set to 0, and creates the window if the size is set to non-zero.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_RIGHT, 9688
 * Expected: void  
 */
static void test_purpose_152()
{
    #define TYPE GTK_TEXT_WINDOW_RIGHT
    #define SIZE 9688
    
    GtkWidget *widget;
    gint size;
    gint real_size;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    size = SIZE;
    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, size);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (size == 0)
    {
        if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for border window size = 0", NULL);
        }
    } else {
        if (!gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
        {
            TEST_FAIL ("gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned NULL for border window size = %d", size);
        }
    
        real_size = gtk_text_view_get_border_window_size (GTK_TEXT_VIEW (widget), 
                                                          TYPE);
        if (real_size != size)
        {
            TEST_FAIL ("real_size = %d, should be %d", real_size, size);
        }
    
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    #undef SIZE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_default_attributes
 * Params: GtkTextView *text_view
 * Returns: GtkTextAttributes*
 * Assertion: Obtains a copy of the default text attributes.
 * Params Values: a newly created GtkTextView*
 * Expected: GtkTextAttributes*  
 */
static void test_purpose_153()
{
    GtkTextAttributes* attrs;
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    attrs = gtk_text_view_get_default_attributes (GTK_TEXT_VIEW (widget));
    
    free (attrs);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_iter_location
 * Params: GtkTextView *text_view, const GtkTextIter *iter, GdkRectangle *location
 * Returns: void
 * Assertion: Gets a rectangle which roughly contains the character at iter.
 * Params Values: a newly created GtkTextView*, const GtkTextIter *iter, GdkRectangle *location
 * Expected: void
 * 
 * Name: gtk_text_view_get_iter_at_location
 * Params: GtkTextView *text_view, const GtkTextIter *iter, gint x, gint y
 * Returns: void
 * Assertion: Retrieves the iterator at buffer coordinates x and y.
 * Params Values: a newly created GtkTextView*, const GtkTextIter *iter, gint x, gint y
 * Expected: void  
 */
static void test_purpose_154()
{
    #define TEST_LINE "Line 0\n Line 1\n"
    #define OFFSET 3
    
    GtkTextIter iter;
    GtkTextIter iter_at_location;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    GdkRectangle location;
    gint iter_offset;
    gint iter_at_location_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    gtk_text_view_get_iter_location (GTK_TEXT_VIEW (widget), &iter, &location);
    gtk_text_view_get_iter_at_location (GTK_TEXT_VIEW (widget), &iter_at_location, 
                                        location.x, location.y);
    
    iter_offset = gtk_text_iter_get_offset (&iter);
    iter_at_location_offset = gtk_text_iter_get_offset (&iter_at_location);
    if (iter_at_location_offset != iter_offset)
    {
        TEST_FAIL ("iter_at_location offset is %d, should be %d", 
                   iter_at_location_offset, iter_offset);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_iter_location
 * Params: GtkTextView *text_view, const GtkTextIter *iter, GdkRectangle *location
 * Returns: void
 * Assertion: Gets a rectangle which roughly contains the character at iter.
 * Params Values: a newly created GtkTextView*, const GtkTextIter *iter, GdkRectangle *location
 * Expected: void
 * 
 * Name: gtk_text_view_get_iter_at_location
 * Params: GtkTextView *text_view, const GtkTextIter *iter, gint x, gint y
 * Returns: void
 * Assertion: Retrieves the iterator at buffer coordinates x and y.
 * Params Values: a newly created GtkTextView*, const GtkTextIter *iter, gint x, gint y
 * Expected: void  
 */
static void test_purpose_155()
{
    #define TEST_LINE "Line 0"
    #define OFFSET 0
    
    GtkTextIter iter;
    GtkTextIter iter_at_location;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    GdkRectangle location;
    gint iter_offset;
    gint iter_at_location_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    gtk_text_view_get_iter_location (GTK_TEXT_VIEW (widget), &iter, &location);
    gtk_text_view_get_iter_at_location (GTK_TEXT_VIEW (widget), &iter_at_location, 
                                        location.x, location.y);
    
    iter_offset = gtk_text_iter_get_offset (&iter);
    iter_at_location_offset = gtk_text_iter_get_offset (&iter_at_location);
    if (iter_at_location_offset != iter_offset)
    {
        TEST_FAIL ("iter_at_location offset is %d, should be %d", 
                   iter_at_location_offset, iter_offset);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_iter_location
 * Params: GtkTextView *text_view, const GtkTextIter *iter, GdkRectangle *location
 * Returns: void
 * Assertion: Gets a rectangle which roughly contains the character at iter.
 * Params Values: a newly created GtkTextView*, const GtkTextIter *iter, GdkRectangle *location
 * Expected: void
 * 
 * Name: gtk_text_view_get_iter_at_location
 * Params: GtkTextView *text_view, const GtkTextIter *iter, gint x, gint y
 * Returns: void
 * Assertion: Retrieves the iterator at buffer coordinates x and y.
 * Params Values: a newly created GtkTextView*, const GtkTextIter *iter, gint x, gint y
 * Expected: void  
 */
static void test_purpose_156()
{
    #define TEST_LINE "Line 0"
    #define OFFSET 6
    
    GtkTextIter iter;
    GtkTextIter iter_at_location;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    GdkRectangle location;
    gint iter_offset;
    gint iter_at_location_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    gtk_text_view_get_iter_location (GTK_TEXT_VIEW (widget), &iter, &location);
    gtk_text_view_get_iter_at_location (GTK_TEXT_VIEW (widget), &iter_at_location, 
                                        location.x, location.y);
    
    iter_offset = gtk_text_iter_get_offset (&iter);
    iter_at_location_offset = gtk_text_iter_get_offset (&iter_at_location);
    if (iter_at_location_offset != iter_offset)
    {
        TEST_FAIL ("iter_at_location offset is %d, should be %d", 
                   iter_at_location_offset, iter_offset);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_iter_location
 * Params: GtkTextView *text_view, const GtkTextIter *iter, GdkRectangle *location
 * Returns: void
 * Assertion: Gets a rectangle which roughly contains the character at iter.
 * Params Values: a newly created GtkTextView*, const GtkTextIter *iter, GdkRectangle *location
 * Expected: void
 * 
 * Name: gtk_text_view_get_iter_at_location
 * Params: GtkTextView *text_view, const GtkTextIter *iter, gint x, gint y
 * Returns: void
 * Assertion: Retrieves the iterator at buffer coordinates x and y.
 * Params Values: a newly created GtkTextView*, const GtkTextIter *iter, gint x, gint y
 * Expected: void  
 */
static void test_purpose_157()
{
    #define TEST_LINE "Line 0"
    #define OFFSET 7
    
    GtkTextIter iter;
    GtkTextIter iter_at_location;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    GdkRectangle location;
    gint iter_offset;
    gint iter_at_location_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    gtk_text_view_get_iter_location (GTK_TEXT_VIEW (widget), &iter, &location);
    gtk_text_view_get_iter_at_location (GTK_TEXT_VIEW (widget), &iter_at_location, 
                                        location.x, location.y);
    
    iter_offset = gtk_text_iter_get_offset (&iter);
    iter_at_location_offset = gtk_text_iter_get_offset (&iter_at_location);
    if (iter_at_location_offset != iter_offset)
    {
        TEST_FAIL ("iter_at_location offset is %d, should be %d", 
                   iter_at_location_offset, iter_offset);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_iter_location
 * Params: GtkTextView *text_view, const GtkTextIter *iter, GdkRectangle *location
 * Returns: void
 * Assertion: Gets a rectangle which roughly contains the character at iter.
 * Params Values: a newly created GtkTextView*, const GtkTextIter *iter, GdkRectangle *location
 * Expected: void
 * 
 * Name: gtk_text_view_get_iter_at_location
 * Params: GtkTextView *text_view, const GtkTextIter *iter, gint x, gint y
 * Returns: void
 * Assertion: Retrieves the iterator at buffer coordinates x and y.
 * Params Values: a newly created GtkTextView*, const GtkTextIter *iter, gint x, gint y
 * Expected: void  
 */
static void test_purpose_158()
{
    #define TEST_LINE "Line 0"
    #define OFFSET 10
    
    GtkTextIter iter;
    GtkTextIter iter_at_location;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    GdkRectangle location;
    gint iter_offset;
    gint iter_at_location_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_offset (buffer, &iter, OFFSET);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    gtk_text_view_get_iter_location (GTK_TEXT_VIEW (widget), &iter, &location);
    gtk_text_view_get_iter_at_location (GTK_TEXT_VIEW (widget), &iter_at_location, 
                                        location.x, location.y);
    
    iter_offset = gtk_text_iter_get_offset (&iter);
    iter_at_location_offset = gtk_text_iter_get_offset (&iter_at_location);
    if (iter_at_location_offset != iter_offset)
    {
        TEST_FAIL ("iter_at_location offset is %d, should be %d", 
                   iter_at_location_offset, iter_offset);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef OFFSET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_line_yrange
 * Params: GtkTextView *text_view, const GtkTextIter *iter, gint *y, gint *height
 * Returns: void
 * Assertion: Gets the y coordinate of the top of the line containing iter, and the height of the line.
 * Params Values: a newly created GtkTextView*, const GtkTextIter *iter, GdkRectangle *location
 * Expected: void
 * 
 * Name: gtk_text_view_get_line_at_y
 * Params: GtkTextView *text_view, const GtkTextIter *iter, gint y, gint *line_top 
 * Returns: void
 * Assertion: Gets the GtkTextIter at the start of the line containing the coordinate y.
 * Params Values: a newly created GtkTextView*, const GtkTextIter *iter, gint y, gint *line_top
 * Expected: void
 * 
 * Name: gtk_text_view_get_line_at_y
 * Params: GtkTextView *text_view, const GtkTextIter *iter, gint y, gint *line_top 
 * Returns: void
 * Assertion: If non-NULL, line_top will be filled with the coordinate of the top edge of the line.
 * Params Values: a newly created GtkTextView*, const GtkTextIter *iter, gint y, gint *line_top
 * Expected: void  
 */
static void test_purpose_159()
{
    #define TEST_LINE "Line 0\n Line 1\n"
    #define LINE_NO 0
    
    GtkTextIter iter;
    GtkTextIter iter_at_line;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gint y;
    gint height;
    gint line_top;
    gint iter_offset;
    gint iter_at_line_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_line (buffer, &iter, LINE_NO);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    gtk_text_view_get_line_yrange (GTK_TEXT_VIEW (widget), &iter, &y, &height);
    
    gtk_text_view_get_line_at_y (GTK_TEXT_VIEW (widget), &iter_at_line, 
                                 y, &line_top);
    iter_offset = gtk_text_iter_get_offset (&iter);
    iter_at_line_offset = gtk_text_iter_get_offset (&iter_at_line);
    if (iter_at_line_offset != iter_offset)
    {
        TEST_FAIL ("1: iter_at_line offset is %d, should be %d", 
                   iter_at_line_offset, iter_offset);
    }
    
    if (line_top != y)
    {
        TEST_FAIL ("1: line_top = %d, y = %d, height = %d, y * height = %d, line_top should be equal to y * height", 
                   line_top, y, height, y * height);
    }
    
    
    gtk_text_view_get_line_at_y (GTK_TEXT_VIEW (widget), &iter_at_line, 
                                 y, &line_top);
    iter_offset = gtk_text_iter_get_offset (&iter);
    iter_at_line_offset = gtk_text_iter_get_offset (&iter_at_line);
    if (iter_at_line_offset != iter_offset)
    {
        TEST_FAIL ("2: iter_at_line offset is %d, should be %d", 
                   iter_at_line_offset, iter_offset);
    }
    
    if (line_top != y)
    {
        TEST_FAIL ("2: line_top = %d, y = %d, height = %d, y * height = %d, line_top should be equal to y * height", 
                   line_top, y, height, y * height);
    }
    
    gtk_text_view_get_line_at_y (GTK_TEXT_VIEW (widget), &iter_at_line, 
                                 y, &line_top);
    iter_offset = gtk_text_iter_get_offset (&iter);
    iter_at_line_offset = gtk_text_iter_get_offset (&iter_at_line);
    if (iter_at_line_offset != iter_offset)
    {
        TEST_FAIL ("3: iter_at_line offset is %d, should be %d", 
                   iter_at_line_offset, iter_offset);
    }
    
    if (line_top != y)
    {
        TEST_FAIL ("3: line_top = %d, y = %d, height = %d, y * height = %d, line_top should be equal to y * height", 
                   line_top, y, height, y * height);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef LINE_NO
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_line_yrange
 * Params: GtkTextView *text_view, const GtkTextIter *iter, gint *y, gint *height
 * Returns: void
 * Assertion: Gets the y coordinate of the top of the line containing iter, and the height of the line.
 * Params Values: a newly created GtkTextView*, const GtkTextIter *iter, GdkRectangle *location
 * Expected: void
 * 
 * Name: gtk_text_view_get_line_at_y
 * Params: GtkTextView *text_view, const GtkTextIter *iter, gint y, gint *line_top 
 * Returns: void
 * Assertion: Gets the GtkTextIter at the start of the line containing the coordinate y.
 * Params Values: a newly created GtkTextView*, const GtkTextIter *iter, gint y, gint *line_top
 * Expected: void
 * 
 * Name: gtk_text_view_get_line_at_y
 * Params: GtkTextView *text_view, const GtkTextIter *iter, gint y, gint *line_top 
 * Returns: void
 * Assertion: If non-NULL, line_top will be filled with the coordinate of the top edge of the line.
 * Params Values: a newly created GtkTextView*, const GtkTextIter *iter, gint y, gint *line_top
 * Expected: void  
 */
static void test_purpose_160()
{
    #define TEST_LINE "Line 0\n Line 1\n"
    #define LINE_NO 1
    
    GtkTextIter iter;
    GtkTextIter iter_at_line;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gint y;
    gint height;
    gint line_top;
    gint iter_offset;
    gint iter_at_line_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_line (buffer, &iter, LINE_NO);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    gtk_text_view_get_line_yrange (GTK_TEXT_VIEW (widget), &iter, &y, &height);
    
    gtk_text_view_get_line_at_y (GTK_TEXT_VIEW (widget), &iter_at_line, 
                                 y, &line_top);
    iter_offset = gtk_text_iter_get_offset (&iter);
    iter_at_line_offset = gtk_text_iter_get_offset (&iter_at_line);
    if (iter_at_line_offset != iter_offset)
    {
        TEST_FAIL ("1: iter_at_line offset is %d, should be %d", 
                   iter_at_line_offset, iter_offset);
    }
    
    if (line_top != y)
    {
        TEST_FAIL ("1: line_top = %d, y = %d, height = %d, y * height = %d, line_top should be equal to y * height", 
                   line_top, y, height, y * height);
    }
    
    
    gtk_text_view_get_line_at_y (GTK_TEXT_VIEW (widget), &iter_at_line, 
                                 y, &line_top);
    iter_offset = gtk_text_iter_get_offset (&iter);
    iter_at_line_offset = gtk_text_iter_get_offset (&iter_at_line);
    if (iter_at_line_offset != iter_offset)
    {
        TEST_FAIL ("2: iter_at_line offset is %d, should be %d", 
                   iter_at_line_offset, iter_offset);
    }
    
    if (line_top != y)
    {
        TEST_FAIL ("2: line_top = %d, y = %d, height = %d, y * height = %d, line_top should be equal to y * height", 
                   line_top, y, height, y * height);
    }
    
    gtk_text_view_get_line_at_y (GTK_TEXT_VIEW (widget), &iter_at_line, 
                                 y, &line_top);
    iter_offset = gtk_text_iter_get_offset (&iter);
    iter_at_line_offset = gtk_text_iter_get_offset (&iter_at_line);
    if (iter_at_line_offset != iter_offset)
    {
        TEST_FAIL ("3: iter_at_line offset is %d, should be %d", 
                   iter_at_line_offset, iter_offset);
    }
    
    if (line_top != y)
    {
        TEST_FAIL ("3: line_top = %d, y = %d, height = %d, y * height = %d, line_top should be equal to y * height", 
                   line_top, y, height, y * height);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef LINE_NO
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_line_yrange
 * Params: GtkTextView *text_view, const GtkTextIter *iter, gint *y, gint *height
 * Returns: void
 * Assertion: Gets the y coordinate of the top of the line containing iter, and the height of the line.
 * Params Values: a newly created GtkTextView*, const GtkTextIter *iter, GdkRectangle *location
 * Expected: void
 * 
 * Name: gtk_text_view_get_line_at_y
 * Params: GtkTextView *text_view, const GtkTextIter *iter, gint y, gint *line_top 
 * Returns: void
 * Assertion: Gets the GtkTextIter at the start of the line containing the coordinate y.
 * Params Values: a newly created GtkTextView*, const GtkTextIter *iter, gint y, gint *line_top
 * Expected: void
 * 
 * Name: gtk_text_view_get_line_at_y
 * Params: GtkTextView *text_view, const GtkTextIter *iter, gint y, gint *line_top 
 * Returns: void
 * Assertion: If non-NULL, line_top will be filled with the coordinate of the top edge of the line.
 * Params Values: a newly created GtkTextView*, const GtkTextIter *iter, gint y, gint *line_top
 * Expected: void  
 */
static void test_purpose_161()
{
    #define TEST_LINE "Line 0\n Line 1\n"
    #define LINE_NO 5
    
    GtkTextIter iter;
    GtkTextIter iter_at_line;
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    gint y;
    gint height;
    gint line_top;
    gint iter_offset;
    gint iter_at_line_offset;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    gtk_text_buffer_get_iter_at_line (buffer, &iter, LINE_NO);
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    gtk_text_view_get_line_yrange (GTK_TEXT_VIEW (widget), &iter, &y, &height);
    
    gtk_text_view_get_line_at_y (GTK_TEXT_VIEW (widget), &iter_at_line, 
                                 y, &line_top);
    iter_offset = gtk_text_iter_get_offset (&iter);
    iter_at_line_offset = gtk_text_iter_get_offset (&iter_at_line);
    if (iter_at_line_offset != iter_offset)
    {
        TEST_FAIL ("1: iter_at_line offset is %d, should be %d", 
                   iter_at_line_offset, iter_offset);
    }
    
    if (line_top != y)
    {
        TEST_FAIL ("1: line_top = %d, y = %d, height = %d, y * height = %d, line_top should be equal to y * height", 
                   line_top, y, height, y * height);
    }
    
    
    gtk_text_view_get_line_at_y (GTK_TEXT_VIEW (widget), &iter_at_line, 
                                 y, &line_top);
    iter_offset = gtk_text_iter_get_offset (&iter);
    iter_at_line_offset = gtk_text_iter_get_offset (&iter_at_line);
    if (iter_at_line_offset != iter_offset)
    {
        TEST_FAIL ("2: iter_at_line offset is %d, should be %d", 
                   iter_at_line_offset, iter_offset);
    }
    
    if (line_top != y)
    {
        TEST_FAIL ("2: line_top = %d, y = %d, height = %d, y * height = %d, line_top should be equal to y * height", 
                   line_top, y, height, y * height);
    }
    
    gtk_text_view_get_line_at_y (GTK_TEXT_VIEW (widget), &iter_at_line, 
                                 y, &line_top);
    iter_offset = gtk_text_iter_get_offset (&iter);
    iter_at_line_offset = gtk_text_iter_get_offset (&iter_at_line);
    if (iter_at_line_offset != iter_offset)
    {
        TEST_FAIL ("3: iter_at_line offset is %d, should be %d", 
                   iter_at_line_offset, iter_offset);
    }
    
    if (line_top != y)
    {
        TEST_FAIL ("3: line_top = %d, y = %d, height = %d, y * height = %d, line_top should be equal to y * height", 
                   line_top, y, height, y * height);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    #undef LINE_NO
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_visible_rect
 * Params: GtkTextView *text_view, GdkRectangle *location
 * Returns: void
 * Assertion: Fills visible_rect with the currently-visible region of the buffer, in buffer coordinates.
 * Params Values: a newly created GtkTextView*, GdkRectangle *location
 * Expected: void  
 */
static void test_purpose_162()
{
    #define TEST_LINE "Line 0"
    
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    GdkRectangle rect;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    gtk_text_view_get_visible_rect (GTK_TEXT_VIEW (widget), &rect);
    if (rect.width <= 0)
    {
        TEST_FAIL ("rect.width = %d, should be > 0", rect.width);
    }
    if (rect.height <= 0)
    {
        TEST_FAIL ("rect.height = %d, should be > 0", rect.height);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_visible_rect
 * Params: GtkTextView *text_view, GdkRectangle *location
 * Returns: void
 * Assertion: Fills visible_rect with the currently-visible region of the buffer, in buffer coordinates.
 * Params Values: a newly created GtkTextView*, GdkRectangle *location
 * Expected: void  
 */
static void test_purpose_163()
{
    #define TEST_LINE "Line 0\n Line 1\n"
    
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    GdkRectangle rect;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    gtk_text_view_get_visible_rect (GTK_TEXT_VIEW (widget), &rect);
    if (rect.width <= 0)
    {
        TEST_FAIL ("rect.width = %d, should be > 0", rect.width);
    }
    if (rect.height <= 0)
    {
        TEST_FAIL ("rect.height = %d, should be > 0", rect.height);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_visible_rect
 * Params: GtkTextView *text_view, GdkRectangle *location
 * Returns: void
 * Assertion: Fills visible_rect with the currently-visible region of the buffer, in buffer coordinates.
 * Params Values: a newly created GtkTextView*, GdkRectangle *location
 * Expected: void  
 */
static void test_purpose_164()
{
    #define TEST_LINE "Line 0\n Line 1\n\n\n\nn\n\nerterty\n\n\r"
    
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    GdkRectangle rect;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEST_LINE, strlen(TEST_LINE));
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    gtk_text_view_get_visible_rect (GTK_TEXT_VIEW (widget), &rect);
    if (rect.width <= 0)
    {
        TEST_FAIL ("rect.width = %d, should be > 0", rect.width);
    }
    if (rect.height <= 0)
    {
        TEST_FAIL ("rect.height = %d, should be > 0", rect.height);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEST_LINE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_window
 * Params: GtkTextView *text_view, GtkTextWindowType win
 * Returns: GdkWindow*
 * Assertion: Retrieves the GdkWindow corresponding to an area of the text view; possible windows include the overall widget window, child windows on the left, right, top, bottom, and the window that displays the text buffer.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_WIDGET
 * Expected: GdkWindow* of type GTK_TEXT_WINDOW_WIDGET
 * 
 * Name: gtk_text_view_get_window_type
 * Params: GtkTextView *text_view, GdkWindow *window of type GTK_TEXT_WINDOW_WIDGET
 * Returns: GtkTextWindowType
 * Assertion: Usually used to find out which window an event corresponds to.
 * Params Values: a newly created GtkTextView*, GdkWindow* of type GTK_TEXT_WINDOW_WIDGET
 * Expected: GTK_TEXT_WINDOW_WIDGET  
 */
static void test_purpose_165()
{
    #define TYPE GTK_TEXT_WINDOW_WIDGET
    
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    GdkWindow *window;
    GtkTextWindowType type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, "text", strlen("text"));
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    window = gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE);
    if (!window)
    {
        if (! (TYPE != GTK_TEXT_WINDOW_WIDGET && TYPE != GTK_TEXT_WINDOW_TEXT))
        {
            TEST_FAIL ("'gtk_text_view_get_window' returns NULL", NULL);
        }
    
    } else {
    
        type = gtk_text_view_get_window_type (GTK_TEXT_VIEW (widget), GDK_WINDOW (window));
    
        if (type != TYPE)
        {
            TEST_FAIL ("type is %d, should be %d", type, TYPE);
        }
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_window
 * Params: GtkTextView *text_view, GtkTextWindowType win
 * Returns: GdkWindow*
 * Assertion: Retrieves the GdkWindow corresponding to an area of the text view; possible windows include the overall widget window, child windows on the left, right, top, bottom, and the window that displays the text buffer.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TEXT
 * Expected: GdkWindow* of type GTK_TEXT_WINDOW_TEXT
 * 
 * Name: gtk_text_view_get_window_type
 * Params: GtkTextView *text_view, GdkWindow *window of type GTK_TEXT_WINDOW_TEXT
 * Returns: GtkTextWindowType
 * Assertion: Usually used to find out which window an event corresponds to.
 * Params Values: a newly created GtkTextView*, GdkWindow* of type GTK_TEXT_WINDOW_TEXT
 * Expected: GTK_TEXT_WINDOW_TEXT  
 */
static void test_purpose_166()
{
    #define TYPE GTK_TEXT_WINDOW_TEXT
    
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    GdkWindow *window;
    GtkTextWindowType type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, "text", strlen("text"));
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    window = gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE);
    if (!window)
    {
        if (! (TYPE != GTK_TEXT_WINDOW_WIDGET && TYPE != GTK_TEXT_WINDOW_TEXT))
        {
            TEST_FAIL ("'gtk_text_view_get_window' returns NULL", NULL);
        }
    
    } else {
    
        type = gtk_text_view_get_window_type (GTK_TEXT_VIEW (widget), GDK_WINDOW (window));
    
        if (type != TYPE)
        {
            TEST_FAIL ("type is %d, should be %d", type, TYPE);
        }
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_window
 * Params: GtkTextView *text_view, GtkTextWindowType win
 * Returns: GdkWindow*
 * Assertion: Retrieves the GdkWindow corresponding to an area of the text view; possible windows include the overall widget window, child windows on the left, right, top, bottom, and the window that displays the text buffer.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_LEFT
 * Expected: GdkWindow* of type GTK_TEXT_WINDOW_LEFT
 * 
 * Name: gtk_text_view_get_window_type
 * Params: GtkTextView *text_view, GdkWindow *window of type GTK_TEXT_WINDOW_LEFT
 * Returns: GtkTextWindowType
 * Assertion: Usually used to find out which window an event corresponds to.
 * Params Values: a newly created GtkTextView*, GdkWindow* of type GTK_TEXT_WINDOW_LEFT
 * Expected: GTK_TEXT_WINDOW_LEFT  
 */
static void test_purpose_167()
{
    #define TYPE GTK_TEXT_WINDOW_LEFT
    
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    GdkWindow *window;
    GtkTextWindowType type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, "text", strlen("text"));
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    window = gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE);
    if (!window)
    {
        if (! (TYPE != GTK_TEXT_WINDOW_WIDGET && TYPE != GTK_TEXT_WINDOW_TEXT))
        {
            TEST_FAIL ("'gtk_text_view_get_window' returns NULL", NULL);
        }
    
    } else {
    
        type = gtk_text_view_get_window_type (GTK_TEXT_VIEW (widget), GDK_WINDOW (window));
    
        if (type != TYPE)
        {
            TEST_FAIL ("type is %d, should be %d", type, TYPE);
        }
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_window
 * Params: GtkTextView *text_view, GtkTextWindowType win
 * Returns: GdkWindow*
 * Assertion: Retrieves the GdkWindow corresponding to an area of the text view; possible windows include the overall widget window, child windows on the left, right, top, bottom, and the window that displays the text buffer.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_RIGHT
 * Expected: GdkWindow* of type GTK_TEXT_WINDOW_RIGHT
 * 
 * Name: gtk_text_view_get_window_type
 * Params: GtkTextView *text_view, GdkWindow *window of type GTK_TEXT_WINDOW_RIGHT
 * Returns: GtkTextWindowType
 * Assertion: Usually used to find out which window an event corresponds to.
 * Params Values: a newly created GtkTextView*, GdkWindow* of type GTK_TEXT_WINDOW_RIGHT
 * Expected: GTK_TEXT_WINDOW_RIGHT  
 */
static void test_purpose_168()
{
    #define TYPE GTK_TEXT_WINDOW_RIGHT
    
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    GdkWindow *window;
    GtkTextWindowType type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, "text", strlen("text"));
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    window = gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE);
    if (!window)
    {
        if (! (TYPE != GTK_TEXT_WINDOW_WIDGET && TYPE != GTK_TEXT_WINDOW_TEXT))
        {
            TEST_FAIL ("'gtk_text_view_get_window' returns NULL", NULL);
        }
    
    } else {
    
        type = gtk_text_view_get_window_type (GTK_TEXT_VIEW (widget), GDK_WINDOW (window));
    
        if (type != TYPE)
        {
            TEST_FAIL ("type is %d, should be %d", type, TYPE);
        }
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_window
 * Params: GtkTextView *text_view, GtkTextWindowType win
 * Returns: GdkWindow*
 * Assertion: Retrieves the GdkWindow corresponding to an area of the text view; possible windows include the overall widget window, child windows on the left, right, top, bottom, and the window that displays the text buffer.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TOP
 * Expected: GdkWindow* of type GTK_TEXT_WINDOW_TOP
 * 
 * Name: gtk_text_view_get_window_type
 * Params: GtkTextView *text_view, GdkWindow *window of type GTK_TEXT_WINDOW_TOP
 * Returns: GtkTextWindowType
 * Assertion: Usually used to find out which window an event corresponds to.
 * Params Values: a newly created GtkTextView*, GdkWindow* of type GTK_TEXT_WINDOW_TOP
 * Expected: GTK_TEXT_WINDOW_TOP  
 */
static void test_purpose_169()
{
    #define TYPE GTK_TEXT_WINDOW_TOP
    
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    GdkWindow *window;
    GtkTextWindowType type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, "text", strlen("text"));
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    window = gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE);
    if (!window)
    {
        if (! (TYPE != GTK_TEXT_WINDOW_WIDGET && TYPE != GTK_TEXT_WINDOW_TEXT))
        {
            TEST_FAIL ("'gtk_text_view_get_window' returns NULL", NULL);
        }
    
    } else {
    
        type = gtk_text_view_get_window_type (GTK_TEXT_VIEW (widget), GDK_WINDOW (window));
    
        if (type != TYPE)
        {
            TEST_FAIL ("type is %d, should be %d", type, TYPE);
        }
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_window
 * Params: GtkTextView *text_view, GtkTextWindowType win
 * Returns: GdkWindow*
 * Assertion: Retrieves the GdkWindow corresponding to an area of the text view; possible windows include the overall widget window, child windows on the left, right, top, bottom, and the window that displays the text buffer.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM
 * Expected: GdkWindow* of type GTK_TEXT_WINDOW_BOTTOM
 * 
 * Name: gtk_text_view_get_window_type
 * Params: GtkTextView *text_view, GdkWindow *window of type GTK_TEXT_WINDOW_BOTTOM
 * Returns: GtkTextWindowType
 * Assertion: Usually used to find out which window an event corresponds to.
 * Params Values: a newly created GtkTextView*, GdkWindow* of type GTK_TEXT_WINDOW_BOTTOM
 * Expected: GTK_TEXT_WINDOW_BOTTOM  
 */
static void test_purpose_170()
{
    #define TYPE GTK_TEXT_WINDOW_BOTTOM
    
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *scrolled_window;
    GdkWindow *window;
    GtkTextWindowType type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, "text", strlen("text"));
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    window = gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE);
    if (!window)
    {
        if (! (TYPE != GTK_TEXT_WINDOW_WIDGET && TYPE != GTK_TEXT_WINDOW_TEXT))
        {
            TEST_FAIL ("'gtk_text_view_get_window' returns NULL", NULL);
        }
    
    } else {
    
        type = gtk_text_view_get_window_type (GTK_TEXT_VIEW (widget), GDK_WINDOW (window));
    
        if (type != TYPE)
        {
            TEST_FAIL ("type is %d, should be %d", type, TYPE);
        }
    }
    
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_window
 * Params: GtkTextView *text_view, GtkTextWindowType win
 * Returns: GdkWindow*
 * Assertion: Windows are NULL and nonexistent if their width or height is 0, and are nonexistent before the widget has been realized.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_LEFT
 * Expected: NULL  
 */
static void test_purpose_171()
{
    #define TYPE GTK_TEXT_WINDOW_LEFT
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 5);
    
    if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
    {
        TEST_FAIL ("1: gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for not yet realized window", NULL);
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 0);
    
    if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
    {
        TEST_FAIL ("2: gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for not yet realized window with size = 0", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
    {
        TEST_FAIL ("3: gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for border window size = 0", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_window
 * Params: GtkTextView *text_view, GtkTextWindowType win
 * Returns: GdkWindow*
 * Assertion: Windows are NULL and nonexistent if their width or height is 0, and are nonexistent before the widget has been realized.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_RIGHT
 * Expected: NULL  
 */
static void test_purpose_172()
{
    #define TYPE GTK_TEXT_WINDOW_RIGHT
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 5);
    
    if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
    {
        TEST_FAIL ("1: gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for not yet realized window", NULL);
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 0);
    
    if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
    {
        TEST_FAIL ("2: gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for not yet realized window with size = 0", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
    {
        TEST_FAIL ("3: gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for border window size = 0", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_window
 * Params: GtkTextView *text_view, GtkTextWindowType win
 * Returns: GdkWindow*
 * Assertion: Windows are NULL and nonexistent if their width or height is 0, and are nonexistent before the widget has been realized.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_TOP
 * Expected: NULL  
 */
static void test_purpose_173()
{
    #define TYPE GTK_TEXT_WINDOW_TOP
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 5);
    
    if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
    {
        TEST_FAIL ("1: gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for not yet realized window", NULL);
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 0);
    
    if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
    {
        TEST_FAIL ("2: gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for not yet realized window with size = 0", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
    {
        TEST_FAIL ("3: gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for border window size = 0", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_get_window
 * Params: GtkTextView *text_view, GtkTextWindowType win
 * Returns: GdkWindow*
 * Assertion: Windows are NULL and nonexistent if their width or height is 0, and are nonexistent before the widget has been realized.
 * Params Values: a newly created GtkTextView*, GTK_TEXT_WINDOW_BOTTOM
 * Expected: NULL  
 */
static void test_purpose_174()
{
    #define TYPE GTK_TEXT_WINDOW_BOTTOM
    
    GtkWidget *widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 5);
    
    if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
    {
        TEST_FAIL ("1: gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for not yet realized window", NULL);
    }
    
    gtk_text_view_set_border_window_size (GTK_TEXT_VIEW (widget), TYPE, 0);
    
    if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
    {
        TEST_FAIL ("2: gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for not yet realized window with size = 0", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE))
    {
        TEST_FAIL ("3: gtk_text_view_get_window (GTK_TEXT_VIEW (widget), TYPE) returned not NULL for border window size = 0", NULL);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_child_anchor_new
 * Params: void
 * Returns: GtkTextChildAnchor* anchor
 * Assertion: Creates a new GtkTextChildAnchor
 * Params Values: void
 * Expected: GtkTextChildAnchor* anchor  
 */
static void test_purpose_175()
{
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *window;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextChildAnchor* anchor;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, "Test line", -1);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, 0);
    
    anchor = gtk_text_child_anchor_new ();
    if (!anchor)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (!GTK_IS_TEXT_CHILD_ANCHOR (anchor))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_child_anchor_get_deleted
 * Params: GtkTextChildAnchor* anchor
 * Returns: gboolean
 * Assertion: Determines whether a child anchor has been deleted from the buffer.
 * Params Values: GtkTextChildAnchor* anchor
 * Expected: gboolean  
 */
static void test_purpose_176()
{
    #define DELETE TRUE
    
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *window;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextChildAnchor* anchor;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, "Test line", -1);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, 0);
    
    anchor = gtk_text_child_anchor_new ();
    if (!anchor)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    g_object_ref (G_OBJECT (anchor));
    gtk_text_buffer_insert_child_anchor (buffer, &start, anchor);
    
    if (DELETE)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &start, 0);
        gtk_text_buffer_get_iter_at_offset (buffer, &end, 1);
        gtk_text_buffer_delete (buffer, &start, &end);
    }
    
    
    if (gtk_text_child_anchor_get_deleted (anchor) != DELETE)
    {
        TEST_FAIL ("'gtk_text_child_anchor_get_deleted' returns %i, should be %i", !DELETE, DELETE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef DELETE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_child_anchor_get_deleted
 * Params: GtkTextChildAnchor* anchor
 * Returns: gboolean
 * Assertion: Determines whether a child anchor has been deleted from the buffer.
 * Params Values: GtkTextChildAnchor* anchor
 * Expected: gboolean  
 */
static void test_purpose_177()
{
    #define DELETE FALSE
    
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkWidget *window;
    GtkTextIter start;
    GtkTextIter end;
    GtkTextChildAnchor* anchor;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, "Test line", -1);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, 0);
    
    anchor = gtk_text_child_anchor_new ();
    if (!anchor)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    g_object_ref (G_OBJECT (anchor));
    gtk_text_buffer_insert_child_anchor (buffer, &start, anchor);
    
    if (DELETE)
    {
        gtk_text_buffer_get_iter_at_offset (buffer, &start, 0);
        gtk_text_buffer_get_iter_at_offset (buffer, &end, 1);
        gtk_text_buffer_delete (buffer, &start, &end);
    }
    
    
    if (gtk_text_child_anchor_get_deleted (anchor) != DELETE)
    {
        TEST_FAIL ("'gtk_text_child_anchor_get_deleted' returns %i, should be %i", !DELETE, DELETE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef DELETE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_child_anchor_get_widgets
 * Params: GtkTextChildAnchor* anchor
 * Returns: GList*
 * Assertion: Gets a list of all widgets anchored at this child anchor
 * Params Values: GtkTextChildAnchor* anchor
 * Expected: GList*  
 */
static void test_purpose_178()
{
    #define WIDGETS FALSE
    
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkTextIter start;
    GtkTextChildAnchor* anchor;
    GList* list;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, "Test line", -1);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, 0);
    
    anchor = gtk_text_buffer_create_child_anchor (buffer, &start);
    if (!anchor)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (WIDGETS)
    {
        gtk_text_view_add_child_at_anchor (GTK_TEXT_VIEW (widget), 
                                           gtk_label_new ("label"), 
                                           anchor);
    }
    list = gtk_text_child_anchor_get_widgets (anchor);
    
    if (WIDGETS)
    {
        if (!list)
        {
            TEST_FAIL ("WIDGETS is not NULL, so gtk_text_child_anchor_get_widgets() returns NULL", NULL);
            return;
        }
        if (g_list_length (list) != 1)
        {
            TEST_FAIL ("list length should be 1", NULL);
        }
        g_list_free (list);
    } else {
        if (list)
        {
            TEST_FAIL ("WIDGETS is NULL, so gtk_text_child_anchor_get_widgets() should return NULL", NULL);
            g_list_free (list);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_child_anchor_get_widgets
 * Params: GtkTextChildAnchor* anchor
 * Returns: GList*
 * Assertion: Gets a list of all widgets anchored at this child anchor
 * Params Values: GtkTextChildAnchor* anchor
 * Expected: GList*  
 */
static void test_purpose_179()
{
    #define WIDGETS TRUE
    
    GtkTextBuffer* buffer;
    GtkWidget *widget;
    GtkTextIter start;
    GtkTextChildAnchor* anchor;
    GList* list;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, "Test line", -1);
    gtk_text_buffer_get_iter_at_offset (buffer, &start, 0);
    
    anchor = gtk_text_buffer_create_child_anchor (buffer, &start);
    if (!anchor)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    if (WIDGETS)
    {
        gtk_text_view_add_child_at_anchor (GTK_TEXT_VIEW (widget), 
                                           gtk_label_new ("label"), 
                                           anchor);
    }
    list = gtk_text_child_anchor_get_widgets (anchor);
    
    if (WIDGETS)
    {
        if (!list)
        {
            TEST_FAIL ("WIDGETS is not NULL, so gtk_text_child_anchor_get_widgets() returns NULL", NULL);
            return;
        }
        if (g_list_length (list) != 1)
        {
            TEST_FAIL ("list length should be 1", NULL);
        }
        g_list_free (list);
    } else {
        if (list)
        {
            TEST_FAIL ("WIDGETS is NULL, so gtk_text_child_anchor_get_widgets() should return NULL", NULL);
            g_list_free (list);
        }
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef WIDGETS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_add_child_in_window
 * Params: GtkTextView* text_view, GtkWidget* child, GtkTextWindowType which_window, gint xpos, gint ypos 
 * Returns: void
 * Assertion: Adds a child at fixed coordinates in one of the text widget's windows'
 * Params Values: GtkTextView* text_view, gtk_entry_new () , GTK_TEXT_WINDOW_WIDGET, 0, 0
 * Expected: void  
 */
static void test_purpose_180()
{
    #define CHILD gtk_entry_new () 
    #define TYPE GTK_TEXT_WINDOW_WIDGET
    #define XPOS 0
    #define YPOS 0
    
    GtkWidget* widget;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child = gtk_text_view_new  ();
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_add_child_in_window (GTK_TEXT_VIEW (widget), child, TYPE, XPOS, YPOS);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef TYPE
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_add_child_in_window
 * Params: GtkTextView* text_view, GtkWidget* child, GtkTextWindowType which_window, gint xpos, gint ypos 
 * Returns: void
 * Assertion: Adds a child at fixed coordinates in one of the text widget's windows'
 * Params Values: GtkTextView* text_view, gtk_button_new_with_label ("Button") , GTK_TEXT_WINDOW_TEXT, 10, 10
 * Expected: void  
 */
static void test_purpose_181()
{
    #define CHILD gtk_button_new_with_label ("Button") 
    #define TYPE GTK_TEXT_WINDOW_TEXT
    #define XPOS 10
    #define YPOS 10
    
    GtkWidget* widget;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child = gtk_text_view_new  ();
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_add_child_in_window (GTK_TEXT_VIEW (widget), child, TYPE, XPOS, YPOS);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef TYPE
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_add_child_in_window
 * Params: GtkTextView* text_view, GtkWidget* child, GtkTextWindowType which_window, gint xpos, gint ypos 
 * Returns: void
 * Assertion: Adds a child at fixed coordinates in one of the text widget's windows'
 * Params Values: GtkTextView* text_view, gtk_label_new ("Label") , GTK_TEXT_WINDOW_LEFT, 10, 10
 * Expected: void  
 */
static void test_purpose_182()
{
    #define CHILD gtk_label_new ("Label") 
    #define TYPE GTK_TEXT_WINDOW_LEFT
    #define XPOS 10
    #define YPOS 10
    
    GtkWidget* widget;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child = gtk_text_view_new  ();
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_add_child_in_window (GTK_TEXT_VIEW (widget), child, TYPE, XPOS, YPOS);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef TYPE
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_add_child_in_window
 * Params: GtkTextView* text_view, GtkWidget* child, GtkTextWindowType which_window, gint xpos, gint ypos 
 * Returns: void
 * Assertion: Adds a child at fixed coordinates in one of the text widget's windows'
 * Params Values: GtkTextView* text_view, gtk_check_button_new_with_label ("Button") , GTK_TEXT_WINDOW_RIGHT, 0, 0
 * Expected: void  
 */
static void test_purpose_183()
{
    #define CHILD gtk_check_button_new_with_label ("Button") 
    #define TYPE GTK_TEXT_WINDOW_RIGHT
    #define XPOS 0
    #define YPOS 0
    
    GtkWidget* widget;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child = gtk_text_view_new  ();
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_add_child_in_window (GTK_TEXT_VIEW (widget), child, TYPE, XPOS, YPOS);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef TYPE
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_add_child_in_window
 * Params: GtkTextView* text_view, GtkWidget* child, GtkTextWindowType which_window, gint xpos, gint ypos 
 * Returns: void
 * Assertion: Adds a child at fixed coordinates in one of the text widget's windows'
 * Params Values: GtkTextView* text_view, gtk_button_new_with_label ("Button") , GTK_TEXT_WINDOW_TOP, 0, 0
 * Expected: void  
 */
static void test_purpose_184()
{
    #define CHILD gtk_button_new_with_label ("Button") 
    #define TYPE GTK_TEXT_WINDOW_TOP
    #define XPOS 0
    #define YPOS 0
    
    GtkWidget* widget;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child = gtk_text_view_new  ();
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_add_child_in_window (GTK_TEXT_VIEW (widget), child, TYPE, XPOS, YPOS);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef TYPE
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_add_child_in_window
 * Params: GtkTextView* text_view, GtkWidget* child, GtkTextWindowType which_window, gint xpos, gint ypos 
 * Returns: void
 * Assertion: Adds a child at fixed coordinates in one of the text widget's windows'
 * Params Values: GtkTextView* text_view, gtk_button_new_with_label ("Button") , GTK_TEXT_WINDOW_BOTTOM, 0, 0
 * Expected: void  
 */
static void test_purpose_185()
{
    #define CHILD gtk_button_new_with_label ("Button") 
    #define TYPE GTK_TEXT_WINDOW_BOTTOM
    #define XPOS 0
    #define YPOS 0
    
    GtkWidget* widget;
    GtkWidget* child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child = gtk_text_view_new  ();
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_add_child_in_window (GTK_TEXT_VIEW (widget), child, TYPE, XPOS, YPOS);
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef TYPE
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_add_child_at_anchor
 * Params: GtkTextView* text_view, GtkWidget* child, GtkTextChildAnchor* anchor
 * Returns: void
 * Assertion: Adds a child widget in the text buffer, at the given anchor.
 * Params Values: GtkTextView* text_view, GtkWidget* child, GtkTextChildAnchor* anchor
 * Expected: void  
 */
static void test_purpose_186()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define CHILD gtk_entry_new () 
    #define LINE 0
    #define OFFS 0
    
    GtkTextBuffer* buffer;
    GtkTextChildAnchor* anchor;
    GtkWidget* widget;
    GtkWidget* child;
    GtkTextIter start;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    anchor = gtk_text_child_anchor_new ();
    if (!anchor)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_insert_child_anchor (buffer, &start, anchor);
    gtk_text_view_add_child_at_anchor (GTK_TEXT_VIEW (widget), child, anchor);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    /* LSB bug 2731 - test crashes at destroy when the child is a gtk_entry
       on some systems, destroy the child first as a workaround */
    gtk_widget_destroy (child);
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef CHILD
    #undef LINE
    #undef OFFS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_add_child_at_anchor
 * Params: GtkTextView* text_view, GtkWidget* child, GtkTextChildAnchor* anchor
 * Returns: void
 * Assertion: Adds a child widget in the text buffer, at the given anchor.
 * Params Values: GtkTextView* text_view, GtkWidget* child, GtkTextChildAnchor* anchor
 * Expected: void  
 */
static void test_purpose_187()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define CHILD gtk_button_new_with_label ("Button") 
    #define LINE 0
    #define OFFS 5
    
    GtkTextBuffer* buffer;
    GtkTextChildAnchor* anchor;
    GtkWidget* widget;
    GtkWidget* child;
    GtkTextIter start;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    anchor = gtk_text_child_anchor_new ();
    if (!anchor)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_insert_child_anchor (buffer, &start, anchor);
    gtk_text_view_add_child_at_anchor (GTK_TEXT_VIEW (widget), child, anchor);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    /* LSB bug 2731 - test crashes at destroy when the child is a gtk_entry
       on some systems, destroy the child first as a workaround */
    gtk_widget_destroy (child);
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef CHILD
    #undef LINE
    #undef OFFS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_add_child_at_anchor
 * Params: GtkTextView* text_view, GtkWidget* child, GtkTextChildAnchor* anchor
 * Returns: void
 * Assertion: Adds a child widget in the text buffer, at the given anchor.
 * Params Values: GtkTextView* text_view, GtkWidget* child, GtkTextChildAnchor* anchor
 * Expected: void  
 */
static void test_purpose_188()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define CHILD gtk_label_new ("Label") 
    #define LINE 5
    #define OFFS 0
    
    GtkTextBuffer* buffer;
    GtkTextChildAnchor* anchor;
    GtkWidget* widget;
    GtkWidget* child;
    GtkTextIter start;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    anchor = gtk_text_child_anchor_new ();
    if (!anchor)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_insert_child_anchor (buffer, &start, anchor);
    gtk_text_view_add_child_at_anchor (GTK_TEXT_VIEW (widget), child, anchor);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    /* LSB bug 2731 - test crashes at destroy when the child is a gtk_entry
       on some systems, destroy the child first as a workaround */
    gtk_widget_destroy (child);
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef CHILD
    #undef LINE
    #undef OFFS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_add_child_at_anchor
 * Params: GtkTextView* text_view, GtkWidget* child, GtkTextChildAnchor* anchor
 * Returns: void
 * Assertion: Adds a child widget in the text buffer, at the given anchor.
 * Params Values: GtkTextView* text_view, GtkWidget* child, GtkTextChildAnchor* anchor
 * Expected: void  
 */
static void test_purpose_189()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define CHILD gtk_check_button_new_with_label ("Button") 
    #define LINE 5
    #define OFFS 5
    
    GtkTextBuffer* buffer;
    GtkTextChildAnchor* anchor;
    GtkWidget* widget;
    GtkWidget* child;
    GtkTextIter start;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    anchor = gtk_text_child_anchor_new ();
    if (!anchor)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_insert_child_anchor (buffer, &start, anchor);
    gtk_text_view_add_child_at_anchor (GTK_TEXT_VIEW (widget), child, anchor);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    /* LSB bug 2731 - test crashes at destroy when the child is a gtk_entry
       on some systems, destroy the child first as a workaround */
    gtk_widget_destroy (child);
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef CHILD
    #undef LINE
    #undef OFFS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_add_child_at_anchor
 * Params: GtkTextView* text_view, GtkWidget* child, GtkTextChildAnchor* anchor
 * Returns: void
 * Assertion: Adds a child widget in the text buffer, at the given anchor.
 * Params Values: GtkTextView* text_view, GtkWidget* child, GtkTextChildAnchor* anchor
 * Expected: void  
 */
static void test_purpose_190()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define CHILD gtk_button_new_with_label ("Button") 
    #define LINE 1
    #define OFFS 2
    
    GtkTextBuffer* buffer;
    GtkTextChildAnchor* anchor;
    GtkWidget* widget;
    GtkWidget* child;
    GtkTextIter start;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    anchor = gtk_text_child_anchor_new ();
    if (!anchor)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_insert_child_anchor (buffer, &start, anchor);
    gtk_text_view_add_child_at_anchor (GTK_TEXT_VIEW (widget), child, anchor);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    /* LSB bug 2731 - test crashes at destroy when the child is a gtk_entry
       on some systems, destroy the child first as a workaround */
    gtk_widget_destroy (child);
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef CHILD
    #undef LINE
    #undef OFFS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_add_child_at_anchor
 * Params: GtkTextView* text_view, GtkWidget* child, GtkTextChildAnchor* anchor
 * Returns: void
 * Assertion: Adds a child widget in the text buffer, at the given anchor.
 * Params Values: GtkTextView* text_view, GtkWidget* child, GtkTextChildAnchor* anchor
 * Expected: void  
 */
static void test_purpose_191()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n "
    #define CHILD gtk_button_new_with_label ("Button") 
    #define LINE 2
    #define OFFS 3
    
    GtkTextBuffer* buffer;
    GtkTextChildAnchor* anchor;
    GtkWidget* widget;
    GtkWidget* child;
    GtkTextIter start;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    child = CHILD;
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    anchor = gtk_text_child_anchor_new ();
    if (!anchor)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    gtk_text_buffer_insert_child_anchor (buffer, &start, anchor);
    gtk_text_view_add_child_at_anchor (GTK_TEXT_VIEW (widget), child, anchor);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    /* LSB bug 2731 - test crashes at destroy when the child is a gtk_entry
       on some systems, destroy the child first as a workaround */
    gtk_widget_destroy (child);
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef CHILD
    #undef LINE
    #undef OFFS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_move_child
 * Params: GtkTextView* text_view, GtkWidget* child, gint xpos, gint ypos 
 * Returns: void
 * Assertion: Updates the position of a child, as for gtk_text_view_add_child_in_window().
 * Params Values: GtkTextView* text_view, gtk_entry_new () , 0, 0, 
 * Expected: void  
 */
static void test_purpose_192()
{
    #define CHILD gtk_entry_new () 
    #define TYPE GTK_TEXT_WINDOW_WIDGET
    #define XPOS 0
    #define YPOS 0
    
    GtkWidget* widget;
    GtkWidget* child;
    GtkTextIter start;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child = gtk_text_view_new  ();
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_add_child_in_window (GTK_TEXT_VIEW (widget), child, TYPE, 0, 0);
    gtk_text_view_move_child (GTK_TEXT_VIEW (widget), child, XPOS, YPOS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef TYPE
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_move_child
 * Params: GtkTextView* text_view, GtkWidget* child, gint xpos, gint ypos 
 * Returns: void
 * Assertion: Updates the position of a child, as for gtk_text_view_add_child_in_window().
 * Params Values: GtkTextView* text_view, gtk_button_new_with_label ("Button") , 10, 10, 
 * Expected: void  
 */
static void test_purpose_193()
{
    #define CHILD gtk_button_new_with_label ("Button") 
    #define TYPE GTK_TEXT_WINDOW_TEXT
    #define XPOS 10
    #define YPOS 10
    
    GtkWidget* widget;
    GtkWidget* child;
    GtkTextIter start;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child = gtk_text_view_new  ();
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_add_child_in_window (GTK_TEXT_VIEW (widget), child, TYPE, 0, 0);
    gtk_text_view_move_child (GTK_TEXT_VIEW (widget), child, XPOS, YPOS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef TYPE
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_move_child
 * Params: GtkTextView* text_view, GtkWidget* child, gint xpos, gint ypos 
 * Returns: void
 * Assertion: Updates the position of a child, as for gtk_text_view_add_child_in_window().
 * Params Values: GtkTextView* text_view, gtk_label_new ("Label") , 10, 10, 
 * Expected: void  
 */
static void test_purpose_194()
{
    #define CHILD gtk_label_new ("Label") 
    #define TYPE GTK_TEXT_WINDOW_LEFT
    #define XPOS 10
    #define YPOS 10
    
    GtkWidget* widget;
    GtkWidget* child;
    GtkTextIter start;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child = gtk_text_view_new  ();
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_add_child_in_window (GTK_TEXT_VIEW (widget), child, TYPE, 0, 0);
    gtk_text_view_move_child (GTK_TEXT_VIEW (widget), child, XPOS, YPOS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef TYPE
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_move_child
 * Params: GtkTextView* text_view, GtkWidget* child, gint xpos, gint ypos 
 * Returns: void
 * Assertion: Updates the position of a child, as for gtk_text_view_add_child_in_window().
 * Params Values: GtkTextView* text_view, gtk_check_button_new_with_label ("Button") , 0, 0, 
 * Expected: void  
 */
static void test_purpose_195()
{
    #define CHILD gtk_check_button_new_with_label ("Button") 
    #define TYPE GTK_TEXT_WINDOW_RIGHT
    #define XPOS 0
    #define YPOS 0
    
    GtkWidget* widget;
    GtkWidget* child;
    GtkTextIter start;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child = gtk_text_view_new  ();
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_add_child_in_window (GTK_TEXT_VIEW (widget), child, TYPE, 0, 0);
    gtk_text_view_move_child (GTK_TEXT_VIEW (widget), child, XPOS, YPOS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef TYPE
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_move_child
 * Params: GtkTextView* text_view, GtkWidget* child, gint xpos, gint ypos 
 * Returns: void
 * Assertion: Updates the position of a child, as for gtk_text_view_add_child_in_window().
 * Params Values: GtkTextView* text_view, gtk_button_new_with_label ("Button") , 0, 0, 
 * Expected: void  
 */
static void test_purpose_196()
{
    #define CHILD gtk_button_new_with_label ("Button") 
    #define TYPE GTK_TEXT_WINDOW_TOP
    #define XPOS 0
    #define YPOS 0
    
    GtkWidget* widget;
    GtkWidget* child;
    GtkTextIter start;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child = gtk_text_view_new  ();
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_add_child_in_window (GTK_TEXT_VIEW (widget), child, TYPE, 0, 0);
    gtk_text_view_move_child (GTK_TEXT_VIEW (widget), child, XPOS, YPOS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef TYPE
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_move_child
 * Params: GtkTextView* text_view, GtkWidget* child, gint xpos, gint ypos 
 * Returns: void
 * Assertion: Updates the position of a child, as for gtk_text_view_add_child_in_window().
 * Params Values: GtkTextView* text_view, gtk_button_new_with_label ("Button") , 0, 0, 
 * Expected: void  
 */
static void test_purpose_197()
{
    #define CHILD gtk_button_new_with_label ("Button") 
    #define TYPE GTK_TEXT_WINDOW_BOTTOM
    #define XPOS 0
    #define YPOS 0
    
    GtkWidget* widget;
    GtkWidget* child;
    GtkTextIter start;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    child = gtk_text_view_new  ();
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_add_child_in_window (GTK_TEXT_VIEW (widget), child, TYPE, 0, 0);
    gtk_text_view_move_child (GTK_TEXT_VIEW (widget), child, XPOS, YPOS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef CHILD
    #undef TYPE
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_scroll_mark_onscreen
 * Params: GtkTextView *text_view, GtkTextMark *mark
 * Returns: void
 * Assertion: Scrolls text_view the minimum distance such that mark is contained within the visible area of the widget.
 * Params Values: GtkTextView *text_view, GtkTextMark *mark
 * Expected: void  
 */
static void test_purpose_198()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n "
    #define LINE 49
    #define OFFS 4
    
    GtkTextBuffer* buffer;
    GtkTextMark* mark;
    GtkWidget* widget;
    GtkTextIter start;
    GtkTextIter end;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    mark = gtk_text_buffer_create_mark (buffer, "Mark", &start, TRUE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (widget), mark);
    gtk_text_buffer_get_iter_at_mark (buffer, &end, mark);
    
    if (!gtk_text_iter_equal (&start, &end))
    {
        TEST_FAIL ("start = (%i, %i), end = (%i, %i)",   
            gtk_text_iter_get_line (&start), gtk_text_iter_get_line_offset (&start),  
            gtk_text_iter_get_line (&end), gtk_text_iter_get_line_offset (&end));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_scroll_mark_onscreen
 * Params: GtkTextView *text_view, GtkTextMark *mark
 * Returns: void
 * Assertion: Scrolls text_view the minimum distance such that mark is contained within the visible area of the widget.
 * Params Values: GtkTextView *text_view, GtkTextMark *mark
 * Expected: void  
 */
static void test_purpose_199()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n "
    #define LINE 0
    #define OFFS 0
    
    GtkTextBuffer* buffer;
    GtkTextMark* mark;
    GtkWidget* widget;
    GtkTextIter start;
    GtkTextIter end;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    mark = gtk_text_buffer_create_mark (buffer, "Mark", &start, TRUE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (widget), mark);
    gtk_text_buffer_get_iter_at_mark (buffer, &end, mark);
    
    if (!gtk_text_iter_equal (&start, &end))
    {
        TEST_FAIL ("start = (%i, %i), end = (%i, %i)",   
            gtk_text_iter_get_line (&start), gtk_text_iter_get_line_offset (&start),  
            gtk_text_iter_get_line (&end), gtk_text_iter_get_line_offset (&end));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_scroll_mark_onscreen
 * Params: GtkTextView *text_view, GtkTextMark *mark
 * Returns: void
 * Assertion: Scrolls text_view the minimum distance such that mark is contained within the visible area of the widget.
 * Params Values: GtkTextView *text_view, GtkTextMark *mark
 * Expected: void  
 */
static void test_purpose_200()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n "
    #define LINE 4
    #define OFFS 4
    
    GtkTextBuffer* buffer;
    GtkTextMark* mark;
    GtkWidget* widget;
    GtkTextIter start;
    GtkTextIter end;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, LINE, OFFS);
    mark = gtk_text_buffer_create_mark (buffer, "Mark", &start, TRUE);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (widget), mark);
    gtk_text_buffer_get_iter_at_mark (buffer, &end, mark);
    
    if (!gtk_text_iter_equal (&start, &end))
    {
        TEST_FAIL ("start = (%i, %i), end = (%i, %i)",   
            gtk_text_iter_get_line (&start), gtk_text_iter_get_line_offset (&start),  
            gtk_text_iter_get_line (&end), gtk_text_iter_get_line_offset (&end));
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef LINE
    #undef OFFS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_move_visually
 * Params: GtkTextView *text_view, GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves iter up or down by count display (wrapped) lines.
 * Params Values: GtkTextView *text_view, GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_201()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n "
    #define COUNT 10
    #define LINE 1
    #define OFFS 3
    
    GtkTextBuffer* buffer;
    GtkWidget* widget;
    GtkTextIter start;
    GtkTextIter end;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, 0, 0);
    if (COUNT < 0)
    {
        gtk_text_iter_forward_to_end (&start);
    }
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_move_visually (GTK_TEXT_VIEW (widget), &start, COUNT);
    
    if (!gtk_text_iter_equal (&start, &end))
    {
        TEST_FAIL ("start = (%i, %i), end = (%i, %i), result = %i",   
            gtk_text_iter_get_line (&start), gtk_text_iter_get_line_offset (&start),  
            gtk_text_iter_get_line (&end), gtk_text_iter_get_line_offset (&end),  result);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef COUNT
    #undef LINE
    #undef OFFS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_move_visually
 * Params: GtkTextView *text_view, GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves iter up or down by count display (wrapped) lines.
 * Params Values: GtkTextView *text_view, GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_202()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n "
    #define COUNT 20
    #define LINE 2
    #define OFFS 5
    
    GtkTextBuffer* buffer;
    GtkWidget* widget;
    GtkTextIter start;
    GtkTextIter end;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, 0, 0);
    if (COUNT < 0)
    {
        gtk_text_iter_forward_to_end (&start);
    }
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_move_visually (GTK_TEXT_VIEW (widget), &start, COUNT);
    
    if (!gtk_text_iter_equal (&start, &end))
    {
        TEST_FAIL ("start = (%i, %i), end = (%i, %i), result = %i",   
            gtk_text_iter_get_line (&start), gtk_text_iter_get_line_offset (&start),  
            gtk_text_iter_get_line (&end), gtk_text_iter_get_line_offset (&end),  result);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef COUNT
    #undef LINE
    #undef OFFS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_move_visually
 * Params: GtkTextView *text_view, GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves iter up or down by count display (wrapped) lines.
 * Params Values: GtkTextView *text_view, GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_203()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n "
    #define COUNT 2
    #define LINE 0
    #define OFFS 2
    
    GtkTextBuffer* buffer;
    GtkWidget* widget;
    GtkTextIter start;
    GtkTextIter end;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, 0, 0);
    if (COUNT < 0)
    {
        gtk_text_iter_forward_to_end (&start);
    }
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_move_visually (GTK_TEXT_VIEW (widget), &start, COUNT);
    
    if (!gtk_text_iter_equal (&start, &end))
    {
        TEST_FAIL ("start = (%i, %i), end = (%i, %i), result = %i",   
            gtk_text_iter_get_line (&start), gtk_text_iter_get_line_offset (&start),  
            gtk_text_iter_get_line (&end), gtk_text_iter_get_line_offset (&end),  result);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef COUNT
    #undef LINE
    #undef OFFS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_move_visually
 * Params: GtkTextView *text_view, GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves iter up or down by count display (wrapped) lines.
 * Params Values: GtkTextView *text_view, GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_204()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n "
    #define COUNT -1
    #define LINE 10
    #define OFFS 0
    
    GtkTextBuffer* buffer;
    GtkWidget* widget;
    GtkTextIter start;
    GtkTextIter end;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, 0, 0);
    if (COUNT < 0)
    {
        gtk_text_iter_forward_to_end (&start);
    }
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_move_visually (GTK_TEXT_VIEW (widget), &start, COUNT);
    
    if (!gtk_text_iter_equal (&start, &end))
    {
        TEST_FAIL ("start = (%i, %i), end = (%i, %i), result = %i",   
            gtk_text_iter_get_line (&start), gtk_text_iter_get_line_offset (&start),  
            gtk_text_iter_get_line (&end), gtk_text_iter_get_line_offset (&end),  result);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef COUNT
    #undef LINE
    #undef OFFS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_move_visually
 * Params: GtkTextView *text_view, GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves iter up or down by count display (wrapped) lines.
 * Params Values: GtkTextView *text_view, GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_205()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n"
    #define COUNT -1
    #define LINE 9
    #define OFFS 7
    
    GtkTextBuffer* buffer;
    GtkWidget* widget;
    GtkTextIter start;
    GtkTextIter end;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, 0, 0);
    if (COUNT < 0)
    {
        gtk_text_iter_forward_to_end (&start);
    }
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_move_visually (GTK_TEXT_VIEW (widget), &start, COUNT);
    
    if (!gtk_text_iter_equal (&start, &end))
    {
        TEST_FAIL ("start = (%i, %i), end = (%i, %i), result = %i",   
            gtk_text_iter_get_line (&start), gtk_text_iter_get_line_offset (&start),  
            gtk_text_iter_get_line (&end), gtk_text_iter_get_line_offset (&end),  result);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef COUNT
    #undef LINE
    #undef OFFS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_move_visually
 * Params: GtkTextView *text_view, GtkTextIter* iter, gint count
 * Returns: gboolean
 * Assertion: Moves iter up or down by count display (wrapped) lines.
 * Params Values: GtkTextView *text_view, GtkTextIter* iter, gint count
 * Expected: gboolean  
 */
static void test_purpose_206()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n"
    #define COUNT -2
    #define LINE 9
    #define OFFS 6
    
    GtkTextBuffer* buffer;
    GtkWidget* widget;
    GtkTextIter start;
    GtkTextIter end;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, 0, 0);
    if (COUNT < 0)
    {
        gtk_text_iter_forward_to_end (&start);
    }
    gtk_text_buffer_get_iter_at_line_offset (buffer, &end, LINE, OFFS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    result = gtk_text_view_move_visually (GTK_TEXT_VIEW (widget), &start, COUNT);
    
    if (!gtk_text_iter_equal (&start, &end))
    {
        TEST_FAIL ("start = (%i, %i), end = (%i, %i), result = %i",   
            gtk_text_iter_get_line (&start), gtk_text_iter_get_line_offset (&start),  
            gtk_text_iter_get_line (&end), gtk_text_iter_get_line_offset (&end),  result);
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef COUNT
    #undef LINE
    #undef OFFS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_place_cursor_onscreen
 * Params: GtkTextView *text_view
 * Returns: gboolean
 * Assertion: Moves the cursor to the currently visible region of the buffer, it it isn't there already.'
 * Params Values: GtkTextView *text_view
 * Expected: gboolean  
 */
static void test_purpose_207()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n "
    
    GtkTextBuffer* buffer;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (widget), TRUE);
    
    gtk_text_view_place_cursor_onscreen (GTK_TEXT_VIEW (widget));
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_place_cursor_onscreen
 * Params: GtkTextView *text_view
 * Returns: gboolean
 * Assertion: Moves the cursor to the currently visible region of the buffer, it it isn't there already.'
 * Params Values: GtkTextView *text_view
 * Expected: gboolean  
 */
static void test_purpose_208()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n "
    
    GtkTextBuffer* buffer;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (widget), TRUE);
    
    gtk_text_view_place_cursor_onscreen (GTK_TEXT_VIEW (widget));
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_place_cursor_onscreen
 * Params: GtkTextView *text_view
 * Returns: gboolean
 * Assertion: Moves the cursor to the currently visible region of the buffer, it it isn't there already.'
 * Params Values: GtkTextView *text_view
 * Expected: gboolean  
 */
static void test_purpose_209()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n "
    
    GtkTextBuffer* buffer;
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (widget), TRUE);
    
    gtk_text_view_place_cursor_onscreen (GTK_TEXT_VIEW (widget));
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_scroll_to_iter
 * Params: GtkTextView* text_view, GtkTextIter* iter, gdouble within_margin, gboolean use_align, gdouble xalign, gdouble yalign
 * Returns: gboolean
 * Assertion: Scrolls text_view so that iter is on the screen in the position indicated by xalign and yalign.
 * Params Values: GtkTextView* text_view, GtkTextIter* iter,  0.0, TRUE, 0.0, 0.0
 * Expected: gboolean  
 */
static void test_purpose_210()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n"
    #define MARGIN 0.0
    #define ALIGN  TRUE
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define XPOS 0
    #define YPOS 0
    
    GtkTextBuffer* buffer;
    GtkWidget* widget;
    GtkWidget* scrolled_window;
    GtkTextIter start;
    gboolean result;
    GdkRectangle rect;
    GdkRectangle iter;
    GdkRectangle dest;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, XPOS, YPOS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_scroll_to_iter (GTK_TEXT_VIEW (widget), &start, MARGIN, ALIGN, XALIGN, YALIGN);
    
    gtk_text_view_get_visible_rect  (GTK_TEXT_VIEW (widget), &rect);
    
    gtk_text_view_get_iter_location (GTK_TEXT_VIEW (widget), &start, &iter);
    
    {
          gint dest_x;
          gint dest_y;
          gint dest_w;
          gint dest_h;
    
          dest_x = MAX (iter.x, rect.x);
          dest_y = MAX (iter.y, rect.y);
          dest_w = MIN (iter.x + iter.width, rect.x + rect.width) - dest_x;
          dest_h = MIN (iter.y + iter.height, rect.y + rect.height) - dest_y;
    
          if (dest_w < 0 || dest_h < 0)
          {
              TEST_FAIL ("Iter isn't in visible rectangle of the buffer %i", result);   
              TEST_FAIL ("visible rect = (%d, %d, %d, %d)", rect.x, rect.y, rect.width, rect.height);   
              TEST_FAIL ("iter         = (%d, %d, %d, %d)", iter.x, iter.y, iter.width, iter.height);   
          }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef MARGIN 
    #undef ALIGN  
    #undef XALIGN 
    #undef YALIGN 
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_scroll_to_iter
 * Params: GtkTextView* text_view, GtkTextIter* iter, gdouble within_margin, gboolean use_align, gdouble xalign, gdouble yalign
 * Returns: gboolean
 * Assertion: Scrolls text_view so that iter is on the screen in the position indicated by xalign and yalign.
 * Params Values: GtkTextView* text_view, GtkTextIter* iter,  0.0, FALSE, 0.0, 0.0
 * Expected: gboolean  
 */
static void test_purpose_211()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n"
    #define MARGIN 0.0
    #define ALIGN  FALSE
    #define XALIGN 0.0
    #define YALIGN 0.0
    #define XPOS 0
    #define YPOS 0
    
    GtkTextBuffer* buffer;
    GtkWidget* widget;
    GtkWidget* scrolled_window;
    GtkTextIter start;
    gboolean result;
    GdkRectangle rect;
    GdkRectangle iter;
    GdkRectangle dest;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, XPOS, YPOS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_scroll_to_iter (GTK_TEXT_VIEW (widget), &start, MARGIN, ALIGN, XALIGN, YALIGN);
    
    gtk_text_view_get_visible_rect  (GTK_TEXT_VIEW (widget), &rect);
    
    gtk_text_view_get_iter_location (GTK_TEXT_VIEW (widget), &start, &iter);
    
    {
          gint dest_x;
          gint dest_y;
          gint dest_w;
          gint dest_h;
    
          dest_x = MAX (iter.x, rect.x);
          dest_y = MAX (iter.y, rect.y);
          dest_w = MIN (iter.x + iter.width, rect.x + rect.width) - dest_x;
          dest_h = MIN (iter.y + iter.height, rect.y + rect.height) - dest_y;
    
          if (dest_w < 0 || dest_h < 0)
          {
              TEST_FAIL ("Iter isn't in visible rectangle of the buffer %i", result);   
              TEST_FAIL ("visible rect = (%d, %d, %d, %d)", rect.x, rect.y, rect.width, rect.height);   
              TEST_FAIL ("iter         = (%d, %d, %d, %d)", iter.x, iter.y, iter.width, iter.height);   
          }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef MARGIN 
    #undef ALIGN  
    #undef XALIGN 
    #undef YALIGN 
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_scroll_to_iter
 * Params: GtkTextView* text_view, GtkTextIter* iter, gdouble within_margin, gboolean use_align, gdouble xalign, gdouble yalign
 * Returns: gboolean
 * Assertion: Scrolls text_view so that iter is on the screen in the position indicated by xalign and yalign.
 * Params Values: GtkTextView* text_view, GtkTextIter* iter,  0.0, TRUE, 0.3, 0.3
 * Expected: gboolean  
 */
static void test_purpose_212()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n"
    #define MARGIN 0.0
    #define ALIGN  TRUE
    #define XALIGN 0.3
    #define YALIGN 0.3
    #define XPOS 20
    #define YPOS 2
    
    GtkTextBuffer* buffer;
    GtkWidget* widget;
    GtkWidget* scrolled_window;
    GtkTextIter start;
    gboolean result;
    GdkRectangle rect;
    GdkRectangle iter;
    GdkRectangle dest;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, XPOS, YPOS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_scroll_to_iter (GTK_TEXT_VIEW (widget), &start, MARGIN, ALIGN, XALIGN, YALIGN);
    
    gtk_text_view_get_visible_rect  (GTK_TEXT_VIEW (widget), &rect);
    
    gtk_text_view_get_iter_location (GTK_TEXT_VIEW (widget), &start, &iter);
    
    {
          gint dest_x;
          gint dest_y;
          gint dest_w;
          gint dest_h;
    
          dest_x = MAX (iter.x, rect.x);
          dest_y = MAX (iter.y, rect.y);
          dest_w = MIN (iter.x + iter.width, rect.x + rect.width) - dest_x;
          dest_h = MIN (iter.y + iter.height, rect.y + rect.height) - dest_y;
    
          if (dest_w < 0 || dest_h < 0)
          {
              TEST_FAIL ("Iter isn't in visible rectangle of the buffer %i", result);   
              TEST_FAIL ("visible rect = (%d, %d, %d, %d)", rect.x, rect.y, rect.width, rect.height);   
              TEST_FAIL ("iter         = (%d, %d, %d, %d)", iter.x, iter.y, iter.width, iter.height);   
          }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef MARGIN 
    #undef ALIGN  
    #undef XALIGN 
    #undef YALIGN 
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_scroll_to_iter
 * Params: GtkTextView* text_view, GtkTextIter* iter, gdouble within_margin, gboolean use_align, gdouble xalign, gdouble yalign
 * Returns: gboolean
 * Assertion: Scrolls text_view so that iter is on the screen in the position indicated by xalign and yalign.
 * Params Values: GtkTextView* text_view, GtkTextIter* iter,  0.0, TRUE, 0.5, 0.0
 * Expected: gboolean  
 */
static void test_purpose_213()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n"
    #define MARGIN 0.0
    #define ALIGN  TRUE
    #define XALIGN 0.5
    #define YALIGN 0.0
    #define XPOS 15
    #define YPOS 0
    
    GtkTextBuffer* buffer;
    GtkWidget* widget;
    GtkWidget* scrolled_window;
    GtkTextIter start;
    gboolean result;
    GdkRectangle rect;
    GdkRectangle iter;
    GdkRectangle dest;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, XPOS, YPOS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_scroll_to_iter (GTK_TEXT_VIEW (widget), &start, MARGIN, ALIGN, XALIGN, YALIGN);
    
    gtk_text_view_get_visible_rect  (GTK_TEXT_VIEW (widget), &rect);
    
    gtk_text_view_get_iter_location (GTK_TEXT_VIEW (widget), &start, &iter);
    
    {
          gint dest_x;
          gint dest_y;
          gint dest_w;
          gint dest_h;
    
          dest_x = MAX (iter.x, rect.x);
          dest_y = MAX (iter.y, rect.y);
          dest_w = MIN (iter.x + iter.width, rect.x + rect.width) - dest_x;
          dest_h = MIN (iter.y + iter.height, rect.y + rect.height) - dest_y;
    
          if (dest_w < 0 || dest_h < 0)
          {
              TEST_FAIL ("Iter isn't in visible rectangle of the buffer %i", result);   
              TEST_FAIL ("visible rect = (%d, %d, %d, %d)", rect.x, rect.y, rect.width, rect.height);   
              TEST_FAIL ("iter         = (%d, %d, %d, %d)", iter.x, iter.y, iter.width, iter.height);   
          }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef MARGIN 
    #undef ALIGN  
    #undef XALIGN 
    #undef YALIGN 
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_scroll_to_iter
 * Params: GtkTextView* text_view, GtkTextIter* iter, gdouble within_margin, gboolean use_align, gdouble xalign, gdouble yalign
 * Returns: gboolean
 * Assertion: Scrolls text_view so that iter is on the screen in the position indicated by xalign and yalign.
 * Params Values: GtkTextView* text_view, GtkTextIter* iter,  0.0, TRUE, 0.0, 0.5
 * Expected: gboolean  
 */
static void test_purpose_214()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n"
    #define MARGIN 0.0
    #define ALIGN  TRUE
    #define XALIGN 0.0
    #define YALIGN 0.5
    #define XPOS 6
    #define YPOS 6
    
    GtkTextBuffer* buffer;
    GtkWidget* widget;
    GtkWidget* scrolled_window;
    GtkTextIter start;
    gboolean result;
    GdkRectangle rect;
    GdkRectangle iter;
    GdkRectangle dest;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, XPOS, YPOS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_scroll_to_iter (GTK_TEXT_VIEW (widget), &start, MARGIN, ALIGN, XALIGN, YALIGN);
    
    gtk_text_view_get_visible_rect  (GTK_TEXT_VIEW (widget), &rect);
    
    gtk_text_view_get_iter_location (GTK_TEXT_VIEW (widget), &start, &iter);
    
    {
          gint dest_x;
          gint dest_y;
          gint dest_w;
          gint dest_h;
    
          dest_x = MAX (iter.x, rect.x);
          dest_y = MAX (iter.y, rect.y);
          dest_w = MIN (iter.x + iter.width, rect.x + rect.width) - dest_x;
          dest_h = MIN (iter.y + iter.height, rect.y + rect.height) - dest_y;
    
          if (dest_w < 0 || dest_h < 0)
          {
              TEST_FAIL ("Iter isn't in visible rectangle of the buffer %i", result);   
              TEST_FAIL ("visible rect = (%d, %d, %d, %d)", rect.x, rect.y, rect.width, rect.height);   
              TEST_FAIL ("iter         = (%d, %d, %d, %d)", iter.x, iter.y, iter.width, iter.height);   
          }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef MARGIN 
    #undef ALIGN  
    #undef XALIGN 
    #undef YALIGN 
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_scroll_to_iter
 * Params: GtkTextView* text_view, GtkTextIter* iter, gdouble within_margin, gboolean use_align, gdouble xalign, gdouble yalign
 * Returns: gboolean
 * Assertion: Scrolls text_view so that iter is on the screen in the position indicated by xalign and yalign.
 * Params Values: GtkTextView* text_view, GtkTextIter* iter,  0.0, FALSE, 0.0, 0.5
 * Expected: gboolean  
 */
static void test_purpose_215()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n"
    #define MARGIN 0.0
    #define ALIGN  FALSE
    #define XALIGN 0.0
    #define YALIGN 0.5
    #define XPOS 0
    #define YPOS 0 
    
    GtkTextBuffer* buffer;
    GtkWidget* widget;
    GtkWidget* scrolled_window;
    GtkTextIter start;
    gboolean result;
    GdkRectangle rect;
    GdkRectangle iter;
    GdkRectangle dest;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, XPOS, YPOS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_scroll_to_iter (GTK_TEXT_VIEW (widget), &start, MARGIN, ALIGN, XALIGN, YALIGN);
    
    gtk_text_view_get_visible_rect  (GTK_TEXT_VIEW (widget), &rect);
    
    gtk_text_view_get_iter_location (GTK_TEXT_VIEW (widget), &start, &iter);
    
    {
          gint dest_x;
          gint dest_y;
          gint dest_w;
          gint dest_h;
    
          dest_x = MAX (iter.x, rect.x);
          dest_y = MAX (iter.y, rect.y);
          dest_w = MIN (iter.x + iter.width, rect.x + rect.width) - dest_x;
          dest_h = MIN (iter.y + iter.height, rect.y + rect.height) - dest_y;
    
          if (dest_w < 0 || dest_h < 0)
          {
              TEST_FAIL ("Iter isn't in visible rectangle of the buffer %i", result);   
              TEST_FAIL ("visible rect = (%d, %d, %d, %d)", rect.x, rect.y, rect.width, rect.height);   
              TEST_FAIL ("iter         = (%d, %d, %d, %d)", iter.x, iter.y, iter.width, iter.height);   
          }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef MARGIN 
    #undef ALIGN  
    #undef XALIGN 
    #undef YALIGN 
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_scroll_to_iter
 * Params: GtkTextView* text_view, GtkTextIter* iter, gdouble within_margin, gboolean use_align, gdouble xalign, gdouble yalign
 * Returns: gboolean
 * Assertion: Scrolls text_view so that iter is on the screen in the position indicated by xalign and yalign.
 * Params Values: GtkTextView* text_view, GtkTextIter* iter,  0.0, TRUE, 0.5, 0.5
 * Expected: gboolean  
 */
static void test_purpose_216()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n"
    #define MARGIN 0.0
    #define ALIGN  TRUE
    #define XALIGN 0.5
    #define YALIGN 0.5
    #define XPOS 10
    #define YPOS 7
    
    GtkTextBuffer* buffer;
    GtkWidget* widget;
    GtkWidget* scrolled_window;
    GtkTextIter start;
    gboolean result;
    GdkRectangle rect;
    GdkRectangle iter;
    GdkRectangle dest;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, XPOS, YPOS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_scroll_to_iter (GTK_TEXT_VIEW (widget), &start, MARGIN, ALIGN, XALIGN, YALIGN);
    
    gtk_text_view_get_visible_rect  (GTK_TEXT_VIEW (widget), &rect);
    
    gtk_text_view_get_iter_location (GTK_TEXT_VIEW (widget), &start, &iter);
    
    {
          gint dest_x;
          gint dest_y;
          gint dest_w;
          gint dest_h;
    
          dest_x = MAX (iter.x, rect.x);
          dest_y = MAX (iter.y, rect.y);
          dest_w = MIN (iter.x + iter.width, rect.x + rect.width) - dest_x;
          dest_h = MIN (iter.y + iter.height, rect.y + rect.height) - dest_y;
    
          if (dest_w < 0 || dest_h < 0)
          {
              TEST_FAIL ("Iter isn't in visible rectangle of the buffer %i", result);   
              TEST_FAIL ("visible rect = (%d, %d, %d, %d)", rect.x, rect.y, rect.width, rect.height);   
              TEST_FAIL ("iter         = (%d, %d, %d, %d)", iter.x, iter.y, iter.width, iter.height);   
          }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef MARGIN 
    #undef ALIGN  
    #undef XALIGN 
    #undef YALIGN 
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_scroll_to_iter
 * Params: GtkTextView* text_view, GtkTextIter* iter, gdouble within_margin, gboolean use_align, gdouble xalign, gdouble yalign
 * Returns: gboolean
 * Assertion: Scrolls text_view so that iter is on the screen in the position indicated by xalign and yalign.
 * Params Values: GtkTextView* text_view, GtkTextIter* iter,  0.0, FALSE, 0.5, 0.5
 * Expected: gboolean  
 */
static void test_purpose_217()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n"
    #define MARGIN 0.0
    #define ALIGN  FALSE
    #define XALIGN 0.5
    #define YALIGN 0.5
    #define XPOS 0
    #define YPOS 0 
    
    GtkTextBuffer* buffer;
    GtkWidget* widget;
    GtkWidget* scrolled_window;
    GtkTextIter start;
    gboolean result;
    GdkRectangle rect;
    GdkRectangle iter;
    GdkRectangle dest;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, XPOS, YPOS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_scroll_to_iter (GTK_TEXT_VIEW (widget), &start, MARGIN, ALIGN, XALIGN, YALIGN);
    
    gtk_text_view_get_visible_rect  (GTK_TEXT_VIEW (widget), &rect);
    
    gtk_text_view_get_iter_location (GTK_TEXT_VIEW (widget), &start, &iter);
    
    {
          gint dest_x;
          gint dest_y;
          gint dest_w;
          gint dest_h;
    
          dest_x = MAX (iter.x, rect.x);
          dest_y = MAX (iter.y, rect.y);
          dest_w = MIN (iter.x + iter.width, rect.x + rect.width) - dest_x;
          dest_h = MIN (iter.y + iter.height, rect.y + rect.height) - dest_y;
    
          if (dest_w < 0 || dest_h < 0)
          {
              TEST_FAIL ("Iter isn't in visible rectangle of the buffer %i", result);   
              TEST_FAIL ("visible rect = (%d, %d, %d, %d)", rect.x, rect.y, rect.width, rect.height);   
              TEST_FAIL ("iter         = (%d, %d, %d, %d)", iter.x, iter.y, iter.width, iter.height);   
          }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef MARGIN 
    #undef ALIGN  
    #undef XALIGN 
    #undef YALIGN 
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_scroll_to_iter
 * Params: GtkTextView* text_view, GtkTextIter* iter, gdouble within_margin, gboolean use_align, gdouble xalign, gdouble yalign
 * Returns: gboolean
 * Assertion: Scrolls text_view so that iter is on the screen in the position indicated by xalign and yalign.
 * Params Values: GtkTextView* text_view, GtkTextIter* iter,  0.4, TRUE, 0.5, 0.5
 * Expected: gboolean  
 */
static void test_purpose_218()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n"
    #define MARGIN 0.4
    #define ALIGN  TRUE
    #define XALIGN 0.5
    #define YALIGN 0.5
    #define XPOS 1
    #define YPOS 1 
    
    GtkTextBuffer* buffer;
    GtkWidget* widget;
    GtkWidget* scrolled_window;
    GtkTextIter start;
    gboolean result;
    GdkRectangle rect;
    GdkRectangle iter;
    GdkRectangle dest;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, XPOS, YPOS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_scroll_to_iter (GTK_TEXT_VIEW (widget), &start, MARGIN, ALIGN, XALIGN, YALIGN);
    
    gtk_text_view_get_visible_rect  (GTK_TEXT_VIEW (widget), &rect);
    
    gtk_text_view_get_iter_location (GTK_TEXT_VIEW (widget), &start, &iter);
    
    {
          gint dest_x;
          gint dest_y;
          gint dest_w;
          gint dest_h;
    
          dest_x = MAX (iter.x, rect.x);
          dest_y = MAX (iter.y, rect.y);
          dest_w = MIN (iter.x + iter.width, rect.x + rect.width) - dest_x;
          dest_h = MIN (iter.y + iter.height, rect.y + rect.height) - dest_y;
    
          if (dest_w < 0 || dest_h < 0)
          {
              TEST_FAIL ("Iter isn't in visible rectangle of the buffer %i", result);   
              TEST_FAIL ("visible rect = (%d, %d, %d, %d)", rect.x, rect.y, rect.width, rect.height);   
              TEST_FAIL ("iter         = (%d, %d, %d, %d)", iter.x, iter.y, iter.width, iter.height);   
          }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef MARGIN 
    #undef ALIGN  
    #undef XALIGN 
    #undef YALIGN 
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_scroll_to_iter
 * Params: GtkTextView* text_view, GtkTextIter* iter, gdouble within_margin, gboolean use_align, gdouble xalign, gdouble yalign
 * Returns: gboolean
 * Assertion: Scrolls text_view so that iter is on the screen in the position indicated by xalign and yalign.
 * Params Values: GtkTextView* text_view, GtkTextIter* iter,  0.4, TRUE, 1.0, 1.0
 * Expected: gboolean  
 */
static void test_purpose_219()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n"
    #define MARGIN 0.4
    #define ALIGN  TRUE
    #define XALIGN 1.0
    #define YALIGN 1.0
    #define XPOS 0
    #define YPOS 0
    
    GtkTextBuffer* buffer;
    GtkWidget* widget;
    GtkWidget* scrolled_window;
    GtkTextIter start;
    gboolean result;
    GdkRectangle rect;
    GdkRectangle iter;
    GdkRectangle dest;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, XPOS, YPOS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_scroll_to_iter (GTK_TEXT_VIEW (widget), &start, MARGIN, ALIGN, XALIGN, YALIGN);
    
    gtk_text_view_get_visible_rect  (GTK_TEXT_VIEW (widget), &rect);
    
    gtk_text_view_get_iter_location (GTK_TEXT_VIEW (widget), &start, &iter);
    
    {
          gint dest_x;
          gint dest_y;
          gint dest_w;
          gint dest_h;
    
          dest_x = MAX (iter.x, rect.x);
          dest_y = MAX (iter.y, rect.y);
          dest_w = MIN (iter.x + iter.width, rect.x + rect.width) - dest_x;
          dest_h = MIN (iter.y + iter.height, rect.y + rect.height) - dest_y;
    
          if (dest_w < 0 || dest_h < 0)
          {
              TEST_FAIL ("Iter isn't in visible rectangle of the buffer %i", result);   
              TEST_FAIL ("visible rect = (%d, %d, %d, %d)", rect.x, rect.y, rect.width, rect.height);   
              TEST_FAIL ("iter         = (%d, %d, %d, %d)", iter.x, iter.y, iter.width, iter.height);   
          }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef MARGIN 
    #undef ALIGN  
    #undef XALIGN 
    #undef YALIGN 
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_text_view_scroll_to_iter
 * Params: GtkTextView* text_view, GtkTextIter* iter, gdouble within_margin, gboolean use_align, gdouble xalign, gdouble yalign
 * Returns: gboolean
 * Assertion: Scrolls text_view so that iter is on the screen in the position indicated by xalign and yalign.
 * Params Values: GtkTextView* text_view, GtkTextIter* iter,  0.4, FALSE, 1.0, 1.0
 * Expected: gboolean  
 */
static void test_purpose_220()
{
    #define TEXT "Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n  Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n Line 0\n Line 1\n Line 2\n Line 3\n Line 4\n Line 5\n Line 6\n Line 7\n Line 8\n Line 9\n"
    #define MARGIN 0.4
    #define ALIGN  FALSE
    #define XALIGN 1.0
    #define YALIGN 1.0
    #define XPOS 0
    #define YPOS 0
    
    GtkTextBuffer* buffer;
    GtkWidget* widget;
    GtkWidget* scrolled_window;
    GtkTextIter start;
    gboolean result;
    GdkRectangle rect;
    GdkRectangle iter;
    GdkRectangle dest;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_text_view_new  ();
    gtk_widget_set_size_request (widget, 100, 20);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    
    scrolled_window = gtk_scrolled_window_new (NULL, NULL);
    if (!scrolled_window)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
    
    gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (widget), GTK_WRAP_NONE);
    buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (widget));
    gtk_text_buffer_set_text (buffer, TEXT, -1);
    
    gtk_text_buffer_get_iter_at_line_offset (buffer, &start, XPOS, YPOS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (scrolled_window);
    /******* -------------  *******/  
    
    result = gtk_text_view_scroll_to_iter (GTK_TEXT_VIEW (widget), &start, MARGIN, ALIGN, XALIGN, YALIGN);
    
    gtk_text_view_get_visible_rect  (GTK_TEXT_VIEW (widget), &rect);
    
    gtk_text_view_get_iter_location (GTK_TEXT_VIEW (widget), &start, &iter);
    
    {
          gint dest_x;
          gint dest_y;
          gint dest_w;
          gint dest_h;
    
          dest_x = MAX (iter.x, rect.x);
          dest_y = MAX (iter.y, rect.y);
          dest_w = MIN (iter.x + iter.width, rect.x + rect.width) - dest_x;
          dest_h = MIN (iter.y + iter.height, rect.y + rect.height) - dest_y;
    
          if (dest_w < 0 || dest_h < 0)
          {
              TEST_FAIL ("Iter isn't in visible rectangle of the buffer %i", result);   
              TEST_FAIL ("visible rect = (%d, %d, %d, %d)", rect.x, rect.y, rect.width, rect.height);   
              TEST_FAIL ("iter         = (%d, %d, %d, %d)", iter.x, iter.y, iter.width, iter.height);   
          }
    }
    
    gtk_widget_destroy (gtk_widget_get_toplevel (widget));
    
    #undef TEXT
    #undef MARGIN 
    #undef ALIGN  
    #undef XALIGN 
    #undef YALIGN 
    #undef XPOS
    #undef YPOS
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkTextView ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {test_purpose_79, 1},
    {test_purpose_80, 1},
    {test_purpose_81, 1},
    {test_purpose_82, 1},
    {test_purpose_83, 1},
    {test_purpose_84, 1},
    {test_purpose_85, 1},
    {test_purpose_86, 1},
    {test_purpose_87, 1},
    {test_purpose_88, 1},
    {test_purpose_89, 1},
    {test_purpose_90, 1},
    {test_purpose_91, 1},
    {test_purpose_92, 1},
    {test_purpose_93, 1},
    {test_purpose_94, 1},
    {test_purpose_95, 1},
    {test_purpose_96, 1},
    {test_purpose_97, 1},
    {test_purpose_98, 1},
    {test_purpose_99, 1},
    {test_purpose_100, 1},
    {test_purpose_101, 1},
    {test_purpose_102, 1},
    {test_purpose_103, 1},
    {test_purpose_104, 1},
    {test_purpose_105, 1},
    {test_purpose_106, 1},
    {test_purpose_107, 1},
    {test_purpose_108, 1},
    {test_purpose_109, 1},
    {test_purpose_110, 1},
    {test_purpose_111, 1},
    {test_purpose_112, 1},
    {test_purpose_113, 1},
    {test_purpose_114, 1},
    {test_purpose_115, 1},
    {test_purpose_116, 1},
    {test_purpose_117, 1},
    {test_purpose_118, 1},
    {test_purpose_119, 1},
    {test_purpose_120, 1},
    {test_purpose_121, 1},
    {test_purpose_122, 1},
    {test_purpose_123, 1},
    {test_purpose_124, 1},
    {test_purpose_125, 1},
    {test_purpose_126, 1},
    {test_purpose_127, 1},
    {test_purpose_128, 1},
    {test_purpose_129, 1},
    {test_purpose_130, 1},
    {test_purpose_131, 1},
    {test_purpose_132, 1},
    {test_purpose_133, 1},
    {test_purpose_134, 1},
    {test_purpose_135, 1},
    {test_purpose_136, 1},
    {test_purpose_137, 1},
    {test_purpose_138, 1},
    {test_purpose_139, 1},
    {test_purpose_140, 1},
    {test_purpose_141, 1},
    {test_purpose_142, 1},
    {test_purpose_143, 1},
    {test_purpose_144, 1},
    {test_purpose_145, 1},
    {test_purpose_146, 1},
    {test_purpose_147, 1},
    {test_purpose_148, 1},
    {test_purpose_149, 1},
    {test_purpose_150, 1},
    {test_purpose_151, 1},
    {test_purpose_152, 1},
    {test_purpose_153, 1},
    {test_purpose_154, 1},
    {test_purpose_155, 1},
    {test_purpose_156, 1},
    {test_purpose_157, 1},
    {test_purpose_158, 1},
    {test_purpose_159, 1},
    {test_purpose_160, 1},
    {test_purpose_161, 1},
    {test_purpose_162, 1},
    {test_purpose_163, 1},
    {test_purpose_164, 1},
    {test_purpose_165, 1},
    {test_purpose_166, 1},
    {test_purpose_167, 1},
    {test_purpose_168, 1},
    {test_purpose_169, 1},
    {test_purpose_170, 1},
    {test_purpose_171, 1},
    {test_purpose_172, 1},
    {test_purpose_173, 1},
    {test_purpose_174, 1},
    {test_purpose_175, 1},
    {test_purpose_176, 1},
    {test_purpose_177, 1},
    {test_purpose_178, 1},
    {test_purpose_179, 1},
    {test_purpose_180, 1},
    {test_purpose_181, 1},
    {test_purpose_182, 1},
    {test_purpose_183, 1},
    {test_purpose_184, 1},
    {test_purpose_185, 1},
    {test_purpose_186, 1},
    {test_purpose_187, 1},
    {test_purpose_188, 1},
    {test_purpose_189, 1},
    {test_purpose_190, 1},
    {test_purpose_191, 1},
    {test_purpose_192, 1},
    {test_purpose_193, 1},
    {test_purpose_194, 1},
    {test_purpose_195, 1},
    {test_purpose_196, 1},
    {test_purpose_197, 1},
    {test_purpose_198, 1},
    {test_purpose_199, 1},
    {test_purpose_200, 1},
    {test_purpose_201, 1},
    {test_purpose_202, 1},
    {test_purpose_203, 1},
    {test_purpose_204, 1},
    {test_purpose_205, 1},
    {test_purpose_206, 1},
    {test_purpose_207, 1},
    {test_purpose_208, 1},
    {test_purpose_209, 1},
    {test_purpose_210, 1},
    {test_purpose_211, 1},
    {test_purpose_212, 1},
    {test_purpose_213, 1},
    {test_purpose_214, 1},
    {test_purpose_215, 1},
    {test_purpose_216, 1},
    {test_purpose_217, 1},
    {test_purpose_218, 1},
    {test_purpose_219, 1},
    {test_purpose_220, 1},
    {NULL,0}
};
