/*
 * GtkTreeModel methods tests
 * Testing GtkTreeModel methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;
#include <float.h>
gchar* global_condition;

void global_signal_handler (GObject *object, GtkTreePath *path, GtkTreeIter *iter, gint *new_order,  gpointer data)
{
    global_condition = "HANDLED";
}

gboolean  
global_count_nodes (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer data)
{
    (*((gint*) data))++;
    return (FALSE);
}  


global_valist (GtkTreeStore* tree_store, GtkTreeIter* iter, ...)
{
    va_list list;

    va_start (list, iter);
    gtk_tree_model_get_valist (GTK_TREE_MODEL (tree_store), iter, list);
    va_end (list);
}

/*
 * Name: gtk_tree_path_new
 * Params: void
 * Returns: GtkTreePath*
 * Assertion: Creates a new GtkTreePath.
 * Params Values: void
 * Expected: GtkTreePath*  
 */
static void test_purpose_1()
{
    GtkTreePath *path;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new ();
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_string
 * Params: gchar *path
 * Returns: GtkTreePath*
 * Assertion: Creates a new GtkTreePath initialized to path.
 * Params Values: "0:0:0"
 * Expected: GtkTreePath* with depth 3  
 */
static void test_purpose_2()
{
    #define PATH "0:0:0"
    #define CORRECT_DEPTH 3
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (CORRECT_DEPTH != 0)
    {
        if (!path)
        {
            TEST_FAIL (get_not_created_msg(), NULL); 
        }
        
        real_depth = gtk_tree_path_get_depth (path);
        
        if (real_depth != CORRECT_DEPTH)
        {
            TEST_FAIL("Incorrect path depth", NULL);
        }
    } else {
        if (path)
        {
            TEST_FAIL("path = %p", path);
        }
    }
    
    #undef PATH
    #undef CORRECT_DEPTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_string
 * Params: gchar *path
 * Returns: GtkTreePath*
 * Assertion: Creates a new GtkTreePath initialized to path.
 * Params Values: "5:5:5"
 * Expected: GtkTreePath* with depth 3  
 */
static void test_purpose_3()
{
    #define PATH "5:5:5"
    #define CORRECT_DEPTH 3
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (CORRECT_DEPTH != 0)
    {
        if (!path)
        {
            TEST_FAIL (get_not_created_msg(), NULL); 
        }
        
        real_depth = gtk_tree_path_get_depth (path);
        
        if (real_depth != CORRECT_DEPTH)
        {
            TEST_FAIL("Incorrect path depth", NULL);
        }
    } else {
        if (path)
        {
            TEST_FAIL("path = %p", path);
        }
    }
    
    #undef PATH
    #undef CORRECT_DEPTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_string
 * Params: gchar *path
 * Returns: GtkTreePath*
 * Assertion: Creates a new GtkTreePath initialized to path.
 * Params Values: "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
 * Expected: GtkTreePath* with depth 27  
 */
static void test_purpose_4()
{
    #define PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    #define CORRECT_DEPTH 27
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (CORRECT_DEPTH != 0)
    {
        if (!path)
        {
            TEST_FAIL (get_not_created_msg(), NULL); 
        }
        
        real_depth = gtk_tree_path_get_depth (path);
        
        if (real_depth != CORRECT_DEPTH)
        {
            TEST_FAIL("Incorrect path depth", NULL);
        }
    } else {
        if (path)
        {
            TEST_FAIL("path = %p", path);
        }
    }
    
    #undef PATH
    #undef CORRECT_DEPTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_string
 * Params: gchar *path
 * Returns: GtkTreePath*
 * Assertion: Creates a new GtkTreePath initialized to path.
 * Params Values: "100000:100000:100000"
 * Expected: GtkTreePath* with depth 3  
 */
static void test_purpose_5()
{
    #define PATH "100000:100000:100000"
    #define CORRECT_DEPTH 3
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (CORRECT_DEPTH != 0)
    {
        if (!path)
        {
            TEST_FAIL (get_not_created_msg(), NULL); 
        }
        
        real_depth = gtk_tree_path_get_depth (path);
        
        if (real_depth != CORRECT_DEPTH)
        {
            TEST_FAIL("Incorrect path depth", NULL);
        }
    } else {
        if (path)
        {
            TEST_FAIL("path = %p", path);
        }
    }
    
    #undef PATH
    #undef CORRECT_DEPTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_string
 * Params: gchar *path
 * Returns: GtkTreePath*
 * Assertion: Creates a new GtkTreePath initialized to path.
 * Params Values: "2147483647:2147483647:2147483647"
 * Expected: GtkTreePath* with depth 3  
 */
static void test_purpose_6()
{
    #define PATH "2147483647:2147483647:2147483647"
    #define CORRECT_DEPTH 3
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (CORRECT_DEPTH != 0)
    {
        if (!path)
        {
            TEST_FAIL (get_not_created_msg(), NULL); 
        }
        
        real_depth = gtk_tree_path_get_depth (path);
        
        if (real_depth != CORRECT_DEPTH)
        {
            TEST_FAIL("Incorrect path depth", NULL);
        }
    } else {
        if (path)
        {
            TEST_FAIL("path = %p", path);
        }
    }
    
    #undef PATH
    #undef CORRECT_DEPTH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_string
 * Params: gchar *path
 * Returns: GtkTreePath*
 * Assertion: For example, the string "10:4:0" would create a path of depth 3 pointing to the 11th child of the root node, the 5th child of that 11th child, and the 1st child of that 5th child.
 * Params Values: 10:4:0
 * Expected: see assertion description  
 */
static void test_purpose_7()
{
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string ("10:4:0");
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
        
    real_depth = gtk_tree_path_get_depth (path);
    
    if (real_depth != 3)
    {
        TEST_FAIL("path depth = %d, should be 3", real_depth);
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_string
 * Params: gchar *path
 * Returns: GtkTreePath*
 * Assertion: If an invalid path string is passed in, NULL is returned.
 * Params Values: "0:NULL:0"
 * Expected: NULL  
 */
static void test_purpose_8()
{
    #define PATH "0:NULL:0"
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (path)
    {
        TEST_FAIL ("the return value should be NULL if incorrect path is passed", 
                   NULL);
    }
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_string
 * Params: gchar *path
 * Returns: GtkTreePath*
 * Assertion: If an invalid path string is passed in, NULL is returned.
 * Params Values: "0:q:0"
 * Expected: NULL  
 */
static void test_purpose_9()
{
    #define PATH "0:q:0"
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (path)
    {
        TEST_FAIL ("the return value should be NULL if incorrect path is passed", 
                   NULL);
    }
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_string
 * Params: gchar *path
 * Returns: GtkTreePath*
 * Assertion: If an invalid path string is passed in, NULL is returned.
 * Params Values: "-5:-5:-5"
 * Expected: NULL  
 */
static void test_purpose_10()
{
    #define PATH "-5:-5:-5"
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (path)
    {
        TEST_FAIL ("the return value should be NULL if incorrect path is passed", 
                   NULL);
    }
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_string
 * Params: gchar *path
 * Returns: GtkTreePath*
 * Assertion: If an invalid path string is passed in, NULL is returned.
 * Params Values: "5.5.5"
 * Expected: NULL  
 */
static void test_purpose_11()
{
    #define PATH "5.5.5"
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (path)
    {
        TEST_FAIL ("the return value should be NULL if incorrect path is passed", 
                   NULL);
    }
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_string
 * Params: gchar *path
 * Returns: GtkTreePath*
 * Assertion: If an invalid path string is passed in, NULL is returned.
 * Params Values: "Text"
 * Expected: NULL  
 */
static void test_purpose_12()
{
    #define PATH "Text"
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (path)
    {
        TEST_FAIL ("the return value should be NULL if incorrect path is passed", 
                   NULL);
    }
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_string
 * Params: gchar *path
 * Returns: GtkTreePath*
 * Assertion: If an invalid path string is passed in, NULL is returned.
 * Params Values: "\b\n\t"
 * Expected: NULL  
 */
static void test_purpose_13()
{
    #define PATH "\b\n\t"
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (path)
    {
        TEST_FAIL ("the return value should be NULL if incorrect path is passed", 
                   NULL);
    }
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_string
 * Params: gchar *path
 * Returns: GtkTreePath*
 * Assertion: If an invalid path string is passed in, NULL is returned.
 * Params Values: ""
 * Expected: NULL  
 */
static void test_purpose_14()
{
    #define PATH ""
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (path)
    {
        TEST_FAIL ("the return value should be NULL if incorrect path is passed", 
                   NULL);
    }
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_string
 * Params: gchar *path
 * Returns: GtkTreePath*
 * Assertion: If an invalid path string is passed in, NULL is returned.
 * Params Values: " "
 * Expected: NULL  
 */
static void test_purpose_15()
{
    #define PATH " "
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (path)
    {
        TEST_FAIL ("the return value should be NULL if incorrect path is passed", 
                   NULL);
    }
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_string
 * Params: gchar *path
 * Returns: GtkTreePath*
 * Assertion: If an invalid path string is passed in, NULL is returned.
 * Params Values: "                  "
 * Expected: NULL  
 */
static void test_purpose_16()
{
    #define PATH "                  "
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (path)
    {
        TEST_FAIL ("the return value should be NULL if incorrect path is passed", 
                   NULL);
    }
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_string
 * Params: gchar *path
 * Returns: GtkTreePath*
 * Assertion: If an invalid path string is passed in, NULL is returned.
 * Params Values: NULL 
 * Expected: NULL  
 */
static void test_purpose_17()
{
    #define PATH NULL 
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (path)
    {
        TEST_FAIL ("the return value should be NULL if incorrect path is passed", 
                   NULL);
    }
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_string
 * Params: gchar *path
 * Returns: GtkTreePath*
 * Assertion: If an invalid path string is passed in, NULL is returned.
 * Params Values: "G_MAXINT:G_MAXINT:G_MAXINT"
 * Expected: NULL  
 */
static void test_purpose_18()
{
    #define PATH "G_MAXINT:G_MAXINT:G_MAXINT"
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (path)
    {
        TEST_FAIL ("the return value should be NULL if incorrect path is passed", 
                   NULL);
    }
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_indices
 * Params: gint first_index, ...
 * Returns: GtkTreePath*
 * Assertion: Creates a new path with first_index and varargs as indices.
 * Params Values: 0, 0, 0, -1
 * Expected: GtkTreePath* with str representation "0:0:0"  
 */
static void test_purpose_19()
{
    #define INDICES 0, 0, 0, -1
    #define CORRECT_PATH "0:0:0"
    
    GtkTreePath *path;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_indices (INDICES);
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, CORRECT_PATH))
    {
        TEST_FAIL("path string = %s, should be %s", path_str, CORRECT_PATH);
    }
    
    g_free (path_str);
    
    #undef INDICES
    #undef CORRECT_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_indices
 * Params: gint first_index, ...
 * Returns: GtkTreePath*
 * Assertion: Creates a new path with first_index and varargs as indices.
 * Params Values: 5, 5, 5, -1
 * Expected: GtkTreePath* with str representation "5:5:5"  
 */
static void test_purpose_20()
{
    #define INDICES 5, 5, 5, -1
    #define CORRECT_PATH "5:5:5"
    
    GtkTreePath *path;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_indices (INDICES);
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, CORRECT_PATH))
    {
        TEST_FAIL("path string = %s, should be %s", path_str, CORRECT_PATH);
    }
    
    g_free (path_str);
    
    #undef INDICES
    #undef CORRECT_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_indices
 * Params: gint first_index, ...
 * Returns: GtkTreePath*
 * Assertion: Creates a new path with first_index and varargs as indices.
 * Params Values: 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,-1
 * Expected: GtkTreePath* with str representation "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"  
 */
static void test_purpose_21()
{
    #define INDICES 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,-1
    #define CORRECT_PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    
    GtkTreePath *path;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_indices (INDICES);
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, CORRECT_PATH))
    {
        TEST_FAIL("path string = %s, should be %s", path_str, CORRECT_PATH);
    }
    
    g_free (path_str);
    
    #undef INDICES
    #undef CORRECT_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_indices
 * Params: gint first_index, ...
 * Returns: GtkTreePath*
 * Assertion: Creates a new path with first_index and varargs as indices.
 * Params Values: 100000, 100000, 100000, -1
 * Expected: GtkTreePath* with str representation "100000:100000:100000"  
 */
static void test_purpose_22()
{
    #define INDICES 100000, 100000, 100000, -1
    #define CORRECT_PATH "100000:100000:100000"
    
    GtkTreePath *path;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_indices (INDICES);
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, CORRECT_PATH))
    {
        TEST_FAIL("path string = %s, should be %s", path_str, CORRECT_PATH);
    }
    
    g_free (path_str);
    
    #undef INDICES
    #undef CORRECT_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_from_indices
 * Params: gint first_index, ...
 * Returns: GtkTreePath*
 * Assertion: Creates a new path with first_index and varargs as indices.
 * Params Values: 2147483647, 2147483647, 2147483647, -1
 * Expected: GtkTreePath* with str representation "2147483647:2147483647:2147483647"  
 */
static void test_purpose_23()
{
    #define INDICES 2147483647, 2147483647, 2147483647, -1
    #define CORRECT_PATH "2147483647:2147483647:2147483647"
    
    GtkTreePath *path;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_indices (INDICES);
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, CORRECT_PATH))
    {
        TEST_FAIL("path string = %s, should be %s", path_str, CORRECT_PATH);
    }
    
    g_free (path_str);
    
    #undef INDICES
    #undef CORRECT_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_get_depth
 * Params: GtkTreePath *path
 * Returns: gint
 * Assertion: Returns the current depth of path.
 * Params Values: "0:0:0"
 * Expected: GtkTreePath* with depth 3  
 */
static void test_purpose_24()
{
    #define PATH "0:0:0"
    #define CORRECT_DEPTH 3
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    if (CORRECT_DEPTH != 0)
    {
        real_depth = gtk_tree_path_get_depth (path);
        
        if (real_depth != CORRECT_DEPTH)
        {
            TEST_FAIL("path depth = %i, should be %i", real_depth, CORRECT_DEPTH);
        }
    } else {
        if (path)
        {
            TEST_FAIL("path = %p", path);
        }
    }
    
    #undef PATH
    #undef CORRECT_DEPTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_get_depth
 * Params: GtkTreePath *path
 * Returns: gint
 * Assertion: Returns the current depth of path.
 * Params Values: "5:5:5"
 * Expected: GtkTreePath* with depth 3  
 */
static void test_purpose_25()
{
    #define PATH "5:5:5"
    #define CORRECT_DEPTH 3
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    if (CORRECT_DEPTH != 0)
    {
        real_depth = gtk_tree_path_get_depth (path);
        
        if (real_depth != CORRECT_DEPTH)
        {
            TEST_FAIL("path depth = %i, should be %i", real_depth, CORRECT_DEPTH);
        }
    } else {
        if (path)
        {
            TEST_FAIL("path = %p", path);
        }
    }
    
    #undef PATH
    #undef CORRECT_DEPTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_get_depth
 * Params: GtkTreePath *path
 * Returns: gint
 * Assertion: Returns the current depth of path.
 * Params Values: "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
 * Expected: GtkTreePath* with depth 27  
 */
static void test_purpose_26()
{
    #define PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    #define CORRECT_DEPTH 27
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    if (CORRECT_DEPTH != 0)
    {
        real_depth = gtk_tree_path_get_depth (path);
        
        if (real_depth != CORRECT_DEPTH)
        {
            TEST_FAIL("path depth = %i, should be %i", real_depth, CORRECT_DEPTH);
        }
    } else {
        if (path)
        {
            TEST_FAIL("path = %p", path);
        }
    }
    
    #undef PATH
    #undef CORRECT_DEPTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_get_depth
 * Params: GtkTreePath *path
 * Returns: gint
 * Assertion: Returns the current depth of path.
 * Params Values: "100000:100000:100000"
 * Expected: GtkTreePath* with depth 3  
 */
static void test_purpose_27()
{
    #define PATH "100000:100000:100000"
    #define CORRECT_DEPTH 3
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    if (CORRECT_DEPTH != 0)
    {
        real_depth = gtk_tree_path_get_depth (path);
        
        if (real_depth != CORRECT_DEPTH)
        {
            TEST_FAIL("path depth = %i, should be %i", real_depth, CORRECT_DEPTH);
        }
    } else {
        if (path)
        {
            TEST_FAIL("path = %p", path);
        }
    }
    
    #undef PATH
    #undef CORRECT_DEPTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_get_depth
 * Params: GtkTreePath *path
 * Returns: gint
 * Assertion: Returns the current depth of path.
 * Params Values: "2147483647:2147483647:2147483647"
 * Expected: GtkTreePath* with depth 3  
 */
static void test_purpose_28()
{
    #define PATH "2147483647:2147483647:2147483647"
    #define CORRECT_DEPTH 3
    
    GtkTreePath *path;
    gint real_depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    if (CORRECT_DEPTH != 0)
    {
        real_depth = gtk_tree_path_get_depth (path);
        
        if (real_depth != CORRECT_DEPTH)
        {
            TEST_FAIL("path depth = %i, should be %i", real_depth, CORRECT_DEPTH);
        }
    } else {
        if (path)
        {
            TEST_FAIL("path = %p", path);
        }
    }
    
    #undef PATH
    #undef CORRECT_DEPTH
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_get_indices
 * Params: GtkTreePath *path
 * Returns: gint
 * Assertion: Returns the current indices of path.
 * Params Values: newly created GtkTreePath*
 * Expected: pointer to the GtkTreePath indices array  
 */
static void test_purpose_29()
{
    #define PATH "0:0:0"
    #define DEPTH 3
    #define INDICES {0, 0, 0}
    
    GtkTreePath* path;
    int i;
    gint indices[] = INDICES;
    gint* real_indices;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    real_indices = gtk_tree_path_get_indices (path);
    
    if (DEPTH != 0)
    {
        for (i = 0; i < DEPTH; i++)
        {
            if (indices[i] != real_indices[i])
            {
                TEST_FAIL("path indices[%i] = %i, should be %i", i, real_indices[i], indices[i]);
            }
        }
    } else {
        if (path)
        {
            TEST_FAIL("path = %p", path);
        }
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_get_indices
 * Params: GtkTreePath *path
 * Returns: gint
 * Assertion: Returns the current indices of path.
 * Params Values: newly created GtkTreePath*
 * Expected: pointer to the GtkTreePath indices array  
 */
static void test_purpose_30()
{
    #define PATH "5:5:5"
    #define DEPTH 3
    #define INDICES {5, 5, 5} 
    
    GtkTreePath* path;
    int i;
    gint indices[] = INDICES;
    gint* real_indices;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    real_indices = gtk_tree_path_get_indices (path);
    
    if (DEPTH != 0)
    {
        for (i = 0; i < DEPTH; i++)
        {
            if (indices[i] != real_indices[i])
            {
                TEST_FAIL("path indices[%i] = %i, should be %i", i, real_indices[i], indices[i]);
            }
        }
    } else {
        if (path)
        {
            TEST_FAIL("path = %p", path);
        }
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_get_indices
 * Params: GtkTreePath *path
 * Returns: gint
 * Assertion: Returns the current indices of path.
 * Params Values: newly created GtkTreePath*
 * Expected: pointer to the GtkTreePath indices array  
 */
static void test_purpose_31()
{
    #define PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    #define DEPTH 27
    #define INDICES {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}
    
    GtkTreePath* path;
    int i;
    gint indices[] = INDICES;
    gint* real_indices;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    real_indices = gtk_tree_path_get_indices (path);
    
    if (DEPTH != 0)
    {
        for (i = 0; i < DEPTH; i++)
        {
            if (indices[i] != real_indices[i])
            {
                TEST_FAIL("path indices[%i] = %i, should be %i", i, real_indices[i], indices[i]);
            }
        }
    } else {
        if (path)
        {
            TEST_FAIL("path = %p", path);
        }
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_get_indices
 * Params: GtkTreePath *path
 * Returns: gint
 * Assertion: Returns the current indices of path.
 * Params Values: newly created GtkTreePath*
 * Expected: pointer to the GtkTreePath indices array  
 */
static void test_purpose_32()
{
    #define PATH "100000:100000:100000"
    #define DEPTH 3
    #define INDICES {100000, 100000, 100000}
    
    GtkTreePath* path;
    int i;
    gint indices[] = INDICES;
    gint* real_indices;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    real_indices = gtk_tree_path_get_indices (path);
    
    if (DEPTH != 0)
    {
        for (i = 0; i < DEPTH; i++)
        {
            if (indices[i] != real_indices[i])
            {
                TEST_FAIL("path indices[%i] = %i, should be %i", i, real_indices[i], indices[i]);
            }
        }
    } else {
        if (path)
        {
            TEST_FAIL("path = %p", path);
        }
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_get_indices
 * Params: GtkTreePath *path
 * Returns: gint
 * Assertion: Returns the current indices of path.
 * Params Values: newly created GtkTreePath*
 * Expected: pointer to the GtkTreePath indices array  
 */
static void test_purpose_33()
{
    #define PATH "2147483647:2147483647:2147483647"
    #define DEPTH 3
    #define INDICES {2147483647, 2147483647, 2147483647}
    
    GtkTreePath* path;
    int i;
    gint indices[] = INDICES;
    gint* real_indices;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    real_indices = gtk_tree_path_get_indices (path);
    
    if (DEPTH != 0)
    {
        for (i = 0; i < DEPTH; i++)
        {
            if (indices[i] != real_indices[i])
            {
                TEST_FAIL("path indices[%i] = %i, should be %i", i, real_indices[i], indices[i]);
            }
        }
    } else {
        if (path)
        {
            TEST_FAIL("path = %p", path);
        }
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_flags
 * Params: GtkTreeModel *tree_model
 * Returns: GtkTreeModelFlags
 * Assertion:Returns a set of flags supported by this interface.
 * Params Values: newly created GtkTreeModel*
 * Expected: set of flags supported by this interface.  
 */
static void test_purpose_34()
{
    GtkTreeModel *model;
    GtkTreeModelFlags flags;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    model = GTK_TREE_MODEL (gtk_tree_store_new (1, G_TYPE_UINT));
    
    if (!model)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    flags = gtk_tree_model_get_flags (model);
    /*
    if (flags < GTK_TREE_MODEL_ITERS_PERSIST)
    {
        TEST_FAIL("tree model flags = %i. It's less then GTK_TREE_MODEL_ITERS_PERSIST ", flags);
    } else 
    */
    if (flags > GTK_TREE_MODEL_LIST_ONLY)
    {
        TEST_FAIL("tree model flags = %i. It's greater then GTK_TREE_MODEL_LIST_ONLY", flags);
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_n_columns
 * Params: GtkTreeModel *tree_model
 * Returns: gint
 * Assertion: Returns the number of columns supported by tree_model.
 * Params Values: newly created GtkTreeModel*
 * Expected:  1  
 */
static void test_purpose_35()
{
    #define N_COLUMNS 1
    #define ALL_TYPES G_TYPE_UINT
    
    GtkTreeStore *tree_store;
    gint n_columns;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (N_COLUMNS, ALL_TYPES);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    n_columns = gtk_tree_model_get_n_columns (GTK_TREE_MODEL (tree_store));
    if (n_columns != N_COLUMNS)
    {
        TEST_FAIL("tree model columns number = %i, should be %i", n_columns, N_COLUMNS);
    }
    
    #undef N_COLUMNS
    #undef ALL_TYPES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_n_columns
 * Params: GtkTreeModel *tree_model
 * Returns: gint
 * Assertion: Returns the number of columns supported by tree_model.
 * Params Values: newly created GtkTreeModel*
 * Expected:  9  
 */
static void test_purpose_36()
{
    #define N_COLUMNS 9
    #define ALL_TYPES G_TYPE_UINT, G_TYPE_INT, G_TYPE_UCHAR, G_TYPE_CHAR, G_TYPE_BOOLEAN, G_TYPE_POINTER, G_TYPE_FLOAT, G_TYPE_DOUBLE, G_TYPE_STRING
    
    GtkTreeStore *tree_store;
    gint n_columns;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (N_COLUMNS, ALL_TYPES);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    n_columns = gtk_tree_model_get_n_columns (GTK_TREE_MODEL (tree_store));
    if (n_columns != N_COLUMNS)
    {
        TEST_FAIL("tree model columns number = %i, should be %i", n_columns, N_COLUMNS);
    }
    
    #undef N_COLUMNS
    #undef ALL_TYPES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_column_type
 * Params: GtkTreeModel *tree_model, gint index
 * Returns: GType
 * Assertion: Returns the type of the column.
 * Params Values: newly created GtkTreeModel*, 0
 * Expected: G_TYPE_UINT                 
 */
static void test_purpose_37()
{
    #define N_COLUMNS 1
    #define ALL_TYPES G_TYPE_UINT 
    #define INDEX 0
    #define EXPECTED_TYPE G_TYPE_UINT             
    
    GtkTreeStore *tree_store;
    GType column_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (N_COLUMNS, ALL_TYPES);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    column_type = gtk_tree_model_get_column_type (GTK_TREE_MODEL (tree_store), INDEX);
    if (column_type != EXPECTED_TYPE)
    {
        TEST_FAIL("tree model %li column type = %li, should be %li", INDEX, column_type, EXPECTED_TYPE);
    }
    
    #undef N_COLUMNS
    #undef ALL_TYPES
    #undef INDEX
    #undef EXPECTED_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_column_type
 * Params: GtkTreeModel *tree_model, gint index
 * Returns: GType
 * Assertion: Returns the type of the column.
 * Params Values: newly created GtkTreeModel*, 7
 * Expected: G_TYPE_DOUBLE    
 */
static void test_purpose_38()
{
    #define N_COLUMNS 9
    #define ALL_TYPES G_TYPE_UINT, G_TYPE_INT, G_TYPE_UCHAR, G_TYPE_CHAR, G_TYPE_BOOLEAN, G_TYPE_POINTER, G_TYPE_FLOAT, G_TYPE_DOUBLE, G_TYPE_STRING 
    #define INDEX 7
    #define EXPECTED_TYPE G_TYPE_DOUBLE
    
    GtkTreeStore *tree_store;
    GType column_type;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (N_COLUMNS, ALL_TYPES);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    column_type = gtk_tree_model_get_column_type (GTK_TREE_MODEL (tree_store), INDEX);
    if (column_type != EXPECTED_TYPE)
    {
        TEST_FAIL("tree model %li column type = %li, should be %li", INDEX, column_type, EXPECTED_TYPE);
    }
    
    #undef N_COLUMNS
    #undef ALL_TYPES
    #undef INDEX
    #undef EXPECTED_TYPE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_iter
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreePath* path
 * Returns: gboolean
 * Assertion: Sets iter to a valid iterator pointing to path.
 * Params Values: newly created GtkTreeModel*, uninitialized iter, "0:0:0"
 * Expected:    
 */
static void test_purpose_39()
{
    #define PATH "0:0:0"
    #define DEPTH 3
    #define INDICES {0, 0, 0}
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreePath *path;
    gchar* path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    path = gtk_tree_path_new_from_string (PATH);
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    was_set = gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &iter, path);
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter));
    
    if (strcmp (PATH, path_str))
    {
        TEST_FAIL("gtk_tree_model_get_iter () returned wrong iter", NULL);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_iter
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreePath* path
 * Returns: gboolean
 * Assertion: Sets iter to a valid iterator pointing to path.
 * Params Values: newly created GtkTreeModel*, uninitialized iter, "5:7:3"
 * Expected:    
 */
static void test_purpose_40()
{
    #define PATH "5:7:3"
    #define DEPTH 3
    #define INDICES {5, 7, 3} 
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreePath *path;
    gchar* path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    path = gtk_tree_path_new_from_string (PATH);
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    was_set = gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &iter, path);
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter));
    
    if (strcmp (PATH, path_str))
    {
        TEST_FAIL("gtk_tree_model_get_iter () returned wrong iter", NULL);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_iter
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreePath* path
 * Returns: gboolean
 * Assertion: Sets iter to a valid iterator pointing to path.
 * Params Values: newly created GtkTreeModel*, uninitialized iter, "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
 * Expected:    
 */
static void test_purpose_41()
{
    #define PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    #define DEPTH 27
    #define INDICES {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreePath *path;
    gchar* path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    path = gtk_tree_path_new_from_string (PATH);
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    was_set = gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &iter, path);
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter));
    
    if (strcmp (PATH, path_str))
    {
        TEST_FAIL("gtk_tree_model_get_iter () returned wrong iter", NULL);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_iter
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreePath* path
 * Returns: gboolean
 * Assertion: Sets iter to a valid iterator pointing to path.
 * Params Values: newly created GtkTreeModel*, uninitialized iter, "10:1:10"
 * Expected:    
 */
static void test_purpose_42()
{
    #define PATH "10:1:10"
    #define DEPTH 3
    #define INDICES {10, 1, 10}
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreePath *path;
    gchar* path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    path = gtk_tree_path_new_from_string (PATH);
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    was_set = gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &iter, path);
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter));
    
    if (strcmp (PATH, path_str))
    {
        TEST_FAIL("gtk_tree_model_get_iter () returned wrong iter", NULL);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_iter_from_string
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, const gchar *path_string
 * Returns: gboolean
 * Assertion: Sets iter to a valid iterator pointing to path_string, if it exists.
 * Params Values: newly created GtkTreeModel*, uninitialized iter, "0:0:0" (correct path)
 * Expected: TRUE
 * 
 * Name: gtk_tree_model_get_string_from_iter
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: gchar*
 * Assertion: Generates a string representation of the iter.
 * Params Values: newly created GtkTreeModel*, iter pointing to "0:0:0"
 * Expected: "0:0:0"  
 */
static void test_purpose_43()
{
    #define PATH "0:0:0"
    #define DEPTH 3
    #define INDICES {0, 0, 0}
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* real_path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    was_set = gtk_tree_model_get_iter_from_string 
        (GTK_TREE_MODEL (tree_store), &iter, PATH);
    
    if (was_set == FALSE)
    {
        TEST_FAIL("gtk_tree_model_get_iter_from_string () can't get path '%s'", 
                  PATH);
    } else {
        real_path_str = gtk_tree_model_get_string_from_iter 
            (GTK_TREE_MODEL (tree_store), &iter);
        if (!real_path_str)
        {
            TEST_FAIL ("real_path_str is NULL, should be '%s'\n", PATH);
        } else if (strcmp (real_path_str, PATH)) {
            TEST_FAIL ("real_path_str is '%s', should be '%s'\n", 
                       real_path_str, PATH);
        }
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_iter_from_string
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, const gchar *path_string
 * Returns: gboolean
 * Assertion: Sets iter to a valid iterator pointing to path_string, if it exists.
 * Params Values: newly created GtkTreeModel*, uninitialized iter, "5:7:3" (correct path)
 * Expected: TRUE
 * 
 * Name: gtk_tree_model_get_string_from_iter
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: gchar*
 * Assertion: Generates a string representation of the iter.
 * Params Values: newly created GtkTreeModel*, iter pointing to "5:7:3"
 * Expected: "5:7:3"  
 */
static void test_purpose_44()
{
    #define PATH "5:7:3"
    #define DEPTH 3
    #define INDICES {5, 7, 3} 
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* real_path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    was_set = gtk_tree_model_get_iter_from_string 
        (GTK_TREE_MODEL (tree_store), &iter, PATH);
    
    if (was_set == FALSE)
    {
        TEST_FAIL("gtk_tree_model_get_iter_from_string () can't get path '%s'", 
                  PATH);
    } else {
        real_path_str = gtk_tree_model_get_string_from_iter 
            (GTK_TREE_MODEL (tree_store), &iter);
        if (!real_path_str)
        {
            TEST_FAIL ("real_path_str is NULL, should be '%s'\n", PATH);
        } else if (strcmp (real_path_str, PATH)) {
            TEST_FAIL ("real_path_str is '%s', should be '%s'\n", 
                       real_path_str, PATH);
        }
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_iter_from_string
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, const gchar *path_string
 * Returns: gboolean
 * Assertion: Sets iter to a valid iterator pointing to path_string, if it exists.
 * Params Values: newly created GtkTreeModel*, uninitialized iter, "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0" (correct path)
 * Expected: TRUE
 * 
 * Name: gtk_tree_model_get_string_from_iter
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: gchar*
 * Assertion: Generates a string representation of the iter.
 * Params Values: newly created GtkTreeModel*, iter pointing to "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
 * Expected: "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"  
 */
static void test_purpose_45()
{
    #define PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    #define DEPTH 27
    #define INDICES {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* real_path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    was_set = gtk_tree_model_get_iter_from_string 
        (GTK_TREE_MODEL (tree_store), &iter, PATH);
    
    if (was_set == FALSE)
    {
        TEST_FAIL("gtk_tree_model_get_iter_from_string () can't get path '%s'", 
                  PATH);
    } else {
        real_path_str = gtk_tree_model_get_string_from_iter 
            (GTK_TREE_MODEL (tree_store), &iter);
        if (!real_path_str)
        {
            TEST_FAIL ("real_path_str is NULL, should be '%s'\n", PATH);
        } else if (strcmp (real_path_str, PATH)) {
            TEST_FAIL ("real_path_str is '%s', should be '%s'\n", 
                       real_path_str, PATH);
        }
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_iter_from_string
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, const gchar *path_string
 * Returns: gboolean
 * Assertion: Sets iter to a valid iterator pointing to path_string, if it exists.
 * Params Values: newly created GtkTreeModel*, uninitialized iter, "10:1:10" (correct path)
 * Expected: TRUE
 * 
 * Name: gtk_tree_model_get_string_from_iter
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: gchar*
 * Assertion: Generates a string representation of the iter.
 * Params Values: newly created GtkTreeModel*, iter pointing to "10:1:10"
 * Expected: "10:1:10"  
 */
static void test_purpose_46()
{
    #define PATH "10:1:10"
    #define DEPTH 3
    #define INDICES {10, 1, 10}
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* real_path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    was_set = gtk_tree_model_get_iter_from_string 
        (GTK_TREE_MODEL (tree_store), &iter, PATH);
    
    if (was_set == FALSE)
    {
        TEST_FAIL("gtk_tree_model_get_iter_from_string () can't get path '%s'", 
                  PATH);
    } else {
        real_path_str = gtk_tree_model_get_string_from_iter 
            (GTK_TREE_MODEL (tree_store), &iter);
        if (!real_path_str)
        {
            TEST_FAIL ("real_path_str is NULL, should be '%s'\n", PATH);
        } else if (strcmp (real_path_str, PATH)) {
            TEST_FAIL ("real_path_str is '%s', should be '%s'\n", 
                       real_path_str, PATH);
        }
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_iter_from_string
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, const gchar *path_string
 * Returns: gboolean
 * Assertion: Sets iter to a valid iterator pointing to path_string, if it exists.
 * Params Values: newly created GtkTreeModel*, uninitialized iter, "10:1" (correct path)
 * Expected: TRUE
 * 
 * Name: gtk_tree_model_get_string_from_iter
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: gchar*
 * Assertion: Generates a string representation of the iter.
 * Params Values: newly created GtkTreeModel*, iter pointing to "10:1"
 * Expected: "10:1"  
 */
static void test_purpose_47()
{
    #define PATH "10:1"
    #define DEPTH 3
    #define INDICES {10, 1, 10}
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* real_path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    was_set = gtk_tree_model_get_iter_from_string 
        (GTK_TREE_MODEL (tree_store), &iter, PATH);
    
    if (was_set == FALSE)
    {
        TEST_FAIL("gtk_tree_model_get_iter_from_string () can't get path '%s'", 
                  PATH);
    } else {
        real_path_str = gtk_tree_model_get_string_from_iter 
            (GTK_TREE_MODEL (tree_store), &iter);
        if (!real_path_str)
        {
            TEST_FAIL ("real_path_str is NULL, should be '%s'\n", PATH);
        } else if (strcmp (real_path_str, PATH)) {
            TEST_FAIL ("real_path_str is '%s', should be '%s'\n", 
                       real_path_str, PATH);
        }
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_iter_from_string
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, const gchar *path_string
 * Returns: gboolean
 * Assertion: Sets iter to a valid iterator pointing to path_string, if it exists.
 * Params Values: newly created GtkTreeModel*, uninitialized iter, "10" (correct path)
 * Expected: TRUE
 * 
 * Name: gtk_tree_model_get_string_from_iter
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: gchar*
 * Assertion: Generates a string representation of the iter.
 * Params Values: newly created GtkTreeModel*, iter pointing to "10"
 * Expected: "10"  
 */
static void test_purpose_48()
{
    #define PATH "10"
    #define DEPTH 3
    #define INDICES {10, 1, 10}
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* real_path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    was_set = gtk_tree_model_get_iter_from_string 
        (GTK_TREE_MODEL (tree_store), &iter, PATH);
    
    if (was_set == FALSE)
    {
        TEST_FAIL("gtk_tree_model_get_iter_from_string () can't get path '%s'", 
                  PATH);
    } else {
        real_path_str = gtk_tree_model_get_string_from_iter 
            (GTK_TREE_MODEL (tree_store), &iter);
        if (!real_path_str)
        {
            TEST_FAIL ("real_path_str is NULL, should be '%s'\n", PATH);
        } else if (strcmp (real_path_str, PATH)) {
            TEST_FAIL ("real_path_str is '%s', should be '%s'\n", 
                       real_path_str, PATH);
        }
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_iter_from_string
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, const gchar *path_string
 * Returns: gboolean
 * Assertion: Sets iter to a valid iterator pointing to path_string, if it exists.
 * Params Values: newly created GtkTreeModel*, uninitialized iter, "10:5:7" (correct path)
 * Expected: TRUE
 * 
 * Name: gtk_tree_model_get_string_from_iter
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: gchar*
 * Assertion: Generates a string representation of the iter.
 * Params Values: newly created GtkTreeModel*, iter pointing to "10:5:7"
 * Expected: "10:5:7"  
 */
static void test_purpose_49()
{
    #define PATH "10:5:7"
    #define DEPTH 3
    #define INDICES {10, 5, 10}
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* real_path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    was_set = gtk_tree_model_get_iter_from_string 
        (GTK_TREE_MODEL (tree_store), &iter, PATH);
    
    if (was_set == FALSE)
    {
        TEST_FAIL("gtk_tree_model_get_iter_from_string () can't get path '%s'", 
                  PATH);
    } else {
        real_path_str = gtk_tree_model_get_string_from_iter 
            (GTK_TREE_MODEL (tree_store), &iter);
        if (!real_path_str)
        {
            TEST_FAIL ("real_path_str is NULL, should be '%s'\n", PATH);
        } else if (strcmp (real_path_str, PATH)) {
            TEST_FAIL ("real_path_str is '%s', should be '%s'\n", 
                       real_path_str, PATH);
        }
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_iter_from_string
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, const gchar *path_string
 * Returns: gboolean
 * Assertion: Otherwise, iter is left invalid and FALSE is returned.
 * Params Values: newly created GtkTreeModel*, uninitialized iter, "1:0:0" (correct path)
 * Expected:    
 */
static void test_purpose_50()
{
    #define PATH "1:0:0"
    #define DEPTH 3
    #define INDICES {0, 0, 0}
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    was_set = gtk_tree_model_get_iter_from_string 
        (GTK_TREE_MODEL (tree_store), &iter, PATH);
    
    if (was_set == TRUE)
    {
        TEST_FAIL("gtk_tree_model_get_iter_from_string () returned TRUE for invalid path '%s'", PATH);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_iter_from_string
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, const gchar *path_string
 * Returns: gboolean
 * Assertion: Otherwise, iter is left invalid and FALSE is returned.
 * Params Values: newly created GtkTreeModel*, uninitialized iter, "5:8:3" (correct path)
 * Expected:    
 */
static void test_purpose_51()
{
    #define PATH "5:8:3"
    #define DEPTH 3
    #define INDICES {5, 7, 3} 
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    was_set = gtk_tree_model_get_iter_from_string 
        (GTK_TREE_MODEL (tree_store), &iter, PATH);
    
    if (was_set == TRUE)
    {
        TEST_FAIL("gtk_tree_model_get_iter_from_string () returned TRUE for invalid path '%s'", PATH);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_iter_from_string
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, const gchar *path_string
 * Returns: gboolean
 * Assertion: Otherwise, iter is left invalid and FALSE is returned.
 * Params Values: newly created GtkTreeModel*, uninitialized iter, "10:5:11" (correct path)
 * Expected:    
 */
static void test_purpose_52()
{
    #define PATH "10:5:11"
    #define DEPTH 3
    #define INDICES {10, 5, 10}
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    was_set = gtk_tree_model_get_iter_from_string 
        (GTK_TREE_MODEL (tree_store), &iter, PATH);
    
    if (was_set == TRUE)
    {
        TEST_FAIL("gtk_tree_model_get_iter_from_string () returned TRUE for invalid path '%s'", PATH);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_iter_from_string
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, const gchar *path_string
 * Returns: gboolean
 * Assertion: Otherwise, iter is left invalid and FALSE is returned.
 * Params Values: newly created GtkTreeModel*, uninitialized iter, "10:2" (correct path)
 * Expected:    
 */
static void test_purpose_53()
{
    #define PATH "10:2"
    #define DEPTH 3
    #define INDICES {10, 1, 10}
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gchar* path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    was_set = gtk_tree_model_get_iter_from_string 
        (GTK_TREE_MODEL (tree_store), &iter, PATH);
    
    if (was_set == TRUE)
    {
        TEST_FAIL("gtk_tree_model_get_iter_from_string () returned TRUE for invalid path '%s'", PATH);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_path
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: GtkTreePath*
 * Assertion: Returns a newly-created GtkTreePath referenced by iter. 
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: GtkTreePath* referenced by iter    
 */
static void test_purpose_54()
{
    #define PATH "0:0:0"
    #define DEPTH 3
    #define INDICES {0, 0, 0}
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreePath *path;
    gchar* path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter);
    path_str = gtk_tree_path_to_string (path);
    gtk_tree_path_free (path);
    if (strcmp (PATH, path_str))
    {
        TEST_FAIL("path = %s, should be %s", path_str, PATH);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_path
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: GtkTreePath*
 * Assertion: Returns a newly-created GtkTreePath referenced by iter. 
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: GtkTreePath* referenced by iter    
 */
static void test_purpose_55()
{
    #define PATH "5:7:3"
    #define DEPTH 3
    #define INDICES {5, 7, 3} 
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreePath *path;
    gchar* path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter);
    path_str = gtk_tree_path_to_string (path);
    gtk_tree_path_free (path);
    if (strcmp (PATH, path_str))
    {
        TEST_FAIL("path = %s, should be %s", path_str, PATH);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_path
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: GtkTreePath*
 * Assertion: Returns a newly-created GtkTreePath referenced by iter. 
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: GtkTreePath* referenced by iter    
 */
static void test_purpose_56()
{
    #define PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    #define DEPTH 27
    #define INDICES {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreePath *path;
    gchar* path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter);
    path_str = gtk_tree_path_to_string (path);
    gtk_tree_path_free (path);
    if (strcmp (PATH, path_str))
    {
        TEST_FAIL("path = %s, should be %s", path_str, PATH);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_path
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: GtkTreePath*
 * Assertion: Returns a newly-created GtkTreePath referenced by iter. 
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: GtkTreePath* referenced by iter    
 */
static void test_purpose_57()
{
    #define PATH "10:1:10"
    #define DEPTH 3
    #define INDICES {10, 1, 10}
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreePath *path;
    gchar* path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter);
    path_str = gtk_tree_path_to_string (path);
    gtk_tree_path_free (path);
    if (strcmp (PATH, path_str))
    {
        TEST_FAIL("path = %s, should be %s", path_str, PATH);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_value
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, gint column, GValue *value
 * Returns: void
 * Assertion: Sets initializes and sets value to that at column.
 * Params Values: newly created GtkTreeModel*, initialized *iter, uninitialized *value
 * Expected: void  
 */
static void test_purpose_58()
{
    #define N_COLUMNS 1
    #define TYPES G_TYPE_DOUBLE
    #define INDEX 0
    #define VALUE G_MINDOUBLE
    #define DEPTH 3
    #define INDICES {0, 0, 0}
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GValue val = {0, };
    gdouble double_val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (N_COLUMNS, TYPES);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    gtk_tree_store_set (tree_store, &iter, INDEX, (gdouble)VALUE, -1);
    gtk_tree_model_get_value (GTK_TREE_MODEL (tree_store), &iter, INDEX, &val);
    double_val = g_value_get_double (&val);
    if (double_val != VALUE)
    {
        TEST_FAIL ("gtk_tree_model_get_value () extracted value = %i, should be %i.", double_val, VALUE); 
    }
    
    #undef N_COLUMNS
    #undef TYPES
    #undef INDEX
    #undef VALUE
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_value
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, gint column, GValue *value
 * Returns: void
 * Assertion: Sets initializes and sets value to that at column.
 * Params Values: newly created GtkTreeModel*, initialized *iter, uninitialized *value
 * Expected: void  
 */
static void test_purpose_59()
{
    #define N_COLUMNS 7
    #define TYPES G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE, G_TYPE_DOUBLE 
    #define INDEX 6
    #define VALUE G_MAXDOUBLE
    #define DEPTH 3
    #define INDICES {5, 7, 3} 
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GValue val = {0, };
    gdouble double_val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (N_COLUMNS, TYPES);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    gtk_tree_store_set (tree_store, &iter, INDEX, (gdouble)VALUE, -1);
    gtk_tree_model_get_value (GTK_TREE_MODEL (tree_store), &iter, INDEX, &val);
    double_val = g_value_get_double (&val);
    if (double_val != VALUE)
    {
        TEST_FAIL ("gtk_tree_model_get_value () extracted value = %i, should be %i.", double_val, VALUE); 
    }
    
    #undef N_COLUMNS
    #undef TYPES
    #undef INDEX
    #undef VALUE
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_value
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, gint column, GValue *value
 * Returns: void
 * Assertion: Sets initializes and sets value to that at column.
 * Params Values: newly created GtkTreeModel*, initialized *iter, uninitialized *value
 * Expected: void  
 */
static void test_purpose_60()
{
    #define N_COLUMNS 7
    #define TYPES G_TYPE_UCHAR, G_TYPE_UINT, G_TYPE_INT, GDK_TYPE_PIXBUF, G_TYPE_DOUBLE, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_CHAR 
    #define INDEX 4
    #define VALUE 17.13
    #define DEPTH 27
    #define INDICES {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0}
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GValue val = {0, };
    gdouble double_val;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (N_COLUMNS, TYPES);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    gtk_tree_store_set (tree_store, &iter, INDEX, (gdouble)VALUE, -1);
    gtk_tree_model_get_value (GTK_TREE_MODEL (tree_store), &iter, INDEX, &val);
    double_val = g_value_get_double (&val);
    if (double_val != VALUE)
    {
        TEST_FAIL ("gtk_tree_model_get_value () extracted value = %i, should be %i.", double_val, VALUE); 
    }
    
    #undef N_COLUMNS
    #undef TYPES
    #undef INDEX
    #undef VALUE
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_to_string
 * Params: GtkTreePath *path
 * Returns: gchar*
 * Assertion: Generates a string representation of the path.
 * Params Values: newly created GtkTreePath*
 * Expected: "0:0:0"  
 */
static void test_purpose_61()
{
    #define PATH "0:0:0"
    
    GtkTreePath *path;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    path_str = gtk_tree_path_to_string (path);
    
    if (strcmp (path_str, PATH))
    {
        TEST_FAIL("path string = %s, should be %s", path_str, PATH);
    }
    
    g_free (path_str);
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_to_string
 * Params: GtkTreePath *path
 * Returns: gchar*
 * Assertion: Generates a string representation of the path.
 * Params Values: newly created GtkTreePath*
 * Expected: "5:5:5"  
 */
static void test_purpose_62()
{
    #define PATH "5:5:5"
    
    GtkTreePath *path;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    path_str = gtk_tree_path_to_string (path);
    
    if (strcmp (path_str, PATH))
    {
        TEST_FAIL("path string = %s, should be %s", path_str, PATH);
    }
    
    g_free (path_str);
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_to_string
 * Params: GtkTreePath *path
 * Returns: gchar*
 * Assertion: Generates a string representation of the path.
 * Params Values: newly created GtkTreePath*
 * Expected: "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"  
 */
static void test_purpose_63()
{
    #define PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    
    GtkTreePath *path;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    path_str = gtk_tree_path_to_string (path);
    
    if (strcmp (path_str, PATH))
    {
        TEST_FAIL("path string = %s, should be %s", path_str, PATH);
    }
    
    g_free (path_str);
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_to_string
 * Params: GtkTreePath *path
 * Returns: gchar*
 * Assertion: Generates a string representation of the path.
 * Params Values: newly created GtkTreePath*
 * Expected: "100000:100000:100000"  
 */
static void test_purpose_64()
{
    #define PATH "100000:100000:100000"
    
    GtkTreePath *path;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    path_str = gtk_tree_path_to_string (path);
    
    if (strcmp (path_str, PATH))
    {
        TEST_FAIL("path string = %s, should be %s", path_str, PATH);
    }
    
    g_free (path_str);
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_to_string
 * Params: GtkTreePath *path
 * Returns: gchar*
 * Assertion: Generates a string representation of the path.
 * Params Values: newly created GtkTreePath*
 * Expected: "2147483647:2147483647:2147483647"  
 */
static void test_purpose_65()
{
    #define PATH "2147483647:2147483647:2147483647"
    
    GtkTreePath *path;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    path_str = gtk_tree_path_to_string (path);
    
    if (strcmp (path_str, PATH))
    {
        TEST_FAIL("path string = %s, should be %s", path_str, PATH);
    }
    
    g_free (path_str);
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_to_string
 * Params: GtkTreePath *path
 * Returns: gchar*
 * Assertion: For example, "4:10:0:3" would be an acceptable return value for this string.
 * Params Values: GtkTreePath* 
 * Expected: void  
 */
static void test_purpose_66()
{
    #define DEPTH 4
    #define INDICES {4, 10, 0, 3}
    #define PATH_STR "4:10:0:3"
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter);
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, PATH_STR))
    {
        TEST_FAIL ("path string = %s, shoul be %s.", path_str, PATH_STR); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_append_index
 * Params: GtkTreePath *path, gint index
 * Returns: void
 * Assertion: Appends a new index to a path.
 * Params Values: newly created GtkTreePath*, "0:0:0"
 * Expected: index should be appended to a path.  
 */
static void test_purpose_67()
{
    #define PATH "0:0:0"
    #define DEPTH 3
    #define INDEX 0
    
    GtkTreePath* path;
    int i;
    gint* indices;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_append_index (path, INDEX);
    indices = gtk_tree_path_get_indices (path);
    if (indices[DEPTH] != INDEX)
    {
        TEST_FAIL("GtkTreePath indices[DEPTH] = %i, should be %i", indices[DEPTH], INDEX);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_append_index
 * Params: GtkTreePath *path, gint index
 * Returns: void
 * Assertion: Appends a new index to a path.
 * Params Values: newly created GtkTreePath*, "5:5:5"
 * Expected: index should be appended to a path.  
 */
static void test_purpose_68()
{
    #define PATH "5:5:5"
    #define DEPTH 3
    #define INDEX 17   
    
    GtkTreePath* path;
    int i;
    gint* indices;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_append_index (path, INDEX);
    indices = gtk_tree_path_get_indices (path);
    if (indices[DEPTH] != INDEX)
    {
        TEST_FAIL("GtkTreePath indices[DEPTH] = %i, should be %i", indices[DEPTH], INDEX);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_append_index
 * Params: GtkTreePath *path, gint index
 * Returns: void
 * Assertion: Appends a new index to a path.
 * Params Values: newly created GtkTreePath*, "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
 * Expected: index should be appended to a path.  
 */
static void test_purpose_69()
{
    #define PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    #define DEPTH 27
    #define INDEX G_MAXINT
    
    GtkTreePath* path;
    int i;
    gint* indices;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_append_index (path, INDEX);
    indices = gtk_tree_path_get_indices (path);
    if (indices[DEPTH] != INDEX)
    {
        TEST_FAIL("GtkTreePath indices[DEPTH] = %i, should be %i", indices[DEPTH], INDEX);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_append_index
 * Params: GtkTreePath *path, gint index
 * Returns: void
 * Assertion: Appends a new index to a path.
 * Params Values: newly created GtkTreePath*, "100000:100000:100000"
 * Expected: index should be appended to a path.  
 */
static void test_purpose_70()
{
    #define PATH "100000:100000:100000"
    #define DEPTH 3
    #define INDEX 111
    
    GtkTreePath* path;
    int i;
    gint* indices;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_append_index (path, INDEX);
    indices = gtk_tree_path_get_indices (path);
    if (indices[DEPTH] != INDEX)
    {
        TEST_FAIL("GtkTreePath indices[DEPTH] = %i, should be %i", indices[DEPTH], INDEX);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_append_index
 * Params: GtkTreePath *path, gint index
 * Returns: void
 * Assertion: Appends a new index to a path.
 * Params Values: newly created GtkTreePath*, "2147483647:2147483647:2147483647"
 * Expected: index should be appended to a path.  
 */
static void test_purpose_71()
{
    #define PATH "2147483647:2147483647:2147483647"
    #define DEPTH 3
    #define INDEX 1
    
    GtkTreePath* path;
    int i;
    gint* indices;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_append_index (path, INDEX);
    indices = gtk_tree_path_get_indices (path);
    if (indices[DEPTH] != INDEX)
    {
        TEST_FAIL("GtkTreePath indices[DEPTH] = %i, should be %i", indices[DEPTH], INDEX);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_append_index
 * Params: GtkTreePath *path, gint index
 * Returns: void
 * Assertion: As a result, the depth of the path is increased.
 * Params Values: newly created GtkTreePath*, "0:0:0"
 * Expected: the depth of the path = 3+1  
 */
static void test_purpose_72()
{
    #define PATH "0:0:0"
    #define DEPTH 3
    #define INDEX 0
    
    GtkTreePath* path;
    int i;
    gint* indices;
    gint depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_append_index (path, INDEX);
    depth = gtk_tree_path_get_depth (path);
    if (depth != (DEPTH + 1))
    {
        TEST_FAIL("GtkTreePath depth = %i after append index, should be %i", depth, DEPTH + 1);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_append_index
 * Params: GtkTreePath *path, gint index
 * Returns: void
 * Assertion: As a result, the depth of the path is increased.
 * Params Values: newly created GtkTreePath*, "5:5:5"
 * Expected: the depth of the path = 3+1  
 */
static void test_purpose_73()
{
    #define PATH "5:5:5"
    #define DEPTH 3
    #define INDEX 17   
    
    GtkTreePath* path;
    int i;
    gint* indices;
    gint depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_append_index (path, INDEX);
    depth = gtk_tree_path_get_depth (path);
    if (depth != (DEPTH + 1))
    {
        TEST_FAIL("GtkTreePath depth = %i after append index, should be %i", depth, DEPTH + 1);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_append_index
 * Params: GtkTreePath *path, gint index
 * Returns: void
 * Assertion: As a result, the depth of the path is increased.
 * Params Values: newly created GtkTreePath*, "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
 * Expected: the depth of the path = 27+1  
 */
static void test_purpose_74()
{
    #define PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    #define DEPTH 27
    #define INDEX G_MAXINT
    
    GtkTreePath* path;
    int i;
    gint* indices;
    gint depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_append_index (path, INDEX);
    depth = gtk_tree_path_get_depth (path);
    if (depth != (DEPTH + 1))
    {
        TEST_FAIL("GtkTreePath depth = %i after append index, should be %i", depth, DEPTH + 1);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_append_index
 * Params: GtkTreePath *path, gint index
 * Returns: void
 * Assertion: As a result, the depth of the path is increased.
 * Params Values: newly created GtkTreePath*, "100000:100000:100000"
 * Expected: the depth of the path = 3+1  
 */
static void test_purpose_75()
{
    #define PATH "100000:100000:100000"
    #define DEPTH 3
    #define INDEX 111
    
    GtkTreePath* path;
    int i;
    gint* indices;
    gint depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_append_index (path, INDEX);
    depth = gtk_tree_path_get_depth (path);
    if (depth != (DEPTH + 1))
    {
        TEST_FAIL("GtkTreePath depth = %i after append index, should be %i", depth, DEPTH + 1);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_append_index
 * Params: GtkTreePath *path, gint index
 * Returns: void
 * Assertion: As a result, the depth of the path is increased.
 * Params Values: newly created GtkTreePath*, "2147483647:2147483647:2147483647"
 * Expected: the depth of the path = 3+1  
 */
static void test_purpose_76()
{
    #define PATH "2147483647:2147483647:2147483647"
    #define DEPTH 3
    #define INDEX 1
    
    GtkTreePath* path;
    int i;
    gint* indices;
    gint depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_append_index (path, INDEX);
    depth = gtk_tree_path_get_depth (path);
    if (depth != (DEPTH + 1))
    {
        TEST_FAIL("GtkTreePath depth = %i after append index, should be %i", depth, DEPTH + 1);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_prepend_index
 * Params: GtkTreePath *path, gint index
 * Returns: void
 * Assertion: Prepends a new index to a path.
 * Params Values: newly created GtkTreePath*, "0:0:0"
 * Expected: index should be prepended to a path.  
 */
static void test_purpose_77()
{
    #define PATH "0:0:0"
    #define DEPTH 3
    #define INDEX 0
    
    GtkTreePath* path;
    int i;
    gint* indices;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_prepend_index (path, INDEX);
    indices = gtk_tree_path_get_indices (path);
    if (indices[0] != INDEX)
    {
        TEST_FAIL("GtkTreePath indices[0] = %i, should be %i", indices[0], INDEX);
    }
    
    
    #undef PATH
    #undef DEPTH
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_prepend_index
 * Params: GtkTreePath *path, gint index
 * Returns: void
 * Assertion: Prepends a new index to a path.
 * Params Values: newly created GtkTreePath*, "5:5:5"
 * Expected: index should be prepended to a path.  
 */
static void test_purpose_78()
{
    #define PATH "5:5:5"
    #define DEPTH 3
    #define INDEX 17   
    
    GtkTreePath* path;
    int i;
    gint* indices;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_prepend_index (path, INDEX);
    indices = gtk_tree_path_get_indices (path);
    if (indices[0] != INDEX)
    {
        TEST_FAIL("GtkTreePath indices[0] = %i, should be %i", indices[0], INDEX);
    }
    
    
    #undef PATH
    #undef DEPTH
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_prepend_index
 * Params: GtkTreePath *path, gint index
 * Returns: void
 * Assertion: Prepends a new index to a path.
 * Params Values: newly created GtkTreePath*, "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
 * Expected: index should be prepended to a path.  
 */
static void test_purpose_79()
{
    #define PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    #define DEPTH 27
    #define INDEX G_MAXINT
    
    GtkTreePath* path;
    int i;
    gint* indices;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_prepend_index (path, INDEX);
    indices = gtk_tree_path_get_indices (path);
    if (indices[0] != INDEX)
    {
        TEST_FAIL("GtkTreePath indices[0] = %i, should be %i", indices[0], INDEX);
    }
    
    
    #undef PATH
    #undef DEPTH
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_prepend_index
 * Params: GtkTreePath *path, gint index
 * Returns: void
 * Assertion: Prepends a new index to a path.
 * Params Values: newly created GtkTreePath*, "100000:100000:100000"
 * Expected: index should be prepended to a path.  
 */
static void test_purpose_80()
{
    #define PATH "100000:100000:100000"
    #define DEPTH 3
    #define INDEX 111
    
    GtkTreePath* path;
    int i;
    gint* indices;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_prepend_index (path, INDEX);
    indices = gtk_tree_path_get_indices (path);
    if (indices[0] != INDEX)
    {
        TEST_FAIL("GtkTreePath indices[0] = %i, should be %i", indices[0], INDEX);
    }
    
    
    #undef PATH
    #undef DEPTH
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_prepend_index
 * Params: GtkTreePath *path, gint index
 * Returns: void
 * Assertion: Prepends a new index to a path.
 * Params Values: newly created GtkTreePath*, "2147483647:2147483647:2147483647"
 * Expected: index should be prepended to a path.  
 */
static void test_purpose_81()
{
    #define PATH "2147483647:2147483647:2147483647"
    #define DEPTH 3
    #define INDEX 1
    
    GtkTreePath* path;
    int i;
    gint* indices;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_prepend_index (path, INDEX);
    indices = gtk_tree_path_get_indices (path);
    if (indices[0] != INDEX)
    {
        TEST_FAIL("GtkTreePath indices[0] = %i, should be %i", indices[0], INDEX);
    }
    
    
    #undef PATH
    #undef DEPTH
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_prepend_index
 * Params: GtkTreePath *path, gint index
 * Returns: void
 * Assertion: As a result, the depth of the path is increased.
 * Params Values: newly created GtkTreePath*, "0:0:0"
 * Expected: the depth of the path = 3+1  
 */
static void test_purpose_82()
{
    #define PATH "0:0:0"
    #define DEPTH 3
    #define INDEX 0
    
    GtkTreePath* path;
    int i;
    gint* indices;
    gint depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_prepend_index (path, INDEX);
    depth = gtk_tree_path_get_depth (path);
    if (depth != (DEPTH + 1))
    {
        TEST_FAIL("GtkTreePath depth = %i after prepend index, should be %i", depth, DEPTH + 1);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_prepend_index
 * Params: GtkTreePath *path, gint index
 * Returns: void
 * Assertion: As a result, the depth of the path is increased.
 * Params Values: newly created GtkTreePath*, "5:5:5"
 * Expected: the depth of the path = 3+1  
 */
static void test_purpose_83()
{
    #define PATH "5:5:5"
    #define DEPTH 3
    #define INDEX 17   
    
    GtkTreePath* path;
    int i;
    gint* indices;
    gint depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_prepend_index (path, INDEX);
    depth = gtk_tree_path_get_depth (path);
    if (depth != (DEPTH + 1))
    {
        TEST_FAIL("GtkTreePath depth = %i after prepend index, should be %i", depth, DEPTH + 1);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_prepend_index
 * Params: GtkTreePath *path, gint index
 * Returns: void
 * Assertion: As a result, the depth of the path is increased.
 * Params Values: newly created GtkTreePath*, "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
 * Expected: the depth of the path = 27+1  
 */
static void test_purpose_84()
{
    #define PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    #define DEPTH 27
    #define INDEX G_MAXINT
    
    GtkTreePath* path;
    int i;
    gint* indices;
    gint depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_prepend_index (path, INDEX);
    depth = gtk_tree_path_get_depth (path);
    if (depth != (DEPTH + 1))
    {
        TEST_FAIL("GtkTreePath depth = %i after prepend index, should be %i", depth, DEPTH + 1);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_prepend_index
 * Params: GtkTreePath *path, gint index
 * Returns: void
 * Assertion: As a result, the depth of the path is increased.
 * Params Values: newly created GtkTreePath*, "100000:100000:100000"
 * Expected: the depth of the path = 3+1  
 */
static void test_purpose_85()
{
    #define PATH "100000:100000:100000"
    #define DEPTH 3
    #define INDEX 111
    
    GtkTreePath* path;
    int i;
    gint* indices;
    gint depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_prepend_index (path, INDEX);
    depth = gtk_tree_path_get_depth (path);
    if (depth != (DEPTH + 1))
    {
        TEST_FAIL("GtkTreePath depth = %i after prepend index, should be %i", depth, DEPTH + 1);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_prepend_index
 * Params: GtkTreePath *path, gint index
 * Returns: void
 * Assertion: As a result, the depth of the path is increased.
 * Params Values: newly created GtkTreePath*, "2147483647:2147483647:2147483647"
 * Expected: the depth of the path = 3+1  
 */
static void test_purpose_86()
{
    #define PATH "2147483647:2147483647:2147483647"
    #define DEPTH 3
    #define INDEX 1
    
    GtkTreePath* path;
    int i;
    gint* indices;
    gint depth;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_prepend_index (path, INDEX);
    depth = gtk_tree_path_get_depth (path);
    if (depth != (DEPTH + 1))
    {
        TEST_FAIL("GtkTreePath depth = %i after prepend index, should be %i", depth, DEPTH + 1);
    }
    
    #undef PATH
    #undef DEPTH
    #undef INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_free
 * Params: GtkTreePath *path
 * Returns: void
 * Assertion: Frees path.
 * Params Values: newly created GtkTreePath*, "0:0:0"
 * Expected:   
 */
static void test_purpose_87()
{
    #define PATH "0:0:0"
    
    GtkTreePath* path;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_free (path);
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_free
 * Params: GtkTreePath *path
 * Returns: void
 * Assertion: Frees path.
 * Params Values: newly created GtkTreePath*, "5:5:5"
 * Expected:   
 */
static void test_purpose_88()
{
    #define PATH "5:5:5"
    
    GtkTreePath* path;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_free (path);
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_free
 * Params: GtkTreePath *path
 * Returns: void
 * Assertion: Frees path.
 * Params Values: newly created GtkTreePath*, "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
 * Expected:   
 */
static void test_purpose_89()
{
    #define PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    
    GtkTreePath* path;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_free (path);
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_free
 * Params: GtkTreePath *path
 * Returns: void
 * Assertion: Frees path.
 * Params Values: newly created GtkTreePath*, "100000:100000:100000"
 * Expected:   
 */
static void test_purpose_90()
{
    #define PATH "100000:100000:100000"
    
    GtkTreePath* path;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_free (path);
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_free
 * Params: GtkTreePath *path
 * Returns: void
 * Assertion: Frees path.
 * Params Values: newly created GtkTreePath*, "2147483647:2147483647:2147483647"
 * Expected:   
 */
static void test_purpose_91()
{
    #define PATH "2147483647:2147483647:2147483647"
    
    GtkTreePath* path;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_free (path);
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_copy
 * Params: const GtkTreePath *path
 * Returns: GtkTreePath* 
 * Assertion: Creates a new GtkTreePath as a copy of path.
 * Params Values: newly created GtkTreePath*
 * Expected: new GtkTreePath with path = "0:0:0"   
 */
static void test_purpose_92()
{
    #define PATH "0:0:0"
    
    GtkTreePath* path;
    GtkTreePath* path_copy;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    path_copy = gtk_tree_path_copy (path);
    path_str = gtk_tree_path_to_string (path_copy);
    if (strcmp (path_str, PATH))
    {
        TEST_FAIL("path copy = %s, should be %s", path_str, PATH);
    }
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_copy
 * Params: const GtkTreePath *path
 * Returns: GtkTreePath* 
 * Assertion: Creates a new GtkTreePath as a copy of path.
 * Params Values: newly created GtkTreePath*
 * Expected: new GtkTreePath with path = "5:5:5"   
 */
static void test_purpose_93()
{
    #define PATH "5:5:5"
    
    GtkTreePath* path;
    GtkTreePath* path_copy;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    path_copy = gtk_tree_path_copy (path);
    path_str = gtk_tree_path_to_string (path_copy);
    if (strcmp (path_str, PATH))
    {
        TEST_FAIL("path copy = %s, should be %s", path_str, PATH);
    }
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_copy
 * Params: const GtkTreePath *path
 * Returns: GtkTreePath* 
 * Assertion: Creates a new GtkTreePath as a copy of path.
 * Params Values: newly created GtkTreePath*
 * Expected: new GtkTreePath with path = "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"   
 */
static void test_purpose_94()
{
    #define PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    
    GtkTreePath* path;
    GtkTreePath* path_copy;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    path_copy = gtk_tree_path_copy (path);
    path_str = gtk_tree_path_to_string (path_copy);
    if (strcmp (path_str, PATH))
    {
        TEST_FAIL("path copy = %s, should be %s", path_str, PATH);
    }
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_copy
 * Params: const GtkTreePath *path
 * Returns: GtkTreePath* 
 * Assertion: Creates a new GtkTreePath as a copy of path.
 * Params Values: newly created GtkTreePath*
 * Expected: new GtkTreePath with path = "100000:100000:100000"   
 */
static void test_purpose_95()
{
    #define PATH "100000:100000:100000"
    
    GtkTreePath* path;
    GtkTreePath* path_copy;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    path_copy = gtk_tree_path_copy (path);
    path_str = gtk_tree_path_to_string (path_copy);
    if (strcmp (path_str, PATH))
    {
        TEST_FAIL("path copy = %s, should be %s", path_str, PATH);
    }
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_copy
 * Params: const GtkTreePath *path
 * Returns: GtkTreePath* 
 * Assertion: Creates a new GtkTreePath as a copy of path.
 * Params Values: newly created GtkTreePath*
 * Expected: new GtkTreePath with path = "2147483647:2147483647:2147483647"   
 */
static void test_purpose_96()
{
    #define PATH "2147483647:2147483647:2147483647"
    
    GtkTreePath* path;
    GtkTreePath* path_copy;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    path_copy = gtk_tree_path_copy (path);
    path_str = gtk_tree_path_to_string (path_copy);
    if (strcmp (path_str, PATH))
    {
        TEST_FAIL("path copy = %s, should be %s", path_str, PATH);
    }
    
    #undef PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_compare
 * Params: const GtkTreePath *a, const GtkTreePath *b
 * Returns: gint
 * Assertion: Compares two paths.
 * Params Values: newly created GtkTreePath*, newly created GtkTreePath
 * Expected: -1 
 * 
 * Name: gtk_tree_path_compare
 * Params: const GtkTreePath *a, const GtkTreePath *b
 * Returns: gint
 * Assertion: If a appears before b in a tree, then -1 is returned. 
 * Params Values: newly created GtkTreePath*, newly created GtkTreePath
 * Expected: -1   
 */
static void test_purpose_97()
{
    #define A_PATH "0:0"
    #define B_PATH "0:0:0"
    
    GtkTreePath* a;
    GtkTreePath* b;
    gint result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    a = gtk_tree_path_new_from_string (A_PATH);
    
    if (!a)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    b = gtk_tree_path_new_from_string (B_PATH);
    
    if (!b)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    result = gtk_tree_path_compare (a, b);
    if (result != -1)
    {
        TEST_FAIL("gtk_tree_path_compare (a, b) result = %i, should be -1", result);
    }
    
    #undef A_PATH
    #undef B_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_compare
 * Params: const GtkTreePath *a, const GtkTreePath *b
 * Returns: gint
 * Assertion: Compares two paths.
 * Params Values: newly created GtkTreePath*, newly created GtkTreePath
 * Expected: -1 
 * 
 * Name: gtk_tree_path_compare
 * Params: const GtkTreePath *a, const GtkTreePath *b
 * Returns: gint
 * Assertion: If a appears before b in a tree, then -1 is returned. 
 * Params Values: newly created GtkTreePath*, newly created GtkTreePath
 * Expected: -1   
 */
static void test_purpose_98()
{
    #define A_PATH "2:0:2"
    #define B_PATH "3:2:0:2"
    
    GtkTreePath* a;
    GtkTreePath* b;
    gint result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    a = gtk_tree_path_new_from_string (A_PATH);
    
    if (!a)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    b = gtk_tree_path_new_from_string (B_PATH);
    
    if (!b)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    result = gtk_tree_path_compare (a, b);
    if (result != -1)
    {
        TEST_FAIL("gtk_tree_path_compare (a, b) result = %i, should be -1", result);
    }
    
    #undef A_PATH
    #undef B_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_compare
 * Params: const GtkTreePath *a, const GtkTreePath *b
 * Returns: gint
 * Assertion: If b appears before a, then 1 is returned. 
 * Params Values: newly created GtkTreePath*, newly created GtkTreePath
 * Expected: 1   
 */
static void test_purpose_99()
{
    #define A_PATH "0:0:0"
    #define B_PATH "0:0"
    
    GtkTreePath* a;
    GtkTreePath* b;
    gint result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    a = gtk_tree_path_new_from_string (A_PATH);
    
    if (!a)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    b = gtk_tree_path_new_from_string (B_PATH);
    
    if (!b)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    result = gtk_tree_path_compare (a, b);
    if (result != 1)
    {
        TEST_FAIL("gtk_tree_path_compare (a, b) result = %i, should be 1", result);
    }
    
    #undef A_PATH
    #undef B_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_compare
 * Params: const GtkTreePath *a, const GtkTreePath *b
 * Returns: gint
 * Assertion: If b appears before a, then 1 is returned. 
 * Params Values: newly created GtkTreePath*, newly created GtkTreePath
 * Expected: 1   
 */
static void test_purpose_100()
{
    #define A_PATH "3:2:0:2"
    #define B_PATH "2:0:2"
    
    GtkTreePath* a;
    GtkTreePath* b;
    gint result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    a = gtk_tree_path_new_from_string (A_PATH);
    
    if (!a)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    b = gtk_tree_path_new_from_string (B_PATH);
    
    if (!b)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    result = gtk_tree_path_compare (a, b);
    if (result != 1)
    {
        TEST_FAIL("gtk_tree_path_compare (a, b) result = %i, should be 1", result);
    }
    
    #undef A_PATH
    #undef B_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_compare
 * Params: const GtkTreePath *a, const GtkTreePath *b
 * Returns: gint
 * Assertion: If the two nodes are equal, then 0 is returned.
 * Params Values: newly created GtkTreePath*, newly created GtkTreePath
 * Expected: 0  
 */
static void test_purpose_101()
{
    #define A_PATH "0:0:0"
    #define B_PATH "0:0:0"
    
    GtkTreePath* a;
    GtkTreePath* b;
    gint result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    a = gtk_tree_path_new_from_string (A_PATH);
    
    if (!a)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    b = gtk_tree_path_new_from_string (B_PATH);
    
    if (!b)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    result = gtk_tree_path_compare (a, b);
    if (result != 0)
    {
        TEST_FAIL("gtk_tree_path_compare (a, b) result = %i, should be 0", result);
    }
    
    #undef A_PATH
    #undef B_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_compare
 * Params: const GtkTreePath *a, const GtkTreePath *b
 * Returns: gint
 * Assertion: If the two nodes are equal, then 0 is returned.
 * Params Values: newly created GtkTreePath*, newly created GtkTreePath
 * Expected: 0  
 */
static void test_purpose_102()
{
    #define A_PATH "3:2:0:2"
    #define B_PATH "3:2:0:2"
    
    GtkTreePath* a;
    GtkTreePath* b;
    gint result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    a = gtk_tree_path_new_from_string (A_PATH);
    
    if (!a)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    b = gtk_tree_path_new_from_string (B_PATH);
    
    if (!b)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    result = gtk_tree_path_compare (a, b);
    if (result != 0)
    {
        TEST_FAIL("gtk_tree_path_compare (a, b) result = %i, should be 0", result);
    }
    
    #undef A_PATH
    #undef B_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_next
 * Params: GtkTreePath *path
 * Returns: void 
 * Assertion: Moves the path to point to the next node at the current depth.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "0:0:1"   
 */
static void test_purpose_103()
{
    #define PATH "0:0:0"
    #define NEXT_PATH "0:0:1"
    
    GtkTreePath* path;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_next (path);
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, NEXT_PATH))
    {
        TEST_FAIL("next node path = %s, should be %s", path_str, NEXT_PATH);
    }
    
    #undef PATH
    #undef NEXT_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_next
 * Params: GtkTreePath *path
 * Returns: void 
 * Assertion: Moves the path to point to the next node at the current depth.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "5:5:6"   
 */
static void test_purpose_104()
{
    #define PATH "5:5:5"
    #define NEXT_PATH "5:5:6"
    
    GtkTreePath* path;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_next (path);
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, NEXT_PATH))
    {
        TEST_FAIL("next node path = %s, should be %s", path_str, NEXT_PATH);
    }
    
    #undef PATH
    #undef NEXT_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_next
 * Params: GtkTreePath *path
 * Returns: void 
 * Assertion: Moves the path to point to the next node at the current depth.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:1"   
 */
static void test_purpose_105()
{
    #define PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    #define NEXT_PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:1"
    
    GtkTreePath* path;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_next (path);
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, NEXT_PATH))
    {
        TEST_FAIL("next node path = %s, should be %s", path_str, NEXT_PATH);
    }
    
    #undef PATH
    #undef NEXT_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_next
 * Params: GtkTreePath *path
 * Returns: void 
 * Assertion: Moves the path to point to the next node at the current depth.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "100000:100000:100001"   
 */
static void test_purpose_106()
{
    #define PATH "100000:100000:100000"
    #define NEXT_PATH "100000:100000:100001"
    
    GtkTreePath* path;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_next (path);
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, NEXT_PATH))
    {
        TEST_FAIL("next node path = %s, should be %s", path_str, NEXT_PATH);
    }
    
    #undef PATH
    #undef NEXT_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_next
 * Params: GtkTreePath *path
 * Returns: void 
 * Assertion: Moves the path to point to the next node at the current depth.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "2147483647:2147483647:2147483646"   
 */
static void test_purpose_107()
{
    #define PATH "2147483647:2147483647:2147483645"
    #define NEXT_PATH "2147483647:2147483647:2147483646"
    
    GtkTreePath* path;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_next (path);
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, NEXT_PATH))
    {
        TEST_FAIL("next node path = %s, should be %s", path_str, NEXT_PATH);
    }
    
    #undef PATH
    #undef NEXT_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_prev
 * Params: GtkTreePath *path
 * Returns: gboolean 
 * Assertion: Moves the path to point to the previous node at the current depth, if it exists.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "0:0:0" and TRUE as a result   
 */
static void test_purpose_108()
{
    #define PATH "0:0:1"
    #define PREV_PATH "0:0:0"
    #define RESULT TRUE
    
    GtkTreePath* path;
    gchar* path_str;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    result = gtk_tree_path_prev (path);
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, PREV_PATH))
    {
        TEST_FAIL("previous node path = %s, should be %s", path_str, PREV_PATH);
    } 
    if (result != RESULT)
    {
        TEST_FAIL("gtk_tree_path_prev () return %i instead of %i", result, RESULT);
    } 
    
    #undef PATH
    #undef PREV_PATH
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_prev
 * Params: GtkTreePath *path
 * Returns: gboolean 
 * Assertion: Moves the path to point to the previous node at the current depth, if it exists.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "5:5:5" and TRUE as a result   
 */
static void test_purpose_109()
{
    #define PATH "5:5:6"
    #define PREV_PATH "5:5:5"
    #define RESULT TRUE
    
    GtkTreePath* path;
    gchar* path_str;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    result = gtk_tree_path_prev (path);
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, PREV_PATH))
    {
        TEST_FAIL("previous node path = %s, should be %s", path_str, PREV_PATH);
    } 
    if (result != RESULT)
    {
        TEST_FAIL("gtk_tree_path_prev () return %i instead of %i", result, RESULT);
    } 
    
    #undef PATH
    #undef PREV_PATH
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_prev
 * Params: GtkTreePath *path
 * Returns: gboolean 
 * Assertion: Moves the path to point to the previous node at the current depth, if it exists.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0" and TRUE as a result   
 */
static void test_purpose_110()
{
    #define PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:1"
    #define PREV_PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    #define RESULT TRUE
    
    GtkTreePath* path;
    gchar* path_str;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    result = gtk_tree_path_prev (path);
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, PREV_PATH))
    {
        TEST_FAIL("previous node path = %s, should be %s", path_str, PREV_PATH);
    } 
    if (result != RESULT)
    {
        TEST_FAIL("gtk_tree_path_prev () return %i instead of %i", result, RESULT);
    } 
    
    #undef PATH
    #undef PREV_PATH
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_prev
 * Params: GtkTreePath *path
 * Returns: gboolean 
 * Assertion: Moves the path to point to the previous node at the current depth, if it exists.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "100000:100000:100000" and TRUE as a result   
 */
static void test_purpose_111()
{
    #define PATH "100000:100000:100001"
    #define PREV_PATH "100000:100000:100000"
    #define RESULT TRUE
    
    GtkTreePath* path;
    gchar* path_str;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    result = gtk_tree_path_prev (path);
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, PREV_PATH))
    {
        TEST_FAIL("previous node path = %s, should be %s", path_str, PREV_PATH);
    } 
    if (result != RESULT)
    {
        TEST_FAIL("gtk_tree_path_prev () return %i instead of %i", result, RESULT);
    } 
    
    #undef PATH
    #undef PREV_PATH
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_prev
 * Params: GtkTreePath *path
 * Returns: gboolean 
 * Assertion: Moves the path to point to the previous node at the current depth, if it exists.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "2147483647:2147483647:2147483645" and TRUE as a result   
 */
static void test_purpose_112()
{
    #define PATH "2147483647:2147483647:2147483646"
    #define PREV_PATH "2147483647:2147483647:2147483645"
    #define RESULT TRUE
    
    GtkTreePath* path;
    gchar* path_str;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    result = gtk_tree_path_prev (path);
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, PREV_PATH))
    {
        TEST_FAIL("previous node path = %s, should be %s", path_str, PREV_PATH);
    } 
    if (result != RESULT)
    {
        TEST_FAIL("gtk_tree_path_prev () return %i instead of %i", result, RESULT);
    } 
    
    #undef PATH
    #undef PREV_PATH
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_prev
 * Params: GtkTreePath *path
 * Returns: gboolean 
 * Assertion: Moves the path to point to the previous node at the current depth, if it exists.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0" and FALSE as a result   
 */
static void test_purpose_113()
{
    #define PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    #define PREV_PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    #define RESULT FALSE
    
    GtkTreePath* path;
    gchar* path_str;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    result = gtk_tree_path_prev (path);
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, PREV_PATH))
    {
        TEST_FAIL("previous node path = %s, should be %s", path_str, PREV_PATH);
    } 
    if (result != RESULT)
    {
        TEST_FAIL("gtk_tree_path_prev () return %i instead of %i", result, RESULT);
    } 
    
    #undef PATH
    #undef PREV_PATH
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_up
 * Params: GtkTreePath *path
 * Returns: gboolean 
 * Assertion: Moves the path to point to it`s parent node, if it has a parent.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "0:0" and TRUE as a result   
 */
static void test_purpose_114()
{
    #define PATH "0:0:1"
    #define UP_PATH "0:0"
    #define RESULT TRUE
    
    GtkTreePath* path;
    gchar* path_str;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    result = gtk_tree_path_up (path);
    path_str = gtk_tree_path_to_string (path);
    if (path_str != NULL)
    {
        if (strcmp (path_str, UP_PATH))
        {
            TEST_FAIL("up node path = %s, should be %s", path_str, UP_PATH);
        } 
    }
    if (result != RESULT)
    {
        TEST_FAIL("gtk_tree_path_prev () return %i instead of %i", result, RESULT);
    } 
    
    #undef PATH
    #undef UP_PATH
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_up
 * Params: GtkTreePath *path
 * Returns: gboolean 
 * Assertion: Moves the path to point to it`s parent node, if it has a parent.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "5:5" and TRUE as a result   
 */
static void test_purpose_115()
{
    #define PATH "5:5:6"
    #define UP_PATH "5:5"
    #define RESULT TRUE
    
    GtkTreePath* path;
    gchar* path_str;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    result = gtk_tree_path_up (path);
    path_str = gtk_tree_path_to_string (path);
    if (path_str != NULL)
    {
        if (strcmp (path_str, UP_PATH))
        {
            TEST_FAIL("up node path = %s, should be %s", path_str, UP_PATH);
        } 
    }
    if (result != RESULT)
    {
        TEST_FAIL("gtk_tree_path_prev () return %i instead of %i", result, RESULT);
    } 
    
    #undef PATH
    #undef UP_PATH
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_up
 * Params: GtkTreePath *path
 * Returns: gboolean 
 * Assertion: Moves the path to point to it`s parent node, if it has a parent.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0" and TRUE as a result   
 */
static void test_purpose_116()
{
    #define PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:1"
    #define UP_PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    #define RESULT TRUE
    
    GtkTreePath* path;
    gchar* path_str;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    result = gtk_tree_path_up (path);
    path_str = gtk_tree_path_to_string (path);
    if (path_str != NULL)
    {
        if (strcmp (path_str, UP_PATH))
        {
            TEST_FAIL("up node path = %s, should be %s", path_str, UP_PATH);
        } 
    }
    if (result != RESULT)
    {
        TEST_FAIL("gtk_tree_path_prev () return %i instead of %i", result, RESULT);
    } 
    
    #undef PATH
    #undef UP_PATH
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_up
 * Params: GtkTreePath *path
 * Returns: gboolean 
 * Assertion: Moves the path to point to it`s parent node, if it has a parent.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "100000:100000" and TRUE as a result   
 */
static void test_purpose_117()
{
    #define PATH "100000:100000:100001"
    #define UP_PATH "100000:100000"
    #define RESULT TRUE
    
    GtkTreePath* path;
    gchar* path_str;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    result = gtk_tree_path_up (path);
    path_str = gtk_tree_path_to_string (path);
    if (path_str != NULL)
    {
        if (strcmp (path_str, UP_PATH))
        {
            TEST_FAIL("up node path = %s, should be %s", path_str, UP_PATH);
        } 
    }
    if (result != RESULT)
    {
        TEST_FAIL("gtk_tree_path_prev () return %i instead of %i", result, RESULT);
    } 
    
    #undef PATH
    #undef UP_PATH
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_up
 * Params: GtkTreePath *path
 * Returns: gboolean 
 * Assertion: Moves the path to point to it`s parent node, if it has a parent.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "2147483647:2147483647" and TRUE as a result   
 */
static void test_purpose_118()
{
    #define PATH "2147483647:2147483647:2147483646"
    #define UP_PATH "2147483647:2147483647"
    #define RESULT TRUE
    
    GtkTreePath* path;
    gchar* path_str;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    result = gtk_tree_path_up (path);
    path_str = gtk_tree_path_to_string (path);
    if (path_str != NULL)
    {
        if (strcmp (path_str, UP_PATH))
        {
            TEST_FAIL("up node path = %s, should be %s", path_str, UP_PATH);
        } 
    }
    if (result != RESULT)
    {
        TEST_FAIL("gtk_tree_path_prev () return %i instead of %i", result, RESULT);
    } 
    
    #undef PATH
    #undef UP_PATH
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_up
 * Params: GtkTreePath *path
 * Returns: gboolean 
 * Assertion: Moves the path to point to it`s parent node, if it has a parent.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "4" and TRUE as a result   
 */
static void test_purpose_119()
{
    #define PATH "4"
    #define UP_PATH "4"
    #define RESULT TRUE
    
    GtkTreePath* path;
    gchar* path_str;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    result = gtk_tree_path_up (path);
    path_str = gtk_tree_path_to_string (path);
    if (path_str != NULL)
    {
        if (strcmp (path_str, UP_PATH))
        {
            TEST_FAIL("up node path = %s, should be %s", path_str, UP_PATH);
        } 
    }
    if (result != RESULT)
    {
        TEST_FAIL("gtk_tree_path_prev () return %i instead of %i", result, RESULT);
    } 
    
    #undef PATH
    #undef UP_PATH
    #undef RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_down
 * Params: GtkTreePath *path
 * Returns: void 
 * Assertion: Moves path to point to the first child of the current path.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "0:0:0:0"   
 */
static void test_purpose_120()
{
    #define PATH "0:0:0"
    #define DOWN_PATH "0:0:0:0"
    
    GtkTreePath* path;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_down (path);
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, DOWN_PATH))
    {
        TEST_FAIL("down node path = %s, should be %s", path_str, DOWN_PATH);
    }
    
    #undef PATH
    #undef DOWN_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_down
 * Params: GtkTreePath *path
 * Returns: void 
 * Assertion: Moves path to point to the first child of the current path.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "5:5:5:0"   
 */
static void test_purpose_121()
{
    #define PATH "5:5:5"
    #define DOWN_PATH "5:5:5:0"
    
    GtkTreePath* path;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_down (path);
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, DOWN_PATH))
    {
        TEST_FAIL("down node path = %s, should be %s", path_str, DOWN_PATH);
    }
    
    #undef PATH
    #undef DOWN_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_down
 * Params: GtkTreePath *path
 * Returns: void 
 * Assertion: Moves path to point to the first child of the current path.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"   
 */
static void test_purpose_122()
{
    #define PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    #define DOWN_PATH "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    
    GtkTreePath* path;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_down (path);
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, DOWN_PATH))
    {
        TEST_FAIL("down node path = %s, should be %s", path_str, DOWN_PATH);
    }
    
    #undef PATH
    #undef DOWN_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_down
 * Params: GtkTreePath *path
 * Returns: void 
 * Assertion: Moves path to point to the first child of the current path.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "100000:100000:100000:0"   
 */
static void test_purpose_123()
{
    #define PATH "100000:100000:100000"
    #define DOWN_PATH "100000:100000:100000:0"
    
    GtkTreePath* path;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_down (path);
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, DOWN_PATH))
    {
        TEST_FAIL("down node path = %s, should be %s", path_str, DOWN_PATH);
    }
    
    #undef PATH
    #undef DOWN_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_down
 * Params: GtkTreePath *path
 * Returns: void 
 * Assertion: Moves path to point to the first child of the current path.
 * Params Values: newly created GtkTreePath*
 * Expected: path = "2147483647:2147483647:2147483645:0"   
 */
static void test_purpose_124()
{
    #define PATH "2147483647:2147483647:2147483645"
    #define DOWN_PATH "2147483647:2147483647:2147483645:0"
    
    GtkTreePath* path;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH);
    
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_path_down (path);
    path_str = gtk_tree_path_to_string (path);
    if (strcmp (path_str, DOWN_PATH))
    {
        TEST_FAIL("down node path = %s, should be %s", path_str, DOWN_PATH);
    }
    
    #undef PATH
    #undef DOWN_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_iter_copy
 * Params: GtkTreeIter *iter
 * Returns: GtkTreeIter*
 * Assertion: Creates a dynamically allocated tree iterator as a copy of iter.
 * Params Values: initialized GtkTreeIter*
 * Expected: copy of iter 
 * 
 * Name: gtk_tree_iter_free
 * Params: GtkTreeIter* iter
 * Returns: void
 * Assertion: Frees an iterator that has been allocated on the heap. 
 * Params Values: newly created GtkTreeIter*
 * Expected: void  
 */
static void test_purpose_125()
{
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter *iter_copy;
    gchar* path_str;
    gchar* path_copy_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_store_append (tree_store, &iter, NULL);
    iter_copy = gtk_tree_iter_copy (&iter);
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter));
    path_copy_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), iter_copy));
    
    if (strcmp (path_str, path_copy_str))
    {
        TEST_FAIL("gtk_tree_iter_copy () return iter %s instead of %s", path_copy_str, path_str);
    }
    
    gtk_tree_iter_free (iter_copy);
    
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_next
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Sets iter to point to the node following it at the current level.
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: TRUE  
 */
static void test_purpose_126()
{
    #define N_NODES 3
    #define NODE_INDEX 0
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter save_iter;
    GtkTreeIter next_iter;
    gchar* path_str;
    gchar* next_path_str;
    guint i;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < N_NODES; i++)
    {
        gtk_tree_store_append (tree_store, &iter, NULL);
        if (i == NODE_INDEX)
        {
            save_iter = iter;
        }
        if (i == NODE_INDEX + 1)
        {
            next_iter = iter;
        }
    
    }
    
    was_set = gtk_tree_model_iter_next (GTK_TREE_MODEL (tree_store), &save_iter);
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &next_iter));
    next_path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &save_iter));
    
    if (strcmp (next_path_str, path_str))
    {
        TEST_FAIL("gtk_tree_model_iter_next () set iter to %s, should be iter with path %s", next_path_str, path_str);
    }
    
    #undef N_NODES
    #undef NODE_INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_next
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Sets iter to point to the node following it at the current level.
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: TRUE  
 */
static void test_purpose_127()
{
    #define N_NODES 3
    #define NODE_INDEX 1
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter save_iter;
    GtkTreeIter next_iter;
    gchar* path_str;
    gchar* next_path_str;
    guint i;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < N_NODES; i++)
    {
        gtk_tree_store_append (tree_store, &iter, NULL);
        if (i == NODE_INDEX)
        {
            save_iter = iter;
        }
        if (i == NODE_INDEX + 1)
        {
            next_iter = iter;
        }
    
    }
    
    was_set = gtk_tree_model_iter_next (GTK_TREE_MODEL (tree_store), &save_iter);
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &next_iter));
    next_path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &save_iter));
    
    if (strcmp (next_path_str, path_str))
    {
        TEST_FAIL("gtk_tree_model_iter_next () set iter to %s, should be iter with path %s", next_path_str, path_str);
    }
    
    #undef N_NODES
    #undef NODE_INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_next
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: If there is no next iter, FALSE is returned and iter is set to be invalid.
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: FALSE    
 */
static void test_purpose_128()
{
    #define N_NODES 1
    #define NODE_INDEX 0
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter save_iter;
    GtkTreeIter next_iter;
    gchar* path_str;
    gchar* next_path_str;
    guint i;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < N_NODES; i++)
    {
        gtk_tree_store_append (tree_store, &iter, NULL);
        if (i == NODE_INDEX)
        {
            save_iter = iter;
        }
    
        if (i == NODE_INDEX + 1)
        {
            next_iter = iter;
        }
    }
    
    was_set = gtk_tree_model_iter_next (GTK_TREE_MODEL (tree_store), &save_iter);
    
    if (was_set != FALSE)
    {
        TEST_FAIL("gtk_tree_model_iter_next () return TRUE insead of FALSE", NULL);
    }
    
    #undef N_NODES
    #undef NODE_INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_next
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: If there is no next iter, FALSE is returned and iter is set to be invalid.
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: FALSE    
 */
static void test_purpose_129()
{
    #define N_NODES 11
    #define NODE_INDEX 10
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter save_iter;
    GtkTreeIter next_iter;
    gchar* path_str;
    gchar* next_path_str;
    guint i;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < N_NODES; i++)
    {
        gtk_tree_store_append (tree_store, &iter, NULL);
        if (i == NODE_INDEX)
        {
            save_iter = iter;
        }
    
        if (i == NODE_INDEX + 1)
        {
            next_iter = iter;
        }
    }
    
    was_set = gtk_tree_model_iter_next (GTK_TREE_MODEL (tree_store), &save_iter);
    
    if (was_set != FALSE)
    {
        TEST_FAIL("gtk_tree_model_iter_next () return TRUE insead of FALSE", NULL);
    }
    
    #undef N_NODES
    #undef NODE_INDEX
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_children
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *parent 
 * Returns: gboolean
 * Assertion: Sets iter to point to the first child of parent. 
 * Params Values: newly created GtkTreeModel*, uninitialized iter, initialized iter
 * Expected: TRUE  
 */
static void test_purpose_130()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PARENT_LEVEL 0
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter iter_children;
    GtkTreeIter child_iter;
    gchar* path_str;
    gchar* children_path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
            if ((i == PARENT_LEVEL + 1) && (j == 0))
            {
                iter_children = child_iter;
            }
            
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == PARENT_LEVEL)
        {
            parent_iter = iter;
        }
    }
    
    was_set = gtk_tree_model_iter_children (GTK_TREE_MODEL (tree_store), &iter, &parent_iter);
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter));
    children_path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter_children));
    
    if (strcmp (children_path_str, path_str))
    {
        TEST_FAIL("gtk_tree_model_iter_children () set iter to %s, should be iter with path %s", path_str, children_path_str);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PARENT_LEVEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_children
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *parent 
 * Returns: gboolean
 * Assertion: Sets iter to point to the first child of parent. 
 * Params Values: newly created GtkTreeModel*, uninitialized iter, initialized iter
 * Expected: TRUE  
 */
static void test_purpose_131()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PARENT_LEVEL 2
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter iter_children;
    GtkTreeIter child_iter;
    gchar* path_str;
    gchar* children_path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
            if ((i == PARENT_LEVEL + 1) && (j == 0))
            {
                iter_children = child_iter;
            }
            
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == PARENT_LEVEL)
        {
            parent_iter = iter;
        }
    }
    
    was_set = gtk_tree_model_iter_children (GTK_TREE_MODEL (tree_store), &iter, &parent_iter);
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter));
    children_path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter_children));
    
    if (strcmp (children_path_str, path_str))
    {
        TEST_FAIL("gtk_tree_model_iter_children () set iter to %s, should be iter with path %s", path_str, children_path_str);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PARENT_LEVEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_children
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *parent 
 * Returns: gboolean
 * Assertion: Sets iter to point to the first child of parent. 
 * Params Values: newly created GtkTreeModel*, uninitialized iter, initialized iter
 * Expected: TRUE  
 */
static void test_purpose_132()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PARENT_LEVEL 3
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter iter_children;
    GtkTreeIter child_iter;
    gchar* path_str;
    gchar* children_path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
            if ((i == PARENT_LEVEL + 1) && (j == 0))
            {
                iter_children = child_iter;
            }
            
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == PARENT_LEVEL)
        {
            parent_iter = iter;
        }
    }
    
    was_set = gtk_tree_model_iter_children (GTK_TREE_MODEL (tree_store), &iter, &parent_iter);
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter));
    children_path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter_children));
    
    if (strcmp (children_path_str, path_str))
    {
        TEST_FAIL("gtk_tree_model_iter_children () set iter to %s, should be iter with path %s", path_str, children_path_str);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PARENT_LEVEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_children
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *parent 
 * Returns: gboolean
 * Assertion: If parent has no children, FALSE is returned and iter is set to be invalid.
 * Params Values: newly created GtkTreeModel*, uninitialized iter, initialized iter
 * Expected: FALSE  
 */
static void test_purpose_133()
{
    #define DEPTH 1
    #define INDICES {0}
    #define PARENT_LEVEL 0
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter iter_children;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
            if ((i == PARENT_LEVEL + 1) && (j == 0))
            {
                iter_children = child_iter;
            }
            
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == PARENT_LEVEL)
        {
            parent_iter = iter;
        }
    }
    
    was_set = gtk_tree_model_iter_children (GTK_TREE_MODEL (tree_store), &iter, &parent_iter);
    
    if (was_set != FALSE)
    {
        TEST_FAIL("gtk_tree_model_iter_children () return TRUE instead of FALSE", NULL);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PARENT_LEVEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_children
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *parent 
 * Returns: gboolean
 * Assertion: If parent has no children, FALSE is returned and iter is set to be invalid.
 * Params Values: newly created GtkTreeModel*, uninitialized iter, initialized iter
 * Expected: FALSE  
 */
static void test_purpose_134()
{
    #define DEPTH 3
    #define INDICES {0, 1, 0}
    #define PARENT_LEVEL 2
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter iter_children;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
            if ((i == PARENT_LEVEL + 1) && (j == 0))
            {
                iter_children = child_iter;
            }
            
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == PARENT_LEVEL)
        {
            parent_iter = iter;
        }
    }
    
    was_set = gtk_tree_model_iter_children (GTK_TREE_MODEL (tree_store), &iter, &parent_iter);
    
    if (was_set != FALSE)
    {
        TEST_FAIL("gtk_tree_model_iter_children () return TRUE instead of FALSE", NULL);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PARENT_LEVEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_children
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *parent 
 * Returns: gboolean
 * Assertion: If parent is NULL returns the first node, equivalent to gtk_tree_model_get_iter_first (tree_model, iter);
 * Params Values: newly created GtkTreeModel*, uninitialized iter, NULL
 * Expected: TRUE  
 */
static void test_purpose_135()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter iter_children;
    GtkTreeIter child_iter;
    gchar* path_str;
    gchar* children_path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
    }
    
    was_set = gtk_tree_model_iter_children (GTK_TREE_MODEL (tree_store), 
                                            &iter, NULL);
    if (!was_set)
    {
        TEST_FAIL ("was_set = FALSE\n", NULL);
    }
    
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter));
    
    if (strcmp (path_str, "0"))
    {
        TEST_FAIL ("path_str = '%s', should be '0'", path_str);
    }
    
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_has_child
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter has children, FALSE otherwise.
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: TRUE if iter has children, FALSE otherwise.  
 */
static void test_purpose_136()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define NODE_LEVEL 0
    #define EXPECTED_RESULT TRUE
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter save_iter;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean has_child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == NODE_LEVEL)
        {
            save_iter = iter;
        }
    }
    
    has_child = gtk_tree_model_iter_has_child (GTK_TREE_MODEL (tree_store), &save_iter);
    
    if (has_child != EXPECTED_RESULT)
    {
        TEST_FAIL("gtk_tree_model_iter_has_child () return %i instead of %i", has_child, EXPECTED_RESULT);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef NODE_LEVEL
    #undef EXPECTED_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_has_child
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns TRUE if iter has children, FALSE otherwise.
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: TRUE if iter has children, FALSE otherwise.  
 */
static void test_purpose_137()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define NODE_LEVEL 4
    #define EXPECTED_RESULT FALSE
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter save_iter;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean has_child;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == NODE_LEVEL)
        {
            save_iter = iter;
        }
    }
    
    has_child = gtk_tree_model_iter_has_child (GTK_TREE_MODEL (tree_store), &save_iter);
    
    if (has_child != EXPECTED_RESULT)
    {
        TEST_FAIL("gtk_tree_model_iter_has_child () return %i instead of %i", has_child, EXPECTED_RESULT);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef NODE_LEVEL
    #undef EXPECTED_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_n_children
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: gint
 * Assertion: Returns the number of children that iter has.
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: 4  
 */
static void test_purpose_138()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define NODE_LEVEL 0
    #define N_CHILDREN 4
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter save_iter;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gint n_children;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == NODE_LEVEL)
        {
            save_iter = iter;
        }
    }
    
    n_children = gtk_tree_model_iter_n_children (GTK_TREE_MODEL (tree_store), &save_iter);
    
    if (n_children != N_CHILDREN)
    {
        TEST_FAIL("gtk_tree_model_iter_n_children () return %i instead of %i", n_children, N_CHILDREN);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef NODE_LEVEL
    #undef N_CHILDREN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_n_children
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: gint
 * Assertion: As a special case, if iter is NULL, then the number of toplevel nodes is returned.
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: 8  
 */
static void test_purpose_139()
{
    #define DEPTH 2
    #define INDICES {7, 3}
    #define N_CHILDREN 8
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gint n_children;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    n_children = gtk_tree_model_iter_n_children (GTK_TREE_MODEL (tree_store), NULL);
    
    if (n_children != N_CHILDREN)
    {
        TEST_FAIL("gtk_tree_model_iter_n_children () return %i instead of %i", n_children, N_CHILDREN);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef N_CHILDREN
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_nth_child
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *parent, gint n
 * Returns: gboolean
 * Assertion: Sets iter to be the child of parent, using the given index. 
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: TRUE
 * 
 * Name: gtk_tree_model_iter_nth_child
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *parent, gint n
 * Returns: gboolean
 * Assertion: As a special case, if parent is NULL, then the nth root node is set.
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: TRUE  
 */
static void test_purpose_140()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define NODE_LEVEL 1
    #define N 4
    #define EXPECTED_PATH "7:3:4"
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter save_iter;
    GtkTreeIter *psave_iter = NULL;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean no_error;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == NODE_LEVEL)
        {
            save_iter = iter;
        }
    }
    psave_iter = (NODE_LEVEL > 0) ? &save_iter : NULL;
    no_error = gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (tree_store), &iter, psave_iter, N);
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter));
    
    if (strcmp (path_str, EXPECTED_PATH))
    {
        TEST_FAIL("gtk_tree_model_iter_nth_child () set iter to %s, should be iter with path %s", path_str, EXPECTED_PATH);
    }
    
    if (no_error == FALSE)
    {
        TEST_FAIL("gtk_tree_model_iter_nth_child () return FALSE instead of TRUE", NULL);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef NODE_LEVEL
    #undef N
    #undef EXPECTED_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_nth_child
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *parent, gint n
 * Returns: gboolean
 * Assertion: Sets iter to be the child of parent, using the given index. 
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: TRUE
 * 
 * Name: gtk_tree_model_iter_nth_child
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *parent, gint n
 * Returns: gboolean
 * Assertion: As a special case, if parent is NULL, then the nth root node is set.
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: TRUE  
 */
static void test_purpose_141()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define NODE_LEVEL -1
    #define N 5
    #define EXPECTED_PATH "5"
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter save_iter;
    GtkTreeIter *psave_iter = NULL;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean no_error;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == NODE_LEVEL)
        {
            save_iter = iter;
        }
    }
    psave_iter = (NODE_LEVEL > 0) ? &save_iter : NULL;
    no_error = gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (tree_store), &iter, psave_iter, N);
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter));
    
    if (strcmp (path_str, EXPECTED_PATH))
    {
        TEST_FAIL("gtk_tree_model_iter_nth_child () set iter to %s, should be iter with path %s", path_str, EXPECTED_PATH);
    }
    
    if (no_error == FALSE)
    {
        TEST_FAIL("gtk_tree_model_iter_nth_child () return FALSE instead of TRUE", NULL);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef NODE_LEVEL
    #undef N
    #undef EXPECTED_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_nth_child
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *parent, gint n
 * Returns: gboolean
 * Assertion: Sets iter to be the child of parent, using the given index. 
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: TRUE
 * 
 * Name: gtk_tree_model_iter_nth_child
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *parent, gint n
 * Returns: gboolean
 * Assertion: As a special case, if parent is NULL, then the nth root node is set.
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: TRUE  
 */
static void test_purpose_142()
{
    #define DEPTH 1
    #define INDICES {4}
    #define NODE_LEVEL -1
    #define N 0
    #define EXPECTED_PATH "0"
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter save_iter;
    GtkTreeIter *psave_iter = NULL;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean no_error;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == NODE_LEVEL)
        {
            save_iter = iter;
        }
    }
    psave_iter = (NODE_LEVEL > 0) ? &save_iter : NULL;
    no_error = gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (tree_store), &iter, psave_iter, N);
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter));
    
    if (strcmp (path_str, EXPECTED_PATH))
    {
        TEST_FAIL("gtk_tree_model_iter_nth_child () set iter to %s, should be iter with path %s", path_str, EXPECTED_PATH);
    }
    
    if (no_error == FALSE)
    {
        TEST_FAIL("gtk_tree_model_iter_nth_child () return FALSE instead of TRUE", NULL);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef NODE_LEVEL
    #undef N
    #undef EXPECTED_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_nth_child
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *parent, gint n
 * Returns: gboolean
 * Assertion: Sets iter to be the child of parent, using the given index. 
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: TRUE
 * 
 * Name: gtk_tree_model_iter_nth_child
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *parent, gint n
 * Returns: gboolean
 * Assertion: As a special case, if parent is NULL, then the nth root node is set.
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: TRUE  
 */
static void test_purpose_143()
{
    #define DEPTH 13
    #define INDICES {7, 3, 5, 0, 1, 4, 9, 2, 2, 6, 11, 99, 37}
    #define NODE_LEVEL 10
    #define N 0
    #define EXPECTED_PATH "7:3:5:0:1:4:9:2:2:6:11:0"
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter save_iter;
    GtkTreeIter *psave_iter = NULL;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean no_error;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == NODE_LEVEL)
        {
            save_iter = iter;
        }
    }
    psave_iter = (NODE_LEVEL > 0) ? &save_iter : NULL;
    no_error = gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (tree_store), &iter, psave_iter, N);
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter));
    
    if (strcmp (path_str, EXPECTED_PATH))
    {
        TEST_FAIL("gtk_tree_model_iter_nth_child () set iter to %s, should be iter with path %s", path_str, EXPECTED_PATH);
    }
    
    if (no_error == FALSE)
    {
        TEST_FAIL("gtk_tree_model_iter_nth_child () return FALSE instead of TRUE", NULL);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef NODE_LEVEL
    #undef N
    #undef EXPECTED_PATH
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_nth_child
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *parent, gint n
 * Returns: gboolean
 * Assertion: If index_ is too big, or parent has no children, iter is set to an invalid iterator and FALSE is returned. 
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: FALSE  
 */
static void test_purpose_144()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define NODE_LEVEL 1
    #define N 6
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter save_iter;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean no_error;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == NODE_LEVEL)
        {
            save_iter = iter;
        }
    }
    
    no_error = gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (tree_store), &iter, &save_iter, N);
    
    if (no_error != FALSE)
    {
        TEST_FAIL("gtk_tree_model_iter_nth_child () return TRUE instead of FALSE", NULL);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef NODE_LEVEL
    #undef N
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_parent
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *child 
 * Returns: gboolean
 * Assertion: Sets iter to be the parent of child. 
 * Params Values: newly created GtkTreeModel*, uninitialized iter, initialized iter
 * Expected: TRUE  
 */
static void test_purpose_145()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PARENT_LEVEL 0
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter iter_children;
    GtkTreeIter child_iter;
    gchar* path_str;
    gchar* parent_path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
            if ((i == PARENT_LEVEL + 1) && (j == 0))
            {
                iter_children = child_iter;
            }
            
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == PARENT_LEVEL)
        {
            parent_iter = iter;
        }
    }
    
    was_set = gtk_tree_model_iter_parent (GTK_TREE_MODEL (tree_store), &iter, &iter_children);
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter));
    parent_path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &parent_iter));
    
    if (strcmp (parent_path_str, path_str))
    {
        TEST_FAIL("gtk_tree_model_iter_children () set iter to %s, should be iter with path %s", path_str, parent_path_str);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PARENT_LEVEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_parent
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *child 
 * Returns: gboolean
 * Assertion: Sets iter to be the parent of child. 
 * Params Values: newly created GtkTreeModel*, uninitialized iter, initialized iter
 * Expected: TRUE  
 */
static void test_purpose_146()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PARENT_LEVEL 2
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter iter_children;
    GtkTreeIter child_iter;
    gchar* path_str;
    gchar* parent_path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
            if ((i == PARENT_LEVEL + 1) && (j == 0))
            {
                iter_children = child_iter;
            }
            
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == PARENT_LEVEL)
        {
            parent_iter = iter;
        }
    }
    
    was_set = gtk_tree_model_iter_parent (GTK_TREE_MODEL (tree_store), &iter, &iter_children);
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter));
    parent_path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &parent_iter));
    
    if (strcmp (parent_path_str, path_str))
    {
        TEST_FAIL("gtk_tree_model_iter_children () set iter to %s, should be iter with path %s", path_str, parent_path_str);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PARENT_LEVEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_parent
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *child 
 * Returns: gboolean
 * Assertion: Sets iter to be the parent of child. 
 * Params Values: newly created GtkTreeModel*, uninitialized iter, initialized iter
 * Expected: TRUE  
 */
static void test_purpose_147()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PARENT_LEVEL 3
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter iter_children;
    GtkTreeIter child_iter;
    gchar* path_str;
    gchar* parent_path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
            if ((i == PARENT_LEVEL + 1) && (j == 0))
            {
                iter_children = child_iter;
            }
            
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == PARENT_LEVEL)
        {
            parent_iter = iter;
        }
    }
    
    was_set = gtk_tree_model_iter_parent (GTK_TREE_MODEL (tree_store), &iter, &iter_children);
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter));
    parent_path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &parent_iter));
    
    if (strcmp (parent_path_str, path_str))
    {
        TEST_FAIL("gtk_tree_model_iter_children () set iter to %s, should be iter with path %s", path_str, parent_path_str);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PARENT_LEVEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_parent
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *child 
 * Returns: gboolean
 * Assertion: Sets iter to be the parent of child. 
 * Params Values: newly created GtkTreeModel*, uninitialized iter, initialized iter
 * Expected: TRUE  
 */
static void test_purpose_148()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PARENT_LEVEL 0
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter iter_children;
    GtkTreeIter child_iter;
    gchar* path_str;
    gchar* parent_path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
            if ((i == PARENT_LEVEL + 1) && (j == 0))
            {
                iter_children = child_iter;
            }
            
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == PARENT_LEVEL)
        {
            parent_iter = iter;
        }
    }
    
    was_set = gtk_tree_model_iter_parent (GTK_TREE_MODEL (tree_store), &iter, &iter_children);
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter));
    parent_path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &parent_iter));
    
    if (strcmp (parent_path_str, path_str))
    {
        TEST_FAIL("gtk_tree_model_iter_children () set iter to %s, should be iter with path %s", path_str, parent_path_str);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PARENT_LEVEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_parent
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *child 
 * Returns: gboolean
 * Assertion: Sets iter to be the parent of child. 
 * Params Values: newly created GtkTreeModel*, uninitialized iter, initialized iter
 * Expected: TRUE  
 */
static void test_purpose_149()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PARENT_LEVEL 2
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter iter_children;
    GtkTreeIter child_iter;
    gchar* path_str;
    gchar* parent_path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
            if ((i == PARENT_LEVEL + 1) && (j == 0))
            {
                iter_children = child_iter;
            }
            
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == PARENT_LEVEL)
        {
            parent_iter = iter;
        }
    }
    
    was_set = gtk_tree_model_iter_parent (GTK_TREE_MODEL (tree_store), &iter, &iter_children);
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter));
    parent_path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &parent_iter));
    
    if (strcmp (parent_path_str, path_str))
    {
        TEST_FAIL("gtk_tree_model_iter_children () set iter to %s, should be iter with path %s", path_str, parent_path_str);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PARENT_LEVEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_parent
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *child 
 * Returns: gboolean
 * Assertion: Sets iter to be the parent of child. 
 * Params Values: newly created GtkTreeModel*, uninitialized iter, initialized iter
 * Expected: TRUE  
 */
static void test_purpose_150()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PARENT_LEVEL 3
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter iter_children;
    GtkTreeIter child_iter;
    gchar* path_str;
    gchar* parent_path_str;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
            if ((i == PARENT_LEVEL + 1) && (j == 0))
            {
                iter_children = child_iter;
            }
            
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == PARENT_LEVEL)
        {
            parent_iter = iter;
        }
    }
    
    was_set = gtk_tree_model_iter_parent (GTK_TREE_MODEL (tree_store), &iter, &iter_children);
    path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &iter));
    parent_path_str = gtk_tree_path_to_string (gtk_tree_model_get_path (GTK_TREE_MODEL (tree_store), &parent_iter));
    
    if (strcmp (parent_path_str, path_str))
    {
        TEST_FAIL("gtk_tree_model_iter_children () set iter to %s, should be iter with path %s", path_str, parent_path_str);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PARENT_LEVEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_iter_parent
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, GtkTreeIter *child 
 * Returns: gboolean
 * Assertion: If child is at the toplevel, and doesn`t have a parent, then iter is set to an invalid iterator and FALSE is returned. 
 * Params Values: newly created GtkTreeModel*, uninitialized iter, initialized iter
 * Expected: FALSE  
 */
static void test_purpose_151()
{
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gboolean was_set;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_store_append (tree_store, &child_iter, NULL);
    
    was_set = gtk_tree_model_iter_parent (GTK_TREE_MODEL (tree_store), &iter, &child_iter);
    
    if (was_set != FALSE)
    {
        TEST_FAIL("gtk_tree_model_iter_children () return TRUE instead of FALSE", NULL);
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_ref_node
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: void
 * Assertion: Lets the tree ref the node.
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: void  
 */
static void test_purpose_152()
{
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_store_append (tree_store, &iter, NULL);
    
    gtk_tree_model_ref_node (GTK_TREE_MODEL (tree_store), &iter);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_unref_node
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: void
 * Assertion: Lets the tree unref the node
 * Params Values: newly created GtkTreeModel*, initialized iter
 * Expected: void  
 */
static void test_purpose_153()
{
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    gtk_tree_store_append (tree_store, &iter, NULL);
    
    gtk_tree_model_ref_node (GTK_TREE_MODEL (tree_store), &iter);
    gtk_tree_model_unref_node (GTK_TREE_MODEL (tree_store), &iter);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, ...
 * Returns: void
 * Assertion: Gets the value of one or more cells in the row referenced by iter.
 * Params Values: newly created GtkTreeModel*, initialized *iter, ...
 * Expected: void  
 */
static void test_purpose_154()
{
    #define DEPTH 3
    #define INDICES {0, 0, 0}
    #define LEVEL 0
    #define INT_VAL 0
    #define DOUBLE_VAL 0.0
    #define STRING_VAL ""
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gint int_place;
    gdouble double_place;
    gchar* string_place;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (3, G_TYPE_INT, G_TYPE_DOUBLE, G_TYPE_STRING);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == LEVEL)
        {
            saved_iter = iter;
        }
    }
    
    gtk_tree_store_set (tree_store, &saved_iter, 0, INT_VAL, 1, (gdouble)DOUBLE_VAL, 2, STRING_VAL, -1);
    gtk_tree_model_get (GTK_TREE_MODEL (tree_store), &saved_iter, 0, &int_place, 1, &double_place, 2, &string_place, -1);
    
    if (int_place != INT_VAL)
    {
        TEST_FAIL ("gtk_tree_model_get () return %i instead of %i", int_place, INT_VAL);     
    }
    if (double_place != DOUBLE_VAL)
    {
        TEST_FAIL ("gtk_tree_model_get () return %d instead of %d", double_place, DOUBLE_VAL);     
    }
    if (strcmp(string_place, STRING_VAL))
    {
        TEST_FAIL ("gtk_tree_model_get () return '%s' instead of '%s'", string_place, STRING_VAL);     
    }
    
    #undef DEPTH
    #undef INDICES
    #undef LEVEL
    #undef INT_VAL
    #undef DOUBLE_VAL
    #undef STRING_VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, ...
 * Returns: void
 * Assertion: Gets the value of one or more cells in the row referenced by iter.
 * Params Values: newly created GtkTreeModel*, initialized *iter, ...
 * Expected: void  
 */
static void test_purpose_155()
{
    #define DEPTH 3
    #define INDICES {7, 3, 5}
    #define LEVEL 1
    #define INT_VAL G_MAXINT
    #define DOUBLE_VAL G_MAXDOUBLE
    #define STRING_VAL "!@#$%^&*()_+|~=\";:'?<>`/"
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gint int_place;
    gdouble double_place;
    gchar* string_place;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (3, G_TYPE_INT, G_TYPE_DOUBLE, G_TYPE_STRING);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == LEVEL)
        {
            saved_iter = iter;
        }
    }
    
    gtk_tree_store_set (tree_store, &saved_iter, 0, INT_VAL, 1, (gdouble)DOUBLE_VAL, 2, STRING_VAL, -1);
    gtk_tree_model_get (GTK_TREE_MODEL (tree_store), &saved_iter, 0, &int_place, 1, &double_place, 2, &string_place, -1);
    
    if (int_place != INT_VAL)
    {
        TEST_FAIL ("gtk_tree_model_get () return %i instead of %i", int_place, INT_VAL);     
    }
    if (double_place != DOUBLE_VAL)
    {
        TEST_FAIL ("gtk_tree_model_get () return %d instead of %d", double_place, DOUBLE_VAL);     
    }
    if (strcmp(string_place, STRING_VAL))
    {
        TEST_FAIL ("gtk_tree_model_get () return '%s' instead of '%s'", string_place, STRING_VAL);     
    }
    
    #undef DEPTH
    #undef INDICES
    #undef LEVEL
    #undef INT_VAL
    #undef DOUBLE_VAL
    #undef STRING_VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, ...
 * Returns: void
 * Assertion: Gets the value of one or more cells in the row referenced by iter.
 * Params Values: newly created GtkTreeModel*, initialized *iter, ...
 * Expected: void  
 */
static void test_purpose_156()
{
    #define DEPTH 3
    #define INDICES {0, 5, 7}
    #define LEVEL 2
    #define INT_VAL G_MININT
    #define DOUBLE_VAL G_MINDOUBLE
    #define STRING_VAL "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gint int_place;
    gdouble double_place;
    gchar* string_place;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (3, G_TYPE_INT, G_TYPE_DOUBLE, G_TYPE_STRING);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == LEVEL)
        {
            saved_iter = iter;
        }
    }
    
    gtk_tree_store_set (tree_store, &saved_iter, 0, INT_VAL, 1, (gdouble)DOUBLE_VAL, 2, STRING_VAL, -1);
    gtk_tree_model_get (GTK_TREE_MODEL (tree_store), &saved_iter, 0, &int_place, 1, &double_place, 2, &string_place, -1);
    
    if (int_place != INT_VAL)
    {
        TEST_FAIL ("gtk_tree_model_get () return %i instead of %i", int_place, INT_VAL);     
    }
    if (double_place != DOUBLE_VAL)
    {
        TEST_FAIL ("gtk_tree_model_get () return %d instead of %d", double_place, DOUBLE_VAL);     
    }
    if (strcmp(string_place, STRING_VAL))
    {
        TEST_FAIL ("gtk_tree_model_get () return '%s' instead of '%s'", string_place, STRING_VAL);     
    }
    
    #undef DEPTH
    #undef INDICES
    #undef LEVEL
    #undef INT_VAL
    #undef DOUBLE_VAL
    #undef STRING_VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, ...
 * Returns: void
 * Assertion:  For example, to get a value from column 0 with type G_TYPE_STRING, you would write: gtk_tree_model_get (model, iter, 0, &place_string_here, -1), where place_string_here is a gchar* to be filled with the string.
 * Params Values: newly created GtkTreeModel*, initialized *iter, ...
 * Expected: void  
 */
static void test_purpose_157()
{
    #define DEPTH 3
    #define INDICES {0, 0, 0}
    #define LEVEL 0
    #define STRING_VAL ""
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gchar* string_place;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (3, G_TYPE_INT, G_TYPE_DOUBLE, G_TYPE_STRING);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == LEVEL)
        {
            saved_iter = iter;
        }
    }
    
    gtk_tree_store_set (tree_store, &saved_iter, 2, STRING_VAL, -1);
    gtk_tree_model_get (GTK_TREE_MODEL (tree_store), &saved_iter, 2, &string_place, -1);
    
    if (strcmp(string_place, STRING_VAL))
    {
        TEST_FAIL ("gtk_tree_model_get () return '%s' instead of '%s'", string_place, STRING_VAL);     
    }
    
    #undef DEPTH
    #undef INDICES
    #undef LEVEL
    #undef STRING_VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, ...
 * Returns: void
 * Assertion:  For example, to get a value from column 0 with type G_TYPE_STRING, you would write: gtk_tree_model_get (model, iter, 0, &place_string_here, -1), where place_string_here is a gchar* to be filled with the string.
 * Params Values: newly created GtkTreeModel*, initialized *iter, ...
 * Expected: void  
 */
static void test_purpose_158()
{
    #define DEPTH 3
    #define INDICES {0, 0, 0}
    #define LEVEL 0
    #define STRING_VAL "Test string"
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gchar* string_place;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (3, G_TYPE_INT, G_TYPE_DOUBLE, G_TYPE_STRING);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == LEVEL)
        {
            saved_iter = iter;
        }
    }
    
    gtk_tree_store_set (tree_store, &saved_iter, 2, STRING_VAL, -1);
    gtk_tree_model_get (GTK_TREE_MODEL (tree_store), &saved_iter, 2, &string_place, -1);
    
    if (strcmp(string_place, STRING_VAL))
    {
        TEST_FAIL ("gtk_tree_model_get () return '%s' instead of '%s'", string_place, STRING_VAL);     
    }
    
    #undef DEPTH
    #undef INDICES
    #undef LEVEL
    #undef STRING_VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_valist
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, va_list var_args
 * Returns: void
 * Assertion: See gtk_tree_model_get(), this version takes a va_list for language bindings to use. 
 * Params Values: newly created GtkTreeModel*, initialized *iter, va_list var_args
 * Expected: void  
 */
static void test_purpose_159()
{
    #define DEPTH 3
    #define INDICES {0, 0, 0}
    #define LEVEL 0
    #define STRING_VAL ""
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gchar* string_place;
    gchararray buff;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (3, G_TYPE_INT, G_TYPE_DOUBLE, G_TYPE_STRING);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == LEVEL)
        {
            saved_iter = iter;
        }
    }
    
    
    gtk_tree_store_set (tree_store, &saved_iter, 2, STRING_VAL, -1);
    
    global_valist (tree_store, &saved_iter, 2, &buff,  -1);
    
    if (strcmp (buff, STRING_VAL))
    {
        TEST_FAIL ("gtk_tree_model_get_valist () return '%s' instead of '%s'", buff, STRING_VAL);     
    }
    
    #undef DEPTH
    #undef INDICES
    #undef LEVEL
    #undef STRING_VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_valist
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, va_list var_args
 * Returns: void
 * Assertion: See gtk_tree_model_get(), this version takes a va_list for language bindings to use. 
 * Params Values: newly created GtkTreeModel*, initialized *iter, va_list var_args
 * Expected: void  
 */
static void test_purpose_160()
{
    #define DEPTH 3
    #define INDICES {0, 0, 0}
    #define LEVEL 0
    #define STRING_VAL "Test"
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gchar* string_place;
    gchararray buff;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (3, G_TYPE_INT, G_TYPE_DOUBLE, G_TYPE_STRING);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == LEVEL)
        {
            saved_iter = iter;
        }
    }
    
    
    gtk_tree_store_set (tree_store, &saved_iter, 2, STRING_VAL, -1);
    
    global_valist (tree_store, &saved_iter, 2, &buff,  -1);
    
    if (strcmp (buff, STRING_VAL))
    {
        TEST_FAIL ("gtk_tree_model_get_valist () return '%s' instead of '%s'", buff, STRING_VAL);     
    }
    
    #undef DEPTH
    #undef INDICES
    #undef LEVEL
    #undef STRING_VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_valist
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter, va_list var_args
 * Returns: void
 * Assertion: See gtk_tree_model_get(), this version takes a va_list for language bindings to use. 
 * Params Values: newly created GtkTreeModel*, initialized *iter, va_list var_args
 * Expected: void  
 */
static void test_purpose_161()
{
    #define DEPTH 3
    #define INDICES {0, 0, 0}
    #define LEVEL 0
    #define STRING_VAL "Looooong test string"
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GtkTreeIter child_iter;
    gint indices[] = INDICES;
    guint i;
    guint j;
    gchar* string_place;
    gchararray buff;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (3, G_TYPE_INT, G_TYPE_DOUBLE, G_TYPE_STRING);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == LEVEL)
        {
            saved_iter = iter;
        }
    }
    
    
    gtk_tree_store_set (tree_store, &saved_iter, 2, STRING_VAL, -1);
    
    global_valist (tree_store, &saved_iter, 2, &buff,  -1);
    
    if (strcmp (buff, STRING_VAL))
    {
        TEST_FAIL ("gtk_tree_model_get_valist () return '%s' instead of '%s'", buff, STRING_VAL);     
    }
    
    #undef DEPTH
    #undef INDICES
    #undef LEVEL
    #undef STRING_VAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_foreach
 * Params: GtkTreeModel* model, GtkTreeModelForeachFunc func, gpointer user_data 
 * Returns: void
 * Assertion: Calls func on each node in model in a depth-first fashion. 
 * Params Values: newly created GtkTreeModel*, global_count_nodes (), n_nodes
 * Expected: void  
 */
static void test_purpose_162()
{
    #define DEPTH 3
    #define INDICES {0, 0, 0}
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint n_nodes = 0;
    gint real_n_nodes = 0;
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
            real_n_nodes++;
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    gtk_tree_model_foreach (GTK_TREE_MODEL (tree_store), global_count_nodes, &n_nodes);
    
    if (real_n_nodes != n_nodes)
    {
        TEST_FAIL ("n_nodes = %i, should be %i", n_nodes, real_n_nodes); 
    }
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_foreach
 * Params: GtkTreeModel* model, GtkTreeModelForeachFunc func, gpointer user_data 
 * Returns: void
 * Assertion: Calls func on each node in model in a depth-first fashion. 
 * Params Values: newly created GtkTreeModel*, global_count_nodes (), n_nodes
 * Expected: void  
 */
static void test_purpose_163()
{
    #define DEPTH 3
    #define INDICES {5, 7, 3} 
    
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint n_nodes = 0;
    gint real_n_nodes = 0;
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
            real_n_nodes++;
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    gtk_tree_model_foreach (GTK_TREE_MODEL (tree_store), global_count_nodes, &n_nodes);
    
    if (real_n_nodes != n_nodes)
    {
        TEST_FAIL ("n_nodes = %i, should be %i", n_nodes, real_n_nodes); 
    }
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_row_changed
 * Params: GtkTreeModel* tree_model, GtkTreePath *path, GtkTreeIter *iter
 * Returns: void
 * Assertion: Emits the "row_changed" signal on tree_model. 
 * Params Values: newly created GtkTreeModel*, a GtkTreePath pointing to the changed row, a valid GtkTreeIter pointing to the changed row
 * Expected: void  
 */
static void test_purpose_164()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:4"
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &iter, path);
    global_condition = "NONE";
    g_signal_connect (G_OBJECT(tree_store), "row_changed", (GCallback) global_signal_handler, NULL);
    gtk_tree_model_row_changed (GTK_TREE_MODEL (tree_store), path, &iter);
    if (strcmp (global_condition, "HANDLED"))
    {
        TEST_FAIL ("gtk_tree_row_changed () didn't emit the 'row_changed' signal.", NULL); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_row_changed
 * Params: GtkTreeModel* tree_model, GtkTreePath *path, GtkTreeIter *iter
 * Returns: void
 * Assertion: Emits the "row_changed" signal on tree_model. 
 * Params Values: newly created GtkTreeModel*, a GtkTreePath pointing to the changed row, a valid GtkTreeIter pointing to the changed row
 * Expected: void  
 */
static void test_purpose_165()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "5"
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &iter, path);
    global_condition = "NONE";
    g_signal_connect (G_OBJECT(tree_store), "row_changed", (GCallback) global_signal_handler, NULL);
    gtk_tree_model_row_changed (GTK_TREE_MODEL (tree_store), path, &iter);
    if (strcmp (global_condition, "HANDLED"))
    {
        TEST_FAIL ("gtk_tree_row_changed () didn't emit the 'row_changed' signal.", NULL); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_row_changed
 * Params: GtkTreeModel* tree_model, GtkTreePath *path, GtkTreeIter *iter
 * Returns: void
 * Assertion: Emits the "row_changed" signal on tree_model. 
 * Params Values: newly created GtkTreeModel*, a GtkTreePath pointing to the changed row, a valid GtkTreeIter pointing to the changed row
 * Expected: void  
 */
static void test_purpose_166()
{
    #define DEPTH 1
    #define INDICES {4}
    #define PATH_STR "0"
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &iter, path);
    global_condition = "NONE";
    g_signal_connect (G_OBJECT(tree_store), "row_changed", (GCallback) global_signal_handler, NULL);
    gtk_tree_model_row_changed (GTK_TREE_MODEL (tree_store), path, &iter);
    if (strcmp (global_condition, "HANDLED"))
    {
        TEST_FAIL ("gtk_tree_row_changed () didn't emit the 'row_changed' signal.", NULL); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_row_changed
 * Params: GtkTreeModel* tree_model, GtkTreePath *path, GtkTreeIter *iter
 * Returns: void
 * Assertion: Emits the "row_changed" signal on tree_model. 
 * Params Values: newly created GtkTreeModel*, a GtkTreePath pointing to the changed row, a valid GtkTreeIter pointing to the changed row
 * Expected: void  
 */
static void test_purpose_167()
{
    #define DEPTH 13
    #define INDICES {7, 3, 5, 0, 1, 4, 9, 2, 2, 6, 11, 99, 37}
    #define PATH_STR "7:3:5:0:1:4:9:2:2:6:11:0"
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &iter, path);
    global_condition = "NONE";
    g_signal_connect (G_OBJECT(tree_store), "row_changed", (GCallback) global_signal_handler, NULL);
    gtk_tree_model_row_changed (GTK_TREE_MODEL (tree_store), path, &iter);
    if (strcmp (global_condition, "HANDLED"))
    {
        TEST_FAIL ("gtk_tree_row_changed () didn't emit the 'row_changed' signal.", NULL); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_row_deleted
 * Params: GtkTreeModel* tree_model, GtkTreePath *path
 * Returns: void
 * Assertion: Emits the "row_deleted" signal on tree_model.  
 * Params Values: newly created GtkTreeModel*, a GtkTreePath pointing to the previous location of the deleted row.
 * Expected: void  
 */
static void test_purpose_168()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:4"
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    global_condition = "NONE";
    g_signal_connect (G_OBJECT(tree_store), "row_deleted", (GCallback) global_signal_handler, NULL);
    gtk_tree_model_row_deleted (GTK_TREE_MODEL (tree_store), path);
    if (strcmp (global_condition, "HANDLED"))
    {
        TEST_FAIL ("gtk_tree_row_deleted () didn't emit the 'row_deleted' signal.", NULL); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_row_deleted
 * Params: GtkTreeModel* tree_model, GtkTreePath *path
 * Returns: void
 * Assertion: Emits the "row_deleted" signal on tree_model.  
 * Params Values: newly created GtkTreeModel*, a GtkTreePath pointing to the previous location of the deleted row.
 * Expected: void  
 */
static void test_purpose_169()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "5"
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    global_condition = "NONE";
    g_signal_connect (G_OBJECT(tree_store), "row_deleted", (GCallback) global_signal_handler, NULL);
    gtk_tree_model_row_deleted (GTK_TREE_MODEL (tree_store), path);
    if (strcmp (global_condition, "HANDLED"))
    {
        TEST_FAIL ("gtk_tree_row_deleted () didn't emit the 'row_deleted' signal.", NULL); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_row_deleted
 * Params: GtkTreeModel* tree_model, GtkTreePath *path
 * Returns: void
 * Assertion: Emits the "row_deleted" signal on tree_model.  
 * Params Values: newly created GtkTreeModel*, a GtkTreePath pointing to the previous location of the deleted row.
 * Expected: void  
 */
static void test_purpose_170()
{
    #define DEPTH 1
    #define INDICES {4}
    #define PATH_STR "0"
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    global_condition = "NONE";
    g_signal_connect (G_OBJECT(tree_store), "row_deleted", (GCallback) global_signal_handler, NULL);
    gtk_tree_model_row_deleted (GTK_TREE_MODEL (tree_store), path);
    if (strcmp (global_condition, "HANDLED"))
    {
        TEST_FAIL ("gtk_tree_row_deleted () didn't emit the 'row_deleted' signal.", NULL); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_row_deleted
 * Params: GtkTreeModel* tree_model, GtkTreePath *path
 * Returns: void
 * Assertion: Emits the "row_deleted" signal on tree_model.  
 * Params Values: newly created GtkTreeModel*, a GtkTreePath pointing to the previous location of the deleted row.
 * Expected: void  
 */
static void test_purpose_171()
{
    #define DEPTH 1
    #define INDICES {0}
    #define PATH_STR "0"
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    global_condition = "NONE";
    g_signal_connect (G_OBJECT(tree_store), "row_deleted", (GCallback) global_signal_handler, NULL);
    gtk_tree_model_row_deleted (GTK_TREE_MODEL (tree_store), path);
    if (strcmp (global_condition, "HANDLED"))
    {
        TEST_FAIL ("gtk_tree_row_deleted () didn't emit the 'row_deleted' signal.", NULL); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_row_deleted
 * Params: GtkTreeModel* tree_model, GtkTreePath *path
 * Returns: void
 * Assertion: Emits the "row_deleted" signal on tree_model.  
 * Params Values: newly created GtkTreeModel*, a GtkTreePath pointing to the previous location of the deleted row.
 * Expected: void  
 */
static void test_purpose_172()
{
    #define DEPTH 13
    #define INDICES {7, 3, 5, 0, 1, 4, 9, 2, 2, 6, 11, 99, 37}
    #define PATH_STR "7:3:5:0:1:4:9:2:2:6:11:0"
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    global_condition = "NONE";
    g_signal_connect (G_OBJECT(tree_store), "row_deleted", (GCallback) global_signal_handler, NULL);
    gtk_tree_model_row_deleted (GTK_TREE_MODEL (tree_store), path);
    if (strcmp (global_condition, "HANDLED"))
    {
        TEST_FAIL ("gtk_tree_row_deleted () didn't emit the 'row_deleted' signal.", NULL); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_row_has_child_toggled
 * Params: GtkTreeModel* tree_model, GtkTreePath *path, GtkTreeIter *iter
 * Returns: void
 * Assertion: Emits the "row_has_child_toggled" signal on tree_model. 
 * Params Values: newly created GtkTreeModel*, a GtkTreePath pointing to the changed row, a valid GtkTreeIter pointing to the changed row
 * Expected: void  
 */
static void test_purpose_173()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:4"
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &iter, path);
    global_condition = "NONE";
    g_signal_connect (G_OBJECT(tree_store), "row_has_child_toggled", (GCallback) global_signal_handler, NULL);
    gtk_tree_model_row_has_child_toggled (GTK_TREE_MODEL (tree_store), path, &iter);
    if (strcmp (global_condition, "HANDLED"))
    {
        TEST_FAIL ("gtk_tree_row_has_child_toggled () didn't emit the 'row_has_child_toggled' signal.", NULL); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_row_has_child_toggled
 * Params: GtkTreeModel* tree_model, GtkTreePath *path, GtkTreeIter *iter
 * Returns: void
 * Assertion: Emits the "row_has_child_toggled" signal on tree_model. 
 * Params Values: newly created GtkTreeModel*, a GtkTreePath pointing to the changed row, a valid GtkTreeIter pointing to the changed row
 * Expected: void  
 */
static void test_purpose_174()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "5"
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &iter, path);
    global_condition = "NONE";
    g_signal_connect (G_OBJECT(tree_store), "row_has_child_toggled", (GCallback) global_signal_handler, NULL);
    gtk_tree_model_row_has_child_toggled (GTK_TREE_MODEL (tree_store), path, &iter);
    if (strcmp (global_condition, "HANDLED"))
    {
        TEST_FAIL ("gtk_tree_row_has_child_toggled () didn't emit the 'row_has_child_toggled' signal.", NULL); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_row_has_child_toggled
 * Params: GtkTreeModel* tree_model, GtkTreePath *path, GtkTreeIter *iter
 * Returns: void
 * Assertion: Emits the "row_has_child_toggled" signal on tree_model. 
 * Params Values: newly created GtkTreeModel*, a GtkTreePath pointing to the changed row, a valid GtkTreeIter pointing to the changed row
 * Expected: void  
 */
static void test_purpose_175()
{
    #define DEPTH 1
    #define INDICES {4}
    #define PATH_STR "0"
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &iter, path);
    global_condition = "NONE";
    g_signal_connect (G_OBJECT(tree_store), "row_has_child_toggled", (GCallback) global_signal_handler, NULL);
    gtk_tree_model_row_has_child_toggled (GTK_TREE_MODEL (tree_store), path, &iter);
    if (strcmp (global_condition, "HANDLED"))
    {
        TEST_FAIL ("gtk_tree_row_has_child_toggled () didn't emit the 'row_has_child_toggled' signal.", NULL); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_row_has_child_toggled
 * Params: GtkTreeModel* tree_model, GtkTreePath *path, GtkTreeIter *iter
 * Returns: void
 * Assertion: Emits the "row_has_child_toggled" signal on tree_model. 
 * Params Values: newly created GtkTreeModel*, a GtkTreePath pointing to the changed row, a valid GtkTreeIter pointing to the changed row
 * Expected: void  
 */
static void test_purpose_176()
{
    #define DEPTH 13
    #define INDICES {7, 3, 5, 0, 1, 4, 9, 2, 2, 6, 11, 99, 37}
    #define PATH_STR "7:3:5:0:1:4:9:2:2:6:11:0"
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &iter, path);
    global_condition = "NONE";
    g_signal_connect (G_OBJECT(tree_store), "row_has_child_toggled", (GCallback) global_signal_handler, NULL);
    gtk_tree_model_row_has_child_toggled (GTK_TREE_MODEL (tree_store), path, &iter);
    if (strcmp (global_condition, "HANDLED"))
    {
        TEST_FAIL ("gtk_tree_row_has_child_toggled () didn't emit the 'row_has_child_toggled' signal.", NULL); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_row_inserted
 * Params: GtkTreeModel* tree_model, GtkTreePath *path, GtkTreeIter *iter
 * Returns: void
 * Assertion: Emits the "row_inserted" signal on tree_model. 
 * Params Values: newly created GtkTreeModel*, a GtkTreePath pointing to the inserted row, a valid GtkTreeIter pointing to the inserted row
 * Expected: void  
 */
static void test_purpose_177()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:4"
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &iter, path);
    global_condition = "NONE";
    g_signal_connect (G_OBJECT(tree_store), "row_inserted", (GCallback) global_signal_handler, NULL);
    gtk_tree_model_row_inserted (GTK_TREE_MODEL (tree_store), path, &iter);
    if (strcmp (global_condition, "HANDLED"))
    {
        TEST_FAIL ("gtk_tree_row_inserted () didn't emit the 'row_inserted' signal.", NULL); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_row_inserted
 * Params: GtkTreeModel* tree_model, GtkTreePath *path, GtkTreeIter *iter
 * Returns: void
 * Assertion: Emits the "row_inserted" signal on tree_model. 
 * Params Values: newly created GtkTreeModel*, a GtkTreePath pointing to the inserted row, a valid GtkTreeIter pointing to the inserted row
 * Expected: void  
 */
static void test_purpose_178()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "5"
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &iter, path);
    global_condition = "NONE";
    g_signal_connect (G_OBJECT(tree_store), "row_inserted", (GCallback) global_signal_handler, NULL);
    gtk_tree_model_row_inserted (GTK_TREE_MODEL (tree_store), path, &iter);
    if (strcmp (global_condition, "HANDLED"))
    {
        TEST_FAIL ("gtk_tree_row_inserted () didn't emit the 'row_inserted' signal.", NULL); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_row_inserted
 * Params: GtkTreeModel* tree_model, GtkTreePath *path, GtkTreeIter *iter
 * Returns: void
 * Assertion: Emits the "row_inserted" signal on tree_model. 
 * Params Values: newly created GtkTreeModel*, a GtkTreePath pointing to the inserted row, a valid GtkTreeIter pointing to the inserted row
 * Expected: void  
 */
static void test_purpose_179()
{
    #define DEPTH 1
    #define INDICES {4}
    #define PATH_STR "0"
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &iter, path);
    global_condition = "NONE";
    g_signal_connect (G_OBJECT(tree_store), "row_inserted", (GCallback) global_signal_handler, NULL);
    gtk_tree_model_row_inserted (GTK_TREE_MODEL (tree_store), path, &iter);
    if (strcmp (global_condition, "HANDLED"))
    {
        TEST_FAIL ("gtk_tree_row_inserted () didn't emit the 'row_inserted' signal.", NULL); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_row_inserted
 * Params: GtkTreeModel* tree_model, GtkTreePath *path, GtkTreeIter *iter
 * Returns: void
 * Assertion: Emits the "row_inserted" signal on tree_model. 
 * Params Values: newly created GtkTreeModel*, a GtkTreePath pointing to the inserted row, a valid GtkTreeIter pointing to the inserted row
 * Expected: void  
 */
static void test_purpose_180()
{
    #define DEPTH 13
    #define INDICES {7, 3, 5, 0, 1, 4, 9, 2, 2, 6, 11, 99, 37}
    #define PATH_STR "7:3:5:0:1:4:9:2:2:6:11:0"
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &iter, path);
    global_condition = "NONE";
    g_signal_connect (G_OBJECT(tree_store), "row_inserted", (GCallback) global_signal_handler, NULL);
    gtk_tree_model_row_inserted (GTK_TREE_MODEL (tree_store), path, &iter);
    if (strcmp (global_condition, "HANDLED"))
    {
        TEST_FAIL ("gtk_tree_row_inserted () didn't emit the 'row_inserted' signal.", NULL); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_rows_reordered
 * Params: GtkTreeModel* tree_model, GtkTreePath *path, GtkTreeIter *iter, gint *new_order
 * Returns: void
 * Assertion: Emits the "rows_reordered" signal on tree_model.  
 * Params Values: newly created GtkTreeModel*, a GtkTreePath pointing to the tree node whose children have been reordered, a valid GtkTreeIter pointing to the node whose children have been reordered, an array of integers containing the new indices of the children
 * Expected: void  
 */
static void test_purpose_181()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3"
    #define NEW_ORDER {5, 4, 3, 2, 1, 0}
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    gint new_order[] = NEW_ORDER;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &iter, path);
    global_condition = "NONE";
    g_signal_connect (G_OBJECT(tree_store), "rows_reordered", (GCallback) global_signal_handler, NULL);
    gtk_tree_model_rows_reordered (GTK_TREE_MODEL (tree_store), path, &iter, new_order);
    if (strcmp (global_condition, "HANDLED"))
    {
        TEST_FAIL ("gtk_tree_rows_reordered () didn't emit the 'rows_reordered' signal.", NULL); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef NEW_ORDER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_rows_reordered
 * Params: GtkTreeModel* tree_model, GtkTreePath *path, GtkTreeIter *iter, gint *new_order
 * Returns: void
 * Assertion: Emits the "rows_reordered" signal on tree_model.  
 * Params Values: newly created GtkTreeModel*, a GtkTreePath pointing to the tree node whose children have been reordered, a valid GtkTreeIter pointing to the node whose children have been reordered, an array of integers containing the new indices of the children
 * Expected: void  
 */
static void test_purpose_182()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "5"
    #define NEW_ORDER {4, 2, 9, 0}
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    gint new_order[] = NEW_ORDER;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &iter, path);
    global_condition = "NONE";
    g_signal_connect (G_OBJECT(tree_store), "rows_reordered", (GCallback) global_signal_handler, NULL);
    gtk_tree_model_rows_reordered (GTK_TREE_MODEL (tree_store), path, &iter, new_order);
    if (strcmp (global_condition, "HANDLED"))
    {
        TEST_FAIL ("gtk_tree_rows_reordered () didn't emit the 'rows_reordered' signal.", NULL); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef NEW_ORDER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_rows_reordered
 * Params: GtkTreeModel* tree_model, GtkTreePath *path, GtkTreeIter *iter, gint *new_order
 * Returns: void
 * Assertion: Emits the "rows_reordered" signal on tree_model.  
 * Params Values: newly created GtkTreeModel*, a GtkTreePath pointing to the tree node whose children have been reordered, a valid GtkTreeIter pointing to the node whose children have been reordered, an array of integers containing the new indices of the children
 * Expected: void  
 */
static void test_purpose_183()
{
    #define DEPTH 1
    #define INDICES {4}
    #define PATH_STR "4"
    #define NEW_ORDER {7, 1}
    
    GtkTreePath *path;
    GtkTreeStore *tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    gint i;
    gint j;
    gint indices[] = INDICES;
    gint new_order[] = NEW_ORDER;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    if (!GTK_IS_TREE_STORE (tree_store))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    gtk_tree_model_get_iter (GTK_TREE_MODEL (tree_store), &iter, path);
    global_condition = "NONE";
    g_signal_connect (G_OBJECT(tree_store), "rows_reordered", (GCallback) global_signal_handler, NULL);
    gtk_tree_model_rows_reordered (GTK_TREE_MODEL (tree_store), path, &iter, new_order);
    if (strcmp (global_condition, "HANDLED"))
    {
        TEST_FAIL ("gtk_tree_rows_reordered () didn't emit the 'rows_reordered' signal.", NULL); 
    }
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef NEW_ORDER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_is_ancestor
 * Params: GtkTreePath *path, GtkTreePath *descendant
 * Returns: gboolean
 * Assertion: Returns TRUE if descendant is a descendant of path.
 * Params Values: GtkTreePath from string "0:0:0", GtkTreePath from string "0:0:0:0"  
 * Expected: TRUE  
 */
static void test_purpose_184()
{
    #define PATH_STR "0:0:0"
    #define DESCENDANT_STR "0:0:0:0"
    #define EXPECTED_RESULT TRUE
    
    GtkTreePath *path;
    GtkTreePath *descendant;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH_STR);
    descendant = gtk_tree_path_new_from_string (DESCENDANT_STR);
    result = gtk_tree_path_is_ancestor (path, descendant);
    
    if (result != EXPECTED_RESULT)
    {
        TEST_FAIL ("gtk_tree_path_is_ancestor () return %i instead of %i", result, EXPECTED_RESULT); 
    }
        
    #undef PATH_STR
    #undef DESCENDANT_STR
    #undef EXPECTED_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_is_ancestor
 * Params: GtkTreePath *path, GtkTreePath *descendant
 * Returns: gboolean
 * Assertion: Returns TRUE if descendant is a descendant of path.
 * Params Values: GtkTreePath from string "5:5:5", GtkTreePath from string "5:5:5:3"  
 * Expected: TRUE  
 */
static void test_purpose_185()
{
    #define PATH_STR "5:5:5"
    #define DESCENDANT_STR "5:5:5:3"
    #define EXPECTED_RESULT TRUE
    
    GtkTreePath *path;
    GtkTreePath *descendant;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH_STR);
    descendant = gtk_tree_path_new_from_string (DESCENDANT_STR);
    result = gtk_tree_path_is_ancestor (path, descendant);
    
    if (result != EXPECTED_RESULT)
    {
        TEST_FAIL ("gtk_tree_path_is_ancestor () return %i instead of %i", result, EXPECTED_RESULT); 
    }
        
    #undef PATH_STR
    #undef DESCENDANT_STR
    #undef EXPECTED_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_is_ancestor
 * Params: GtkTreePath *path, GtkTreePath *descendant
 * Returns: gboolean
 * Assertion: Returns TRUE if descendant is a descendant of path.
 * Params Values: GtkTreePath from string "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0", GtkTreePath from string "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:7:1:5"                
 * Expected: TRUE  
 */
static void test_purpose_186()
{
    #define PATH_STR "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    #define DESCENDANT_STR "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:7:1:5"              
    #define EXPECTED_RESULT TRUE
    
    GtkTreePath *path;
    GtkTreePath *descendant;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH_STR);
    descendant = gtk_tree_path_new_from_string (DESCENDANT_STR);
    result = gtk_tree_path_is_ancestor (path, descendant);
    
    if (result != EXPECTED_RESULT)
    {
        TEST_FAIL ("gtk_tree_path_is_ancestor () return %i instead of %i", result, EXPECTED_RESULT); 
    }
        
    #undef PATH_STR
    #undef DESCENDANT_STR
    #undef EXPECTED_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_is_ancestor
 * Params: GtkTreePath *path, GtkTreePath *descendant
 * Returns: gboolean
 * Assertion: Returns TRUE if descendant is a descendant of path.
 * Params Values: GtkTreePath from string "0", GtkTreePath from string "0"  
 * Expected: FALSE  
 */
static void test_purpose_187()
{
    #define PATH_STR "0"
    #define DESCENDANT_STR "0"
    #define EXPECTED_RESULT FALSE
    
    GtkTreePath *path;
    GtkTreePath *descendant;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH_STR);
    descendant = gtk_tree_path_new_from_string (DESCENDANT_STR);
    result = gtk_tree_path_is_ancestor (path, descendant);
    
    if (result != EXPECTED_RESULT)
    {
        TEST_FAIL ("gtk_tree_path_is_ancestor () return %i instead of %i", result, EXPECTED_RESULT); 
    }
        
    #undef PATH_STR
    #undef DESCENDANT_STR
    #undef EXPECTED_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_is_ancestor
 * Params: GtkTreePath *path, GtkTreePath *descendant
 * Returns: gboolean
 * Assertion: Returns TRUE if descendant is a descendant of path.
 * Params Values: GtkTreePath from string "2147483647:2147483647:2147483647", GtkTreePath from string "2147483647:2147483647:74837"  
 * Expected: FALSE  
 */
static void test_purpose_188()
{
    #define PATH_STR "2147483647:2147483647:2147483647"
    #define DESCENDANT_STR "2147483647:2147483647:74837"
    #define EXPECTED_RESULT FALSE
    
    GtkTreePath *path;
    GtkTreePath *descendant;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH_STR);
    descendant = gtk_tree_path_new_from_string (DESCENDANT_STR);
    result = gtk_tree_path_is_ancestor (path, descendant);
    
    if (result != EXPECTED_RESULT)
    {
        TEST_FAIL ("gtk_tree_path_is_ancestor () return %i instead of %i", result, EXPECTED_RESULT); 
    }
        
    #undef PATH_STR
    #undef DESCENDANT_STR
    #undef EXPECTED_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_is_descendant
 * Params: GtkTreePath *path, GtkTreePath *ancestor
 * Returns: gboolean
 * Assertion: Returns TRUE if path is a descendant of ancestor.
 * Params Values: GtkTreePath from string "0:0:0", GtkTreePath from string "0:0:0:0"  
 * Expected: TRUE  
 */
static void test_purpose_189()
{
    #define ANCESTOR_STR "0:0:0"
    #define PATH_STR "0:0:0:0"
    #define EXPECTED_RESULT TRUE
    
    GtkTreePath *path;
    GtkTreePath *descendant;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH_STR);
    descendant = gtk_tree_path_new_from_string (ANCESTOR_STR);
    result = gtk_tree_path_is_descendant (path, descendant);
    
    if (result != EXPECTED_RESULT)
    {
        TEST_FAIL ("gtk_tree_path_is_descendant () return %i instead of %i", result, EXPECTED_RESULT); 
    }
    
    #undef ANCESTOR_STR    
    #undef PATH_STR
    #undef EXPECTED_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_is_descendant
 * Params: GtkTreePath *path, GtkTreePath *ancestor
 * Returns: gboolean
 * Assertion: Returns TRUE if path is a descendant of ancestor.
 * Params Values: GtkTreePath from string "5:5:5", GtkTreePath from string "5:5:5:3"  
 * Expected: TRUE  
 */
static void test_purpose_190()
{
    #define ANCESTOR_STR "5:5:5"
    #define PATH_STR "5:5:5:3"
    #define EXPECTED_RESULT TRUE
    
    GtkTreePath *path;
    GtkTreePath *descendant;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH_STR);
    descendant = gtk_tree_path_new_from_string (ANCESTOR_STR);
    result = gtk_tree_path_is_descendant (path, descendant);
    
    if (result != EXPECTED_RESULT)
    {
        TEST_FAIL ("gtk_tree_path_is_descendant () return %i instead of %i", result, EXPECTED_RESULT); 
    }
    
    #undef ANCESTOR_STR    
    #undef PATH_STR
    #undef EXPECTED_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_is_descendant
 * Params: GtkTreePath *path, GtkTreePath *ancestor
 * Returns: gboolean
 * Assertion: Returns TRUE if path is a descendant of ancestor.
 * Params Values: GtkTreePath from string "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0", GtkTreePath from string "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:7:1:5"                
 * Expected: TRUE  
 */
static void test_purpose_191()
{
    #define ANCESTOR_STR "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0"
    #define PATH_STR "0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:7:1:5"              
    #define EXPECTED_RESULT TRUE
    
    GtkTreePath *path;
    GtkTreePath *descendant;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH_STR);
    descendant = gtk_tree_path_new_from_string (ANCESTOR_STR);
    result = gtk_tree_path_is_descendant (path, descendant);
    
    if (result != EXPECTED_RESULT)
    {
        TEST_FAIL ("gtk_tree_path_is_descendant () return %i instead of %i", result, EXPECTED_RESULT); 
    }
    
    #undef ANCESTOR_STR    
    #undef PATH_STR
    #undef EXPECTED_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_is_descendant
 * Params: GtkTreePath *path, GtkTreePath *ancestor
 * Returns: gboolean
 * Assertion: Returns TRUE if path is a descendant of ancestor.
 * Params Values: GtkTreePath from string "0", GtkTreePath from string "0"  
 * Expected: FALSE  
 */
static void test_purpose_192()
{
    #define ANCESTOR_STR "0"
    #define PATH_STR "0"
    #define EXPECTED_RESULT FALSE
    
    GtkTreePath *path;
    GtkTreePath *descendant;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH_STR);
    descendant = gtk_tree_path_new_from_string (ANCESTOR_STR);
    result = gtk_tree_path_is_descendant (path, descendant);
    
    if (result != EXPECTED_RESULT)
    {
        TEST_FAIL ("gtk_tree_path_is_descendant () return %i instead of %i", result, EXPECTED_RESULT); 
    }
    
    #undef ANCESTOR_STR    
    #undef PATH_STR
    #undef EXPECTED_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_is_descendant
 * Params: GtkTreePath *path, GtkTreePath *ancestor
 * Returns: gboolean
 * Assertion: Returns TRUE if path is a descendant of ancestor.
 * Params Values: GtkTreePath from string "2147483647:2147483647:2147483647", GtkTreePath from string "2147483647:2147483647:74837"  
 * Expected: FALSE  
 */
static void test_purpose_193()
{
    #define ANCESTOR_STR "2147483647:2147483647:2147483647"
    #define PATH_STR "2147483647:2147483647:74837"
    #define EXPECTED_RESULT FALSE
    
    GtkTreePath *path;
    GtkTreePath *descendant;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    path = gtk_tree_path_new_from_string (PATH_STR);
    descendant = gtk_tree_path_new_from_string (ANCESTOR_STR);
    result = gtk_tree_path_is_descendant (path, descendant);
    
    if (result != EXPECTED_RESULT)
    {
        TEST_FAIL ("gtk_tree_path_is_descendant () return %i instead of %i", result, EXPECTED_RESULT); 
    }
    
    #undef ANCESTOR_STR    
    #undef PATH_STR
    #undef EXPECTED_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_new
 * Params: GtkTreeModel *model, GtkTreePath *path 
 * Returns: GtkTreeRowReference
 * Assertion: Creates a row reference based on path. 
 * Params Values: newly created GtkTreeModel*, path from string "7:3:4"
 * Expected: a newly allocated GtkTreeRowReference  
 */
static void test_purpose_194()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:4"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (tree_store), path);
    if (row_ref == NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () return NULL, but it shouldn't.", NULL);
    } else {
        path_str = gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
        if (strcmp (path_str, PATH_STR))
        {
            TEST_FAIL("row referense path = '%s', should be '%s'", path_str, PATH_STR);
        }
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_new
 * Params: GtkTreeModel *model, GtkTreePath *path 
 * Returns: GtkTreeRowReference
 * Assertion: Creates a row reference based on path. 
 * Params Values: newly created GtkTreeModel*, path from string "3:5:0"
 * Expected: a newly allocated GtkTreeRowReference  
 */
static void test_purpose_195()
{
    #define DEPTH 3
    #define INDICES {3, 5, 0}
    #define PATH_STR "3:5:0"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (tree_store), path);
    if (row_ref == NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () return NULL, but it shouldn't.", NULL);
    } else {
        path_str = gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
        if (strcmp (path_str, PATH_STR))
        {
            TEST_FAIL("row referense path = '%s', should be '%s'", path_str, PATH_STR);
        }
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_new
 * Params: GtkTreeModel *model, GtkTreePath *path 
 * Returns: GtkTreeRowReference
 * Assertion: Creates a row reference based on path. 
 * Params Values: newly created GtkTreeModel*, path from string "0"
 * Expected: a newly allocated GtkTreeRowReference  
 */
static void test_purpose_196()
{
    #define DEPTH 1
    #define INDICES {0}
    #define PATH_STR "0"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (tree_store), path);
    if (row_ref == NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () return NULL, but it shouldn't.", NULL);
    } else {
        path_str = gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
        if (strcmp (path_str, PATH_STR))
        {
            TEST_FAIL("row referense path = '%s', should be '%s'", path_str, PATH_STR);
        }
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_new
 * Params: GtkTreeModel *model, GtkTreePath *path 
 * Returns: GtkTreeRowReference
 * Assertion: It listens to all signals emitted by model, and updates it's path appropriately.'
 * Params Values: newly created GtkTreeModel*, path from string "7:3:4"
 * Expected: a newly allocated GtkTreeRowReference  
 */
static void test_purpose_197()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:4"
    #define PATH_STR_TO_DEL "7:2"
    #define REF_PATH_STR_AFTER_DEL "7:2:4"
    #define PATH_STR_TO_INS "7:2"
    #define REF_PATH_STR_AFTER_INS "7:2:5"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    gchar* new_path_str;
    gboolean has_first_iter;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (tree_store), path);
    if (row_ref == NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () returned NULL, but it shouldn't.", NULL);
        return;
    } else {
        path_str = gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
        if (strcmp (path_str, PATH_STR))
        {
            TEST_FAIL("row reference path = '%s', should be '%s'", path_str, PATH_STR);
            return;
        }
    }
    
    res = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (tree_store), 
                                               &iter, PATH_STR_TO_DEL);
    if (!res)
    {
        TEST_FAIL ("1:gtk_tree_model_get_iter_from_string() returned NULL", NULL);
        return;
    }
    gtk_tree_store_remove (tree_store, &iter);
    new_path_str = 
        gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
    if (strcmp (new_path_str, REF_PATH_STR_AFTER_DEL))
    {
        TEST_FAIL ("1:new_path_str = %s, should be %s", 
                   new_path_str, REF_PATH_STR_AFTER_DEL);
    }
    
    res = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (tree_store), 
                                               &parent_iter, PATH_STR_TO_INS);
    if (!res)
    {
        TEST_FAIL ("2:gtk_tree_model_get_iter_from_string() returned NULL", NULL);
        return;
    }
    gtk_tree_store_insert (tree_store, &iter, &parent_iter, 0);
    new_path_str = 
        gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
    if (strcmp (new_path_str, REF_PATH_STR_AFTER_INS))
    {
        TEST_FAIL ("2:new_path_str = %s, should be %s", 
                   new_path_str, REF_PATH_STR_AFTER_INS);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef PATH_STR_TO_DEL
    #undef REF_PATH_STR_AFTER_DEL
    #undef PATH_STR_TO_INS
    #undef REF_PATH_STR_AFTER_INS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_new
 * Params: GtkTreeModel *model, GtkTreePath *path 
 * Returns: GtkTreeRowReference
 * Assertion: It listens to all signals emitted by model, and updates it's path appropriately.'
 * Params Values: newly created GtkTreeModel*, path from string "7:3:4"
 * Expected: a newly allocated GtkTreeRowReference  
 */
static void test_purpose_198()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:4"
    #define PATH_STR_TO_DEL "7:0"
    #define REF_PATH_STR_AFTER_DEL "7:2:4"
    #define PATH_STR_TO_INS "7"
    #define REF_PATH_STR_AFTER_INS "7:3:4"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    gchar* new_path_str;
    gboolean has_first_iter;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (tree_store), path);
    if (row_ref == NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () returned NULL, but it shouldn't.", NULL);
        return;
    } else {
        path_str = gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
        if (strcmp (path_str, PATH_STR))
        {
            TEST_FAIL("row reference path = '%s', should be '%s'", path_str, PATH_STR);
            return;
        }
    }
    
    res = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (tree_store), 
                                               &iter, PATH_STR_TO_DEL);
    if (!res)
    {
        TEST_FAIL ("1:gtk_tree_model_get_iter_from_string() returned NULL", NULL);
        return;
    }
    gtk_tree_store_remove (tree_store, &iter);
    new_path_str = 
        gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
    if (strcmp (new_path_str, REF_PATH_STR_AFTER_DEL))
    {
        TEST_FAIL ("1:new_path_str = %s, should be %s", 
                   new_path_str, REF_PATH_STR_AFTER_DEL);
    }
    
    res = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (tree_store), 
                                               &parent_iter, PATH_STR_TO_INS);
    if (!res)
    {
        TEST_FAIL ("2:gtk_tree_model_get_iter_from_string() returned NULL", NULL);
        return;
    }
    gtk_tree_store_insert (tree_store, &iter, &parent_iter, 0);
    new_path_str = 
        gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
    if (strcmp (new_path_str, REF_PATH_STR_AFTER_INS))
    {
        TEST_FAIL ("2:new_path_str = %s, should be %s", 
                   new_path_str, REF_PATH_STR_AFTER_INS);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef PATH_STR_TO_DEL
    #undef REF_PATH_STR_AFTER_DEL
    #undef PATH_STR_TO_INS
    #undef REF_PATH_STR_AFTER_INS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_new
 * Params: GtkTreeModel *model, GtkTreePath *path 
 * Returns: GtkTreeRowReference
 * Assertion: It listens to all signals emitted by model, and updates it's path appropriately.'
 * Params Values: newly created GtkTreeModel*, path from string "7:3:5"
 * Expected: a newly allocated GtkTreeRowReference  
 */
static void test_purpose_199()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:5"
    #define PATH_STR_TO_DEL "7:0"
    #define REF_PATH_STR_AFTER_DEL "7:2:5"
    #define PATH_STR_TO_INS "7:2:5"
    #define REF_PATH_STR_AFTER_INS "7:2:5"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    gchar* new_path_str;
    gboolean has_first_iter;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (tree_store), path);
    if (row_ref == NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () returned NULL, but it shouldn't.", NULL);
        return;
    } else {
        path_str = gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
        if (strcmp (path_str, PATH_STR))
        {
            TEST_FAIL("row reference path = '%s', should be '%s'", path_str, PATH_STR);
            return;
        }
    }
    
    res = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (tree_store), 
                                               &iter, PATH_STR_TO_DEL);
    if (!res)
    {
        TEST_FAIL ("1:gtk_tree_model_get_iter_from_string() returned NULL", NULL);
        return;
    }
    gtk_tree_store_remove (tree_store, &iter);
    new_path_str = 
        gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
    if (strcmp (new_path_str, REF_PATH_STR_AFTER_DEL))
    {
        TEST_FAIL ("1:new_path_str = %s, should be %s", 
                   new_path_str, REF_PATH_STR_AFTER_DEL);
    }
    
    res = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (tree_store), 
                                               &parent_iter, PATH_STR_TO_INS);
    if (!res)
    {
        TEST_FAIL ("2:gtk_tree_model_get_iter_from_string() returned NULL", NULL);
        return;
    }
    gtk_tree_store_insert (tree_store, &iter, &parent_iter, 0);
    new_path_str = 
        gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
    if (strcmp (new_path_str, REF_PATH_STR_AFTER_INS))
    {
        TEST_FAIL ("2:new_path_str = %s, should be %s", 
                   new_path_str, REF_PATH_STR_AFTER_INS);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef PATH_STR_TO_DEL
    #undef REF_PATH_STR_AFTER_DEL
    #undef PATH_STR_TO_INS
    #undef REF_PATH_STR_AFTER_INS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_new
 * Params: GtkTreeModel *model, GtkTreePath *path 
 * Returns: GtkTreeRowReference
 * Assertion: If path isn't a valid path in model, then NULL is returned'
 * Params Values: newly created GtkTreeModel*, path from string "7:3:9"
 * Expected: a newly allocated GtkTreeRowReference  
 */
static void test_purpose_200()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:9"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (tree_store), path);
    if (row_ref != NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () should return NULL, but it didn't.", NULL);
    } 
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_new
 * Params: GtkTreeModel *model, GtkTreePath *path 
 * Returns: GtkTreeRowReference
 * Assertion: If path isn't a valid path in model, then NULL is returned'
 * Params Values: newly created GtkTreeModel*, path from string "3:5:0:1"
 * Expected: a newly allocated GtkTreeRowReference  
 */
static void test_purpose_201()
{
    #define DEPTH 3
    #define INDICES {3, 5, 0}
    #define PATH_STR "3:5:0:1"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (tree_store), path);
    if (row_ref != NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () should return NULL, but it didn't.", NULL);
    } 
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_new
 * Params: GtkTreeModel *model, GtkTreePath *path 
 * Returns: GtkTreeRowReference
 * Assertion: If path isn't a valid path in model, then NULL is returned'
 * Params Values: newly created GtkTreeModel*, path from string "1"
 * Expected: a newly allocated GtkTreeRowReference  
 */
static void test_purpose_202()
{
    #define DEPTH 1
    #define INDICES {0}
    #define PATH_STR "1"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (tree_store), path);
    if (row_ref != NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () should return NULL, but it didn't.", NULL);
    } 
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_get_path
 * Params: GtkTreeRowReference *reference 
 * Returns: GtkTreePath
 * Assertion: Returns a path that the row reference currently points to, or NULL if the path pointed to is no longer valid.
 * Params Values: newly created GtkTreeRowReference*
 * Expected: a current path, or NULL  
 */
static void test_purpose_203()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:5"
    #define SAVED_LEVEL 2
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    GtkTreePath* fetched_path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == SAVED_LEVEL)
        {
            saved_iter = iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (tree_store), path);
    fetched_path = gtk_tree_row_reference_get_path (row_ref);
    path_str = gtk_tree_path_to_string (fetched_path);
    if (strcmp (path_str, PATH_STR))
    {
        TEST_FAIL("row referense path = '%s', should be '%s'", path_str, PATH_STR);
    }
    
    gtk_tree_store_remove (tree_store, &saved_iter);
    fetched_path = gtk_tree_row_reference_get_path (row_ref);
    if (fetched_path != NULL)
    {
        TEST_FAIL("row referense path != NULL, but it should be.", NULL);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef SAVED_LEVEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_get_path
 * Params: GtkTreeRowReference *reference 
 * Returns: GtkTreePath
 * Assertion: Returns a path that the row reference currently points to, or NULL if the path pointed to is no longer valid.
 * Params Values: newly created GtkTreeRowReference*
 * Expected: a current path, or NULL  
 */
static void test_purpose_204()
{
    #define DEPTH 3
    #define INDICES {3, 5, 0}
    #define PATH_STR "3:5:0"
    #define SAVED_LEVEL 2
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    GtkTreePath* fetched_path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == SAVED_LEVEL)
        {
            saved_iter = iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (tree_store), path);
    fetched_path = gtk_tree_row_reference_get_path (row_ref);
    path_str = gtk_tree_path_to_string (fetched_path);
    if (strcmp (path_str, PATH_STR))
    {
        TEST_FAIL("row referense path = '%s', should be '%s'", path_str, PATH_STR);
    }
    
    gtk_tree_store_remove (tree_store, &saved_iter);
    fetched_path = gtk_tree_row_reference_get_path (row_ref);
    if (fetched_path != NULL)
    {
        TEST_FAIL("row referense path != NULL, but it should be.", NULL);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef SAVED_LEVEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_get_path
 * Params: GtkTreeRowReference *reference 
 * Returns: GtkTreePath
 * Assertion: Returns a path that the row reference currently points to, or NULL if the path pointed to is no longer valid.
 * Params Values: newly created GtkTreeRowReference*
 * Expected: a current path, or NULL  
 */
static void test_purpose_205()
{
    #define DEPTH 1
    #define INDICES {0}
    #define PATH_STR "0"
    #define SAVED_LEVEL 0
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    GtkTreePath* fetched_path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == SAVED_LEVEL)
        {
            saved_iter = iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (tree_store), path);
    fetched_path = gtk_tree_row_reference_get_path (row_ref);
    path_str = gtk_tree_path_to_string (fetched_path);
    if (strcmp (path_str, PATH_STR))
    {
        TEST_FAIL("row referense path = '%s', should be '%s'", path_str, PATH_STR);
    }
    
    gtk_tree_store_remove (tree_store, &saved_iter);
    fetched_path = gtk_tree_row_reference_get_path (row_ref);
    if (fetched_path != NULL)
    {
        TEST_FAIL("row referense path != NULL, but it should be.", NULL);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef SAVED_LEVEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_valid
 * Params: GtkTreeRowReference *reference 
 * Returns: gboolean
 * Assertion: Returns TRUE if the reference is non-NULL and refers to a current valid path.
 * Params Values: newly created GtkTreeRowReference*
 * Expected: TRUE if reference points to a valid path.  
 */
static void test_purpose_206()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:5"
    #define SAVED_LEVEL 2
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gboolean valid;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == SAVED_LEVEL)
        {
            saved_iter = iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (tree_store), path);
    valid = gtk_tree_row_reference_valid (row_ref);
    if (!valid)
    {
        TEST_FAIL("gtk_tree_row_reference_valid () return FALSE, should be TRUE", NULL);
    }
    
    gtk_tree_store_remove (tree_store, &saved_iter);
    valid = gtk_tree_row_reference_valid (row_ref);
    if (valid)
    {
        TEST_FAIL("gtk_tree_row_reference_valid () return TRUE, should be FALSE", NULL);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef SAVED_LEVEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_valid
 * Params: GtkTreeRowReference *reference 
 * Returns: gboolean
 * Assertion: Returns TRUE if the reference is non-NULL and refers to a current valid path.
 * Params Values: newly created GtkTreeRowReference*
 * Expected: TRUE if reference points to a valid path.  
 */
static void test_purpose_207()
{
    #define DEPTH 3
    #define INDICES {3, 5, 0}
    #define PATH_STR "3:5:0"
    #define SAVED_LEVEL 2
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gboolean valid;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == SAVED_LEVEL)
        {
            saved_iter = iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (tree_store), path);
    valid = gtk_tree_row_reference_valid (row_ref);
    if (!valid)
    {
        TEST_FAIL("gtk_tree_row_reference_valid () return FALSE, should be TRUE", NULL);
    }
    
    gtk_tree_store_remove (tree_store, &saved_iter);
    valid = gtk_tree_row_reference_valid (row_ref);
    if (valid)
    {
        TEST_FAIL("gtk_tree_row_reference_valid () return TRUE, should be FALSE", NULL);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef SAVED_LEVEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_valid
 * Params: GtkTreeRowReference *reference 
 * Returns: gboolean
 * Assertion: Returns TRUE if the reference is non-NULL and refers to a current valid path.
 * Params Values: newly created GtkTreeRowReference*
 * Expected: TRUE if reference points to a valid path.  
 */
static void test_purpose_208()
{
    #define DEPTH 1
    #define INDICES {0}
    #define PATH_STR "0"
    #define SAVED_LEVEL 0
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gboolean valid;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == SAVED_LEVEL)
        {
            saved_iter = iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (tree_store), path);
    valid = gtk_tree_row_reference_valid (row_ref);
    if (!valid)
    {
        TEST_FAIL("gtk_tree_row_reference_valid () return FALSE, should be TRUE", NULL);
    }
    
    gtk_tree_store_remove (tree_store, &saved_iter);
    valid = gtk_tree_row_reference_valid (row_ref);
    if (valid)
    {
        TEST_FAIL("gtk_tree_row_reference_valid () return TRUE, should be FALSE", NULL);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef SAVED_LEVEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_free
 * Params: GtkTreeRowReference *reference 
 * Returns: void
 * Assertion: Free's reference. ' 
 * Params Values: newly created GtkTreeRowReference*
 * Expected: void
 * 
 * Name: gtk_tree_row_reference_free
 * Params: GtkTreeRowReference *reference 
 * Returns: void
 * Assertion: reference may be NULL. 
 * Params Values: newly created GtkTreeRowReference*
 * Expected: void  
 */
static void test_purpose_209()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:5"
    #define SAVED_LEVEL 2
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter saved_iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gboolean valid;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
        if (i == SAVED_LEVEL)
        {
            saved_iter = iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (tree_store), path);
    gtk_tree_row_reference_free (row_ref);
    
    row_ref = gtk_tree_row_reference_new (GTK_TREE_MODEL (tree_store), path);
    gtk_tree_store_remove (tree_store, &saved_iter);
    gtk_tree_row_reference_free (row_ref);
    
    row_ref = NULL;
    gtk_tree_row_reference_free (row_ref);
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef SAVED_LEVEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_iter_first
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Initializes iter with the first iterator in the tree (the one at the path "0") and returns TRUE.
 * Params Values: newly created GtkTreeModel*
 * Expected: TRUE  
 */
static void test_purpose_210()
{
    #define DEPTH 1
    #define INDICES {0}
    #define UINT_VALUE 123456
    
    GtkTreeStore *store;
    GtkTreeIter iter;
    GtkTreeIter first_iter;
    GtkTreeIter child_iter;
    GtkTreePath *path;
    gboolean result;
    gchar* path_str;
    gint i;
    gint j;
    GValue val = {0, };
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (store, &iter, NULL);
                if (j == 0)
                {
                    first_iter = iter;
                }
            } else {
                gtk_tree_store_append (store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    g_value_init (&val, G_TYPE_UINT);
    g_value_set_uint (&val, UINT_VALUE);
    gtk_tree_store_set_value (store, &first_iter, 0, &val);
    
    result = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (store), &iter);
    if (!result)
    {
        TEST_FAIL ("gtk_tree_model_get_iter_first() returned FALSE for non-empty model", NULL);
    }
    
    path = gtk_tree_model_get_path (GTK_TREE_MODEL (store), &iter);
    path_str = gtk_tree_path_to_string (path);
    
    if (!path_str)
    {
        TEST_FAIL ("path_str is NULL", NULL);
    } else {
        if (strcmp (path_str, "0"))
        {
            TEST_FAIL ("path_str = '%s', should be '0'", path_str);
        }
    }
    
    g_free (path_str);
    
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_iter_first
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Initializes iter with the first iterator in the tree (the one at the path "0") and returns TRUE.
 * Params Values: newly created GtkTreeModel*
 * Expected: TRUE  
 */
static void test_purpose_211()
{
    #define DEPTH 3
    #define INDICES {0, 0, 0}
    #define UINT_VALUE 123456
    
    GtkTreeStore *store;
    GtkTreeIter iter;
    GtkTreeIter first_iter;
    GtkTreeIter child_iter;
    GtkTreePath *path;
    gboolean result;
    gchar* path_str;
    gint i;
    gint j;
    GValue val = {0, };
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (store, &iter, NULL);
                if (j == 0)
                {
                    first_iter = iter;
                }
            } else {
                gtk_tree_store_append (store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    g_value_init (&val, G_TYPE_UINT);
    g_value_set_uint (&val, UINT_VALUE);
    gtk_tree_store_set_value (store, &first_iter, 0, &val);
    
    result = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (store), &iter);
    if (!result)
    {
        TEST_FAIL ("gtk_tree_model_get_iter_first() returned FALSE for non-empty model", NULL);
    }
    
    path = gtk_tree_model_get_path (GTK_TREE_MODEL (store), &iter);
    path_str = gtk_tree_path_to_string (path);
    
    if (!path_str)
    {
        TEST_FAIL ("path_str is NULL", NULL);
    } else {
        if (strcmp (path_str, "0"))
        {
            TEST_FAIL ("path_str = '%s', should be '0'", path_str);
        }
    }
    
    g_free (path_str);
    
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_iter_first
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Initializes iter with the first iterator in the tree (the one at the path "0") and returns TRUE.
 * Params Values: newly created GtkTreeModel*
 * Expected: TRUE  
 */
static void test_purpose_212()
{
    #define DEPTH 15
    #define INDICES {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14}
    #define UINT_VALUE 123456
    
    GtkTreeStore *store;
    GtkTreeIter iter;
    GtkTreeIter first_iter;
    GtkTreeIter child_iter;
    GtkTreePath *path;
    gboolean result;
    gchar* path_str;
    gint i;
    gint j;
    GValue val = {0, };
    gint indices[] = INDICES;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (store, &iter, NULL);
                if (j == 0)
                {
                    first_iter = iter;
                }
            } else {
                gtk_tree_store_append (store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    g_value_init (&val, G_TYPE_UINT);
    g_value_set_uint (&val, UINT_VALUE);
    gtk_tree_store_set_value (store, &first_iter, 0, &val);
    
    result = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (store), &iter);
    if (!result)
    {
        TEST_FAIL ("gtk_tree_model_get_iter_first() returned FALSE for non-empty model", NULL);
    }
    
    path = gtk_tree_model_get_path (GTK_TREE_MODEL (store), &iter);
    path_str = gtk_tree_path_to_string (path);
    
    if (!path_str)
    {
        TEST_FAIL ("path_str is NULL", NULL);
    } else {
        if (strcmp (path_str, "0"))
        {
            TEST_FAIL ("path_str = '%s', should be '0'", path_str);
        }
    }
    
    g_free (path_str);
    
    #undef DEPTH
    #undef INDICES
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_model_get_iter_first
 * Params: GtkTreeModel *tree_model, GtkTreeIter *iter
 * Returns: gboolean
 * Assertion: Returns FALSE if the tree is empty.
 * Params Values: newly created GtkTreeModel*
 * Expected: TRUE  
 */
static void test_purpose_213()
{
    GtkTreeStore *store;
    GtkTreeIter iter;
    gboolean result;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    result = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (store), &iter);
    if (result)
    {
        TEST_FAIL ("gtk_tree_model_get_iter_first() returned TRUE for empty model", NULL);
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_path_new_first
 * Params: void
 * Returns: GtkTreePath*
 * Assertion: Creates a new GtkTreePath.
 * Params Values: a newly created GtkTreeModel* with string string representation "0"
 * Expected: void
 * 
 * Name: gtk_tree_path_new_first
 * Params: void
 * Returns: GtkTreePath*
 * Assertion: The string representation of this path is "0".
 * Params Values: a newly created GtkTreeModel* with string string representation "0"
 * Expected: void  
 */
static void test_purpose_214()
{
    GtkTreeStore *store;
    GtkTreeIter iter;
    GtkTreePath* path;
    gboolean result;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    path = gtk_tree_path_new_first ();
    if (!path)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
        return;
    }
    
    path_str = gtk_tree_path_to_string (path);
    if (!path_str)
    {
        TEST_FAIL ("path_str is NULL", NULL);
    } else {
        if (strcmp (path_str, "0"))
        {
            TEST_FAIL ("path_str = '%s', should be '0'", path_str);
        }
    }
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_new_proxy
 * Params: GObject *proxy, GtkTreeModel *model, GtkTreePath *path 
 * Returns: GtkTreeRowReference
 * Assertion: Creates a row reference based on path. 
 * Params Values: a newly created GtkTreeModel*, path from string "7:3:4"
 * Expected: a newly allocated GtkTreeRowReference  
 */
static void test_purpose_215()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:4"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    row_ref = gtk_tree_row_reference_new_proxy (G_OBJECT (tree_store), 
                                                GTK_TREE_MODEL (tree_store), path);
    if (row_ref == NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () return NULL, but it shouldn't.", NULL);
    } else {
        path_str = gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
        if (strcmp (path_str, PATH_STR))
        {
            TEST_FAIL("row referense path = '%s', should be '%s'", path_str, PATH_STR);
        }
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_new_proxy
 * Params: GObject *proxy, GtkTreeModel *model, GtkTreePath *path 
 * Returns: GtkTreeRowReference
 * Assertion: Creates a row reference based on path. 
 * Params Values: a newly created GtkTreeModel*, path from string "3:5:0"
 * Expected: a newly allocated GtkTreeRowReference  
 */
static void test_purpose_216()
{
    #define DEPTH 3
    #define INDICES {3, 5, 0}
    #define PATH_STR "3:5:0"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    row_ref = gtk_tree_row_reference_new_proxy (G_OBJECT (tree_store), 
                                                GTK_TREE_MODEL (tree_store), path);
    if (row_ref == NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () return NULL, but it shouldn't.", NULL);
    } else {
        path_str = gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
        if (strcmp (path_str, PATH_STR))
        {
            TEST_FAIL("row referense path = '%s', should be '%s'", path_str, PATH_STR);
        }
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_new_proxy
 * Params: GObject *proxy, GtkTreeModel *model, GtkTreePath *path 
 * Returns: GtkTreeRowReference
 * Assertion: Creates a row reference based on path. 
 * Params Values: a newly created GtkTreeModel*, path from string "0"
 * Expected: a newly allocated GtkTreeRowReference  
 */
static void test_purpose_217()
{
    #define DEPTH 1
    #define INDICES {0}
    #define PATH_STR "0"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    row_ref = gtk_tree_row_reference_new_proxy (G_OBJECT (tree_store), 
                                                GTK_TREE_MODEL (tree_store), path);
    if (row_ref == NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () return NULL, but it shouldn't.", NULL);
    } else {
        path_str = gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
        if (strcmp (path_str, PATH_STR))
        {
            TEST_FAIL("row referense path = '%s', should be '%s'", path_str, PATH_STR);
        }
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * BUG ID: 74362
 * Name: gtk_tree_row_reference_new_proxy
 * Params: GObject *proxy, GtkTreeModel *model, GtkTreePath *path 
 * Returns: GtkTreeRowReference
 * Assertion: However, unlike references created with gtk_tree_row_reference_new(), it does not listen to the model for changes.
 * Params Values: a newly created GtkTreeModel*, path from string "7:3:4"
 * Expected: a newly allocated GtkTreeRowReference  
 */
static void test_purpose_218()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:4"
    #define PATH_STR_TO_DEL "7:2"
    #define REF_PATH_STR_AFTER_DEL "7:2:4"
    #define PATH_STR_TO_INS "7:2"
    #define REF_PATH_STR_AFTER_INS "7:2:5"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    gchar* new_path_str;
    gboolean has_first_iter;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    bug_inf = "BUG ID: 74362\n\
    Name: gtk_tree_row_reference_new_proxy\n\
    Params: GObject *proxy, GtkTreeModel *model, GtkTreePath *path \n\
    Returns: GtkTreeRowReference\n\
    Assertion: However, unlike references created with gtk_tree_row_reference_new(), it does not listen to the model for changes.\n\
    Params Values: a newly created GtkTreeModel*, path from string \"7:3:4\"\n\
    Expected: a newly allocated GtkTreeRowReference\n\
   ";
    if(bug_inf) tet_printf("    %s",bug_inf);
    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    
    row_ref = gtk_tree_row_reference_new_proxy (G_OBJECT (tree_store),
                                                GTK_TREE_MODEL (tree_store), path);
    if (row_ref == NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () returned NULL, but it shouldn't.", NULL);
        return;
    } else {
        path_str = gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
        if (strcmp (path_str, PATH_STR))
        {
            TEST_FAIL("row reference path = '%s', should be '%s'", path_str, PATH_STR);
            return;
        }
    }
    
    res = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (tree_store), 
                                               &iter, PATH_STR_TO_DEL);
    if (!res)
    {
        TEST_FAIL ("1:gtk_tree_model_get_iter_from_string() returned NULL", NULL);
        return;
    }
    gtk_tree_store_remove (tree_store, &iter);
    new_path_str = 
        gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
    if (strcmp (new_path_str, REF_PATH_STR_AFTER_DEL))
    {
        TEST_FAIL ("1:new_path_str = %s, should be %s", 
                   new_path_str, REF_PATH_STR_AFTER_DEL);
    }
    
    res = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (tree_store), 
                                               &parent_iter, PATH_STR_TO_INS);
    if (!res)
    {
        TEST_FAIL ("2:gtk_tree_model_get_iter_from_string() returned NULL", NULL);
        return;
    }
    gtk_tree_store_insert (tree_store, &iter, &parent_iter, 0);
    new_path_str = 
        gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
    if (strcmp (new_path_str, REF_PATH_STR_AFTER_INS))
    {
        TEST_FAIL ("2:new_path_str = %s, should be %s", 
                   new_path_str, REF_PATH_STR_AFTER_INS);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef PATH_STR_TO_DEL
    #undef REF_PATH_STR_AFTER_DEL
    #undef PATH_STR_TO_INS
    #undef REF_PATH_STR_AFTER_INS
   
	
    test_passed ();

    double_bug = 0;
}

/*
 * BUG ID: 74362
 * Name: gtk_tree_row_reference_new_proxy
 * Params: GObject *proxy, GtkTreeModel *model, GtkTreePath *path 
 * Returns: GtkTreeRowReference
 * Assertion: However, unlike references created with gtk_tree_row_reference_new(), it does not listen to the model for changes.
 * Params Values: a newly created GtkTreeModel*, path from string "7:3:4"
 * Expected: a newly allocated GtkTreeRowReference  
 */
static void test_purpose_219()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:4"
    #define PATH_STR_TO_DEL "7:0"
    #define REF_PATH_STR_AFTER_DEL "7:2:4"
    #define PATH_STR_TO_INS "7"
    #define REF_PATH_STR_AFTER_INS "7:3:4"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    gchar* new_path_str;
    gboolean has_first_iter;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    bug_inf = "BUG ID: 74362\n\
    Name: gtk_tree_row_reference_new_proxy\n\
    Params: GObject *proxy, GtkTreeModel *model, GtkTreePath *path \n\
    Returns: GtkTreeRowReference\n\
    Assertion: However, unlike references created with gtk_tree_row_reference_new(), it does not listen to the model for changes.\n\
    Params Values: a newly created GtkTreeModel*, path from string \"7:3:4\"\n\
    Expected: a newly allocated GtkTreeRowReference\n\
   ";
    if(bug_inf) tet_printf("    %s",bug_inf);
    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    
    row_ref = gtk_tree_row_reference_new_proxy (G_OBJECT (tree_store),
                                                GTK_TREE_MODEL (tree_store), path);
    if (row_ref == NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () returned NULL, but it shouldn't.", NULL);
        return;
    } else {
        path_str = gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
        if (strcmp (path_str, PATH_STR))
        {
            TEST_FAIL("row reference path = '%s', should be '%s'", path_str, PATH_STR);
            return;
        }
    }
    
    res = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (tree_store), 
                                               &iter, PATH_STR_TO_DEL);
    if (!res)
    {
        TEST_FAIL ("1:gtk_tree_model_get_iter_from_string() returned NULL", NULL);
        return;
    }
    gtk_tree_store_remove (tree_store, &iter);
    new_path_str = 
        gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
    if (strcmp (new_path_str, REF_PATH_STR_AFTER_DEL))
    {
        TEST_FAIL ("1:new_path_str = %s, should be %s", 
                   new_path_str, REF_PATH_STR_AFTER_DEL);
    }
    
    res = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (tree_store), 
                                               &parent_iter, PATH_STR_TO_INS);
    if (!res)
    {
        TEST_FAIL ("2:gtk_tree_model_get_iter_from_string() returned NULL", NULL);
        return;
    }
    gtk_tree_store_insert (tree_store, &iter, &parent_iter, 0);
    new_path_str = 
        gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
    if (strcmp (new_path_str, REF_PATH_STR_AFTER_INS))
    {
        TEST_FAIL ("2:new_path_str = %s, should be %s", 
                   new_path_str, REF_PATH_STR_AFTER_INS);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef PATH_STR_TO_DEL
    #undef REF_PATH_STR_AFTER_DEL
    #undef PATH_STR_TO_INS
    #undef REF_PATH_STR_AFTER_INS
   
	
    test_passed ();

    double_bug = 0;
}

/*
 * BUG ID: 74362
 * Name: gtk_tree_row_reference_new_proxy
 * Params: GObject *proxy, GtkTreeModel *model, GtkTreePath *path 
 * Returns: GtkTreeRowReference
 * Assertion: However, unlike references created with gtk_tree_row_reference_new(), it does not listen to the model for changes.
 * Params Values: a newly created GtkTreeModel*, path from string "7:3:5"
 * Expected: a newly allocated GtkTreeRowReference  
 */
static void test_purpose_220()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:5"
    #define PATH_STR_TO_DEL "7:0"
    #define REF_PATH_STR_AFTER_DEL "7:2:5"
    #define PATH_STR_TO_INS "7:2:5"
    #define REF_PATH_STR_AFTER_INS "7:2:5"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    gchar* new_path_str;
    gboolean has_first_iter;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    bug_inf = "BUG ID: 74362\n\
    Name: gtk_tree_row_reference_new_proxy\n\
    Params: GObject *proxy, GtkTreeModel *model, GtkTreePath *path \n\
    Returns: GtkTreeRowReference\n\
    Assertion: However, unlike references created with gtk_tree_row_reference_new(), it does not listen to the model for changes.\n\
    Params Values: a newly created GtkTreeModel*, path from string \"7:3:5\"\n\
    Expected: a newly allocated GtkTreeRowReference\n\
   ";
    if(bug_inf) tet_printf("    %s",bug_inf);
    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    
    row_ref = gtk_tree_row_reference_new_proxy (G_OBJECT (tree_store),
                                                GTK_TREE_MODEL (tree_store), path);
    if (row_ref == NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () returned NULL, but it shouldn't.", NULL);
        return;
    } else {
        path_str = gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
        if (strcmp (path_str, PATH_STR))
        {
            TEST_FAIL("row reference path = '%s', should be '%s'", path_str, PATH_STR);
            return;
        }
    }
    
    res = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (tree_store), 
                                               &iter, PATH_STR_TO_DEL);
    if (!res)
    {
        TEST_FAIL ("1:gtk_tree_model_get_iter_from_string() returned NULL", NULL);
        return;
    }
    gtk_tree_store_remove (tree_store, &iter);
    new_path_str = 
        gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
    if (strcmp (new_path_str, REF_PATH_STR_AFTER_DEL))
    {
        TEST_FAIL ("1:new_path_str = %s, should be %s", 
                   new_path_str, REF_PATH_STR_AFTER_DEL);
    }
    
    res = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (tree_store), 
                                               &parent_iter, PATH_STR_TO_INS);
    if (!res)
    {
        TEST_FAIL ("2:gtk_tree_model_get_iter_from_string() returned NULL", NULL);
        return;
    }
    gtk_tree_store_insert (tree_store, &iter, &parent_iter, 0);
    new_path_str = 
        gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
    if (strcmp (new_path_str, REF_PATH_STR_AFTER_INS))
    {
        TEST_FAIL ("2:new_path_str = %s, should be %s", 
                   new_path_str, REF_PATH_STR_AFTER_INS);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef PATH_STR_TO_DEL
    #undef REF_PATH_STR_AFTER_DEL
    #undef PATH_STR_TO_INS
    #undef REF_PATH_STR_AFTER_INS
   
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_new_proxy
 * Params: GObject *proxy, GtkTreeModel *model, GtkTreePath *path 
 * Returns: GtkTreeRowReference
 * Assertion: If path isn't a valid path in model, then NULL is returned.'
 * Params Values: a newly created GtkTreeModel*, path from string "7:3:9"
 * Expected: NULL  
 */
static void test_purpose_221()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:9"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    
    row_ref = gtk_tree_row_reference_new_proxy (G_OBJECT (tree_store), 
                                                GTK_TREE_MODEL (tree_store), path);
    if (row_ref != NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () should return NULL, but it didn't.", NULL);
    } 
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_new_proxy
 * Params: GObject *proxy, GtkTreeModel *model, GtkTreePath *path 
 * Returns: GtkTreeRowReference
 * Assertion: If path isn't a valid path in model, then NULL is returned.'
 * Params Values: a newly created GtkTreeModel*, path from string "3:5:0:1"
 * Expected: NULL  
 */
static void test_purpose_222()
{
    #define DEPTH 3
    #define INDICES {3, 5, 0}
    #define PATH_STR "3:5:0:1"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    
    row_ref = gtk_tree_row_reference_new_proxy (G_OBJECT (tree_store), 
                                                GTK_TREE_MODEL (tree_store), path);
    if (row_ref != NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () should return NULL, but it didn't.", NULL);
    } 
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_new_proxy
 * Params: GObject *proxy, GtkTreeModel *model, GtkTreePath *path 
 * Returns: GtkTreeRowReference
 * Assertion: If path isn't a valid path in model, then NULL is returned.'
 * Params Values: a newly created GtkTreeModel*, path from string "1"
 * Expected: NULL  
 */
static void test_purpose_223()
{
    #define DEPTH 1
    #define INDICES {0}
    #define PATH_STR "1"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    
    row_ref = gtk_tree_row_reference_new_proxy (G_OBJECT (tree_store), 
                                                GTK_TREE_MODEL (tree_store), path);
    if (row_ref != NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () should return NULL, but it didn't.", NULL);
    } 
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_inserted
 * Params: GObject *proxy, GtkTreePath *path 
 * Returns: void
 * Assertion: Lets a set of row reference created by gtk_tree_row_reference_new_proxy() know that the model emitted the "row_inserted" signal.
 * Params Values: GObject *proxy, path from string "7:0"
 * Expected: void  
 */
static void test_purpose_224()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:4"
    #define PATH_STR_TO_INS "7:0"
    #define REF_PATH_STR_AFTER_INS "7:4:4"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    gchar* new_path_str;
    gboolean has_first_iter;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    
    row_ref = gtk_tree_row_reference_new_proxy (G_OBJECT (tree_store),
                                                GTK_TREE_MODEL (tree_store), path);
    if (row_ref == NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () returned NULL, but it shouldn't.", NULL);
        return;
    } else {
        path_str = gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
        if (strcmp (path_str, PATH_STR))
        {
            TEST_FAIL("row reference path = '%s', should be '%s'", path_str, PATH_STR);
            return;
        }
    }
    
    gtk_tree_row_reference_inserted (G_OBJECT (tree_store), 
                                     gtk_tree_path_new_from_string (PATH_STR_TO_INS));
    
    res = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (tree_store), 
                                               &parent_iter, PATH_STR_TO_INS);
    if (!res)
    {
        TEST_FAIL ("1:gtk_tree_model_get_iter_from_string() returned NULL", NULL);
        return;
    }
    gtk_tree_store_insert (tree_store, &iter, &parent_iter, 0);
    new_path_str = 
        gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
    if (strcmp (new_path_str, REF_PATH_STR_AFTER_INS))
    {
        TEST_FAIL ("2:new_path_str = %s, should be %s", 
                   new_path_str, REF_PATH_STR_AFTER_INS);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef PATH_STR_TO_INS
    #undef REF_PATH_STR_AFTER_INS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_inserted
 * Params: GObject *proxy, GtkTreePath *path 
 * Returns: void
 * Assertion: Lets a set of row reference created by gtk_tree_row_reference_new_proxy() know that the model emitted the "row_inserted" signal.
 * Params Values: GObject *proxy, path from string "7:3:5:0"
 * Expected: void  
 */
static void test_purpose_225()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:5"
    #define PATH_STR_TO_INS "7:3:5:0"
    #define REF_PATH_STR_AFTER_INS "7:3:5"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    gchar* new_path_str;
    gboolean has_first_iter;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    
    row_ref = gtk_tree_row_reference_new_proxy (G_OBJECT (tree_store),
                                                GTK_TREE_MODEL (tree_store), path);
    if (row_ref == NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () returned NULL, but it shouldn't.", NULL);
        return;
    } else {
        path_str = gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
        if (strcmp (path_str, PATH_STR))
        {
            TEST_FAIL("row reference path = '%s', should be '%s'", path_str, PATH_STR);
            return;
        }
    }
    
    gtk_tree_row_reference_inserted (G_OBJECT (tree_store), 
                                     gtk_tree_path_new_from_string (PATH_STR_TO_INS));
    
    res = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (tree_store), 
                                               &parent_iter, PATH_STR_TO_INS);
    if (!res)
    {
        TEST_FAIL ("1:gtk_tree_model_get_iter_from_string() returned NULL", NULL);
        return;
    }
    gtk_tree_store_insert (tree_store, &iter, &parent_iter, 0);
    new_path_str = 
        gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
    if (strcmp (new_path_str, REF_PATH_STR_AFTER_INS))
    {
        TEST_FAIL ("2:new_path_str = %s, should be %s", 
                   new_path_str, REF_PATH_STR_AFTER_INS);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef PATH_STR_TO_INS
    #undef REF_PATH_STR_AFTER_INS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_inserted
 * Params: GObject *proxy, GtkTreePath *path 
 * Returns: void
 * Assertion: Lets a set of row reference created by gtk_tree_row_reference_new_proxy() know that the model emitted the "row_inserted" signal.
 * Params Values: GObject *proxy, path from string "7:3:5:0:1"
 * Expected: void  
 */
static void test_purpose_226()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:4"
    #define PATH_STR_TO_INS "7:3:5:0:1"
    #define REF_PATH_STR_AFTER_INS "7:3:4"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    gchar* new_path_str;
    gboolean has_first_iter;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    
    row_ref = gtk_tree_row_reference_new_proxy (G_OBJECT (tree_store),
                                                GTK_TREE_MODEL (tree_store), path);
    if (row_ref == NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () returned NULL, but it shouldn't.", NULL);
        return;
    } else {
        path_str = gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
        if (strcmp (path_str, PATH_STR))
        {
            TEST_FAIL("row reference path = '%s', should be '%s'", path_str, PATH_STR);
            return;
        }
    }
    
    gtk_tree_row_reference_inserted (G_OBJECT (tree_store), 
                                     gtk_tree_path_new_from_string (PATH_STR_TO_INS));
    
    res = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (tree_store), 
                                               &parent_iter, PATH_STR_TO_INS);
    if (!res)
    {
        TEST_FAIL ("1:gtk_tree_model_get_iter_from_string() returned NULL", NULL);
        return;
    }
    gtk_tree_store_insert (tree_store, &iter, &parent_iter, 0);
    new_path_str = 
        gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
    if (strcmp (new_path_str, REF_PATH_STR_AFTER_INS))
    {
        TEST_FAIL ("2:new_path_str = %s, should be %s", 
                   new_path_str, REF_PATH_STR_AFTER_INS);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef PATH_STR_TO_INS
    #undef REF_PATH_STR_AFTER_INS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_deleted
 * Params: GObject *proxy, GtkTreePath *path 
 * Returns: void
 * Assertion: Lets a set of row reference created by gtk_tree_row_reference_new_proxy() know that the model emitted the "row_deleted" signal.
 * Params Values: GObject *proxy, path from string "7:0"
 * Expected: void  
 */
static void test_purpose_227()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:4"
    #define PATH_STR_TO_DEL "7:0"
    #define REF_PATH_STR_AFTER_DEL "7:2:4"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    gchar* new_path_str;
    gboolean has_first_iter;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    
    row_ref = gtk_tree_row_reference_new_proxy (G_OBJECT (tree_store),
                                                GTK_TREE_MODEL (tree_store), path);
    if (row_ref == NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () returned NULL, but it shouldn't.", NULL);
        return;
    } else {
        path_str = gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
        if (strcmp (path_str, PATH_STR))
        {
            TEST_FAIL("row reference path = '%s', should be '%s'", path_str, PATH_STR);
            return;
        }
    }
    
    gtk_tree_row_reference_deleted (G_OBJECT (tree_store), 
                                    gtk_tree_path_new_from_string (PATH_STR_TO_DEL));
    
    res = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (tree_store), 
                                               &parent_iter, PATH_STR_TO_DEL);
    if (!res)
    {
        TEST_FAIL ("1:gtk_tree_model_get_iter_from_string() returned NULL", NULL);
        return;
    }
    gtk_tree_store_remove (tree_store, &iter);
    new_path_str = 
        gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
    if (strcmp (new_path_str, REF_PATH_STR_AFTER_DEL))
    {
        TEST_FAIL ("2:new_path_str = %s, should be %s", 
                   new_path_str, REF_PATH_STR_AFTER_DEL);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef PATH_STR_TO_DEL
    #undef REF_PATH_STR_AFTER_DEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_deleted
 * Params: GObject *proxy, GtkTreePath *path 
 * Returns: void
 * Assertion: Lets a set of row reference created by gtk_tree_row_reference_new_proxy() know that the model emitted the "row_deleted" signal.
 * Params Values: GObject *proxy, path from string "7:2"
 * Expected: void  
 */
static void test_purpose_228()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:5"
    #define PATH_STR_TO_DEL "7:2"
    #define REF_PATH_STR_AFTER_DEL "7:2:5"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    gchar* new_path_str;
    gboolean has_first_iter;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    
    row_ref = gtk_tree_row_reference_new_proxy (G_OBJECT (tree_store),
                                                GTK_TREE_MODEL (tree_store), path);
    if (row_ref == NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () returned NULL, but it shouldn't.", NULL);
        return;
    } else {
        path_str = gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
        if (strcmp (path_str, PATH_STR))
        {
            TEST_FAIL("row reference path = '%s', should be '%s'", path_str, PATH_STR);
            return;
        }
    }
    
    gtk_tree_row_reference_deleted (G_OBJECT (tree_store), 
                                    gtk_tree_path_new_from_string (PATH_STR_TO_DEL));
    
    res = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (tree_store), 
                                               &parent_iter, PATH_STR_TO_DEL);
    if (!res)
    {
        TEST_FAIL ("1:gtk_tree_model_get_iter_from_string() returned NULL", NULL);
        return;
    }
    gtk_tree_store_remove (tree_store, &iter);
    new_path_str = 
        gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
    if (strcmp (new_path_str, REF_PATH_STR_AFTER_DEL))
    {
        TEST_FAIL ("2:new_path_str = %s, should be %s", 
                   new_path_str, REF_PATH_STR_AFTER_DEL);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef PATH_STR_TO_DEL
    #undef REF_PATH_STR_AFTER_DEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_deleted
 * Params: GObject *proxy, GtkTreePath *path 
 * Returns: void
 * Assertion: Lets a set of row reference created by gtk_tree_row_reference_new_proxy() know that the model emitted the "row_deleted" signal.
 * Params Values: GObject *proxy, path from string "7:3:5:0:1"
 * Expected: void  
 */
static void test_purpose_229()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:4"
    #define PATH_STR_TO_DEL "7:3:5:0:1"
    #define REF_PATH_STR_AFTER_DEL "7:3:4"
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    gchar* new_path_str;
    gboolean has_first_iter;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    
    row_ref = gtk_tree_row_reference_new_proxy (G_OBJECT (tree_store),
                                                GTK_TREE_MODEL (tree_store), path);
    if (row_ref == NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () returned NULL, but it shouldn't.", NULL);
        return;
    } else {
        path_str = gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
        if (strcmp (path_str, PATH_STR))
        {
            TEST_FAIL("row reference path = '%s', should be '%s'", path_str, PATH_STR);
            return;
        }
    }
    
    gtk_tree_row_reference_deleted (G_OBJECT (tree_store), 
                                    gtk_tree_path_new_from_string (PATH_STR_TO_DEL));
    
    res = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (tree_store), 
                                               &parent_iter, PATH_STR_TO_DEL);
    if (!res)
    {
        TEST_FAIL ("1:gtk_tree_model_get_iter_from_string() returned NULL", NULL);
        return;
    }
    gtk_tree_store_remove (tree_store, &iter);
    new_path_str = 
        gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
    if (strcmp (new_path_str, REF_PATH_STR_AFTER_DEL))
    {
        TEST_FAIL ("2:new_path_str = %s, should be %s", 
                   new_path_str, REF_PATH_STR_AFTER_DEL);
    }
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef PATH_STR_TO_DEL
    #undef REF_PATH_STR_AFTER_DEL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_tree_row_reference_reordered
 * Params: GObject *proxy, GtkTreePath *path,  GtkTreeIter *iter, gint *new_order
 * Returns: void
 * Assertion: Lets a set of row reference created by gtk_tree_row_reference_new_proxy() know that the model emitted the "rows_reordered" signal.
 * Params Values: GObject *proxy, path from string "7:3:3", iter from path "7:3:3", {7, 3, 2}
 * Expected: a newly allocated GtkTreeRowReference  
 */
static void test_purpose_230()
{
    #define DEPTH 5
    #define INDICES {7, 3, 5, 0, 1}
    #define PATH_STR "7:3:4"
    #define PATH_STR_TO_REORDER "7:3:3"
    #define NEW_ORDER {7, 3, 2}
    
    GtkTreeStore* tree_store;
    GtkTreeIter iter;
    GtkTreeIter parent_iter;
    GtkTreeIter child_iter;
    GtkTreePath* path;
    gint indices[] = INDICES;
    guint i;
    guint j;
    GtkTreeRowReference* row_ref;
    gchar* path_str;
    gchar* new_path_str;
    gboolean has_first_iter;
    gboolean res;
    gint new_order[] = NEW_ORDER;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    tree_store = gtk_tree_store_new (1, G_TYPE_UINT);
    
    if (!tree_store)
    {
        TEST_FAIL (get_not_created_msg(), NULL); 
    }
    
    for (i = 0; i < DEPTH; i++)
    {
        for (j = 0; j <= indices[i]; j++)
        {
            if (i == 0)
            {
                gtk_tree_store_append (tree_store, &iter, NULL);
            } else {
                gtk_tree_store_append (tree_store, &child_iter, &iter);            
            }
        }
        if (i != 0)
        {
            iter = child_iter;
        }
    }
    
    path = gtk_tree_path_new_from_string (PATH_STR);
    
    row_ref = gtk_tree_row_reference_new_proxy (G_OBJECT (tree_store),
                                                GTK_TREE_MODEL (tree_store), path);
    if (row_ref == NULL)
    {
        TEST_FAIL("gtk_tree_row_reference_new () returned NULL, but it shouldn't.", NULL);
        return;
    } else {
        path_str = gtk_tree_path_to_string (gtk_tree_row_reference_get_path (row_ref));
        if (strcmp (path_str, PATH_STR))
        {
            TEST_FAIL("row reference path = '%s', should be '%s'", path_str, PATH_STR);
            return;
        }
    }
    
    res = gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (tree_store), 
                                               &parent_iter, PATH_STR_TO_REORDER);
    if (!res)
    {
        TEST_FAIL ("gtk_tree_model_get_iter_from_string() returned NULL", NULL);
        return;
    }
    
    gtk_tree_row_reference_reordered (G_OBJECT (tree_store), 
                                      gtk_tree_path_new_from_string 
                                          (PATH_STR_TO_REORDER),
                                      &parent_iter,
                                      new_order);
    
    
    #undef DEPTH
    #undef INDICES
    #undef PATH_STR
    #undef PATH_STR_TO_REORDER
    #undef NEW_ORDER
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkTreeModel ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {test_purpose_79, 1},
    {test_purpose_80, 1},
    {test_purpose_81, 1},
    {test_purpose_82, 1},
    {test_purpose_83, 1},
    {test_purpose_84, 1},
    {test_purpose_85, 1},
    {test_purpose_86, 1},
    {test_purpose_87, 1},
    {test_purpose_88, 1},
    {test_purpose_89, 1},
    {test_purpose_90, 1},
    {test_purpose_91, 1},
    {test_purpose_92, 1},
    {test_purpose_93, 1},
    {test_purpose_94, 1},
    {test_purpose_95, 1},
    {test_purpose_96, 1},
    {test_purpose_97, 1},
    {test_purpose_98, 1},
    {test_purpose_99, 1},
    {test_purpose_100, 1},
    {test_purpose_101, 1},
    {test_purpose_102, 1},
    {test_purpose_103, 1},
    {test_purpose_104, 1},
    {test_purpose_105, 1},
    {test_purpose_106, 1},
    {test_purpose_107, 1},
    {test_purpose_108, 1},
    {test_purpose_109, 1},
    {test_purpose_110, 1},
    {test_purpose_111, 1},
    {test_purpose_112, 1},
    {test_purpose_113, 1},
    {test_purpose_114, 1},
    {test_purpose_115, 1},
    {test_purpose_116, 1},
    {test_purpose_117, 1},
    {test_purpose_118, 1},
    {test_purpose_119, 1},
    {test_purpose_120, 1},
    {test_purpose_121, 1},
    {test_purpose_122, 1},
    {test_purpose_123, 1},
    {test_purpose_124, 1},
    {test_purpose_125, 1},
    {test_purpose_126, 1},
    {test_purpose_127, 1},
    {test_purpose_128, 1},
    {test_purpose_129, 1},
    {test_purpose_130, 1},
    {test_purpose_131, 1},
    {test_purpose_132, 1},
    {test_purpose_133, 1},
    {test_purpose_134, 1},
    {test_purpose_135, 1},
    {test_purpose_136, 1},
    {test_purpose_137, 1},
    {test_purpose_138, 1},
    {test_purpose_139, 1},
    {test_purpose_140, 1},
    {test_purpose_141, 1},
    {test_purpose_142, 1},
    {test_purpose_143, 1},
    {test_purpose_144, 1},
    {test_purpose_145, 1},
    {test_purpose_146, 1},
    {test_purpose_147, 1},
    {test_purpose_148, 1},
    {test_purpose_149, 1},
    {test_purpose_150, 1},
    {test_purpose_151, 1},
    {test_purpose_152, 1},
    {test_purpose_153, 1},
    {test_purpose_154, 1},
    {test_purpose_155, 1},
    {test_purpose_156, 1},
    {test_purpose_157, 1},
    {test_purpose_158, 1},
    {test_purpose_159, 1},
    {test_purpose_160, 1},
    {test_purpose_161, 1},
    {test_purpose_162, 1},
    {test_purpose_163, 1},
    {test_purpose_164, 1},
    {test_purpose_165, 1},
    {test_purpose_166, 1},
    {test_purpose_167, 1},
    {test_purpose_168, 1},
    {test_purpose_169, 1},
    {test_purpose_170, 1},
    {test_purpose_171, 1},
    {test_purpose_172, 1},
    {test_purpose_173, 1},
    {test_purpose_174, 1},
    {test_purpose_175, 1},
    {test_purpose_176, 1},
    {test_purpose_177, 1},
    {test_purpose_178, 1},
    {test_purpose_179, 1},
    {test_purpose_180, 1},
    {test_purpose_181, 1},
    {test_purpose_182, 1},
    {test_purpose_183, 1},
    {test_purpose_184, 1},
    {test_purpose_185, 1},
    {test_purpose_186, 1},
    {test_purpose_187, 1},
    {test_purpose_188, 1},
    {test_purpose_189, 1},
    {test_purpose_190, 1},
    {test_purpose_191, 1},
    {test_purpose_192, 1},
    {test_purpose_193, 1},
    {test_purpose_194, 1},
    {test_purpose_195, 1},
    {test_purpose_196, 1},
    {test_purpose_197, 1},
    {test_purpose_198, 1},
    {test_purpose_199, 1},
    {test_purpose_200, 1},
    {test_purpose_201, 1},
    {test_purpose_202, 1},
    {test_purpose_203, 1},
    {test_purpose_204, 1},
    {test_purpose_205, 1},
    {test_purpose_206, 1},
    {test_purpose_207, 1},
    {test_purpose_208, 1},
    {test_purpose_209, 1},
    {test_purpose_210, 1},
    {test_purpose_211, 1},
    {test_purpose_212, 1},
    {test_purpose_213, 1},
    {test_purpose_214, 1},
    {test_purpose_215, 1},
    {test_purpose_216, 1},
    {test_purpose_217, 1},
    {test_purpose_218, 1},
    {test_purpose_219, 1},
    {test_purpose_220, 1},
    {test_purpose_221, 1},
    {test_purpose_222, 1},
    {test_purpose_223, 1},
    {test_purpose_224, 1},
    {test_purpose_225, 1},
    {test_purpose_226, 1},
    {test_purpose_227, 1},
    {test_purpose_228, 1},
    {test_purpose_229, 1},
    {test_purpose_230, 1},
    {NULL,0}
};
