/*
 * GtkWindow methods tests
 * Testing GtkWindow methods
 *
 */ 

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <tet_api.h>
#include <ft2build.h>
#include FT_FREETYPE_H
#include <fontconfig/fontconfig.h>
#define _XFT_NO_COMPAT
#define _XFTCOMPAT_H_
#include <X11/Xlib.h>
#include <X11/Xft/Xft.h>
#include <pango/pangoft2.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gstdio.h>
#include <gmodule.h>
#include <gdk/gdkkeysyms.h>
#include <errno.h>
#include <unistd.h>

#include "libtestgen.h"
#include "libstr.h"
#include "libfile.h"
#include "libthr.h"

#define TEST_FAIL(str, ...) {test_failed ();tet_printf("%s, line %d: ", __FILE__, __LINE__);tet_printf (str, __VA_ARGS__);}

/*
 * global variables
 */

int test_purp_passed_num = 0;
int all_test_purp_num = 0;
int double_bug = 0;
unsigned test_passed_flag = 1;

/*
 * function prototypes
 */
static char* get_not_created_msg (void);
static char* get_wrong_type_msg (void);
static void test_passed (void);
static void test_failed (void);
static void startup_func();
static void cleanup_func();


gchar* bug_inf = NULL;

#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <gdk/gdkx.h>
#include "librobot.h"

gint global_iter;
gboolean global_is_fullscreened;
GtkWidget* global_press_me_button;
gint global_press_n_times;

void 
global_activate_handler (GtkButton *button, gpointer user_data)
{
    GtkWindow* window = GTK_WINDOW (user_data);


    if (global_is_fullscreened)
    {
        gtk_window_unfullscreen (window);
    } else {
        gtk_window_fullscreen (window);
    }
    global_is_fullscreened = !global_is_fullscreened;
}

gboolean 
global_window_state_event_handler (GtkWidget* widget, GdkEvent *event, 
     gpointer user_data)
{
    global_iter++;
    return FALSE;
}

gboolean 
global_window_mnemonic_activate_handler (GtkWidget* widget, gboolean arg1,
     gpointer user_data)
{
    global_iter++;
    return FALSE;
}

/*
 * Name:  gtk_window_new
 * Params: GtkWindowType type
 * Returns: GtkWindow*
 * Assertion: Creates a new GtkWindow, which is a toplevel window that can contain other widgets.
 * Params Values: GTK_WINDOW_TOPLEVEL
 * Expected: GtkWindow*  
 */
static void test_purpose_1()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    
    GtkWidget* widget;
    gchararray title;
    gboolean allow_shrink;
    gboolean allow_grow;
    gboolean modal;
    GtkWindowPosition window_position;
    gint default_width;
    gint default_height;
    gboolean destroy_with_parent;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT(widget), "title", &title, NULL);
    if (title != NULL) 
    {
        TEST_FAIL ("title = '%s', should be NULL", title);
    }
    
    g_object_get (GTK_OBJECT(widget), "allow-shrink", &allow_shrink, NULL);
    if (allow_shrink != FALSE) 
    {
        TEST_FAIL ("allow_shrink = %d, should be %d", allow_shrink, FALSE);
    }
    
    g_object_get (GTK_OBJECT(widget), "allow-grow", &allow_grow, NULL);
    if (allow_grow != TRUE) 
    {
        TEST_FAIL ("allow_grow = %d, should be %d", allow_grow, FALSE);
    }
    
    g_object_get (GTK_OBJECT(widget), "modal", &modal, NULL);
    if (modal != FALSE) 
    {
        TEST_FAIL ("modal = %d, should be %d", modal, FALSE);
    }
    
    g_object_get (GTK_OBJECT(widget), "window_position", &window_position, NULL);
    if (window_position != GTK_WIN_POS_NONE) 
    {
        TEST_FAIL ("window_position = %d, should be %d", 
                   window_position, GTK_WIN_POS_NONE);
    }
    
    g_object_get (GTK_OBJECT(widget), "default-width", &default_width, NULL);
    if (default_width != -1) 
    {
        TEST_FAIL ("default_width = %d, should be %d", default_width, -1);
    }
    
    g_object_get (GTK_OBJECT(widget), "default-height", &default_height, NULL);
    if (default_height != -1) 
    {
        TEST_FAIL ("default_height = %d, should be %d", default_height, -1);
    }
    
    g_object_get (GTK_OBJECT(widget), "destroy-with-parent", &destroy_with_parent, NULL);
    if (destroy_with_parent != FALSE) 
    {
        TEST_FAIL ("destroy_with_parent = %d, should be %d", 
                   destroy_with_parent, FALSE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_new
 * Params: GtkWindowType type
 * Returns: GtkWindow*
 * Assertion: Creates a new GtkWindow, which is a toplevel window that can contain other widgets.
 * Params Values: GTK_WINDOW_POPUP
 * Expected: GtkWindow*  
 */
static void test_purpose_2()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    
    GtkWidget* widget;
    gchararray title;
    gboolean allow_shrink;
    gboolean allow_grow;
    gboolean modal;
    GtkWindowPosition window_position;
    gint default_width;
    gint default_height;
    gboolean destroy_with_parent;
    
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_get (GTK_OBJECT(widget), "title", &title, NULL);
    if (title != NULL) 
    {
        TEST_FAIL ("title = '%s', should be NULL", title);
    }
    
    g_object_get (GTK_OBJECT(widget), "allow-shrink", &allow_shrink, NULL);
    if (allow_shrink != FALSE) 
    {
        TEST_FAIL ("allow_shrink = %d, should be %d", allow_shrink, FALSE);
    }
    
    g_object_get (GTK_OBJECT(widget), "allow-grow", &allow_grow, NULL);
    if (allow_grow != TRUE) 
    {
        TEST_FAIL ("allow_grow = %d, should be %d", allow_grow, FALSE);
    }
    
    g_object_get (GTK_OBJECT(widget), "modal", &modal, NULL);
    if (modal != FALSE) 
    {
        TEST_FAIL ("modal = %d, should be %d", modal, FALSE);
    }
    
    g_object_get (GTK_OBJECT(widget), "window_position", &window_position, NULL);
    if (window_position != GTK_WIN_POS_NONE) 
    {
        TEST_FAIL ("window_position = %d, should be %d", 
                   window_position, GTK_WIN_POS_NONE);
    }
    
    g_object_get (GTK_OBJECT(widget), "default-width", &default_width, NULL);
    if (default_width != -1) 
    {
        TEST_FAIL ("default_width = %d, should be %d", default_width, -1);
    }
    
    g_object_get (GTK_OBJECT(widget), "default-height", &default_height, NULL);
    if (default_height != -1) 
    {
        TEST_FAIL ("default_height = %d, should be %d", default_height, -1);
    }
    
    g_object_get (GTK_OBJECT(widget), "destroy-with-parent", &destroy_with_parent, NULL);
    if (destroy_with_parent != FALSE) 
    {
        TEST_FAIL ("destroy_with_parent = %d, should be %d", 
                   destroy_with_parent, FALSE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_title
 * Params: GtkWindow *window, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the GtkWindow.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "Text"
 * Expected: void  
 */
static void test_purpose_3()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define TITLE "Text"
    
    GtkWidget* widget;
    gchararray title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_title (GTK_WINDOW (widget), (gchar*) TITLE);
    
    g_object_get (GTK_OBJECT(widget), "title", &title, NULL);
    
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_title
 * Params: GtkWindow *window, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the GtkWindow.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890" 
 * Expected: void  
 */
static void test_purpose_4()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define TITLE "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890" 
    
    GtkWidget* widget;
    gchararray title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_title (GTK_WINDOW (widget), (gchar*) TITLE);
    
    g_object_get (GTK_OBJECT(widget), "title", &title, NULL);
    
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_title
 * Params: GtkWindow *window, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the GtkWindow.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "!@#$%^&*()_+|~=\";:'?<>`/" 
 * Expected: void  
 */
static void test_purpose_5()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define TITLE "!@#$%^&*()_+|~=\";:'?<>`/" 
    
    GtkWidget* widget;
    gchararray title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_title (GTK_WINDOW (widget), (gchar*) TITLE);
    
    g_object_get (GTK_OBJECT(widget), "title", &title, NULL);
    
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_title
 * Params: GtkWindow *window, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the GtkWindow.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "" 
 * Expected: void  
 */
static void test_purpose_6()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define TITLE "" 
    
    GtkWidget* widget;
    gchararray title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_title (GTK_WINDOW (widget), (gchar*) TITLE);
    
    g_object_get (GTK_OBJECT(widget), "title", &title, NULL);
    
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_title
 * Params: GtkWindow *window, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the GtkWindow.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, " " 
 * Expected: void  
 */
static void test_purpose_7()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define TITLE " " 
    
    GtkWidget* widget;
    gchararray title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_title (GTK_WINDOW (widget), (gchar*) TITLE);
    
    g_object_get (GTK_OBJECT(widget), "title", &title, NULL);
    
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_title
 * Params: GtkWindow *window, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the GtkWindow.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "   " 
 * Expected: void  
 */
static void test_purpose_8()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define TITLE "   " 
    
    GtkWidget* widget;
    gchararray title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_title (GTK_WINDOW (widget), (gchar*) TITLE);
    
    g_object_get (GTK_OBJECT(widget), "title", &title, NULL);
    
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_title
 * Params: GtkWindow *window, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the GtkWindow.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, NULL
 * Expected: void  
 */
static void test_purpose_9()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define TITLE NULL
    
    GtkWidget* widget;
    gchararray title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_title (GTK_WINDOW (widget), (gchar*) TITLE);
    
    g_object_get (GTK_OBJECT(widget), "title", &title, NULL);
    
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_title
 * Params: GtkWindow *window, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the GtkWindow.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, "Text"
 * Expected: void  
 */
static void test_purpose_10()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define TITLE "Text"
    
    GtkWidget* widget;
    gchararray title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_title (GTK_WINDOW (widget), (gchar*) TITLE);
    
    g_object_get (GTK_OBJECT(widget), "title", &title, NULL);
    
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_title
 * Params: GtkWindow *window, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the GtkWindow.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, "\b\n\t" 
 * Expected: void  
 */
static void test_purpose_11()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define TITLE "\b\n\t" 
    
    GtkWidget* widget;
    gchararray title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_title (GTK_WINDOW (widget), (gchar*) TITLE);
    
    g_object_get (GTK_OBJECT(widget), "title", &title, NULL);
    
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_title
 * Params: GtkWindow *window, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the GtkWindow.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, "" 
 * Expected: void  
 */
static void test_purpose_12()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define TITLE "" 
    
    GtkWidget* widget;
    gchararray title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_title (GTK_WINDOW (widget), (gchar*) TITLE);
    
    g_object_get (GTK_OBJECT(widget), "title", &title, NULL);
    
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_title
 * Params: GtkWindow *window, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the GtkWindow.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, " " 
 * Expected: void  
 */
static void test_purpose_13()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define TITLE " " 
    
    GtkWidget* widget;
    gchararray title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_title (GTK_WINDOW (widget), (gchar*) TITLE);
    
    g_object_get (GTK_OBJECT(widget), "title", &title, NULL);
    
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_title
 * Params: GtkWindow *window, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the GtkWindow.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "   " 
 * Expected: void  
 */
static void test_purpose_14()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define TITLE "   " 
    
    GtkWidget* widget;
    gchararray title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_title (GTK_WINDOW (widget), (gchar*) TITLE);
    
    g_object_get (GTK_OBJECT(widget), "title", &title, NULL);
    
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_title
 * Params: GtkWindow *window, const gchar *title
 * Returns: void
 * Assertion: Sets the title of the GtkWindow.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, NULL
 * Expected: void  
 */
static void test_purpose_15()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define TITLE NULL
    
    GtkWidget* widget;
    gchararray title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_title (GTK_WINDOW (widget), (gchar*) TITLE);
    
    g_object_get (GTK_OBJECT(widget), "title", &title, NULL);
    
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_title
 * Params: GtkWindow *window
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the title of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: "Text"  
 */
static void test_purpose_16()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define TITLE "Text"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "title", TITLE, NULL);
    
    title = gtk_window_get_title (GTK_WINDOW (widget));
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_title
 * Params: GtkWindow *window
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the title of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"   
 */
static void test_purpose_17()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define TITLE "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890" 
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "title", TITLE, NULL);
    
    title = gtk_window_get_title (GTK_WINDOW (widget));
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_title
 * Params: GtkWindow *window
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the title of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: "!@#$%^&*()_+|~=\";:'?<>`/"   
 */
static void test_purpose_18()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define TITLE "!@#$%^&*()_+|~=\";:'?<>`/" 
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "title", TITLE, NULL);
    
    title = gtk_window_get_title (GTK_WINDOW (widget));
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_title
 * Params: GtkWindow *window
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the title of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: ""   
 */
static void test_purpose_19()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define TITLE "" 
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "title", TITLE, NULL);
    
    title = gtk_window_get_title (GTK_WINDOW (widget));
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_title
 * Params: GtkWindow *window
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the title of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: " "   
 */
static void test_purpose_20()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define TITLE " " 
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "title", TITLE, NULL);
    
    title = gtk_window_get_title (GTK_WINDOW (widget));
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_title
 * Params: GtkWindow *window
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the title of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: "   "   
 */
static void test_purpose_21()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define TITLE "   " 
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "title", TITLE, NULL);
    
    title = gtk_window_get_title (GTK_WINDOW (widget));
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_title
 * Params: GtkWindow *window
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the title of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: NULL  
 */
static void test_purpose_22()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define TITLE NULL
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "title", TITLE, NULL);
    
    title = gtk_window_get_title (GTK_WINDOW (widget));
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_title
 * Params: GtkWindow *window
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the title of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: "Text"  
 */
static void test_purpose_23()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define TITLE "Text"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "title", TITLE, NULL);
    
    title = gtk_window_get_title (GTK_WINDOW (widget));
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_title
 * Params: GtkWindow *window
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the title of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: "\b\n\t"   
 */
static void test_purpose_24()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define TITLE "\b\n\t" 
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "title", TITLE, NULL);
    
    title = gtk_window_get_title (GTK_WINDOW (widget));
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_title
 * Params: GtkWindow *window
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the title of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: ""   
 */
static void test_purpose_25()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define TITLE "" 
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "title", TITLE, NULL);
    
    title = gtk_window_get_title (GTK_WINDOW (widget));
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_title
 * Params: GtkWindow *window
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the title of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: " "   
 */
static void test_purpose_26()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define TITLE " " 
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "title", TITLE, NULL);
    
    title = gtk_window_get_title (GTK_WINDOW (widget));
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_title
 * Params: GtkWindow *window
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the title of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: "   "   
 */
static void test_purpose_27()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define TITLE "   " 
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "title", TITLE, NULL);
    
    title = gtk_window_get_title (GTK_WINDOW (widget));
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_title
 * Params: GtkWindow *window
 * Returns: G_CONST_RETURN gchar*
 * Assertion: Retrieves the title of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: NULL  
 */
static void test_purpose_28()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define TITLE NULL
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* title;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_object_set(GTK_OBJECT(widget), "title", TITLE, NULL);
    
    title = gtk_window_get_title (GTK_WINDOW (widget));
    if (!TITLE)
    {
        if (title)
        {
            TEST_FAIL ("title should be NULL but it is not", NULL);
        }
    } else if (strcmp (title, (gchar*) TITLE)) {
        TEST_FAIL ("title is '%s', should be '%s'", title, (gchar*) TITLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  TITLE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_wmclass
 * Params: GtkWindow *window, const gchar *wmclass_name, const gchar *wmclass_class
 * Returns: void
 * Assertion: It sets the X Window System "class" and "name" hints for a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "name", "class"
 * Expected: void  
 */
static void test_purpose_29()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define WMCLASS_NAME "name"
    #define WMCLASS_CLASS "class"
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_wmclass (GTK_WINDOW (widget), 
                            (gchar*) WMCLASS_NAME, (gchar*) WMCLASS_CLASS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WMCLASS_NAME
    #undef WMCLASS_CLASS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_wmclass
 * Params: GtkWindow *window, const gchar *wmclass_name, const gchar *wmclass_class
 * Returns: void
 * Assertion: It sets the X Window System "class" and "name" hints for a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, "name", "class"
 * Expected: void  
 */
static void test_purpose_30()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define WMCLASS_NAME "name"
    #define WMCLASS_CLASS "class"
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_wmclass (GTK_WINDOW (widget), 
                            (gchar*) WMCLASS_NAME, (gchar*) WMCLASS_CLASS);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WMCLASS_NAME
    #undef WMCLASS_CLASS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_modal
 * Params: GtkWindow *window, gboolean modal
 * Returns: void
 * Assertion: Sets a window modal or non-modal.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, TRUE
 * Expected: void
 * 
 * Name:  gtk_window_get_modal
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Returns whether the window is modal.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: TRUE  
 */
static void test_purpose_31()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define MODAL TRUE
    
    GtkWidget* widget;
    gboolean modal;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_modal (GTK_WINDOW (widget), MODAL);
    
    g_object_get (GTK_OBJECT (widget), "modal", &modal, NULL);
    if (modal != MODAL)
    {
        TEST_FAIL ("modal is %d, should be %d", modal, MODAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  MODAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_modal
 * Params: GtkWindow *window, gboolean modal
 * Returns: void
 * Assertion: Sets a window modal or non-modal.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, FALSE
 * Expected: void
 * 
 * Name:  gtk_window_get_modal
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Returns whether the window is modal.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: FALSE  
 */
static void test_purpose_32()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define MODAL FALSE
    
    GtkWidget* widget;
    gboolean modal;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_modal (GTK_WINDOW (widget), MODAL);
    
    g_object_get (GTK_OBJECT (widget), "modal", &modal, NULL);
    if (modal != MODAL)
    {
        TEST_FAIL ("modal is %d, should be %d", modal, MODAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  MODAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_modal
 * Params: GtkWindow *window, gboolean modal
 * Returns: void
 * Assertion: Sets a window modal or non-modal.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, TRUE
 * Expected: void
 * 
 * Name:  gtk_window_get_modal
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Returns whether the window is modal.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: TRUE  
 */
static void test_purpose_33()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define MODAL TRUE
    
    GtkWidget* widget;
    gboolean modal;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_modal (GTK_WINDOW (widget), MODAL);
    
    g_object_get (GTK_OBJECT (widget), "modal", &modal, NULL);
    if (modal != MODAL)
    {
        TEST_FAIL ("modal is %d, should be %d", modal, MODAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  MODAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_modal
 * Params: GtkWindow *window, gboolean modal
 * Returns: void
 * Assertion: Sets a window modal or non-modal.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, FALSE
 * Expected: void
 * 
 * Name:  gtk_window_get_modal
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Returns whether the window is modal.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: FALSE  
 */
static void test_purpose_34()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define MODAL FALSE
    
    GtkWidget* widget;
    gboolean modal;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_modal (GTK_WINDOW (widget), MODAL);
    
    g_object_get (GTK_OBJECT (widget), "modal", &modal, NULL);
    if (modal != MODAL)
    {
        TEST_FAIL ("modal is %d, should be %d", modal, MODAL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  MODAL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_set_default_size
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Sets the default size of a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 0
 * Expected: void
 * 
 * Name: gtk_window_set_default_size
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: The default size of a window only affects the first time a window is shown; if a window is hidden and re-shown, it will remember the size it had prior to hiding, rather than using the default size
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 0
 * Expected: void  
 */
static void test_purpose_35()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define WIDTH 0
    #define HEIGHT 0
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_default_size (GTK_WINDOW (widget), WIDTH, HEIGHT);
    
    g_object_get (GTK_OBJECT (widget), "default_width", &width, NULL);
    if (WIDTH == 0)
    {
        if (width != 1)
        {
            TEST_FAIL ("default width is %d, should be %d", width, 1);
        }
    } else if (width != WIDTH) {
        {
            TEST_FAIL ("default width is %d, should be %d", width, WIDTH);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "default_height", &height, NULL);
    if (HEIGHT == 0)
    {
        if (height != 1)
        {        
            TEST_FAIL ("default height is %d, should be %d", height, 1);
        }
    } else if (height != HEIGHT) {
        TEST_FAIL ("default height is %d, should be %d", height, HEIGHT);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_set_default_size
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Sets the default size of a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 56
 * Expected: void
 * 
 * Name: gtk_window_set_default_size
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: The default size of a window only affects the first time a window is shown; if a window is hidden and re-shown, it will remember the size it had prior to hiding, rather than using the default size
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 56
 * Expected: void  
 */
static void test_purpose_36()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define WIDTH 0
    #define HEIGHT 56
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_default_size (GTK_WINDOW (widget), WIDTH, HEIGHT);
    
    g_object_get (GTK_OBJECT (widget), "default_width", &width, NULL);
    if (WIDTH == 0)
    {
        if (width != 1)
        {
            TEST_FAIL ("default width is %d, should be %d", width, 1);
        }
    } else if (width != WIDTH) {
        {
            TEST_FAIL ("default width is %d, should be %d", width, WIDTH);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "default_height", &height, NULL);
    if (HEIGHT == 0)
    {
        if (height != 1)
        {        
            TEST_FAIL ("default height is %d, should be %d", height, 1);
        }
    } else if (height != HEIGHT) {
        TEST_FAIL ("default height is %d, should be %d", height, HEIGHT);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_set_default_size
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Sets the default size of a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 1, 1
 * Expected: void
 * 
 * Name: gtk_window_set_default_size
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: The default size of a window only affects the first time a window is shown; if a window is hidden and re-shown, it will remember the size it had prior to hiding, rather than using the default size
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 1, 1
 * Expected: void  
 */
static void test_purpose_37()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define WIDTH 1
    #define HEIGHT 1
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_default_size (GTK_WINDOW (widget), WIDTH, HEIGHT);
    
    g_object_get (GTK_OBJECT (widget), "default_width", &width, NULL);
    if (WIDTH == 0)
    {
        if (width != 1)
        {
            TEST_FAIL ("default width is %d, should be %d", width, 1);
        }
    } else if (width != WIDTH) {
        {
            TEST_FAIL ("default width is %d, should be %d", width, WIDTH);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "default_height", &height, NULL);
    if (HEIGHT == 0)
    {
        if (height != 1)
        {        
            TEST_FAIL ("default height is %d, should be %d", height, 1);
        }
    } else if (height != HEIGHT) {
        TEST_FAIL ("default height is %d, should be %d", height, HEIGHT);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_set_default_size
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Sets the default size of a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 100000, 100000
 * Expected: void
 * 
 * Name: gtk_window_set_default_size
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: The default size of a window only affects the first time a window is shown; if a window is hidden and re-shown, it will remember the size it had prior to hiding, rather than using the default size
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 100000, 100000
 * Expected: void  
 */
static void test_purpose_38()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define WIDTH 100000
    #define HEIGHT 100000
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_default_size (GTK_WINDOW (widget), WIDTH, HEIGHT);
    
    g_object_get (GTK_OBJECT (widget), "default_width", &width, NULL);
    if (WIDTH == 0)
    {
        if (width != 1)
        {
            TEST_FAIL ("default width is %d, should be %d", width, 1);
        }
    } else if (width != WIDTH) {
        {
            TEST_FAIL ("default width is %d, should be %d", width, WIDTH);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "default_height", &height, NULL);
    if (HEIGHT == 0)
    {
        if (height != 1)
        {        
            TEST_FAIL ("default height is %d, should be %d", height, 1);
        }
    } else if (height != HEIGHT) {
        TEST_FAIL ("default height is %d, should be %d", height, HEIGHT);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_set_default_size
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Sets the default size of a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, G_MAXINT, G_MAXINT
 * Expected: void
 * 
 * Name: gtk_window_set_default_size
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: The default size of a window only affects the first time a window is shown; if a window is hidden and re-shown, it will remember the size it had prior to hiding, rather than using the default size
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, G_MAXINT, G_MAXINT
 * Expected: void  
 */
static void test_purpose_39()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define WIDTH G_MAXINT
    #define HEIGHT G_MAXINT
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_default_size (GTK_WINDOW (widget), WIDTH, HEIGHT);
    
    g_object_get (GTK_OBJECT (widget), "default_width", &width, NULL);
    if (WIDTH == 0)
    {
        if (width != 1)
        {
            TEST_FAIL ("default width is %d, should be %d", width, 1);
        }
    } else if (width != WIDTH) {
        {
            TEST_FAIL ("default width is %d, should be %d", width, WIDTH);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "default_height", &height, NULL);
    if (HEIGHT == 0)
    {
        if (height != 1)
        {        
            TEST_FAIL ("default height is %d, should be %d", height, 1);
        }
    } else if (height != HEIGHT) {
        TEST_FAIL ("default height is %d, should be %d", height, HEIGHT);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_set_default_size
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Sets the default size of a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, 0, 0
 * Expected: void
 * 
 * Name: gtk_window_set_default_size
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: The default size of a window only affects the first time a window is shown; if a window is hidden and re-shown, it will remember the size it had prior to hiding, rather than using the default size
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, 0, 0
 * Expected: void  
 */
static void test_purpose_40()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define WIDTH 0
    #define HEIGHT 0
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_default_size (GTK_WINDOW (widget), WIDTH, HEIGHT);
    
    g_object_get (GTK_OBJECT (widget), "default_width", &width, NULL);
    if (WIDTH == 0)
    {
        if (width != 1)
        {
            TEST_FAIL ("default width is %d, should be %d", width, 1);
        }
    } else if (width != WIDTH) {
        {
            TEST_FAIL ("default width is %d, should be %d", width, WIDTH);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "default_height", &height, NULL);
    if (HEIGHT == 0)
    {
        if (height != 1)
        {        
            TEST_FAIL ("default height is %d, should be %d", height, 1);
        }
    } else if (height != HEIGHT) {
        TEST_FAIL ("default height is %d, should be %d", height, HEIGHT);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_set_default_size
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Sets the default size of a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, 0, 49
 * Expected: void
 * 
 * Name: gtk_window_set_default_size
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: The default size of a window only affects the first time a window is shown; if a window is hidden and re-shown, it will remember the size it had prior to hiding, rather than using the default size
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, 0, 49
 * Expected: void  
 */
static void test_purpose_41()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define WIDTH 0
    #define HEIGHT 49
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_default_size (GTK_WINDOW (widget), WIDTH, HEIGHT);
    
    g_object_get (GTK_OBJECT (widget), "default_width", &width, NULL);
    if (WIDTH == 0)
    {
        if (width != 1)
        {
            TEST_FAIL ("default width is %d, should be %d", width, 1);
        }
    } else if (width != WIDTH) {
        {
            TEST_FAIL ("default width is %d, should be %d", width, WIDTH);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "default_height", &height, NULL);
    if (HEIGHT == 0)
    {
        if (height != 1)
        {        
            TEST_FAIL ("default height is %d, should be %d", height, 1);
        }
    } else if (height != HEIGHT) {
        TEST_FAIL ("default height is %d, should be %d", height, HEIGHT);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_set_default_size
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Sets the default size of a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, -1, -1
 * Expected: void
 * 
 * Name: gtk_window_set_default_size
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: The default size of a window only affects the first time a window is shown; if a window is hidden and re-shown, it will remember the size it had prior to hiding, rather than using the default size
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, -1, -1
 * Expected: void  
 */
static void test_purpose_42()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define WIDTH -1
    #define HEIGHT -1
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_default_size (GTK_WINDOW (widget), WIDTH, HEIGHT);
    
    g_object_get (GTK_OBJECT (widget), "default_width", &width, NULL);
    if (WIDTH == 0)
    {
        if (width != 1)
        {
            TEST_FAIL ("default width is %d, should be %d", width, 1);
        }
    } else if (width != WIDTH) {
        {
            TEST_FAIL ("default width is %d, should be %d", width, WIDTH);
        }
    }
    
    g_object_get (GTK_OBJECT (widget), "default_height", &height, NULL);
    if (HEIGHT == 0)
    {
        if (height != 1)
        {        
            TEST_FAIL ("default height is %d, should be %d", height, 1);
        }
    } else if (height != HEIGHT) {
        TEST_FAIL ("default height is %d, should be %d", height, HEIGHT);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_default_size
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Windows can't actually be 0x0 in size, they must be at least 1x1, but passing 0 for width and height is OK, resulting in a 1x1 default size.'
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 0
 * Expected: void  
 */
static void test_purpose_43()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_default_size (GTK_WINDOW (widget), 0, 0);
    g_object_get (GTK_OBJECT (widget), "default_width", &width, NULL);
    if (width != 1)
    {
        TEST_FAIL ("default width is %d, should be %d", width, 1);
    }
    
    g_object_get (GTK_OBJECT (widget), "default_height", &height, NULL);
    if (height != 1)
    {        
        TEST_FAIL ("default height is %d, should be %d", height, 1);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_default_size
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Windows can't actually be 0x0 in size, they must be at least 1x1, but passing 0 for width and height is OK, resulting in a 1x1 default size.'
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, 0, 0
 * Expected: void  
 */
static void test_purpose_44()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_default_size (GTK_WINDOW (widget), 0, 0);
    g_object_get (GTK_OBJECT (widget), "default_width", &width, NULL);
    if (width != 1)
    {
        TEST_FAIL ("default width is %d, should be %d", width, 1);
    }
    
    g_object_get (GTK_OBJECT (widget), "default_height", &height, NULL);
    if (height != 1)
    {        
        TEST_FAIL ("default height is %d, should be %d", height, 1);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_default_size
 * Params: GtkWindow *window, gint *width, gint *height
 * Returns: void
 * Assertion: Gets the default size of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, gint*, gint*
 * Expected: void  
 */
static void test_purpose_45()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define WIDTH 1
    #define HEIGHT 1
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    g_object_set(GTK_OBJECT (widget), "default_width", WIDTH, NULL);
    g_object_set(GTK_OBJECT (widget), "default_height", HEIGHT, NULL);
    gtk_window_get_default_size (GTK_WINDOW (widget), &width, &height);
    
    if (width != WIDTH) {
        TEST_FAIL ("default width is %d, should be %d", width, WIDTH);
    }
    
    if (height != HEIGHT) {
        TEST_FAIL ("default height is %d, should be %d", height, HEIGHT);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_default_size
 * Params: GtkWindow *window, gint *width, gint *height
 * Returns: void
 * Assertion: Gets the default size of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, gint*, gint*
 * Expected: void  
 */
static void test_purpose_46()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define WIDTH 100000
    #define HEIGHT 100000
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    g_object_set(GTK_OBJECT (widget), "default_width", WIDTH, NULL);
    g_object_set(GTK_OBJECT (widget), "default_height", HEIGHT, NULL);
    gtk_window_get_default_size (GTK_WINDOW (widget), &width, &height);
    
    if (width != WIDTH) {
        TEST_FAIL ("default width is %d, should be %d", width, WIDTH);
    }
    
    if (height != HEIGHT) {
        TEST_FAIL ("default height is %d, should be %d", height, HEIGHT);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_default_size
 * Params: GtkWindow *window, gint *width, gint *height
 * Returns: void
 * Assertion: Gets the default size of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, gint*, gint*
 * Expected: void  
 */
static void test_purpose_47()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define WIDTH G_MAXINT
    #define HEIGHT G_MAXINT
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    g_object_set(GTK_OBJECT (widget), "default_width", WIDTH, NULL);
    g_object_set(GTK_OBJECT (widget), "default_height", HEIGHT, NULL);
    gtk_window_get_default_size (GTK_WINDOW (widget), &width, &height);
    
    if (width != WIDTH) {
        TEST_FAIL ("default width is %d, should be %d", width, WIDTH);
    }
    
    if (height != HEIGHT) {
        TEST_FAIL ("default height is %d, should be %d", height, HEIGHT);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_default_size
 * Params: GtkWindow *window, gint *width, gint *height
 * Returns: void
 * Assertion: Gets the default size of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, gint*, gint*
 * Expected: void  
 */
static void test_purpose_48()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define WIDTH -1
    #define HEIGHT -1
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    g_object_set(GTK_OBJECT (widget), "default_width", WIDTH, NULL);
    g_object_set(GTK_OBJECT (widget), "default_height", HEIGHT, NULL);
    gtk_window_get_default_size (GTK_WINDOW (widget), &width, &height);
    
    if (width != WIDTH) {
        TEST_FAIL ("default width is %d, should be %d", width, WIDTH);
    }
    
    if (height != HEIGHT) {
        TEST_FAIL ("default height is %d, should be %d", height, HEIGHT);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_geometry_hints
 * Params: GtkWindow *window, GtkWidget *geometry_widget, 
 *     GdkGeometry *geometry, GdkWindowHints geom_mask
 * Returns: void
 * Assertion: This function sets up hints about how a window can be resized by the user.
 * Params Values: a newly created GtkWindow, a newly created GtkButton, GdkGeometry*, GdkWindowHints*
 * Expected: void  
 */
static void test_purpose_49()
{
    GtkWidget* widget;
    GtkWidget* widget2;
    GdkGeometry geometry;
    GdkWindowHints geometry_mask;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(GTK_WINDOW_POPUP);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    widget2 = gtk_button_new ();
    geometry_mask = GDK_HINT_MIN_SIZE |  GDK_HINT_BASE_SIZE |  GDK_HINT_RESIZE_INC;
    
    geometry.min_width = 20;
    geometry.min_height = 20;
    geometry.base_width = 30;
    geometry.base_height = 30;
    geometry.width_inc = 10;
    geometry.height_inc = 10;
    
    gtk_window_set_geometry_hints (GTK_WINDOW (widget), NULL, 
                                   &geometry, geometry_mask);
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (widget2);
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_gravity
 * Params: GtkWindow *window, GdkGravity gravity
 * Returns: void
 * Assertion: Window gravity defines the meaning of coordinates passed to gtk_window_move().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_GRAVITY_NORTH_WEST
 * Expected: void
 * 
 * Name:  gtk_window_get_gravity
 * Params: GtkWindow *window
 * Returns: GdkGravity gravity
 * Assertion: Gets the value set by gtk_window_set_gravity().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_GRAVITY_NORTH_WEST  
 */
static void test_purpose_50()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define GRAVITY GDK_GRAVITY_NORTH_WEST
    
    GtkWidget* widget;
    GdkGravity gravity;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_gravity (GTK_WINDOW (widget), GRAVITY);
    gravity = gtk_window_get_gravity (GTK_WINDOW (widget));
    if (gravity != GRAVITY)
    {
        TEST_FAIL ("gravity = %d, should be %d", gravity, GRAVITY);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_gravity
 * Params: GtkWindow *window, GdkGravity gravity
 * Returns: void
 * Assertion: Window gravity defines the meaning of coordinates passed to gtk_window_move().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_GRAVITY_NORTH
 * Expected: void
 * 
 * Name:  gtk_window_get_gravity
 * Params: GtkWindow *window
 * Returns: GdkGravity gravity
 * Assertion: Gets the value set by gtk_window_set_gravity().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_GRAVITY_NORTH  
 */
static void test_purpose_51()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define GRAVITY GDK_GRAVITY_NORTH
    
    GtkWidget* widget;
    GdkGravity gravity;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_gravity (GTK_WINDOW (widget), GRAVITY);
    gravity = gtk_window_get_gravity (GTK_WINDOW (widget));
    if (gravity != GRAVITY)
    {
        TEST_FAIL ("gravity = %d, should be %d", gravity, GRAVITY);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_gravity
 * Params: GtkWindow *window, GdkGravity gravity
 * Returns: void
 * Assertion: Window gravity defines the meaning of coordinates passed to gtk_window_move().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_GRAVITY_NORTH_EAST
 * Expected: void
 * 
 * Name:  gtk_window_get_gravity
 * Params: GtkWindow *window
 * Returns: GdkGravity gravity
 * Assertion: Gets the value set by gtk_window_set_gravity().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_GRAVITY_NORTH_EAST  
 */
static void test_purpose_52()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define GRAVITY GDK_GRAVITY_NORTH_EAST
    
    GtkWidget* widget;
    GdkGravity gravity;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_gravity (GTK_WINDOW (widget), GRAVITY);
    gravity = gtk_window_get_gravity (GTK_WINDOW (widget));
    if (gravity != GRAVITY)
    {
        TEST_FAIL ("gravity = %d, should be %d", gravity, GRAVITY);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_gravity
 * Params: GtkWindow *window, GdkGravity gravity
 * Returns: void
 * Assertion: Window gravity defines the meaning of coordinates passed to gtk_window_move().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_GRAVITY_WEST
 * Expected: void
 * 
 * Name:  gtk_window_get_gravity
 * Params: GtkWindow *window
 * Returns: GdkGravity gravity
 * Assertion: Gets the value set by gtk_window_set_gravity().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_GRAVITY_WEST  
 */
static void test_purpose_53()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define GRAVITY GDK_GRAVITY_WEST
    
    GtkWidget* widget;
    GdkGravity gravity;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_gravity (GTK_WINDOW (widget), GRAVITY);
    gravity = gtk_window_get_gravity (GTK_WINDOW (widget));
    if (gravity != GRAVITY)
    {
        TEST_FAIL ("gravity = %d, should be %d", gravity, GRAVITY);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_gravity
 * Params: GtkWindow *window, GdkGravity gravity
 * Returns: void
 * Assertion: Window gravity defines the meaning of coordinates passed to gtk_window_move().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_GRAVITY_CENTER
 * Expected: void
 * 
 * Name:  gtk_window_get_gravity
 * Params: GtkWindow *window
 * Returns: GdkGravity gravity
 * Assertion: Gets the value set by gtk_window_set_gravity().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_GRAVITY_CENTER  
 */
static void test_purpose_54()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define GRAVITY GDK_GRAVITY_CENTER
    
    GtkWidget* widget;
    GdkGravity gravity;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_gravity (GTK_WINDOW (widget), GRAVITY);
    gravity = gtk_window_get_gravity (GTK_WINDOW (widget));
    if (gravity != GRAVITY)
    {
        TEST_FAIL ("gravity = %d, should be %d", gravity, GRAVITY);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_gravity
 * Params: GtkWindow *window, GdkGravity gravity
 * Returns: void
 * Assertion: Window gravity defines the meaning of coordinates passed to gtk_window_move().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_GRAVITY_EAST
 * Expected: void
 * 
 * Name:  gtk_window_get_gravity
 * Params: GtkWindow *window
 * Returns: GdkGravity gravity
 * Assertion: Gets the value set by gtk_window_set_gravity().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_GRAVITY_EAST  
 */
static void test_purpose_55()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define GRAVITY GDK_GRAVITY_EAST
    
    GtkWidget* widget;
    GdkGravity gravity;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_gravity (GTK_WINDOW (widget), GRAVITY);
    gravity = gtk_window_get_gravity (GTK_WINDOW (widget));
    if (gravity != GRAVITY)
    {
        TEST_FAIL ("gravity = %d, should be %d", gravity, GRAVITY);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_gravity
 * Params: GtkWindow *window, GdkGravity gravity
 * Returns: void
 * Assertion: Window gravity defines the meaning of coordinates passed to gtk_window_move().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_GRAVITY_SOUTH_WEST
 * Expected: void
 * 
 * Name:  gtk_window_get_gravity
 * Params: GtkWindow *window
 * Returns: GdkGravity gravity
 * Assertion: Gets the value set by gtk_window_set_gravity().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_GRAVITY_SOUTH_WEST  
 */
static void test_purpose_56()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define GRAVITY GDK_GRAVITY_SOUTH_WEST
    
    GtkWidget* widget;
    GdkGravity gravity;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_gravity (GTK_WINDOW (widget), GRAVITY);
    gravity = gtk_window_get_gravity (GTK_WINDOW (widget));
    if (gravity != GRAVITY)
    {
        TEST_FAIL ("gravity = %d, should be %d", gravity, GRAVITY);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_gravity
 * Params: GtkWindow *window, GdkGravity gravity
 * Returns: void
 * Assertion: Window gravity defines the meaning of coordinates passed to gtk_window_move().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_GRAVITY_SOUTH
 * Expected: void
 * 
 * Name:  gtk_window_get_gravity
 * Params: GtkWindow *window
 * Returns: GdkGravity gravity
 * Assertion: Gets the value set by gtk_window_set_gravity().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_GRAVITY_SOUTH  
 */
static void test_purpose_57()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define GRAVITY GDK_GRAVITY_SOUTH
    
    GtkWidget* widget;
    GdkGravity gravity;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_gravity (GTK_WINDOW (widget), GRAVITY);
    gravity = gtk_window_get_gravity (GTK_WINDOW (widget));
    if (gravity != GRAVITY)
    {
        TEST_FAIL ("gravity = %d, should be %d", gravity, GRAVITY);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_gravity
 * Params: GtkWindow *window, GdkGravity gravity
 * Returns: void
 * Assertion: Window gravity defines the meaning of coordinates passed to gtk_window_move().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_GRAVITY_SOUTH_EAST
 * Expected: void
 * 
 * Name:  gtk_window_get_gravity
 * Params: GtkWindow *window
 * Returns: GdkGravity gravity
 * Assertion: Gets the value set by gtk_window_set_gravity().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_GRAVITY_SOUTH_EAST  
 */
static void test_purpose_58()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define GRAVITY GDK_GRAVITY_SOUTH_EAST
    
    GtkWidget* widget;
    GdkGravity gravity;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_gravity (GTK_WINDOW (widget), GRAVITY);
    gravity = gtk_window_get_gravity (GTK_WINDOW (widget));
    if (gravity != GRAVITY)
    {
        TEST_FAIL ("gravity = %d, should be %d", gravity, GRAVITY);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_gravity
 * Params: GtkWindow *window, GdkGravity gravity
 * Returns: void
 * Assertion: Window gravity defines the meaning of coordinates passed to gtk_window_move().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_GRAVITY_STATIC
 * Expected: void
 * 
 * Name:  gtk_window_get_gravity
 * Params: GtkWindow *window
 * Returns: GdkGravity gravity
 * Assertion: Gets the value set by gtk_window_set_gravity().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_GRAVITY_STATIC  
 */
static void test_purpose_59()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define GRAVITY GDK_GRAVITY_STATIC
    
    GtkWidget* widget;
    GdkGravity gravity;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_gravity (GTK_WINDOW (widget), GRAVITY);
    gravity = gtk_window_get_gravity (GTK_WINDOW (widget));
    if (gravity != GRAVITY)
    {
        TEST_FAIL ("gravity = %d, should be %d", gravity, GRAVITY);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_gravity
 * Params: GtkWindow *window, GdkGravity gravity
 * Returns: void
 * Assertion: Window gravity defines the meaning of coordinates passed to gtk_window_move().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, GDK_GRAVITY_STATIC
 * Expected: void
 * 
 * Name:  gtk_window_get_gravity
 * Params: GtkWindow *window
 * Returns: GdkGravity gravity
 * Assertion: Gets the value set by gtk_window_set_gravity().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: GDK_GRAVITY_STATIC  
 */
static void test_purpose_60()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define GRAVITY GDK_GRAVITY_STATIC
    
    GtkWidget* widget;
    GdkGravity gravity;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_gravity (GTK_WINDOW (widget), GRAVITY);
    gravity = gtk_window_get_gravity (GTK_WINDOW (widget));
    if (gravity != GRAVITY)
    {
        TEST_FAIL ("gravity = %d, should be %d", gravity, GRAVITY);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  GRAVITY
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_gravity
 * Params: GtkWindow *window, GdkGravity gravity
 * Returns: void
 * Assertion: The default window gravity is GDK_GRAVITY_NORTH_WEST which will typically "do what you mean."
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, <%1%>
 * Expected: void  
 */
static void test_purpose_61()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    
    GtkWidget* widget;
    GdkGravity gravity;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gravity = gtk_window_get_gravity (GTK_WINDOW (widget));
    if (gravity != GDK_GRAVITY_NORTH_WEST)
    {
        TEST_FAIL ("gravity = %d, default value is %d", 
                   gravity, GDK_GRAVITY_NORTH_WEST);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_list_toplevels
 * Params: GtkWindow *window, GtkAccelGroup *accel_group
 * Returns: GList*
 * Assertion: Returns a list of all existing toplevel windows.
 * Params Values: void
 * Expected: list of all toplevel windows  
 */
static void test_purpose_62()
{
    #define WINDOWS_TYPES_STR  "tttttttttttttttttt"
    #define WINDOWS_NUM strlen ("tttttttttttttttttt")
    
    GtkWidget* widget[WINDOWS_NUM];
    gint toplevel_count;
    gint i;
    GList* toplevel_list;
    gint toplevel_list_length;
    gchar* win_types = WINDOWS_TYPES_STR;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    toplevel_count = 0;
    
    for (i = 0; i < strlen (win_types); i++)
    {
        if (win_types[i] == 't')
        {
            widget[i] = gtk_window_new (GTK_WINDOW_TOPLEVEL);
            if (!widget[i])
            {
                TEST_FAIL (get_not_created_msg (), NULL); 
                return;
            } 
            
            if (!GTK_IS_WINDOW (widget[i]))
            {
                TEST_FAIL (get_wrong_type_msg (), NULL); 
                return;
            }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget[i]);
    /******* -------------  *******/  
        } else if (win_types[i] == 'p') {
            widget[i] = gtk_window_new (GTK_WINDOW_POPUP);
            if (!widget[i])
            {
                TEST_FAIL (get_not_created_msg (), NULL); 
                return;
            } 
            
            if (!GTK_IS_WINDOW (widget[i]))
            {
                TEST_FAIL (get_wrong_type_msg (), NULL); 
                return;
            }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget[i]);
    /******* -------------  *******/  
    
    
        } else {
            TEST_FAIL ("unexpected char %c in windows types string", win_types[i]);
        }
        toplevel_count++;
    }        
    
    toplevel_list = gtk_window_list_toplevels ();
    toplevel_list_length = g_list_length (toplevel_list);
    if (toplevel_list_length != toplevel_count)
    {
        TEST_FAIL ("toplevel_list_length = %d, toplevel_count = %d", 
                   toplevel_list_length, toplevel_count);
    }
    
    for (i = 0; i < toplevel_list_length; i++)
    {
        gpointer ptr = g_list_nth_data (toplevel_list, i);
        if (!GTK_IS_WINDOW (ptr))
        {
            TEST_FAIL ("element #%d in the toplevel list is not of GtkWindow type", 
                       i);
        } 
    }        
    
    for (i = 0; i < WINDOWS_NUM; i++)
    {
        gtk_widget_destroy (widget[i]);
    }
    
    #undef WINDOWS_TYPES_STR 
    #undef WINDOWS_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_list_toplevels
 * Params: GtkWindow *window, GtkAccelGroup *accel_group
 * Returns: GList*
 * Assertion: Returns a list of all existing toplevel windows.
 * Params Values: void
 * Expected: list of all toplevel windows  
 */
static void test_purpose_63()
{
    #define WINDOWS_TYPES_STR  "ppppppppppppppp"
    #define WINDOWS_NUM strlen ("ppppppppppppppp")
    
    GtkWidget* widget[WINDOWS_NUM];
    gint toplevel_count;
    gint i;
    GList* toplevel_list;
    gint toplevel_list_length;
    gchar* win_types = WINDOWS_TYPES_STR;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    toplevel_count = 0;
    
    for (i = 0; i < strlen (win_types); i++)
    {
        if (win_types[i] == 't')
        {
            widget[i] = gtk_window_new (GTK_WINDOW_TOPLEVEL);
            if (!widget[i])
            {
                TEST_FAIL (get_not_created_msg (), NULL); 
                return;
            } 
            
            if (!GTK_IS_WINDOW (widget[i]))
            {
                TEST_FAIL (get_wrong_type_msg (), NULL); 
                return;
            }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget[i]);
    /******* -------------  *******/  
        } else if (win_types[i] == 'p') {
            widget[i] = gtk_window_new (GTK_WINDOW_POPUP);
            if (!widget[i])
            {
                TEST_FAIL (get_not_created_msg (), NULL); 
                return;
            } 
            
            if (!GTK_IS_WINDOW (widget[i]))
            {
                TEST_FAIL (get_wrong_type_msg (), NULL); 
                return;
            }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget[i]);
    /******* -------------  *******/  
    
    
        } else {
            TEST_FAIL ("unexpected char %c in windows types string", win_types[i]);
        }
        toplevel_count++;
    }        
    
    toplevel_list = gtk_window_list_toplevels ();
    toplevel_list_length = g_list_length (toplevel_list);
    if (toplevel_list_length != toplevel_count)
    {
        TEST_FAIL ("toplevel_list_length = %d, toplevel_count = %d", 
                   toplevel_list_length, toplevel_count);
    }
    
    for (i = 0; i < toplevel_list_length; i++)
    {
        gpointer ptr = g_list_nth_data (toplevel_list, i);
        if (!GTK_IS_WINDOW (ptr))
        {
            TEST_FAIL ("element #%d in the toplevel list is not of GtkWindow type", 
                       i);
        } 
    }        
    
    for (i = 0; i < WINDOWS_NUM; i++)
    {
        gtk_widget_destroy (widget[i]);
    }
    
    #undef WINDOWS_TYPES_STR 
    #undef WINDOWS_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_list_toplevels
 * Params: GtkWindow *window, GtkAccelGroup *accel_group
 * Returns: GList*
 * Assertion: Returns a list of all existing toplevel windows.
 * Params Values: void
 * Expected: list of all toplevel windows  
 */
static void test_purpose_64()
{
    #define WINDOWS_TYPES_STR  "tpptpptpptpptttpptttppttpptttp"
    #define WINDOWS_NUM strlen ("tpptpptpptpptttpptttppttpptttp")
    
    GtkWidget* widget[WINDOWS_NUM];
    gint toplevel_count;
    gint i;
    GList* toplevel_list;
    gint toplevel_list_length;
    gchar* win_types = WINDOWS_TYPES_STR;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    toplevel_count = 0;
    
    for (i = 0; i < strlen (win_types); i++)
    {
        if (win_types[i] == 't')
        {
            widget[i] = gtk_window_new (GTK_WINDOW_TOPLEVEL);
            if (!widget[i])
            {
                TEST_FAIL (get_not_created_msg (), NULL); 
                return;
            } 
            
            if (!GTK_IS_WINDOW (widget[i]))
            {
                TEST_FAIL (get_wrong_type_msg (), NULL); 
                return;
            }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget[i]);
    /******* -------------  *******/  
        } else if (win_types[i] == 'p') {
            widget[i] = gtk_window_new (GTK_WINDOW_POPUP);
            if (!widget[i])
            {
                TEST_FAIL (get_not_created_msg (), NULL); 
                return;
            } 
            
            if (!GTK_IS_WINDOW (widget[i]))
            {
                TEST_FAIL (get_wrong_type_msg (), NULL); 
                return;
            }
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget[i]);
    /******* -------------  *******/  
    
    
        } else {
            TEST_FAIL ("unexpected char %c in windows types string", win_types[i]);
        }
        toplevel_count++;
    }        
    
    toplevel_list = gtk_window_list_toplevels ();
    toplevel_list_length = g_list_length (toplevel_list);
    if (toplevel_list_length != toplevel_count)
    {
        TEST_FAIL ("toplevel_list_length = %d, toplevel_count = %d", 
                   toplevel_list_length, toplevel_count);
    }
    
    for (i = 0; i < toplevel_list_length; i++)
    {
        gpointer ptr = g_list_nth_data (toplevel_list, i);
        if (!GTK_IS_WINDOW (ptr))
        {
            TEST_FAIL ("element #%d in the toplevel list is not of GtkWindow type", 
                       i);
        } 
    }        
    
    for (i = 0; i < WINDOWS_NUM; i++)
    {
        gtk_widget_destroy (widget[i]);
    }
    
    #undef WINDOWS_TYPES_STR 
    #undef WINDOWS_NUM
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_position
 * Params: GtkWindow *window, GtkWindowPosition position
 * Returns: void
 * Assertion: Sets a position constraint for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GTK_WIN_POS_NONE
 * Expected: void  
 */
static void test_purpose_65()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define POSITION GTK_WIN_POS_NONE
    
    GtkWidget* widget;
    GtkWindowPosition position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_position (GTK_WINDOW (widget), POSITION);
    g_object_get (GTK_OBJECT(widget), "window_position", &position, NULL);
    if (position != POSITION) 
    {
        TEST_FAIL ("position = %d, should be %d", position, POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_position
 * Params: GtkWindow *window, GtkWindowPosition position
 * Returns: void
 * Assertion: Sets a position constraint for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GTK_WIN_POS_CENTER
 * Expected: void  
 */
static void test_purpose_66()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define POSITION GTK_WIN_POS_CENTER
    
    GtkWidget* widget;
    GtkWindowPosition position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_position (GTK_WINDOW (widget), POSITION);
    g_object_get (GTK_OBJECT(widget), "window_position", &position, NULL);
    if (position != POSITION) 
    {
        TEST_FAIL ("position = %d, should be %d", position, POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_position
 * Params: GtkWindow *window, GtkWindowPosition position
 * Returns: void
 * Assertion: Sets a position constraint for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GTK_WIN_POS_MOUSE
 * Expected: void  
 */
static void test_purpose_67()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define POSITION GTK_WIN_POS_MOUSE
    
    GtkWidget* widget;
    GtkWindowPosition position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_position (GTK_WINDOW (widget), POSITION);
    g_object_get (GTK_OBJECT(widget), "window_position", &position, NULL);
    if (position != POSITION) 
    {
        TEST_FAIL ("position = %d, should be %d", position, POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_position
 * Params: GtkWindow *window, GtkWindowPosition position
 * Returns: void
 * Assertion: Sets a position constraint for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GTK_WIN_POS_CENTER_ALWAYS
 * Expected: void  
 */
static void test_purpose_68()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define POSITION GTK_WIN_POS_CENTER_ALWAYS
    
    GtkWidget* widget;
    GtkWindowPosition position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_position (GTK_WINDOW (widget), POSITION);
    g_object_get (GTK_OBJECT(widget), "window_position", &position, NULL);
    if (position != POSITION) 
    {
        TEST_FAIL ("position = %d, should be %d", position, POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_position
 * Params: GtkWindow *window, GtkWindowPosition position
 * Returns: void
 * Assertion: Sets a position constraint for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GTK_WIN_POS_CENTER_ON_PARENT
 * Expected: void  
 */
static void test_purpose_69()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define POSITION GTK_WIN_POS_CENTER_ON_PARENT
    
    GtkWidget* widget;
    GtkWindowPosition position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_position (GTK_WINDOW (widget), POSITION);
    g_object_get (GTK_OBJECT(widget), "window_position", &position, NULL);
    if (position != POSITION) 
    {
        TEST_FAIL ("position = %d, should be %d", position, POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_position
 * Params: GtkWindow *window, GtkWindowPosition position
 * Returns: void
 * Assertion: Sets a position constraint for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, GTK_WIN_POS_NONE
 * Expected: void  
 */
static void test_purpose_70()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define POSITION GTK_WIN_POS_NONE
    
    GtkWidget* widget;
    GtkWindowPosition position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_position (GTK_WINDOW (widget), POSITION);
    g_object_get (GTK_OBJECT(widget), "window_position", &position, NULL);
    if (position != POSITION) 
    {
        TEST_FAIL ("position = %d, should be %d", position, POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_position
 * Params: GtkWindow *window, GtkWindowPosition position
 * Returns: void
 * Assertion: Sets a position constraint for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, GTK_WIN_POS_CENTER_ON_PARENT
 * Expected: void  
 */
static void test_purpose_71()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define POSITION GTK_WIN_POS_CENTER_ON_PARENT
    
    GtkWidget* widget;
    GtkWindowPosition position;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_position (GTK_WINDOW (widget), POSITION);
    g_object_get (GTK_OBJECT(widget), "window_position", &position, NULL);
    if (position != POSITION) 
    {
        TEST_FAIL ("position = %d, should be %d", position, POSITION);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef POSITION
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_transient_for
 * Params: GtkWindow *window, GtkWindow *parent
 * Returns: void
 * Assertion: Dialog windows should be set transient for the main application window they were spawned from.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void
 * 
 * Name:  gtk_window_get_transient_for
 * Params: GtkWindow *window
 * Returns: GtkWidget*
 * Assertion: Fetches the transient parent for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GtkWidget*  
 */
static void test_purpose_72()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    
    GtkWidget* widget;
    GtkWidget* parent;
    GtkWindow* trans;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    parent = gtk_window_new (GTK_WINDOW_POPUP);
    
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (parent))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    gtk_window_set_transient_for (GTK_WINDOW (widget), GTK_WINDOW (parent));
    
    trans = gtk_window_get_transient_for (GTK_WINDOW (widget));
    if (trans != GTK_WINDOW (parent))
    {
        TEST_FAIL ("transient window differ from the one was set", NULL);
    }
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (parent);
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_transient_for
 * Params: GtkWindow *window, GtkWindow *parent
 * Returns: void
 * Assertion: Dialog windows should be set transient for the main application window they were spawned from.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void
 * 
 * Name:  gtk_window_get_transient_for
 * Params: GtkWindow *window
 * Returns: GtkWidget*
 * Assertion: Fetches the transient parent for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: GtkWidget*  
 */
static void test_purpose_73()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    
    GtkWidget* widget;
    GtkWidget* parent;
    GtkWindow* trans;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    parent = gtk_window_new (GTK_WINDOW_POPUP);
    
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (parent))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    gtk_window_set_transient_for (GTK_WINDOW (widget), GTK_WINDOW (parent));
    
    trans = gtk_window_get_transient_for (GTK_WINDOW (widget));
    if (trans != GTK_WINDOW (parent))
    {
        TEST_FAIL ("transient window differ from the one was set", NULL);
    }
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (parent);
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_destroy_with_parent
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion: If setting is TRUE, then destroying the transient parent of window will also destroy window itself.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, TRUE
 * Expected: void
 * 
 * Name:  gtk_window_get_destroy_with_parent
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Returns whether the window will be destroyed with its transient parent.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: TRUE  
 */
static void test_purpose_74()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define SETTING TRUE
    
    GtkWidget* widget;
    GtkWidget* parent;
    gboolean destroy_with_parent;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent = NULL;
    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    parent = gtk_window_new(GTK_WINDOW_POPUP);
    
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    if (!GTK_IS_WINDOW (parent))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_window_set_transient_for (GTK_WINDOW (widget), GTK_WINDOW (parent));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_destroy_with_parent (GTK_WINDOW (widget), SETTING);
    g_object_get (GTK_OBJECT(widget), "destroy-with-parent", &destroy_with_parent, NULL);
    if (destroy_with_parent != SETTING) 
    {
        TEST_FAIL ("destroy_with_parent = %d, should be %d",  
                   destroy_with_parent, SETTING);
    }
    
    gtk_widget_destroy (parent);
    
    if (SETTING == FALSE)
    {
        gtk_widget_destroy (widget);
    }
    
    #undef WINDOW_TYPE 
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_destroy_with_parent
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion: If setting is TRUE, then destroying the transient parent of window will also destroy window itself.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, FALSE
 * Expected: void
 * 
 * Name:  gtk_window_get_destroy_with_parent
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Returns whether the window will be destroyed with its transient parent.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: FALSE  
 */
static void test_purpose_75()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define SETTING FALSE
    
    GtkWidget* widget;
    GtkWidget* parent;
    gboolean destroy_with_parent;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent = NULL;
    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    parent = gtk_window_new(GTK_WINDOW_POPUP);
    
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    if (!GTK_IS_WINDOW (parent))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_window_set_transient_for (GTK_WINDOW (widget), GTK_WINDOW (parent));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_destroy_with_parent (GTK_WINDOW (widget), SETTING);
    g_object_get (GTK_OBJECT(widget), "destroy-with-parent", &destroy_with_parent, NULL);
    if (destroy_with_parent != SETTING) 
    {
        TEST_FAIL ("destroy_with_parent = %d, should be %d",  
                   destroy_with_parent, SETTING);
    }
    
    gtk_widget_destroy (parent);
    
    if (SETTING == FALSE)
    {
        gtk_widget_destroy (widget);
    }
    
    #undef WINDOW_TYPE 
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_destroy_with_parent
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion: If setting is TRUE, then destroying the transient parent of window will also destroy window itself.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, TRUE
 * Expected: void
 * 
 * Name:  gtk_window_get_destroy_with_parent
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Returns whether the window will be destroyed with its transient parent.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: TRUE  
 */
static void test_purpose_76()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define SETTING TRUE
    
    GtkWidget* widget;
    GtkWidget* parent;
    gboolean destroy_with_parent;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent = NULL;
    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    parent = gtk_window_new(GTK_WINDOW_POPUP);
    
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    if (!GTK_IS_WINDOW (parent))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_window_set_transient_for (GTK_WINDOW (widget), GTK_WINDOW (parent));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_destroy_with_parent (GTK_WINDOW (widget), SETTING);
    g_object_get (GTK_OBJECT(widget), "destroy-with-parent", &destroy_with_parent, NULL);
    if (destroy_with_parent != SETTING) 
    {
        TEST_FAIL ("destroy_with_parent = %d, should be %d",  
                   destroy_with_parent, SETTING);
    }
    
    gtk_widget_destroy (parent);
    
    if (SETTING == FALSE)
    {
        gtk_widget_destroy (widget);
    }
    
    #undef WINDOW_TYPE 
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_destroy_with_parent
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion: If setting is TRUE, then destroying the transient parent of window will also destroy window itself.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, FALSE
 * Expected: void
 * 
 * Name:  gtk_window_get_destroy_with_parent
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Returns whether the window will be destroyed with its transient parent.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: FALSE  
 */
static void test_purpose_77()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define SETTING FALSE
    
    GtkWidget* widget;
    GtkWidget* parent;
    gboolean destroy_with_parent;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    parent = NULL;
    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    parent = gtk_window_new(GTK_WINDOW_POPUP);
    
    if (!parent)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    }
    if (!GTK_IS_WINDOW (parent))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_window_set_transient_for (GTK_WINDOW (widget), GTK_WINDOW (parent));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_destroy_with_parent (GTK_WINDOW (widget), SETTING);
    g_object_get (GTK_OBJECT(widget), "destroy-with-parent", &destroy_with_parent, NULL);
    if (destroy_with_parent != SETTING) 
    {
        TEST_FAIL ("destroy_with_parent = %d, should be %d",  
                   destroy_with_parent, SETTING);
    }
    
    gtk_widget_destroy (parent);
    
    if (SETTING == FALSE)
    {
        gtk_widget_destroy (widget);
    }
    
    #undef WINDOW_TYPE 
    #undef SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_decorated
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion: If you set the decorated property to FALSE using this function, GTK+ will do its best to convince the window manager not to decorate the window. 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, TRUE
 * Expected: void
 * 
 * Name:  gtk_window_get_decorated
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Returns whether the window has been set to have decorations such as a title bar via gtk_window_set_decorated().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: TRUE  
 */
static void test_purpose_78()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define SETTING TRUE
    
    GtkWidget* widget;
    gboolean decorated;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_decorated (GTK_WINDOW (widget), SETTING);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    decorated = gtk_window_get_decorated (GTK_WINDOW (widget));
    if (decorated != SETTING)
    {
        TEST_FAIL ("decorated is %d, should be %d", decorated, SETTING);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_decorated
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion: If you set the decorated property to FALSE using this function, GTK+ will do its best to convince the window manager not to decorate the window. 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, FALSE
 * Expected: void
 * 
 * Name:  gtk_window_get_decorated
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Returns whether the window has been set to have decorations such as a title bar via gtk_window_set_decorated().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: FALSE  
 */
static void test_purpose_79()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define SETTING FALSE
    
    GtkWidget* widget;
    gboolean decorated;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_decorated (GTK_WINDOW (widget), SETTING);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    decorated = gtk_window_get_decorated (GTK_WINDOW (widget));
    if (decorated != SETTING)
    {
        TEST_FAIL ("decorated is %d, should be %d", decorated, SETTING);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_decorated
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion: If you set the decorated property to FALSE using this function, GTK+ will do its best to convince the window manager not to decorate the window. 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, TRUE
 * Expected: void
 * 
 * Name:  gtk_window_get_decorated
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Returns whether the window has been set to have decorations such as a title bar via gtk_window_set_decorated().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: TRUE  
 */
static void test_purpose_80()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define SETTING TRUE
    
    GtkWidget* widget;
    gboolean decorated;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_decorated (GTK_WINDOW (widget), SETTING);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    decorated = gtk_window_get_decorated (GTK_WINDOW (widget));
    if (decorated != SETTING)
    {
        TEST_FAIL ("decorated is %d, should be %d", decorated, SETTING);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_decorated
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion: If you set the decorated property to FALSE using this function, GTK+ will do its best to convince the window manager not to decorate the window. 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, FALSE
 * Expected: void
 * 
 * Name:  gtk_window_get_decorated
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Returns whether the window has been set to have decorations such as a title bar via gtk_window_set_decorated().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: FALSE  
 */
static void test_purpose_81()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define SETTING FALSE
    
    GtkWidget* widget;
    gboolean decorated;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_decorated (GTK_WINDOW (widget), SETTING);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    decorated = gtk_window_get_decorated (GTK_WINDOW (widget));
    if (decorated != SETTING)
    {
        TEST_FAIL ("decorated is %d, should be %d", decorated, SETTING);
    }
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  SETTING
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_frame_dimensions
 * Params: GtkWindow *window, gint left, gint top, gint right, gint bottom
 * Returns: void
 * Assertion: For windows with frames (see gtk_window_set_has_frame()) this function can be used to change the size of the frame border.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 0, 0, 0
 * Expected: void
 * 
 * Name:  gtk_window_get_frame_dimensions
 * Params: GtkWindow *window, gint *left, gint *top, gint *right, gint *bottom
 * Returns: void
 * Assertion: Retrieves the dimensions of the frame window for this toplevel. 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, gint*, gint*, gint*, gint*
 * Expected: void  
 */
static void test_purpose_82()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define LEFT 0
    #define TOP 0
    #define RIGHT 0
    #define BOTTOM 0
    #define HAS_FRAME TRUE
    
    GtkWidget* widget;
    gint left;
    gint top;
    gint right;
    gint bottom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_has_frame (GTK_WINDOW (widget), HAS_FRAME);
    gtk_window_set_frame_dimensions (GTK_WINDOW (widget), 
                                     LEFT, TOP, RIGHT, BOTTOM);
    
    gtk_window_get_frame_dimensions (GTK_WINDOW (widget), 
                                     &left, &top, &right, &bottom);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (top != TOP)
    {
        TEST_FAIL ("top is %d, should be %d", top, TOP);
    }
    
    if (left != LEFT)
    {
        TEST_FAIL ("left is %d, should be %d", left, LEFT);
    }
    
    if (right != RIGHT)
    {
        TEST_FAIL ("right is %d, should be %d", right, RIGHT);
    }
    
    if (bottom != BOTTOM)
    {
        TEST_FAIL ("bottom is %d, should be %d", bottom, BOTTOM);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef LEFT
    #undef TOP
    #undef RIGHT
    #undef BOTTOM
    #undef HAS_FRAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_frame_dimensions
 * Params: GtkWindow *window, gint left, gint top, gint right, gint bottom
 * Returns: void
 * Assertion: For windows with frames (see gtk_window_set_has_frame()) this function can be used to change the size of the frame border.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 1, 0, 0, 0
 * Expected: void
 * 
 * Name:  gtk_window_get_frame_dimensions
 * Params: GtkWindow *window, gint *left, gint *top, gint *right, gint *bottom
 * Returns: void
 * Assertion: Retrieves the dimensions of the frame window for this toplevel. 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, gint*, gint*, gint*, gint*
 * Expected: void  
 */
static void test_purpose_83()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define LEFT 1
    #define TOP 0
    #define RIGHT 0
    #define BOTTOM 0
    #define HAS_FRAME TRUE
    
    GtkWidget* widget;
    gint left;
    gint top;
    gint right;
    gint bottom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_has_frame (GTK_WINDOW (widget), HAS_FRAME);
    gtk_window_set_frame_dimensions (GTK_WINDOW (widget), 
                                     LEFT, TOP, RIGHT, BOTTOM);
    
    gtk_window_get_frame_dimensions (GTK_WINDOW (widget), 
                                     &left, &top, &right, &bottom);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (top != TOP)
    {
        TEST_FAIL ("top is %d, should be %d", top, TOP);
    }
    
    if (left != LEFT)
    {
        TEST_FAIL ("left is %d, should be %d", left, LEFT);
    }
    
    if (right != RIGHT)
    {
        TEST_FAIL ("right is %d, should be %d", right, RIGHT);
    }
    
    if (bottom != BOTTOM)
    {
        TEST_FAIL ("bottom is %d, should be %d", bottom, BOTTOM);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef LEFT
    #undef TOP
    #undef RIGHT
    #undef BOTTOM
    #undef HAS_FRAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_frame_dimensions
 * Params: GtkWindow *window, gint left, gint top, gint right, gint bottom
 * Returns: void
 * Assertion: For windows with frames (see gtk_window_set_has_frame()) this function can be used to change the size of the frame border.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 1000, 0, 0, 0
 * Expected: void
 * 
 * Name:  gtk_window_get_frame_dimensions
 * Params: GtkWindow *window, gint *left, gint *top, gint *right, gint *bottom
 * Returns: void
 * Assertion: Retrieves the dimensions of the frame window for this toplevel. 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, gint*, gint*, gint*, gint*
 * Expected: void  
 */
static void test_purpose_84()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define LEFT 1000
    #define TOP 0
    #define RIGHT 0
    #define BOTTOM 0
    #define HAS_FRAME TRUE
    
    GtkWidget* widget;
    gint left;
    gint top;
    gint right;
    gint bottom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_has_frame (GTK_WINDOW (widget), HAS_FRAME);
    gtk_window_set_frame_dimensions (GTK_WINDOW (widget), 
                                     LEFT, TOP, RIGHT, BOTTOM);
    
    gtk_window_get_frame_dimensions (GTK_WINDOW (widget), 
                                     &left, &top, &right, &bottom);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (top != TOP)
    {
        TEST_FAIL ("top is %d, should be %d", top, TOP);
    }
    
    if (left != LEFT)
    {
        TEST_FAIL ("left is %d, should be %d", left, LEFT);
    }
    
    if (right != RIGHT)
    {
        TEST_FAIL ("right is %d, should be %d", right, RIGHT);
    }
    
    if (bottom != BOTTOM)
    {
        TEST_FAIL ("bottom is %d, should be %d", bottom, BOTTOM);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef LEFT
    #undef TOP
    #undef RIGHT
    #undef BOTTOM
    #undef HAS_FRAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_frame_dimensions
 * Params: GtkWindow *window, gint left, gint top, gint right, gint bottom
 * Returns: void
 * Assertion: For windows with frames (see gtk_window_set_has_frame()) this function can be used to change the size of the frame border.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, G_MAXINT, 0, 0, 0
 * Expected: void
 * 
 * Name:  gtk_window_get_frame_dimensions
 * Params: GtkWindow *window, gint *left, gint *top, gint *right, gint *bottom
 * Returns: void
 * Assertion: Retrieves the dimensions of the frame window for this toplevel. 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, gint*, gint*, gint*, gint*
 * Expected: void  
 */
static void test_purpose_85()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define LEFT G_MAXINT
    #define TOP 0
    #define RIGHT 0
    #define BOTTOM 0
    #define HAS_FRAME TRUE
    
    GtkWidget* widget;
    gint left;
    gint top;
    gint right;
    gint bottom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_has_frame (GTK_WINDOW (widget), HAS_FRAME);
    gtk_window_set_frame_dimensions (GTK_WINDOW (widget), 
                                     LEFT, TOP, RIGHT, BOTTOM);
    
    gtk_window_get_frame_dimensions (GTK_WINDOW (widget), 
                                     &left, &top, &right, &bottom);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (top != TOP)
    {
        TEST_FAIL ("top is %d, should be %d", top, TOP);
    }
    
    if (left != LEFT)
    {
        TEST_FAIL ("left is %d, should be %d", left, LEFT);
    }
    
    if (right != RIGHT)
    {
        TEST_FAIL ("right is %d, should be %d", right, RIGHT);
    }
    
    if (bottom != BOTTOM)
    {
        TEST_FAIL ("bottom is %d, should be %d", bottom, BOTTOM);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef LEFT
    #undef TOP
    #undef RIGHT
    #undef BOTTOM
    #undef HAS_FRAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_frame_dimensions
 * Params: GtkWindow *window, gint left, gint top, gint right, gint bottom
 * Returns: void
 * Assertion: For windows with frames (see gtk_window_set_has_frame()) this function can be used to change the size of the frame border.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, -1, 0, 0
 * Expected: void
 * 
 * Name:  gtk_window_get_frame_dimensions
 * Params: GtkWindow *window, gint *left, gint *top, gint *right, gint *bottom
 * Returns: void
 * Assertion: Retrieves the dimensions of the frame window for this toplevel. 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, gint*, gint*, gint*, gint*
 * Expected: void  
 */
static void test_purpose_86()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define LEFT 0
    #define TOP -1
    #define RIGHT 0
    #define BOTTOM 0
    #define HAS_FRAME TRUE
    
    GtkWidget* widget;
    gint left;
    gint top;
    gint right;
    gint bottom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_has_frame (GTK_WINDOW (widget), HAS_FRAME);
    gtk_window_set_frame_dimensions (GTK_WINDOW (widget), 
                                     LEFT, TOP, RIGHT, BOTTOM);
    
    gtk_window_get_frame_dimensions (GTK_WINDOW (widget), 
                                     &left, &top, &right, &bottom);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (top != TOP)
    {
        TEST_FAIL ("top is %d, should be %d", top, TOP);
    }
    
    if (left != LEFT)
    {
        TEST_FAIL ("left is %d, should be %d", left, LEFT);
    }
    
    if (right != RIGHT)
    {
        TEST_FAIL ("right is %d, should be %d", right, RIGHT);
    }
    
    if (bottom != BOTTOM)
    {
        TEST_FAIL ("bottom is %d, should be %d", bottom, BOTTOM);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef LEFT
    #undef TOP
    #undef RIGHT
    #undef BOTTOM
    #undef HAS_FRAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_frame_dimensions
 * Params: GtkWindow *window, gint left, gint top, gint right, gint bottom
 * Returns: void
 * Assertion: For windows with frames (see gtk_window_set_has_frame()) this function can be used to change the size of the frame border.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 1, 0, 0
 * Expected: void
 * 
 * Name:  gtk_window_get_frame_dimensions
 * Params: GtkWindow *window, gint *left, gint *top, gint *right, gint *bottom
 * Returns: void
 * Assertion: Retrieves the dimensions of the frame window for this toplevel. 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, gint*, gint*, gint*, gint*
 * Expected: void  
 */
static void test_purpose_87()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define LEFT 0
    #define TOP 1
    #define RIGHT 0
    #define BOTTOM 0
    #define HAS_FRAME TRUE
    
    GtkWidget* widget;
    gint left;
    gint top;
    gint right;
    gint bottom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_has_frame (GTK_WINDOW (widget), HAS_FRAME);
    gtk_window_set_frame_dimensions (GTK_WINDOW (widget), 
                                     LEFT, TOP, RIGHT, BOTTOM);
    
    gtk_window_get_frame_dimensions (GTK_WINDOW (widget), 
                                     &left, &top, &right, &bottom);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (top != TOP)
    {
        TEST_FAIL ("top is %d, should be %d", top, TOP);
    }
    
    if (left != LEFT)
    {
        TEST_FAIL ("left is %d, should be %d", left, LEFT);
    }
    
    if (right != RIGHT)
    {
        TEST_FAIL ("right is %d, should be %d", right, RIGHT);
    }
    
    if (bottom != BOTTOM)
    {
        TEST_FAIL ("bottom is %d, should be %d", bottom, BOTTOM);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef LEFT
    #undef TOP
    #undef RIGHT
    #undef BOTTOM
    #undef HAS_FRAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_frame_dimensions
 * Params: GtkWindow *window, gint left, gint top, gint right, gint bottom
 * Returns: void
 * Assertion: For windows with frames (see gtk_window_set_has_frame()) this function can be used to change the size of the frame border.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 1000, 0, 0
 * Expected: void
 * 
 * Name:  gtk_window_get_frame_dimensions
 * Params: GtkWindow *window, gint *left, gint *top, gint *right, gint *bottom
 * Returns: void
 * Assertion: Retrieves the dimensions of the frame window for this toplevel. 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, gint*, gint*, gint*, gint*
 * Expected: void  
 */
static void test_purpose_88()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define LEFT 0
    #define TOP 1000
    #define RIGHT 0
    #define BOTTOM 0
    #define HAS_FRAME TRUE
    
    GtkWidget* widget;
    gint left;
    gint top;
    gint right;
    gint bottom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_has_frame (GTK_WINDOW (widget), HAS_FRAME);
    gtk_window_set_frame_dimensions (GTK_WINDOW (widget), 
                                     LEFT, TOP, RIGHT, BOTTOM);
    
    gtk_window_get_frame_dimensions (GTK_WINDOW (widget), 
                                     &left, &top, &right, &bottom);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (top != TOP)
    {
        TEST_FAIL ("top is %d, should be %d", top, TOP);
    }
    
    if (left != LEFT)
    {
        TEST_FAIL ("left is %d, should be %d", left, LEFT);
    }
    
    if (right != RIGHT)
    {
        TEST_FAIL ("right is %d, should be %d", right, RIGHT);
    }
    
    if (bottom != BOTTOM)
    {
        TEST_FAIL ("bottom is %d, should be %d", bottom, BOTTOM);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef LEFT
    #undef TOP
    #undef RIGHT
    #undef BOTTOM
    #undef HAS_FRAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_frame_dimensions
 * Params: GtkWindow *window, gint left, gint top, gint right, gint bottom
 * Returns: void
 * Assertion: For windows with frames (see gtk_window_set_has_frame()) this function can be used to change the size of the frame border.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 1, 0, 0
 * Expected: void
 * 
 * Name:  gtk_window_get_frame_dimensions
 * Params: GtkWindow *window, gint *left, gint *top, gint *right, gint *bottom
 * Returns: void
 * Assertion: Retrieves the dimensions of the frame window for this toplevel. 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, gint*, gint*, gint*, gint*
 * Expected: void  
 */
static void test_purpose_89()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define LEFT 0
    #define TOP 1
    #define RIGHT 0
    #define BOTTOM 0
    #define HAS_FRAME TRUE
    
    GtkWidget* widget;
    gint left;
    gint top;
    gint right;
    gint bottom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_has_frame (GTK_WINDOW (widget), HAS_FRAME);
    gtk_window_set_frame_dimensions (GTK_WINDOW (widget), 
                                     LEFT, TOP, RIGHT, BOTTOM);
    
    gtk_window_get_frame_dimensions (GTK_WINDOW (widget), 
                                     &left, &top, &right, &bottom);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (top != TOP)
    {
        TEST_FAIL ("top is %d, should be %d", top, TOP);
    }
    
    if (left != LEFT)
    {
        TEST_FAIL ("left is %d, should be %d", left, LEFT);
    }
    
    if (right != RIGHT)
    {
        TEST_FAIL ("right is %d, should be %d", right, RIGHT);
    }
    
    if (bottom != BOTTOM)
    {
        TEST_FAIL ("bottom is %d, should be %d", bottom, BOTTOM);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef LEFT
    #undef TOP
    #undef RIGHT
    #undef BOTTOM
    #undef HAS_FRAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_frame_dimensions
 * Params: GtkWindow *window, gint left, gint top, gint right, gint bottom
 * Returns: void
 * Assertion: For windows with frames (see gtk_window_set_has_frame()) this function can be used to change the size of the frame border.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 0, 1, 0
 * Expected: void
 * 
 * Name:  gtk_window_get_frame_dimensions
 * Params: GtkWindow *window, gint *left, gint *top, gint *right, gint *bottom
 * Returns: void
 * Assertion: Retrieves the dimensions of the frame window for this toplevel. 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, gint*, gint*, gint*, gint*
 * Expected: void  
 */
static void test_purpose_90()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define LEFT 0
    #define TOP 0
    #define RIGHT 1
    #define BOTTOM 0
    #define HAS_FRAME TRUE
    
    GtkWidget* widget;
    gint left;
    gint top;
    gint right;
    gint bottom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_has_frame (GTK_WINDOW (widget), HAS_FRAME);
    gtk_window_set_frame_dimensions (GTK_WINDOW (widget), 
                                     LEFT, TOP, RIGHT, BOTTOM);
    
    gtk_window_get_frame_dimensions (GTK_WINDOW (widget), 
                                     &left, &top, &right, &bottom);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (top != TOP)
    {
        TEST_FAIL ("top is %d, should be %d", top, TOP);
    }
    
    if (left != LEFT)
    {
        TEST_FAIL ("left is %d, should be %d", left, LEFT);
    }
    
    if (right != RIGHT)
    {
        TEST_FAIL ("right is %d, should be %d", right, RIGHT);
    }
    
    if (bottom != BOTTOM)
    {
        TEST_FAIL ("bottom is %d, should be %d", bottom, BOTTOM);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef LEFT
    #undef TOP
    #undef RIGHT
    #undef BOTTOM
    #undef HAS_FRAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_frame_dimensions
 * Params: GtkWindow *window, gint left, gint top, gint right, gint bottom
 * Returns: void
 * Assertion: For windows with frames (see gtk_window_set_has_frame()) this function can be used to change the size of the frame border.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 0, 1000, 0
 * Expected: void
 * 
 * Name:  gtk_window_get_frame_dimensions
 * Params: GtkWindow *window, gint *left, gint *top, gint *right, gint *bottom
 * Returns: void
 * Assertion: Retrieves the dimensions of the frame window for this toplevel. 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, gint*, gint*, gint*, gint*
 * Expected: void  
 */
static void test_purpose_91()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define LEFT 0
    #define TOP 0
    #define RIGHT 1000
    #define BOTTOM 0
    #define HAS_FRAME TRUE
    
    GtkWidget* widget;
    gint left;
    gint top;
    gint right;
    gint bottom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_has_frame (GTK_WINDOW (widget), HAS_FRAME);
    gtk_window_set_frame_dimensions (GTK_WINDOW (widget), 
                                     LEFT, TOP, RIGHT, BOTTOM);
    
    gtk_window_get_frame_dimensions (GTK_WINDOW (widget), 
                                     &left, &top, &right, &bottom);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (top != TOP)
    {
        TEST_FAIL ("top is %d, should be %d", top, TOP);
    }
    
    if (left != LEFT)
    {
        TEST_FAIL ("left is %d, should be %d", left, LEFT);
    }
    
    if (right != RIGHT)
    {
        TEST_FAIL ("right is %d, should be %d", right, RIGHT);
    }
    
    if (bottom != BOTTOM)
    {
        TEST_FAIL ("bottom is %d, should be %d", bottom, BOTTOM);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef LEFT
    #undef TOP
    #undef RIGHT
    #undef BOTTOM
    #undef HAS_FRAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_frame_dimensions
 * Params: GtkWindow *window, gint left, gint top, gint right, gint bottom
 * Returns: void
 * Assertion: For windows with frames (see gtk_window_set_has_frame()) this function can be used to change the size of the frame border.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 0, 0, 1
 * Expected: void
 * 
 * Name:  gtk_window_get_frame_dimensions
 * Params: GtkWindow *window, gint *left, gint *top, gint *right, gint *bottom
 * Returns: void
 * Assertion: Retrieves the dimensions of the frame window for this toplevel. 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, gint*, gint*, gint*, gint*
 * Expected: void  
 */
static void test_purpose_92()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define LEFT 0
    #define TOP 0
    #define RIGHT 0
    #define BOTTOM 1
    #define HAS_FRAME TRUE
    
    GtkWidget* widget;
    gint left;
    gint top;
    gint right;
    gint bottom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_has_frame (GTK_WINDOW (widget), HAS_FRAME);
    gtk_window_set_frame_dimensions (GTK_WINDOW (widget), 
                                     LEFT, TOP, RIGHT, BOTTOM);
    
    gtk_window_get_frame_dimensions (GTK_WINDOW (widget), 
                                     &left, &top, &right, &bottom);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (top != TOP)
    {
        TEST_FAIL ("top is %d, should be %d", top, TOP);
    }
    
    if (left != LEFT)
    {
        TEST_FAIL ("left is %d, should be %d", left, LEFT);
    }
    
    if (right != RIGHT)
    {
        TEST_FAIL ("right is %d, should be %d", right, RIGHT);
    }
    
    if (bottom != BOTTOM)
    {
        TEST_FAIL ("bottom is %d, should be %d", bottom, BOTTOM);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef LEFT
    #undef TOP
    #undef RIGHT
    #undef BOTTOM
    #undef HAS_FRAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_frame_dimensions
 * Params: GtkWindow *window, gint left, gint top, gint right, gint bottom
 * Returns: void
 * Assertion: For windows with frames (see gtk_window_set_has_frame()) this function can be used to change the size of the frame border.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 0, 0, 100
 * Expected: void
 * 
 * Name:  gtk_window_get_frame_dimensions
 * Params: GtkWindow *window, gint *left, gint *top, gint *right, gint *bottom
 * Returns: void
 * Assertion: Retrieves the dimensions of the frame window for this toplevel. 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, gint*, gint*, gint*, gint*
 * Expected: void  
 */
static void test_purpose_93()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define LEFT 0
    #define TOP 0
    #define RIGHT 0
    #define BOTTOM 100
    #define HAS_FRAME TRUE
    
    GtkWidget* widget;
    gint left;
    gint top;
    gint right;
    gint bottom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_has_frame (GTK_WINDOW (widget), HAS_FRAME);
    gtk_window_set_frame_dimensions (GTK_WINDOW (widget), 
                                     LEFT, TOP, RIGHT, BOTTOM);
    
    gtk_window_get_frame_dimensions (GTK_WINDOW (widget), 
                                     &left, &top, &right, &bottom);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (top != TOP)
    {
        TEST_FAIL ("top is %d, should be %d", top, TOP);
    }
    
    if (left != LEFT)
    {
        TEST_FAIL ("left is %d, should be %d", left, LEFT);
    }
    
    if (right != RIGHT)
    {
        TEST_FAIL ("right is %d, should be %d", right, RIGHT);
    }
    
    if (bottom != BOTTOM)
    {
        TEST_FAIL ("bottom is %d, should be %d", bottom, BOTTOM);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef LEFT
    #undef TOP
    #undef RIGHT
    #undef BOTTOM
    #undef HAS_FRAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_frame_dimensions
 * Params: GtkWindow *window, gint left, gint top, gint right, gint bottom
 * Returns: void
 * Assertion: For windows with frames (see gtk_window_set_has_frame()) this function can be used to change the size of the frame border.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 0, 0, 0
 * Expected: void
 * 
 * Name:  gtk_window_get_frame_dimensions
 * Params: GtkWindow *window, gint *left, gint *top, gint *right, gint *bottom
 * Returns: void
 * Assertion: Retrieves the dimensions of the frame window for this toplevel. 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, gint*, gint*, gint*, gint*
 * Expected: void  
 */
static void test_purpose_94()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define LEFT 0
    #define TOP 0
    #define RIGHT 0
    #define BOTTOM 0
    #define HAS_FRAME FALSE
    
    GtkWidget* widget;
    gint left;
    gint top;
    gint right;
    gint bottom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_has_frame (GTK_WINDOW (widget), HAS_FRAME);
    gtk_window_set_frame_dimensions (GTK_WINDOW (widget), 
                                     LEFT, TOP, RIGHT, BOTTOM);
    
    gtk_window_get_frame_dimensions (GTK_WINDOW (widget), 
                                     &left, &top, &right, &bottom);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (top != TOP)
    {
        TEST_FAIL ("top is %d, should be %d", top, TOP);
    }
    
    if (left != LEFT)
    {
        TEST_FAIL ("left is %d, should be %d", left, LEFT);
    }
    
    if (right != RIGHT)
    {
        TEST_FAIL ("right is %d, should be %d", right, RIGHT);
    }
    
    if (bottom != BOTTOM)
    {
        TEST_FAIL ("bottom is %d, should be %d", bottom, BOTTOM);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef LEFT
    #undef TOP
    #undef RIGHT
    #undef BOTTOM
    #undef HAS_FRAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_frame_dimensions
 * Params: GtkWindow *window, gint left, gint top, gint right, gint bottom
 * Returns: void
 * Assertion: For windows with frames (see gtk_window_set_has_frame()) this function can be used to change the size of the frame border.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 0, 100, 0
 * Expected: void
 * 
 * Name:  gtk_window_get_frame_dimensions
 * Params: GtkWindow *window, gint *left, gint *top, gint *right, gint *bottom
 * Returns: void
 * Assertion: Retrieves the dimensions of the frame window for this toplevel. 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, gint*, gint*, gint*, gint*
 * Expected: void  
 */
static void test_purpose_95()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define LEFT 0
    #define TOP 0
    #define RIGHT 100
    #define BOTTOM 0
    #define HAS_FRAME TRUE
    
    GtkWidget* widget;
    gint left;
    gint top;
    gint right;
    gint bottom;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_has_frame (GTK_WINDOW (widget), HAS_FRAME);
    gtk_window_set_frame_dimensions (GTK_WINDOW (widget), 
                                     LEFT, TOP, RIGHT, BOTTOM);
    
    gtk_window_get_frame_dimensions (GTK_WINDOW (widget), 
                                     &left, &top, &right, &bottom);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (top != TOP)
    {
        TEST_FAIL ("top is %d, should be %d", top, TOP);
    }
    
    if (left != LEFT)
    {
        TEST_FAIL ("left is %d, should be %d", left, LEFT);
    }
    
    if (right != RIGHT)
    {
        TEST_FAIL ("right is %d, should be %d", right, RIGHT);
    }
    
    if (bottom != BOTTOM)
    {
        TEST_FAIL ("bottom is %d, should be %d", bottom, BOTTOM);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef LEFT
    #undef TOP
    #undef RIGHT
    #undef BOTTOM
    #undef HAS_FRAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_has_frame
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion: If this function is called on a window with setting of TRUE, before it is realized or showed, it will have a "frame" window around window->window, accessible in window->frame.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, TRUE
 * Expected: void
 * 
 * Name:  gtk_window_set_has_frame
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion: Using the signal frame_event you can recieve all events targeted at the frame
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, TRUE
 * Expected: void
 * 
 * Name:  gtk_window_get_has_frame
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Accessor for whether the window has a frame window exterior to window->window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: TRUE
 * 
 * Name:  gtk_window_get_has_frame
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Gets the value set by gtk_window_set_has_frame().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: TRUE  
 */
static void test_purpose_96()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define HAS_FRAME  TRUE
    
    GtkWidget* widget;
    gboolean has_frame;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_iter = 0;
    widget = gtk_window_new (WINDOW_TYPE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_signal_connect (G_OBJECT (widget), "frame_event",
                      GTK_SIGNAL_FUNC (global_window_state_event_handler), NULL);
    
    gtk_window_set_has_frame (GTK_WINDOW (widget), HAS_FRAME);
    has_frame = gtk_window_get_has_frame (GTK_WINDOW (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (HAS_FRAME && !global_iter)
    {
        TEST_FAIL ("global_iter = %i", global_iter);
    }
    
    if (has_frame != HAS_FRAME)
    {
        TEST_FAIL ("has_frame is %d, should be %d", has_frame, HAS_FRAME);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef HAS_FRAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_has_frame
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion: If this function is called on a window with setting of TRUE, before it is realized or showed, it will have a "frame" window around window->window, accessible in window->frame.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, TRUE
 * Expected: void
 * 
 * Name:  gtk_window_set_has_frame
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion: Using the signal frame_event you can recieve all events targeted at the frame
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, TRUE
 * Expected: void
 * 
 * Name:  gtk_window_get_has_frame
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Accessor for whether the window has a frame window exterior to window->window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: TRUE
 * 
 * Name:  gtk_window_get_has_frame
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Gets the value set by gtk_window_set_has_frame().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: TRUE  
 */
static void test_purpose_97()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define HAS_FRAME  TRUE
    
    GtkWidget* widget;
    gboolean has_frame;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_iter = 0;
    widget = gtk_window_new (WINDOW_TYPE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_signal_connect (G_OBJECT (widget), "frame_event",
                      GTK_SIGNAL_FUNC (global_window_state_event_handler), NULL);
    
    gtk_window_set_has_frame (GTK_WINDOW (widget), HAS_FRAME);
    has_frame = gtk_window_get_has_frame (GTK_WINDOW (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (HAS_FRAME && !global_iter)
    {
        TEST_FAIL ("global_iter = %i", global_iter);
    }
    
    if (has_frame != HAS_FRAME)
    {
        TEST_FAIL ("has_frame is %d, should be %d", has_frame, HAS_FRAME);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef HAS_FRAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_has_frame
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion: If this function is called on a window with setting of TRUE, before it is realized or showed, it will have a "frame" window around window->window, accessible in window->frame.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, FALSE
 * Expected: void
 * 
 * Name:  gtk_window_set_has_frame
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion: Using the signal frame_event you can recieve all events targeted at the frame
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, FALSE
 * Expected: void
 * 
 * Name:  gtk_window_get_has_frame
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Accessor for whether the window has a frame window exterior to window->window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: FALSE
 * 
 * Name:  gtk_window_get_has_frame
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Gets the value set by gtk_window_set_has_frame().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: FALSE  
 */
static void test_purpose_98()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define HAS_FRAME  FALSE
    
    GtkWidget* widget;
    gboolean has_frame;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_iter = 0;
    widget = gtk_window_new (WINDOW_TYPE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_signal_connect (G_OBJECT (widget), "frame_event",
                      GTK_SIGNAL_FUNC (global_window_state_event_handler), NULL);
    
    gtk_window_set_has_frame (GTK_WINDOW (widget), HAS_FRAME);
    has_frame = gtk_window_get_has_frame (GTK_WINDOW (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (HAS_FRAME && !global_iter)
    {
        TEST_FAIL ("global_iter = %i", global_iter);
    }
    
    if (has_frame != HAS_FRAME)
    {
        TEST_FAIL ("has_frame is %d, should be %d", has_frame, HAS_FRAME);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef HAS_FRAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_has_frame
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion: If this function is called on a window with setting of TRUE, before it is realized or showed, it will have a "frame" window around window->window, accessible in window->frame.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, FALSE
 * Expected: void
 * 
 * Name:  gtk_window_set_has_frame
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion: Using the signal frame_event you can recieve all events targeted at the frame
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, FALSE
 * Expected: void
 * 
 * Name:  gtk_window_get_has_frame
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Accessor for whether the window has a frame window exterior to window->window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: FALSE
 * 
 * Name:  gtk_window_get_has_frame
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Gets the value set by gtk_window_set_has_frame().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: FALSE  
 */
static void test_purpose_99()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define HAS_FRAME  FALSE
    
    GtkWidget* widget;
    gboolean has_frame;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_iter = 0;
    widget = gtk_window_new (WINDOW_TYPE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    
    g_signal_connect (G_OBJECT (widget), "frame_event",
                      GTK_SIGNAL_FUNC (global_window_state_event_handler), NULL);
    
    gtk_window_set_has_frame (GTK_WINDOW (widget), HAS_FRAME);
    has_frame = gtk_window_get_has_frame (GTK_WINDOW (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (HAS_FRAME && !global_iter)
    {
        TEST_FAIL ("global_iter = %i", global_iter);
    }
    
    if (has_frame != HAS_FRAME)
    {
        TEST_FAIL ("has_frame is %d, should be %d", has_frame, HAS_FRAME);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef HAS_FRAME
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_mnemonic_modifier
 * Params: GtkWindow *window, GdkModifierType modifier
 * Returns: void
 * Assertion: Sets the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_SHIFT_MASK
 * Expected: void
 * 
 * Name:  gtk_window_get_mnemonic_modifier
 * Params: GtkWindow *window
 * Returns: GdkModifierType
 * Assertion: Returns the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_SHIFT_MASK  
 */
static void test_purpose_100()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define MODIFIER GDK_SHIFT_MASK
    
    GtkWidget* widget;
    GdkModifierType modifier;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_mnemonic_modifier (GTK_WINDOW (widget), MODIFIER);
    
    modifier = gtk_window_get_mnemonic_modifier (GTK_WINDOW (widget));
    if (modifier != MODIFIER)
    {
        TEST_FAIL ("modifier is %d, should be %d", modifier, MODIFIER);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef MODIFIER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_mnemonic_modifier
 * Params: GtkWindow *window, GdkModifierType modifier
 * Returns: void
 * Assertion: Sets the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_LOCK_MASK
 * Expected: void
 * 
 * Name:  gtk_window_get_mnemonic_modifier
 * Params: GtkWindow *window
 * Returns: GdkModifierType
 * Assertion: Returns the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_LOCK_MASK  
 */
static void test_purpose_101()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define MODIFIER GDK_LOCK_MASK
    
    GtkWidget* widget;
    GdkModifierType modifier;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_mnemonic_modifier (GTK_WINDOW (widget), MODIFIER);
    
    modifier = gtk_window_get_mnemonic_modifier (GTK_WINDOW (widget));
    if (modifier != MODIFIER)
    {
        TEST_FAIL ("modifier is %d, should be %d", modifier, MODIFIER);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef MODIFIER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_mnemonic_modifier
 * Params: GtkWindow *window, GdkModifierType modifier
 * Returns: void
 * Assertion: Sets the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_CONTROL_MASK
 * Expected: void
 * 
 * Name:  gtk_window_get_mnemonic_modifier
 * Params: GtkWindow *window
 * Returns: GdkModifierType
 * Assertion: Returns the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_CONTROL_MASK  
 */
static void test_purpose_102()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define MODIFIER GDK_CONTROL_MASK
    
    GtkWidget* widget;
    GdkModifierType modifier;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_mnemonic_modifier (GTK_WINDOW (widget), MODIFIER);
    
    modifier = gtk_window_get_mnemonic_modifier (GTK_WINDOW (widget));
    if (modifier != MODIFIER)
    {
        TEST_FAIL ("modifier is %d, should be %d", modifier, MODIFIER);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef MODIFIER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_mnemonic_modifier
 * Params: GtkWindow *window, GdkModifierType modifier
 * Returns: void
 * Assertion: Sets the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_MOD1_MASK
 * Expected: void
 * 
 * Name:  gtk_window_get_mnemonic_modifier
 * Params: GtkWindow *window
 * Returns: GdkModifierType
 * Assertion: Returns the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_MOD1_MASK  
 */
static void test_purpose_103()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define MODIFIER GDK_MOD1_MASK
    
    GtkWidget* widget;
    GdkModifierType modifier;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_mnemonic_modifier (GTK_WINDOW (widget), MODIFIER);
    
    modifier = gtk_window_get_mnemonic_modifier (GTK_WINDOW (widget));
    if (modifier != MODIFIER)
    {
        TEST_FAIL ("modifier is %d, should be %d", modifier, MODIFIER);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef MODIFIER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_mnemonic_modifier
 * Params: GtkWindow *window, GdkModifierType modifier
 * Returns: void
 * Assertion: Sets the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_MOD2_MASK
 * Expected: void
 * 
 * Name:  gtk_window_get_mnemonic_modifier
 * Params: GtkWindow *window
 * Returns: GdkModifierType
 * Assertion: Returns the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_MOD2_MASK  
 */
static void test_purpose_104()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define MODIFIER GDK_MOD2_MASK
    
    GtkWidget* widget;
    GdkModifierType modifier;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_mnemonic_modifier (GTK_WINDOW (widget), MODIFIER);
    
    modifier = gtk_window_get_mnemonic_modifier (GTK_WINDOW (widget));
    if (modifier != MODIFIER)
    {
        TEST_FAIL ("modifier is %d, should be %d", modifier, MODIFIER);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef MODIFIER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_mnemonic_modifier
 * Params: GtkWindow *window, GdkModifierType modifier
 * Returns: void
 * Assertion: Sets the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_MOD3_MASK
 * Expected: void
 * 
 * Name:  gtk_window_get_mnemonic_modifier
 * Params: GtkWindow *window
 * Returns: GdkModifierType
 * Assertion: Returns the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_MOD3_MASK  
 */
static void test_purpose_105()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define MODIFIER GDK_MOD3_MASK
    
    GtkWidget* widget;
    GdkModifierType modifier;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_mnemonic_modifier (GTK_WINDOW (widget), MODIFIER);
    
    modifier = gtk_window_get_mnemonic_modifier (GTK_WINDOW (widget));
    if (modifier != MODIFIER)
    {
        TEST_FAIL ("modifier is %d, should be %d", modifier, MODIFIER);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef MODIFIER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_mnemonic_modifier
 * Params: GtkWindow *window, GdkModifierType modifier
 * Returns: void
 * Assertion: Sets the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_MOD4_MASK
 * Expected: void
 * 
 * Name:  gtk_window_get_mnemonic_modifier
 * Params: GtkWindow *window
 * Returns: GdkModifierType
 * Assertion: Returns the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_MOD4_MASK  
 */
static void test_purpose_106()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define MODIFIER GDK_MOD4_MASK
    
    GtkWidget* widget;
    GdkModifierType modifier;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_mnemonic_modifier (GTK_WINDOW (widget), MODIFIER);
    
    modifier = gtk_window_get_mnemonic_modifier (GTK_WINDOW (widget));
    if (modifier != MODIFIER)
    {
        TEST_FAIL ("modifier is %d, should be %d", modifier, MODIFIER);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef MODIFIER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_mnemonic_modifier
 * Params: GtkWindow *window, GdkModifierType modifier
 * Returns: void
 * Assertion: Sets the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_MOD5_MASK
 * Expected: void
 * 
 * Name:  gtk_window_get_mnemonic_modifier
 * Params: GtkWindow *window
 * Returns: GdkModifierType
 * Assertion: Returns the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_MOD5_MASK  
 */
static void test_purpose_107()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define MODIFIER GDK_MOD5_MASK
    
    GtkWidget* widget;
    GdkModifierType modifier;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_mnemonic_modifier (GTK_WINDOW (widget), MODIFIER);
    
    modifier = gtk_window_get_mnemonic_modifier (GTK_WINDOW (widget));
    if (modifier != MODIFIER)
    {
        TEST_FAIL ("modifier is %d, should be %d", modifier, MODIFIER);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef MODIFIER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_mnemonic_modifier
 * Params: GtkWindow *window, GdkModifierType modifier
 * Returns: void
 * Assertion: Sets the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_BUTTON1_MASK
 * Expected: void
 * 
 * Name:  gtk_window_get_mnemonic_modifier
 * Params: GtkWindow *window
 * Returns: GdkModifierType
 * Assertion: Returns the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_BUTTON1_MASK  
 */
static void test_purpose_108()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define MODIFIER GDK_BUTTON1_MASK
    
    GtkWidget* widget;
    GdkModifierType modifier;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_mnemonic_modifier (GTK_WINDOW (widget), MODIFIER);
    
    modifier = gtk_window_get_mnemonic_modifier (GTK_WINDOW (widget));
    if (modifier != MODIFIER)
    {
        TEST_FAIL ("modifier is %d, should be %d", modifier, MODIFIER);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef MODIFIER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_mnemonic_modifier
 * Params: GtkWindow *window, GdkModifierType modifier
 * Returns: void
 * Assertion: Sets the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_BUTTON2_MASK
 * Expected: void
 * 
 * Name:  gtk_window_get_mnemonic_modifier
 * Params: GtkWindow *window
 * Returns: GdkModifierType
 * Assertion: Returns the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_BUTTON2_MASK  
 */
static void test_purpose_109()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define MODIFIER GDK_BUTTON2_MASK
    
    GtkWidget* widget;
    GdkModifierType modifier;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_mnemonic_modifier (GTK_WINDOW (widget), MODIFIER);
    
    modifier = gtk_window_get_mnemonic_modifier (GTK_WINDOW (widget));
    if (modifier != MODIFIER)
    {
        TEST_FAIL ("modifier is %d, should be %d", modifier, MODIFIER);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef MODIFIER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_mnemonic_modifier
 * Params: GtkWindow *window, GdkModifierType modifier
 * Returns: void
 * Assertion: Sets the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_BUTTON3_MASK
 * Expected: void
 * 
 * Name:  gtk_window_get_mnemonic_modifier
 * Params: GtkWindow *window
 * Returns: GdkModifierType
 * Assertion: Returns the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_BUTTON3_MASK  
 */
static void test_purpose_110()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define MODIFIER GDK_BUTTON3_MASK
    
    GtkWidget* widget;
    GdkModifierType modifier;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_mnemonic_modifier (GTK_WINDOW (widget), MODIFIER);
    
    modifier = gtk_window_get_mnemonic_modifier (GTK_WINDOW (widget));
    if (modifier != MODIFIER)
    {
        TEST_FAIL ("modifier is %d, should be %d", modifier, MODIFIER);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef MODIFIER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_mnemonic_modifier
 * Params: GtkWindow *window, GdkModifierType modifier
 * Returns: void
 * Assertion: Sets the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_BUTTON4_MASK
 * Expected: void
 * 
 * Name:  gtk_window_get_mnemonic_modifier
 * Params: GtkWindow *window
 * Returns: GdkModifierType
 * Assertion: Returns the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_BUTTON4_MASK  
 */
static void test_purpose_111()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define MODIFIER GDK_BUTTON4_MASK
    
    GtkWidget* widget;
    GdkModifierType modifier;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_mnemonic_modifier (GTK_WINDOW (widget), MODIFIER);
    
    modifier = gtk_window_get_mnemonic_modifier (GTK_WINDOW (widget));
    if (modifier != MODIFIER)
    {
        TEST_FAIL ("modifier is %d, should be %d", modifier, MODIFIER);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef MODIFIER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_mnemonic_modifier
 * Params: GtkWindow *window, GdkModifierType modifier
 * Returns: void
 * Assertion: Sets the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_BUTTON5_MASK
 * Expected: void
 * 
 * Name:  gtk_window_get_mnemonic_modifier
 * Params: GtkWindow *window
 * Returns: GdkModifierType
 * Assertion: Returns the mnemonic modifier for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_BUTTON5_MASK  
 */
static void test_purpose_112()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define MODIFIER GDK_BUTTON5_MASK
    
    GtkWidget* widget;
    GdkModifierType modifier;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_set_mnemonic_modifier (GTK_WINDOW (widget), MODIFIER);
    
    modifier = gtk_window_get_mnemonic_modifier (GTK_WINDOW (widget));
    if (modifier != MODIFIER)
    {
        TEST_FAIL ("modifier is %d, should be %d", modifier, MODIFIER);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef MODIFIER
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_role
 * Params: GtkWindow *window, const gchar *role
 * Returns: void
 * Assertion: In combination with the window title, the window role allows a window manager to identify "the same" window when an application is restarted.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "Text"
 * Expected: void
 * 
 * Name:  gtk_window_get_role
 * Params: GtkWindow *window
 * Returns: const gchar *role
 * Assertion: Returns the role of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: "Text"  
 */
static void test_purpose_113()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define ROLE "Text"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* role;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_role (GTK_WINDOW (widget), ROLE);
    
    role = gtk_window_get_role (GTK_WINDOW (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (ROLE != NULL)
    {
        if (!role)
        {
            TEST_FAIL ("role is NULL, ROLE is not", NULL);
        } else {
            if (strcmp (role, ROLE))
            {
                TEST_FAIL ("role is '%s', should be '%s'", role, ROLE);
            }
        } 
    } else {
        if (role)
        {
            TEST_FAIL ("role is not NULL, ROLE is", NULL);
        }
    }
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef ROLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_role
 * Params: GtkWindow *window, const gchar *role
 * Returns: void
 * Assertion: In combination with the window title, the window role allows a window manager to identify "the same" window when an application is restarted.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
 * Expected: void
 * 
 * Name:  gtk_window_get_role
 * Params: GtkWindow *window
 * Returns: const gchar *role
 * Assertion: Returns the role of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"  
 */
static void test_purpose_114()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define ROLE "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* role;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_role (GTK_WINDOW (widget), ROLE);
    
    role = gtk_window_get_role (GTK_WINDOW (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (ROLE != NULL)
    {
        if (!role)
        {
            TEST_FAIL ("role is NULL, ROLE is not", NULL);
        } else {
            if (strcmp (role, ROLE))
            {
                TEST_FAIL ("role is '%s', should be '%s'", role, ROLE);
            }
        } 
    } else {
        if (role)
        {
            TEST_FAIL ("role is not NULL, ROLE is", NULL);
        }
    }
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef ROLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_role
 * Params: GtkWindow *window, const gchar *role
 * Returns: void
 * Assertion: In combination with the window title, the window role allows a window manager to identify "the same" window when an application is restarted.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "!@#$%^&*()_+|~=\";:'?<>`/" 
 * Expected: void
 * 
 * Name:  gtk_window_get_role
 * Params: GtkWindow *window
 * Returns: const gchar *role
 * Assertion: Returns the role of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: "!@#$%^&*()_+|~=\";:'?<>`/"   
 */
static void test_purpose_115()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define ROLE "!@#$%^&*()_+|~=\";:'?<>`/" 
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* role;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_role (GTK_WINDOW (widget), ROLE);
    
    role = gtk_window_get_role (GTK_WINDOW (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (ROLE != NULL)
    {
        if (!role)
        {
            TEST_FAIL ("role is NULL, ROLE is not", NULL);
        } else {
            if (strcmp (role, ROLE))
            {
                TEST_FAIL ("role is '%s', should be '%s'", role, ROLE);
            }
        } 
    } else {
        if (role)
        {
            TEST_FAIL ("role is not NULL, ROLE is", NULL);
        }
    }
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef ROLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_role
 * Params: GtkWindow *window, const gchar *role
 * Returns: void
 * Assertion: In combination with the window title, the window role allows a window manager to identify "the same" window when an application is restarted.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "\b\n\t"
 * Expected: void
 * 
 * Name:  gtk_window_get_role
 * Params: GtkWindow *window
 * Returns: const gchar *role
 * Assertion: Returns the role of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: "\b\n\t"  
 */
static void test_purpose_116()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define ROLE "\b\n\t"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* role;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_role (GTK_WINDOW (widget), ROLE);
    
    role = gtk_window_get_role (GTK_WINDOW (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (ROLE != NULL)
    {
        if (!role)
        {
            TEST_FAIL ("role is NULL, ROLE is not", NULL);
        } else {
            if (strcmp (role, ROLE))
            {
                TEST_FAIL ("role is '%s', should be '%s'", role, ROLE);
            }
        } 
    } else {
        if (role)
        {
            TEST_FAIL ("role is not NULL, ROLE is", NULL);
        }
    }
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef ROLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_role
 * Params: GtkWindow *window, const gchar *role
 * Returns: void
 * Assertion: In combination with the window title, the window role allows a window manager to identify "the same" window when an application is restarted.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, ""
 * Expected: void
 * 
 * Name:  gtk_window_get_role
 * Params: GtkWindow *window
 * Returns: const gchar *role
 * Assertion: Returns the role of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: ""  
 */
static void test_purpose_117()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define ROLE ""
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* role;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_role (GTK_WINDOW (widget), ROLE);
    
    role = gtk_window_get_role (GTK_WINDOW (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (ROLE != NULL)
    {
        if (!role)
        {
            TEST_FAIL ("role is NULL, ROLE is not", NULL);
        } else {
            if (strcmp (role, ROLE))
            {
                TEST_FAIL ("role is '%s', should be '%s'", role, ROLE);
            }
        } 
    } else {
        if (role)
        {
            TEST_FAIL ("role is not NULL, ROLE is", NULL);
        }
    }
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef ROLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_role
 * Params: GtkWindow *window, const gchar *role
 * Returns: void
 * Assertion: In combination with the window title, the window role allows a window manager to identify "the same" window when an application is restarted.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "  "
 * Expected: void
 * 
 * Name:  gtk_window_get_role
 * Params: GtkWindow *window
 * Returns: const gchar *role
 * Assertion: Returns the role of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: "  "  
 */
static void test_purpose_118()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define ROLE "  "
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* role;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_role (GTK_WINDOW (widget), ROLE);
    
    role = gtk_window_get_role (GTK_WINDOW (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (ROLE != NULL)
    {
        if (!role)
        {
            TEST_FAIL ("role is NULL, ROLE is not", NULL);
        } else {
            if (strcmp (role, ROLE))
            {
                TEST_FAIL ("role is '%s', should be '%s'", role, ROLE);
            }
        } 
    } else {
        if (role)
        {
            TEST_FAIL ("role is not NULL, ROLE is", NULL);
        }
    }
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef ROLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_role
 * Params: GtkWindow *window, const gchar *role
 * Returns: void
 * Assertion: In combination with the window title, the window role allows a window manager to identify "the same" window when an application is restarted.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, NULL
 * Expected: void
 * 
 * Name:  gtk_window_get_role
 * Params: GtkWindow *window
 * Returns: const gchar *role
 * Assertion: Returns the role of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: NULL  
 */
static void test_purpose_119()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define ROLE NULL
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* role;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_role (GTK_WINDOW (widget), ROLE);
    
    role = gtk_window_get_role (GTK_WINDOW (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (ROLE != NULL)
    {
        if (!role)
        {
            TEST_FAIL ("role is NULL, ROLE is not", NULL);
        } else {
            if (strcmp (role, ROLE))
            {
                TEST_FAIL ("role is '%s', should be '%s'", role, ROLE);
            }
        } 
    } else {
        if (role)
        {
            TEST_FAIL ("role is not NULL, ROLE is", NULL);
        }
    }
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef ROLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_role
 * Params: GtkWindow *window, const gchar *role
 * Returns: void
 * Assertion: In combination with the window title, the window role allows a window manager to identify "the same" window when an application is restarted.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, "Text"
 * Expected: void
 * 
 * Name:  gtk_window_get_role
 * Params: GtkWindow *window
 * Returns: const gchar *role
 * Assertion: Returns the role of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: "Text"  
 */
static void test_purpose_120()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define ROLE "Text"
    
    GtkWidget* widget;
    G_CONST_RETURN gchar* role;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_role (GTK_WINDOW (widget), ROLE);
    
    role = gtk_window_get_role (GTK_WINDOW (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (ROLE != NULL)
    {
        if (!role)
        {
            TEST_FAIL ("role is NULL, ROLE is not", NULL);
        } else {
            if (strcmp (role, ROLE))
            {
                TEST_FAIL ("role is '%s', should be '%s'", role, ROLE);
            }
        } 
    } else {
        if (role)
        {
            TEST_FAIL ("role is not NULL, ROLE is", NULL);
        }
    }
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef ROLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_type_hint
 * Params: GtkWindow *window, GdkWindowTypeHint hint
 * Returns: void
 * Assertion: By setting the type hint for the window, you allow the window manager to decorate and handle the window in a way which is suitable to the function of the window in your application.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_WINDOW_TYPE_HINT_NORMAL
 * Expected: void
 * 
 * Name:  gtk_window_get_type_hint
 * Params: GtkWindow *window
 * Returns: GdkWindowTypeHint hint
 * Assertion: Gets the type hint for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_WINDOW_TYPE_HINT_NORMAL  
 */
static void test_purpose_121()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define TYPE_HINT GDK_WINDOW_TYPE_HINT_NORMAL
    
    GtkWidget* widget;
    GdkWindowTypeHint type_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_window_set_type_hint (GTK_WINDOW (widget), TYPE_HINT);
    
    type_hint = gtk_window_get_type_hint (GTK_WINDOW (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (type_hint != TYPE_HINT)
    {
        TEST_FAIL ("type_hint is %d, should be %d", type_hint, TYPE_HINT);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef TYPE_HINT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_type_hint
 * Params: GtkWindow *window, GdkWindowTypeHint hint
 * Returns: void
 * Assertion: By setting the type hint for the window, you allow the window manager to decorate and handle the window in a way which is suitable to the function of the window in your application.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_WINDOW_TYPE_HINT_DIALOG
 * Expected: void
 * 
 * Name:  gtk_window_get_type_hint
 * Params: GtkWindow *window
 * Returns: GdkWindowTypeHint hint
 * Assertion: Gets the type hint for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_WINDOW_TYPE_HINT_DIALOG  
 */
static void test_purpose_122()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define TYPE_HINT GDK_WINDOW_TYPE_HINT_DIALOG
    
    GtkWidget* widget;
    GdkWindowTypeHint type_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_window_set_type_hint (GTK_WINDOW (widget), TYPE_HINT);
    
    type_hint = gtk_window_get_type_hint (GTK_WINDOW (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (type_hint != TYPE_HINT)
    {
        TEST_FAIL ("type_hint is %d, should be %d", type_hint, TYPE_HINT);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef TYPE_HINT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_type_hint
 * Params: GtkWindow *window, GdkWindowTypeHint hint
 * Returns: void
 * Assertion: By setting the type hint for the window, you allow the window manager to decorate and handle the window in a way which is suitable to the function of the window in your application.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_WINDOW_TYPE_HINT_MENU
 * Expected: void
 * 
 * Name:  gtk_window_get_type_hint
 * Params: GtkWindow *window
 * Returns: GdkWindowTypeHint hint
 * Assertion: Gets the type hint for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_WINDOW_TYPE_HINT_MENU  
 */
static void test_purpose_123()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define TYPE_HINT GDK_WINDOW_TYPE_HINT_MENU
    
    GtkWidget* widget;
    GdkWindowTypeHint type_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_window_set_type_hint (GTK_WINDOW (widget), TYPE_HINT);
    
    type_hint = gtk_window_get_type_hint (GTK_WINDOW (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (type_hint != TYPE_HINT)
    {
        TEST_FAIL ("type_hint is %d, should be %d", type_hint, TYPE_HINT);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef TYPE_HINT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_type_hint
 * Params: GtkWindow *window, GdkWindowTypeHint hint
 * Returns: void
 * Assertion: By setting the type hint for the window, you allow the window manager to decorate and handle the window in a way which is suitable to the function of the window in your application.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_WINDOW_TYPE_HINT_TOOLBAR
 * Expected: void
 * 
 * Name:  gtk_window_get_type_hint
 * Params: GtkWindow *window
 * Returns: GdkWindowTypeHint hint
 * Assertion: Gets the type hint for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GDK_WINDOW_TYPE_HINT_TOOLBAR  
 */
static void test_purpose_124()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define TYPE_HINT GDK_WINDOW_TYPE_HINT_TOOLBAR
    
    GtkWidget* widget;
    GdkWindowTypeHint type_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_window_set_type_hint (GTK_WINDOW (widget), TYPE_HINT);
    
    type_hint = gtk_window_get_type_hint (GTK_WINDOW (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (type_hint != TYPE_HINT)
    {
        TEST_FAIL ("type_hint is %d, should be %d", type_hint, TYPE_HINT);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef TYPE_HINT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_type_hint
 * Params: GtkWindow *window, GdkWindowTypeHint hint
 * Returns: void
 * Assertion: By setting the type hint for the window, you allow the window manager to decorate and handle the window in a way which is suitable to the function of the window in your application.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, GDK_WINDOW_TYPE_HINT_TOOLBAR
 * Expected: void
 * 
 * Name:  gtk_window_get_type_hint
 * Params: GtkWindow *window
 * Returns: GdkWindowTypeHint hint
 * Assertion: Gets the type hint for this window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: GDK_WINDOW_TYPE_HINT_TOOLBAR  
 */
static void test_purpose_125()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define TYPE_HINT GDK_WINDOW_TYPE_HINT_TOOLBAR
    
    GtkWidget* widget;
    GdkWindowTypeHint type_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_window_set_type_hint (GTK_WINDOW (widget), TYPE_HINT);
    
    type_hint = gtk_window_get_type_hint (GTK_WINDOW (widget));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (type_hint != TYPE_HINT)
    {
        TEST_FAIL ("type_hint is %d, should be %d", type_hint, TYPE_HINT);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef TYPE_HINT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_add_accel_group
 * Params: GtkWindow *window, GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: Associate accel_group with window, such that calling gtk_accel_groups_activate() on window will activate accelerators in accel_group.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, a newly created GtkAccelGroup
 * Expected: void  
 */
static void test_purpose_126()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    
    GtkWidget* widget;
    GtkAccelGroup* accel_group;
    GSList* obj_list;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    accel_group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (widget), accel_group);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_add_accel_group
 * Params: GtkWindow *window, GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: Associate accel_group with window, such that calling gtk_accel_groups_activate() on window will activate accelerators in accel_group.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, a newly created GtkAccelGroup
 * Expected: void  
 */
static void test_purpose_127()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    
    GtkWidget* widget;
    GtkAccelGroup* accel_group;
    GSList* obj_list;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    accel_group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (widget), accel_group);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_remove_accel_group
 * Params: GtkWindow *window, GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: Reverses the effects of gtk_window_add_accel_group().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, a newly created GtkAccelGroup
 * Expected: void  
 */
static void test_purpose_128()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    
    GtkWidget* widget;
    GtkAccelGroup* accel_group;
    GSList* obj_list;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    accel_group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (widget), accel_group);
    gtk_window_remove_accel_group (GTK_WINDOW (widget), accel_group);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_remove_accel_group
 * Params: GtkWindow *window, GtkAccelGroup *accel_group
 * Returns: void
 * Assertion: Reverses the effects of gtk_window_add_accel_group().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, a newly created GtkAccelGroup
 * Expected: void  
 */
static void test_purpose_129()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    
    GtkWidget* widget;
    GtkAccelGroup* accel_group;
    GSList* obj_list;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    accel_group = gtk_accel_group_new ();
    gtk_window_add_accel_group (GTK_WINDOW (widget), accel_group);
    gtk_window_remove_accel_group (GTK_WINDOW (widget), accel_group);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_present
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Presents a window to the user.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void  
 */
static void test_purpose_130()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define WINDOW_TYPE_1  GTK_WINDOW_TOPLEVEL
    
    GtkWidget* widget;
    GtkWidget* widget1;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget1 = gtk_window_new (WINDOW_TYPE_1);
    
    if (!widget1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget1))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_present (GTK_WINDOW (widget1));
    
    gtk_window_present (GTK_WINDOW (widget));
    g_object_get (GTK_OBJECT(widget), "visible", &visible, NULL);
    if (visible != TRUE)
    {
        TEST_FAIL ("presented window is not visible", NULL);
    }
    
    /******* VISUALISATION *******/
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (widget1);
    
    #undef WINDOW_TYPE 
    #undef WINDOW_TYPE_1 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_present
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Presents a window to the user.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void  
 */
static void test_purpose_131()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define WINDOW_TYPE_1  GTK_WINDOW_POPUP
    
    GtkWidget* widget;
    GtkWidget* widget1;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget1 = gtk_window_new (WINDOW_TYPE_1);
    
    if (!widget1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget1))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_present (GTK_WINDOW (widget1));
    
    gtk_window_present (GTK_WINDOW (widget));
    g_object_get (GTK_OBJECT(widget), "visible", &visible, NULL);
    if (visible != TRUE)
    {
        TEST_FAIL ("presented window is not visible", NULL);
    }
    
    /******* VISUALISATION *******/
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (widget1);
    
    #undef WINDOW_TYPE 
    #undef WINDOW_TYPE_1 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_present
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Presents a window to the user.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void  
 */
static void test_purpose_132()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define WINDOW_TYPE_1  GTK_WINDOW_POPUP
    
    GtkWidget* widget;
    GtkWidget* widget1;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget1 = gtk_window_new (WINDOW_TYPE_1);
    
    if (!widget1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget1))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_present (GTK_WINDOW (widget1));
    
    gtk_window_present (GTK_WINDOW (widget));
    g_object_get (GTK_OBJECT(widget), "visible", &visible, NULL);
    if (visible != TRUE)
    {
        TEST_FAIL ("presented window is not visible", NULL);
    }
    
    /******* VISUALISATION *******/
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (widget1);
    
    #undef WINDOW_TYPE 
    #undef WINDOW_TYPE_1 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_present
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Presents a window to the user.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void  
 */
static void test_purpose_133()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define WINDOW_TYPE_1  GTK_WINDOW_TOPLEVEL
    
    GtkWidget* widget;
    GtkWidget* widget1;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget1 = gtk_window_new (WINDOW_TYPE_1);
    
    if (!widget1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget1))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_present (GTK_WINDOW (widget1));
    
    gtk_window_present (GTK_WINDOW (widget));
    g_object_get (GTK_OBJECT(widget), "visible", &visible, NULL);
    if (visible != TRUE)
    {
        TEST_FAIL ("presented window is not visible", NULL);
    }
    
    /******* VISUALISATION *******/
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (widget1);
    
    #undef WINDOW_TYPE 
    #undef WINDOW_TYPE_1 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_present
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: If window is hidden, this function calls gtk_widget_show() as well.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void  
 */
static void test_purpose_134()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define WINDOW_TYPE_1  GTK_WINDOW_TOPLEVEL
    
    GtkWidget* widget;
    GtkWidget* widget1;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget1 = gtk_window_new (WINDOW_TYPE_1);
    
    if (!widget1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget1))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_present (GTK_WINDOW (widget1));
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_widget_hide (widget);
    gtk_window_present (GTK_WINDOW (widget));
    g_object_get (GTK_OBJECT(widget), "visible", &visible, NULL);
    if (visible != TRUE)
    {
        TEST_FAIL ("presented window is not visible", NULL);
    }
    
    /******* VISUALISATION *******/
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (widget1);
    
    #undef WINDOW_TYPE 
    #undef WINDOW_TYPE_1 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_present
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: If window is hidden, this function calls gtk_widget_show() as well.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void  
 */
static void test_purpose_135()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define WINDOW_TYPE_1  GTK_WINDOW_POPUP
    
    GtkWidget* widget;
    GtkWidget* widget1;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget1 = gtk_window_new (WINDOW_TYPE_1);
    
    if (!widget1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget1))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_present (GTK_WINDOW (widget1));
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_widget_hide (widget);
    gtk_window_present (GTK_WINDOW (widget));
    g_object_get (GTK_OBJECT(widget), "visible", &visible, NULL);
    if (visible != TRUE)
    {
        TEST_FAIL ("presented window is not visible", NULL);
    }
    
    /******* VISUALISATION *******/
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (widget1);
    
    #undef WINDOW_TYPE 
    #undef WINDOW_TYPE_1 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_present
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: If window is hidden, this function calls gtk_widget_show() as well.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void  
 */
static void test_purpose_136()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define WINDOW_TYPE_1  GTK_WINDOW_POPUP
    
    GtkWidget* widget;
    GtkWidget* widget1;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget1 = gtk_window_new (WINDOW_TYPE_1);
    
    if (!widget1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget1))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_present (GTK_WINDOW (widget1));
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_widget_hide (widget);
    gtk_window_present (GTK_WINDOW (widget));
    g_object_get (GTK_OBJECT(widget), "visible", &visible, NULL);
    if (visible != TRUE)
    {
        TEST_FAIL ("presented window is not visible", NULL);
    }
    
    /******* VISUALISATION *******/
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (widget1);
    
    #undef WINDOW_TYPE 
    #undef WINDOW_TYPE_1 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_present
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: If window is hidden, this function calls gtk_widget_show() as well.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void  
 */
static void test_purpose_137()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define WINDOW_TYPE_1  GTK_WINDOW_TOPLEVEL
    
    GtkWidget* widget;
    GtkWidget* widget1;
    gboolean visible;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget1 = gtk_window_new (WINDOW_TYPE_1);
    
    if (!widget1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget1))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_present (GTK_WINDOW (widget1));
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_widget_hide (widget);
    gtk_window_present (GTK_WINDOW (widget));
    g_object_get (GTK_OBJECT(widget), "visible", &visible, NULL);
    if (visible != TRUE)
    {
        TEST_FAIL ("presented window is not visible", NULL);
    }
    
    /******* VISUALISATION *******/
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (widget1);
    
    #undef WINDOW_TYPE 
    #undef WINDOW_TYPE_1 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_iconify
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Asks to iconify (i.e. minimize) the specified window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void
 * 
 * Name: gtk_window_iconify
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: It's permitted to call this function before showing a window, in which case the window will be iconified before it ever appears onscreen'
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void
 * 
 * Name: gtk_window_iconify
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: You can track iconification via the "window_state_event" signal on GtkWidget
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void  
 */
static void test_purpose_138()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_iter = 0;
    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "window_state_event",
                      GTK_SIGNAL_FUNC (global_window_state_event_handler), NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_iconify (GTK_WINDOW (widget));
    
    /*  due to #64949 bug
    
    if (global_iter != 1)
    {
        TEST_FAIL ("'window_state_event' signal was not emitted, global_iter = %d", global_iter);
    }
    */
    gtk_widget_destroy (widget);
    
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_iconify
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Asks to iconify (i.e. minimize) the specified window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void
 * 
 * Name: gtk_window_iconify
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: It's permitted to call this function before showing a window, in which case the window will be iconified before it ever appears onscreen'
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void
 * 
 * Name: gtk_window_iconify
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: You can track iconification via the "window_state_event" signal on GtkWidget
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void  
 */
static void test_purpose_139()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_iter = 0;
    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "window_state_event",
                      GTK_SIGNAL_FUNC (global_window_state_event_handler), NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_iconify (GTK_WINDOW (widget));
    
    /*  due to #64949 bug
    
    if (global_iter != 1)
    {
        TEST_FAIL ("'window_state_event' signal was not emitted, global_iter = %d", global_iter);
    }
    */
    gtk_widget_destroy (widget);
    
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_deiconify
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Asks to deiconify (i.e. unminimize) the specified window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void
 * 
 * Name: gtk_window_deiconify
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: You can track iconification via the "window_state_event" signal on GtkWidget
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void  
 */
static void test_purpose_140()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_iter = 0;
    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "window_state_event",
                      GTK_SIGNAL_FUNC (global_window_state_event_handler), NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_deiconify (GTK_WINDOW (widget));
    
    /*  due to #64949 bug
    
    if (global_iter != 1)
    {
        TEST_FAIL ("'window_state_event' signal was not emitted, global_iter = %d", global_iter);
    }
    */
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_deiconify
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Asks to deiconify (i.e. unminimize) the specified window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void
 * 
 * Name: gtk_window_deiconify
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: You can track iconification via the "window_state_event" signal on GtkWidget
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void  
 */
static void test_purpose_141()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_iter = 0;
    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "window_state_event",
                      GTK_SIGNAL_FUNC (global_window_state_event_handler), NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_deiconify (GTK_WINDOW (widget));
    
    /*  due to #64949 bug
    
    if (global_iter != 1)
    {
        TEST_FAIL ("'window_state_event' signal was not emitted, global_iter = %d", global_iter);
    }
    */
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_stick
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Asks to stick window, which means that it will appear on all user desktops.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void
 * 
 * Name:  gtk_window_stick
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: It's permitted to call this function before showing a window'
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void
 * 
 * Name:  gtk_window_stick
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: You can track stickiness via the "window_state_event" signal on GtkWidget
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void  
 */
static void test_purpose_142()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_iter = 0;
    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    g_signal_connect (G_OBJECT (widget), "window_state_event",
                      GTK_SIGNAL_FUNC (global_window_state_event_handler), NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_stick (GTK_WINDOW (widget));
    
    
    /*  due to #64949 bug
    
    if (global_iter != 1)
    {
        TEST_FAIL ("'window_state_event' signal was not emitted, global_iter = %d", global_iter);
    }
    */
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_stick
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Asks to stick window, which means that it will appear on all user desktops.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void
 * 
 * Name:  gtk_window_stick
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: It's permitted to call this function before showing a window'
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void
 * 
 * Name:  gtk_window_stick
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: You can track stickiness via the "window_state_event" signal on GtkWidget
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void  
 */
static void test_purpose_143()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_iter = 0;
    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    g_signal_connect (G_OBJECT (widget), "window_state_event",
                      GTK_SIGNAL_FUNC (global_window_state_event_handler), NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_stick (GTK_WINDOW (widget));
    
    
    /*  due to #64949 bug
    
    if (global_iter != 1)
    {
        TEST_FAIL ("'window_state_event' signal was not emitted, global_iter = %d", global_iter);
    }
    */
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_unstick
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Asks to unstick window, which means that it will appear on only one of the user's desktops.'
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void
 * 
 * Name:  gtk_window_unstick
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: You can track stickiness via the "window_state_event" signal on GtkWidget
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void  
 */
static void test_purpose_144()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_iter = 0;
    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    g_signal_connect (G_OBJECT (widget), "window_state_event",
                      GTK_SIGNAL_FUNC (global_window_state_event_handler), NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_unstick (GTK_WINDOW (widget));
    
    /*  due to #64949 bug
    
    if (global_iter != 1)
    {
        TEST_FAIL ("'window_state_event' signal was not emitted, global_iter = %d", global_iter);
    }
    */
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_unstick
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Asks to unstick window, which means that it will appear on only one of the user's desktops.'
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void
 * 
 * Name:  gtk_window_unstick
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: You can track stickiness via the "window_state_event" signal on GtkWidget
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void  
 */
static void test_purpose_145()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_iter = 0;
    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    g_signal_connect (G_OBJECT (widget), "window_state_event",
                      GTK_SIGNAL_FUNC (global_window_state_event_handler), NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_unstick (GTK_WINDOW (widget));
    
    /*  due to #64949 bug
    
    if (global_iter != 1)
    {
        TEST_FAIL ("'window_state_event' signal was not emitted, global_iter = %d", global_iter);
    }
    */
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_maximize
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Asks to maximize window, so that it becomes full-screen.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void
 * 
 * Name:  gtk_window_maximize
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: It's permitted to call this function before showing a window, in which case the window will be maximized when it appears onscreen initially'
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void
 * 
 * Name:  gtk_window_maximize
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: You can track maximization via the "window_state_event" signal on GtkWidget
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void  
 */
static void test_purpose_146()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_iter = 0;
    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "window_state_event",
                      GTK_SIGNAL_FUNC (global_window_state_event_handler), NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_maximize (GTK_WINDOW (widget));
    
    /*  due to #64949 bug
    
    if (global_iter != 1)
    {
        TEST_FAIL ("'window_state_event' signal was not emitted, global_iter = %d", global_iter);
    }
    */
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_maximize
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Asks to maximize window, so that it becomes full-screen.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void
 * 
 * Name:  gtk_window_maximize
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: It's permitted to call this function before showing a window, in which case the window will be maximized when it appears onscreen initially'
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void
 * 
 * Name:  gtk_window_maximize
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: You can track maximization via the "window_state_event" signal on GtkWidget
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void  
 */
static void test_purpose_147()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_iter = 0;
    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "window_state_event",
                      GTK_SIGNAL_FUNC (global_window_state_event_handler), NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_maximize (GTK_WINDOW (widget));
    
    /*  due to #64949 bug
    
    if (global_iter != 1)
    {
        TEST_FAIL ("'window_state_event' signal was not emitted, global_iter = %d", global_iter);
    }
    */
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_unmaximize
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Asks to unmaximize window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void
 * 
 * Name:  gtk_window_unmaximize
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: You can track maximization via the "window_state_event" signal on GtkWidget
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void  
 */
static void test_purpose_148()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_iter = 0;
    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "window_state_event",
                      GTK_SIGNAL_FUNC (global_window_state_event_handler), NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_unmaximize (GTK_WINDOW (widget));
    
    /*  due to #64949 bug
    
    if (global_iter != 1)
    {
        TEST_FAIL ("'window_state_event' signal was not emitted, global_iter = %d", global_iter);
    }
    */
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_unmaximize
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Asks to unmaximize window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void
 * 
 * Name:  gtk_window_unmaximize
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: You can track maximization via the "window_state_event" signal on GtkWidget
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void  
 */
static void test_purpose_149()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_iter = 0;
    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    g_signal_connect (G_OBJECT (widget), "window_state_event",
                      GTK_SIGNAL_FUNC (global_window_state_event_handler), NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_unmaximize (GTK_WINDOW (widget));
    
    /*  due to #64949 bug
    
    if (global_iter != 1)
    {
        TEST_FAIL ("'window_state_event' signal was not emitted, global_iter = %d", global_iter);
    }
    */
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_resize_drag
 * Params: GtkWindow *window, GdkWindowEdge edge, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts resizing a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, GDK_WINDOW_EDGE_NORTH_WEST, 1, 0,0,1
 * Expected: void  
 */
static void test_purpose_150()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define EDGE  GDK_WINDOW_EDGE_NORTH_WEST
    #define BUTTON  1
    #define ROOT_X  0
    #define ROOT_Y  0
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_resize_drag (GTK_WINDOW (widget), EDGE, BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef EDGE
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_resize_drag
 * Params: GtkWindow *window, GdkWindowEdge edge, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts resizing a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_WINDOW_EDGE_NORTH_WEST, 1, 0,0,1
 * Expected: void  
 */
static void test_purpose_151()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define EDGE  GDK_WINDOW_EDGE_NORTH_WEST
    #define BUTTON  1
    #define ROOT_X  0
    #define ROOT_Y  0
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_resize_drag (GTK_WINDOW (widget), EDGE, BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef EDGE
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_resize_drag
 * Params: GtkWindow *window, GdkWindowEdge edge, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts resizing a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_WINDOW_EDGE_NORTH, 1, 0,0,1
 * Expected: void  
 */
static void test_purpose_152()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define EDGE  GDK_WINDOW_EDGE_NORTH
    #define BUTTON  1
    #define ROOT_X  0
    #define ROOT_Y  0
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_resize_drag (GTK_WINDOW (widget), EDGE, BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef EDGE
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_resize_drag
 * Params: GtkWindow *window, GdkWindowEdge edge, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts resizing a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_WINDOW_EDGE_NORTH_EAST, 1, 0,0,1
 * Expected: void  
 */
static void test_purpose_153()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define EDGE  GDK_WINDOW_EDGE_NORTH_EAST
    #define BUTTON  1
    #define ROOT_X  0
    #define ROOT_Y  0
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_resize_drag (GTK_WINDOW (widget), EDGE, BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef EDGE
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_resize_drag
 * Params: GtkWindow *window, GdkWindowEdge edge, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts resizing a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_WINDOW_EDGE_WEST, 1, 0,0,1
 * Expected: void  
 */
static void test_purpose_154()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define EDGE  GDK_WINDOW_EDGE_WEST
    #define BUTTON  1
    #define ROOT_X  0
    #define ROOT_Y  0
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_resize_drag (GTK_WINDOW (widget), EDGE, BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef EDGE
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_resize_drag
 * Params: GtkWindow *window, GdkWindowEdge edge, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts resizing a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_WINDOW_EDGE_EAST, 1, 0,0,1
 * Expected: void  
 */
static void test_purpose_155()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define EDGE  GDK_WINDOW_EDGE_EAST
    #define BUTTON  1
    #define ROOT_X  0
    #define ROOT_Y  0
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_resize_drag (GTK_WINDOW (widget), EDGE, BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef EDGE
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_resize_drag
 * Params: GtkWindow *window, GdkWindowEdge edge, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts resizing a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_WINDOW_EDGE_SOUTH_EAST, 1, 0,0,1
 * Expected: void  
 */
static void test_purpose_156()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define EDGE  GDK_WINDOW_EDGE_SOUTH_EAST
    #define BUTTON  1
    #define ROOT_X  0
    #define ROOT_Y  0
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_resize_drag (GTK_WINDOW (widget), EDGE, BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef EDGE
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_resize_drag
 * Params: GtkWindow *window, GdkWindowEdge edge, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts resizing a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_WINDOW_EDGE_SOUTH, 1, 0,0,1
 * Expected: void  
 */
static void test_purpose_157()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define EDGE  GDK_WINDOW_EDGE_SOUTH
    #define BUTTON  1
    #define ROOT_X  0
    #define ROOT_Y  0
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_resize_drag (GTK_WINDOW (widget), EDGE, BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef EDGE
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_resize_drag
 * Params: GtkWindow *window, GdkWindowEdge edge, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts resizing a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_WINDOW_EDGE_SOUTH_WEST, 1, 0,0,1
 * Expected: void  
 */
static void test_purpose_158()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define EDGE  GDK_WINDOW_EDGE_SOUTH_WEST
    #define BUTTON  1
    #define ROOT_X  0
    #define ROOT_Y  0
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_resize_drag (GTK_WINDOW (widget), EDGE, BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef EDGE
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_resize_drag
 * Params: GtkWindow *window, GdkWindowEdge edge, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts resizing a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_WINDOW_EDGE_SOUTH_WEST, 2, 0,0,1
 * Expected: void  
 */
static void test_purpose_159()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define EDGE  GDK_WINDOW_EDGE_SOUTH_WEST
    #define BUTTON  2
    #define ROOT_X  0
    #define ROOT_Y  0
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_resize_drag (GTK_WINDOW (widget), EDGE, BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef EDGE
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_resize_drag
 * Params: GtkWindow *window, GdkWindowEdge edge, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts resizing a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_WINDOW_EDGE_SOUTH_WEST, 3, 0,0,1
 * Expected: void  
 */
static void test_purpose_160()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define EDGE  GDK_WINDOW_EDGE_SOUTH_WEST
    #define BUTTON  3
    #define ROOT_X  0
    #define ROOT_Y  0
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_resize_drag (GTK_WINDOW (widget), EDGE, BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef EDGE
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_resize_drag
 * Params: GtkWindow *window, GdkWindowEdge edge, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts resizing a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_WINDOW_EDGE_SOUTH_WEST, 3, 1000,0,1
 * Expected: void  
 */
static void test_purpose_161()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define EDGE  GDK_WINDOW_EDGE_SOUTH_WEST
    #define BUTTON  3
    #define ROOT_X  1000
    #define ROOT_Y  0
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_resize_drag (GTK_WINDOW (widget), EDGE, BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef EDGE
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_resize_drag
 * Params: GtkWindow *window, GdkWindowEdge edge, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts resizing a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_WINDOW_EDGE_SOUTH_WEST, 3, 0,1000,1
 * Expected: void  
 */
static void test_purpose_162()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define EDGE  GDK_WINDOW_EDGE_SOUTH_WEST
    #define BUTTON  3
    #define ROOT_X  0
    #define ROOT_Y  1000
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_resize_drag (GTK_WINDOW (widget), EDGE, BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef EDGE
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_resize_drag
 * Params: GtkWindow *window, GdkWindowEdge edge, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts resizing a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_WINDOW_EDGE_SOUTH_WEST, 3, 3000,3000,1
 * Expected: void  
 */
static void test_purpose_163()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define EDGE  GDK_WINDOW_EDGE_SOUTH_WEST
    #define BUTTON  3
    #define ROOT_X  3000
    #define ROOT_Y  3000
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_resize_drag (GTK_WINDOW (widget), EDGE, BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef EDGE
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_resize_drag
 * Params: GtkWindow *window, GdkWindowEdge edge, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts resizing a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_WINDOW_EDGE_SOUTH_WEST, 3, 3000,3000,3000
 * Expected: void  
 */
static void test_purpose_164()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define EDGE  GDK_WINDOW_EDGE_SOUTH_WEST
    #define BUTTON  3
    #define ROOT_X  3000
    #define ROOT_Y  3000
    #define TIMESTAMP  3000
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_resize_drag (GTK_WINDOW (widget), EDGE, BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef EDGE
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_move_drag
 * Params: GtkWindow *window, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts moving a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, 1, 0, 0,1,<%5%>,
 * Expected: void  
 */
static void test_purpose_165()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define BUTTON  1
    #define ROOT_X  0
    #define ROOT_Y  0
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_move_drag (GTK_WINDOW (widget), BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_move_drag
 * Params: GtkWindow *window, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts moving a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 1, 0, 0,1,<%5%>,
 * Expected: void  
 */
static void test_purpose_166()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define BUTTON  1
    #define ROOT_X  0
    #define ROOT_Y  0
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_move_drag (GTK_WINDOW (widget), BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_move_drag
 * Params: GtkWindow *window, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts moving a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 2, 0, 0,1,<%5%>,
 * Expected: void  
 */
static void test_purpose_167()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define BUTTON  2
    #define ROOT_X  0
    #define ROOT_Y  0
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_move_drag (GTK_WINDOW (widget), BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_move_drag
 * Params: GtkWindow *window, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts moving a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 3, 0, 0,1,<%5%>,
 * Expected: void  
 */
static void test_purpose_168()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define BUTTON  3
    #define ROOT_X  0
    #define ROOT_Y  0
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_move_drag (GTK_WINDOW (widget), BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_move_drag
 * Params: GtkWindow *window, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts moving a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 3, 1000, 0,1,<%5%>,
 * Expected: void  
 */
static void test_purpose_169()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define BUTTON  3
    #define ROOT_X  1000
    #define ROOT_Y  0
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_move_drag (GTK_WINDOW (widget), BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_move_drag
 * Params: GtkWindow *window, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts moving a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 3, 0, 1000,1,<%5%>,
 * Expected: void  
 */
static void test_purpose_170()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define BUTTON  3
    #define ROOT_X  0
    #define ROOT_Y  1000
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_move_drag (GTK_WINDOW (widget), BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_move_drag
 * Params: GtkWindow *window, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts moving a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 3, 3000, 3000,1,<%5%>,
 * Expected: void  
 */
static void test_purpose_171()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define BUTTON  3
    #define ROOT_X  3000
    #define ROOT_Y  3000
    #define TIMESTAMP  1
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_move_drag (GTK_WINDOW (widget), BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_begin_move_drag
 * Params: GtkWindow *window, gint button, gint root_x, gint root_y, guint32 timestamp
 * Returns: void
 * Assertion: Starts moving a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 3, 3000, 3000,3000,<%5%>,
 * Expected: void  
 */
static void test_purpose_172()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define BUTTON  3
    #define ROOT_X  3000
    #define ROOT_Y  3000
    #define TIMESTAMP  3000
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_present (GTK_WINDOW (widget));
    gtk_window_begin_move_drag (GTK_WINDOW (widget), BUTTON, ROOT_X, ROOT_Y, TIMESTAMP);
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef BUTTON
    #undef ROOT_X
    #undef ROOT_Y
    #undef TIMESTAMP
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_position
 * Params: GtkWindow *window, gint *root_x, gint *root_y
 * Returns: void
 * Assertion: This function returns the position you need to pass to gtk_window_move() to keep window in its current position.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, gint*, gint*
 * Expected: void
 * 
 * Name:  gtk_window_get_position
 * Params: GtkWindow *window, gint *root_x, gint *root_y
 * Returns: void
 * Assertion: If you haven't changed the window gravity, its gravity will be GDK_GRAVITY_NORTH_WEST'
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, gint*, gint*
 * Expected: void  
 */
static void test_purpose_173()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    
    GtkWidget* widget;
    gint x1;
    gint y1;
    gint x2;
    gint y2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (gtk_window_get_gravity (GTK_WINDOW (widget)) != GDK_GRAVITY_NORTH_WEST)
    {
        TEST_FAIL ("'gravity' should be GDK_GRAVITY_NORTH_WEST", NULL);
    }
    
    gtk_window_get_position (GTK_WINDOW (widget), &x1, &y1);
    gtk_window_move (GTK_WINDOW (widget), x1, y1);
    gtk_window_get_position (GTK_WINDOW (widget), &x2, &y2);
    
    
    if (x1 != x2) {
        TEST_FAIL ("x1 = %d, x2 = %d, they should be equal", x1, x2);
    }
    
    if (y1 != y2) {
        TEST_FAIL ("y1 = %d, y2 = %d, they should be equal", y1, y2);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_position
 * Params: GtkWindow *window, gint *root_x, gint *root_y
 * Returns: void
 * Assertion: This function returns the position you need to pass to gtk_window_move() to keep window in its current position.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, gint*, gint*
 * Expected: void
 * 
 * Name:  gtk_window_get_position
 * Params: GtkWindow *window, gint *root_x, gint *root_y
 * Returns: void
 * Assertion: If you haven't changed the window gravity, its gravity will be GDK_GRAVITY_NORTH_WEST'
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, gint*, gint*
 * Expected: void  
 */
static void test_purpose_174()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    
    GtkWidget* widget;
    gint x1;
    gint y1;
    gint x2;
    gint y2;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (gtk_window_get_gravity (GTK_WINDOW (widget)) != GDK_GRAVITY_NORTH_WEST)
    {
        TEST_FAIL ("'gravity' should be GDK_GRAVITY_NORTH_WEST", NULL);
    }
    
    gtk_window_get_position (GTK_WINDOW (widget), &x1, &y1);
    gtk_window_move (GTK_WINDOW (widget), x1, y1);
    gtk_window_get_position (GTK_WINDOW (widget), &x2, &y2);
    
    
    if (x1 != x2) {
        TEST_FAIL ("x1 = %d, x2 = %d, they should be equal", x1, x2);
    }
    
    if (y1 != y2) {
        TEST_FAIL ("y1 = %d, y2 = %d, they should be equal", y1, y2);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_size
 * Params: GtkWindow *window, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the current size of window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 100, 100
 * Expected: void  
 */
static void test_purpose_175()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define WIDTH  100
    #define HEIGHT 100
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_window_resize (GTK_WINDOW (widget), WIDTH, HEIGHT);
    gtk_window_get_size (GTK_WINDOW (widget), &width, &height);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (width != WIDTH) 
    {
        TEST_FAIL ("width is %d, should be %d", width, WIDTH);
    }
    
    if (height != HEIGHT) 
    {
        TEST_FAIL ("height is %d, should be %d", height, HEIGHT);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_size
 * Params: GtkWindow *window, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the current size of window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 1, 1
 * Expected: void  
 */
static void test_purpose_176()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define WIDTH  1
    #define HEIGHT 1
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_window_resize (GTK_WINDOW (widget), WIDTH, HEIGHT);
    gtk_window_get_size (GTK_WINDOW (widget), &width, &height);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (width != WIDTH) 
    {
        TEST_FAIL ("width is %d, should be %d", width, WIDTH);
    }
    
    if (height != HEIGHT) 
    {
        TEST_FAIL ("height is %d, should be %d", height, HEIGHT);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_size
 * Params: GtkWindow *window, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the current size of window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 300, 50
 * Expected: void  
 */
static void test_purpose_177()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define WIDTH  300
    #define HEIGHT 50
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_window_resize (GTK_WINDOW (widget), WIDTH, HEIGHT);
    gtk_window_get_size (GTK_WINDOW (widget), &width, &height);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (width != WIDTH) 
    {
        TEST_FAIL ("width is %d, should be %d", width, WIDTH);
    }
    
    if (height != HEIGHT) 
    {
        TEST_FAIL ("height is %d, should be %d", height, HEIGHT);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_size
 * Params: GtkWindow *window, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the current size of window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, 200, 200
 * Expected: void  
 */
static void test_purpose_178()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define WIDTH  200
    #define HEIGHT 200
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_window_resize (GTK_WINDOW (widget), WIDTH, HEIGHT);
    gtk_window_get_size (GTK_WINDOW (widget), &width, &height);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (width != WIDTH) 
    {
        TEST_FAIL ("width is %d, should be %d", width, WIDTH);
    }
    
    if (height != HEIGHT) 
    {
        TEST_FAIL ("height is %d, should be %d", height, HEIGHT);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_size
 * Params: GtkWindow *window, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the current size of window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, 20, 10
 * Expected: void  
 */
static void test_purpose_179()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define WIDTH  20
    #define HEIGHT 10
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_window_resize (GTK_WINDOW (widget), WIDTH, HEIGHT);
    gtk_window_get_size (GTK_WINDOW (widget), &width, &height);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (width != WIDTH) 
    {
        TEST_FAIL ("width is %d, should be %d", width, WIDTH);
    }
    
    if (height != HEIGHT) 
    {
        TEST_FAIL ("height is %d, should be %d", height, HEIGHT);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_size
 * Params: GtkWindow *window, gint *width, gint *height
 * Returns: void
 * Assertion: Obtains the current size of window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, 1, 1
 * Expected: void  
 */
static void test_purpose_180()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define WIDTH  1
    #define HEIGHT 1
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    gtk_window_resize (GTK_WINDOW (widget), WIDTH, HEIGHT);
    gtk_window_get_size (GTK_WINDOW (widget), &width, &height);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (width != WIDTH) 
    {
        TEST_FAIL ("width is %d, should be %d", width, WIDTH);
    }
    
    if (height != HEIGHT) 
    {
        TEST_FAIL ("height is %d, should be %d", height, HEIGHT);
    }
    
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: Asks the window manager to move window to the given position.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 0
 * Expected: void
 * 
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: The top-left corner of the window decorations (aka window frame or border) will be placed at x, y
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 0
 * Expected: void
 * 
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: By default the gravity is GDK_GRAVITY_NORTH_WEST, so the reference point is simply the x, y supplied to gtk_window_move()
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 0
 * Expected: void  
 */
static void test_purpose_181()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define X 0
    #define Y 0
    
    GtkWidget* widget;
    gint xpos;
    gint ypos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_window_get_gravity (GTK_WINDOW (widget)) != GDK_GRAVITY_NORTH_WEST)
    {
        TEST_FAIL ("default gravity should be GDK_GRAVITY_NORTH_WEST", NULL);
    }
    
    gtk_window_move (GTK_WINDOW (widget), X, Y);
    
    gtk_window_get_position (GTK_WINDOW (widget), &xpos, &ypos);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((xpos != X) || (ypos != Y))
    {
        TEST_FAIL ("window position = (%i, %i), should be (%i, %i)", xpos, ypos, X, Y);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: Asks the window manager to move window to the given position.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 49
 * Expected: void
 * 
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: The top-left corner of the window decorations (aka window frame or border) will be placed at x, y
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 49
 * Expected: void
 * 
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: By default the gravity is GDK_GRAVITY_NORTH_WEST, so the reference point is simply the x, y supplied to gtk_window_move()
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, 0, 49
 * Expected: void  
 */
static void test_purpose_182()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define X 0
    #define Y 49
    
    GtkWidget* widget;
    gint xpos;
    gint ypos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_window_get_gravity (GTK_WINDOW (widget)) != GDK_GRAVITY_NORTH_WEST)
    {
        TEST_FAIL ("default gravity should be GDK_GRAVITY_NORTH_WEST", NULL);
    }
    
    gtk_window_move (GTK_WINDOW (widget), X, Y);
    
    gtk_window_get_position (GTK_WINDOW (widget), &xpos, &ypos);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((xpos != X) || (ypos != Y))
    {
        TEST_FAIL ("window position = (%i, %i), should be (%i, %i)", xpos, ypos, X, Y);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: Asks the window manager to move window to the given position.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, ( gdk_screen_width() / 4 ), ( gdk_screen_height() / 4 )
 * Expected: void
 * 
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: The top-left corner of the window decorations (aka window frame or border) will be placed at x, y
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, ( gdk_screen_width() / 4 ), ( gdk_screen_height() / 4 )
 * Expected: void
 * 
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: By default the gravity is GDK_GRAVITY_NORTH_WEST, so the reference point is simply the x, y supplied to gtk_window_move()
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, ( gdk_screen_width() / 4 ), ( gdk_screen_height() / 4 )
 * Expected: void  
 */
static void test_purpose_183()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define X ( gdk_screen_width() / 4 )
    #define Y ( gdk_screen_height() / 4 )
    
    GtkWidget* widget;
    gint xpos;
    gint ypos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_window_get_gravity (GTK_WINDOW (widget)) != GDK_GRAVITY_NORTH_WEST)
    {
        TEST_FAIL ("default gravity should be GDK_GRAVITY_NORTH_WEST", NULL);
    }
    
    gtk_window_move (GTK_WINDOW (widget), X, Y);
    
    gtk_window_get_position (GTK_WINDOW (widget), &xpos, &ypos);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((xpos != X) || (ypos != Y))
    {
        TEST_FAIL ("window position = (%i, %i), should be (%i, %i)", xpos, ypos, X, Y);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: Asks the window manager to move window to the given position.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, ( gdk_screen_width() / 2 ), ( gdk_screen_height() / 2 )
 * Expected: void
 * 
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: The top-left corner of the window decorations (aka window frame or border) will be placed at x, y
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, ( gdk_screen_width() / 2 ), ( gdk_screen_height() / 2 )
 * Expected: void
 * 
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: By default the gravity is GDK_GRAVITY_NORTH_WEST, so the reference point is simply the x, y supplied to gtk_window_move()
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, ( gdk_screen_width() / 2 ), ( gdk_screen_height() / 2 )
 * Expected: void  
 */
static void test_purpose_184()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define X ( gdk_screen_width() / 2 )
    #define Y ( gdk_screen_height() / 2 )
    
    GtkWidget* widget;
    gint xpos;
    gint ypos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_window_get_gravity (GTK_WINDOW (widget)) != GDK_GRAVITY_NORTH_WEST)
    {
        TEST_FAIL ("default gravity should be GDK_GRAVITY_NORTH_WEST", NULL);
    }
    
    gtk_window_move (GTK_WINDOW (widget), X, Y);
    
    gtk_window_get_position (GTK_WINDOW (widget), &xpos, &ypos);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((xpos != X) || (ypos != Y))
    {
        TEST_FAIL ("window position = (%i, %i), should be (%i, %i)", xpos, ypos, X, Y);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: Asks the window manager to move window to the given position.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, 0, 0
 * Expected: void
 * 
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: The top-left corner of the window decorations (aka window frame or border) will be placed at x, y
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, 0, 0
 * Expected: void
 * 
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: By default the gravity is GDK_GRAVITY_NORTH_WEST, so the reference point is simply the x, y supplied to gtk_window_move()
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, 0, 0
 * Expected: void  
 */
static void test_purpose_185()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define X 0
    #define Y 0
    
    GtkWidget* widget;
    gint xpos;
    gint ypos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_window_get_gravity (GTK_WINDOW (widget)) != GDK_GRAVITY_NORTH_WEST)
    {
        TEST_FAIL ("default gravity should be GDK_GRAVITY_NORTH_WEST", NULL);
    }
    
    gtk_window_move (GTK_WINDOW (widget), X, Y);
    
    gtk_window_get_position (GTK_WINDOW (widget), &xpos, &ypos);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((xpos != X) || (ypos != Y))
    {
        TEST_FAIL ("window position = (%i, %i), should be (%i, %i)", xpos, ypos, X, Y);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: Asks the window manager to move window to the given position.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, 0, 49
 * Expected: void
 * 
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: The top-left corner of the window decorations (aka window frame or border) will be placed at x, y
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, 0, 49
 * Expected: void
 * 
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: By default the gravity is GDK_GRAVITY_NORTH_WEST, so the reference point is simply the x, y supplied to gtk_window_move()
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, 0, 49
 * Expected: void  
 */
static void test_purpose_186()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define X 0
    #define Y 49
    
    GtkWidget* widget;
    gint xpos;
    gint ypos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_window_get_gravity (GTK_WINDOW (widget)) != GDK_GRAVITY_NORTH_WEST)
    {
        TEST_FAIL ("default gravity should be GDK_GRAVITY_NORTH_WEST", NULL);
    }
    
    gtk_window_move (GTK_WINDOW (widget), X, Y);
    
    gtk_window_get_position (GTK_WINDOW (widget), &xpos, &ypos);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((xpos != X) || (ypos != Y))
    {
        TEST_FAIL ("window position = (%i, %i), should be (%i, %i)", xpos, ypos, X, Y);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: Asks the window manager to move window to the given position.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, ( gdk_screen_width() / 4 ), ( gdk_screen_height() / 4 )
 * Expected: void
 * 
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: The top-left corner of the window decorations (aka window frame or border) will be placed at x, y
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, ( gdk_screen_width() / 4 ), ( gdk_screen_height() / 4 )
 * Expected: void
 * 
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: By default the gravity is GDK_GRAVITY_NORTH_WEST, so the reference point is simply the x, y supplied to gtk_window_move()
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, ( gdk_screen_width() / 4 ), ( gdk_screen_height() / 4 )
 * Expected: void  
 */
static void test_purpose_187()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define X ( gdk_screen_width() / 4 )
    #define Y ( gdk_screen_height() / 4 )
    
    GtkWidget* widget;
    gint xpos;
    gint ypos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_window_get_gravity (GTK_WINDOW (widget)) != GDK_GRAVITY_NORTH_WEST)
    {
        TEST_FAIL ("default gravity should be GDK_GRAVITY_NORTH_WEST", NULL);
    }
    
    gtk_window_move (GTK_WINDOW (widget), X, Y);
    
    gtk_window_get_position (GTK_WINDOW (widget), &xpos, &ypos);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((xpos != X) || (ypos != Y))
    {
        TEST_FAIL ("window position = (%i, %i), should be (%i, %i)", xpos, ypos, X, Y);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: Asks the window manager to move window to the given position.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, ( gdk_screen_width() / 2 ), ( gdk_screen_height() / 2 )
 * Expected: void
 * 
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: The top-left corner of the window decorations (aka window frame or border) will be placed at x, y
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, ( gdk_screen_width() / 2 ), ( gdk_screen_height() / 2 )
 * Expected: void
 * 
 * Name:  gtk_window_move
 * Params: GtkWindow *window, gint x, gint y
 * Returns: void
 * Assertion: By default the gravity is GDK_GRAVITY_NORTH_WEST, so the reference point is simply the x, y supplied to gtk_window_move()
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, ( gdk_screen_width() / 2 ), ( gdk_screen_height() / 2 )
 * Expected: void  
 */
static void test_purpose_188()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define X ( gdk_screen_width() / 2 )
    #define Y ( gdk_screen_height() / 2 )
    
    GtkWidget* widget;
    gint xpos;
    gint ypos;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (gtk_window_get_gravity (GTK_WINDOW (widget)) != GDK_GRAVITY_NORTH_WEST)
    {
        TEST_FAIL ("default gravity should be GDK_GRAVITY_NORTH_WEST", NULL);
    }
    
    gtk_window_move (GTK_WINDOW (widget), X, Y);
    
    gtk_window_get_position (GTK_WINDOW (widget), &xpos, &ypos);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((xpos != X) || (ypos != Y))
    {
        TEST_FAIL ("window position = (%i, %i), should be (%i, %i)", xpos, ypos, X, Y);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef X
    #undef Y
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: Parses a standard X Window System geometry string - see the manual page for X (type 'man X') for details on this
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "999x1000+5+10"
 * Expected: TRUE
 * 
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: If gtk_window_parse_geometry() returns TRUE, it will also set the GDK_HINT_USER_POS and/or GDK_HINT_USER_SIZE hints indicating to the window manager that the size/position of the window was user-specified 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "999x1000+5+10"
 * Expected: TRUE
 * 
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: If either a size or a position can be extracted from the geometry string, gtk_window_parse_geometry() returns TRUE and calls gtk_window_set_default_size() and/or gtk_window_move() to resize/move the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "999x1000+5+10"
 * Expected: TRUE  
 */
static void test_purpose_189()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define GEOMETRY "999x1000+5+10"
    #define CORRECT_DEFAULT_WIDTH 999
    #define CORRECT_DEFAULT_HEIGHT 1000
    #define CORRECT_RESULT TRUE
    
    
    GtkWidget* widget;
    gboolean result;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    result = gtk_window_parse_geometry (GTK_WINDOW (widget), GEOMETRY);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (result != CORRECT_RESULT)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RESULT);
        return;
    }
    
    gtk_window_get_default_size (GTK_WINDOW (widget), &width, &height);
    if (width != CORRECT_DEFAULT_WIDTH)
    {
        TEST_FAIL ("default width = %d, should be %d" , 
                   width, CORRECT_DEFAULT_WIDTH);
    }
    if (height != CORRECT_DEFAULT_HEIGHT)
    {
        TEST_FAIL ("default height = %d, should be %d" , 
                   height, CORRECT_DEFAULT_HEIGHT);
    }
    
    if (result)
    {
        XSizeHints hints;
        glong junk = 1;
    
        if (!XGetWMNormalHints (GDK_WINDOW_XDISPLAY (widget->window), GDK_WINDOW_XID (widget->window), 
                                &hints, &junk))
        {
            TEST_FAIL ("can't obtain flags", NULL);
        }
        if (!((hints.flags & USPosition) || (hints.flags & USSize)))
        {
            TEST_FAIL ("GDK_HINT_USER_POS or GDK_HINT_USER_SIZE flags doesn't set 0x%x", hints.flags);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef GEOMETRY
    #undef CORRECT_DEFAULT_WIDTH
    #undef CORRECT_DEFAULT_HEIGHT
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: Parses a standard X Window System geometry string - see the manual page for X (type 'man X') for details on this
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "0x1000+5+10"
 * Expected: TRUE
 * 
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: If gtk_window_parse_geometry() returns TRUE, it will also set the GDK_HINT_USER_POS and/or GDK_HINT_USER_SIZE hints indicating to the window manager that the size/position of the window was user-specified 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "0x1000+5+10"
 * Expected: TRUE
 * 
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: If either a size or a position can be extracted from the geometry string, gtk_window_parse_geometry() returns TRUE and calls gtk_window_set_default_size() and/or gtk_window_move() to resize/move the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "0x1000+5+10"
 * Expected: TRUE  
 */
static void test_purpose_190()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define GEOMETRY "0x1000+5+10"
    #define CORRECT_DEFAULT_WIDTH 1
    #define CORRECT_DEFAULT_HEIGHT 1000
    #define CORRECT_RESULT TRUE
    
    
    GtkWidget* widget;
    gboolean result;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    result = gtk_window_parse_geometry (GTK_WINDOW (widget), GEOMETRY);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (result != CORRECT_RESULT)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RESULT);
        return;
    }
    
    gtk_window_get_default_size (GTK_WINDOW (widget), &width, &height);
    if (width != CORRECT_DEFAULT_WIDTH)
    {
        TEST_FAIL ("default width = %d, should be %d" , 
                   width, CORRECT_DEFAULT_WIDTH);
    }
    if (height != CORRECT_DEFAULT_HEIGHT)
    {
        TEST_FAIL ("default height = %d, should be %d" , 
                   height, CORRECT_DEFAULT_HEIGHT);
    }
    
    if (result)
    {
        XSizeHints hints;
        glong junk = 1;
    
        if (!XGetWMNormalHints (GDK_WINDOW_XDISPLAY (widget->window), GDK_WINDOW_XID (widget->window), 
                                &hints, &junk))
        {
            TEST_FAIL ("can't obtain flags", NULL);
        }
        if (!((hints.flags & USPosition) || (hints.flags & USSize)))
        {
            TEST_FAIL ("GDK_HINT_USER_POS or GDK_HINT_USER_SIZE flags doesn't set 0x%x", hints.flags);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef GEOMETRY
    #undef CORRECT_DEFAULT_WIDTH
    #undef CORRECT_DEFAULT_HEIGHT
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: Parses a standard X Window System geometry string - see the manual page for X (type 'man X') for details on this
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "999x0+5+10"
 * Expected: TRUE
 * 
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: If gtk_window_parse_geometry() returns TRUE, it will also set the GDK_HINT_USER_POS and/or GDK_HINT_USER_SIZE hints indicating to the window manager that the size/position of the window was user-specified 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "999x0+5+10"
 * Expected: TRUE
 * 
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: If either a size or a position can be extracted from the geometry string, gtk_window_parse_geometry() returns TRUE and calls gtk_window_set_default_size() and/or gtk_window_move() to resize/move the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "999x0+5+10"
 * Expected: TRUE  
 */
static void test_purpose_191()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define GEOMETRY "999x0+5+10"
    #define CORRECT_DEFAULT_WIDTH 999
    #define CORRECT_DEFAULT_HEIGHT 1
    #define CORRECT_RESULT TRUE
    
    
    GtkWidget* widget;
    gboolean result;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    result = gtk_window_parse_geometry (GTK_WINDOW (widget), GEOMETRY);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (result != CORRECT_RESULT)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RESULT);
        return;
    }
    
    gtk_window_get_default_size (GTK_WINDOW (widget), &width, &height);
    if (width != CORRECT_DEFAULT_WIDTH)
    {
        TEST_FAIL ("default width = %d, should be %d" , 
                   width, CORRECT_DEFAULT_WIDTH);
    }
    if (height != CORRECT_DEFAULT_HEIGHT)
    {
        TEST_FAIL ("default height = %d, should be %d" , 
                   height, CORRECT_DEFAULT_HEIGHT);
    }
    
    if (result)
    {
        XSizeHints hints;
        glong junk = 1;
    
        if (!XGetWMNormalHints (GDK_WINDOW_XDISPLAY (widget->window), GDK_WINDOW_XID (widget->window), 
                                &hints, &junk))
        {
            TEST_FAIL ("can't obtain flags", NULL);
        }
        if (!((hints.flags & USPosition) || (hints.flags & USSize)))
        {
            TEST_FAIL ("GDK_HINT_USER_POS or GDK_HINT_USER_SIZE flags doesn't set 0x%x", hints.flags);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef GEOMETRY
    #undef CORRECT_DEFAULT_WIDTH
    #undef CORRECT_DEFAULT_HEIGHT
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: Parses a standard X Window System geometry string - see the manual page for X (type 'man X') for details on this
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "rx1000+5+10"
 * Expected: FALSE
 * 
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: If gtk_window_parse_geometry() returns TRUE, it will also set the GDK_HINT_USER_POS and/or GDK_HINT_USER_SIZE hints indicating to the window manager that the size/position of the window was user-specified 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "rx1000+5+10"
 * Expected: FALSE
 * 
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: If either a size or a position can be extracted from the geometry string, gtk_window_parse_geometry() returns TRUE and calls gtk_window_set_default_size() and/or gtk_window_move() to resize/move the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "rx1000+5+10"
 * Expected: FALSE  
 */
static void test_purpose_192()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define GEOMETRY "rx1000+5+10"
    #define CORRECT_DEFAULT_WIDTH -1
    #define CORRECT_DEFAULT_HEIGHT -1
    #define CORRECT_RESULT FALSE
    
    
    GtkWidget* widget;
    gboolean result;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    result = gtk_window_parse_geometry (GTK_WINDOW (widget), GEOMETRY);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (result != CORRECT_RESULT)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RESULT);
        return;
    }
    
    gtk_window_get_default_size (GTK_WINDOW (widget), &width, &height);
    if (width != CORRECT_DEFAULT_WIDTH)
    {
        TEST_FAIL ("default width = %d, should be %d" , 
                   width, CORRECT_DEFAULT_WIDTH);
    }
    if (height != CORRECT_DEFAULT_HEIGHT)
    {
        TEST_FAIL ("default height = %d, should be %d" , 
                   height, CORRECT_DEFAULT_HEIGHT);
    }
    
    if (result)
    {
        XSizeHints hints;
        glong junk = 1;
    
        if (!XGetWMNormalHints (GDK_WINDOW_XDISPLAY (widget->window), GDK_WINDOW_XID (widget->window), 
                                &hints, &junk))
        {
            TEST_FAIL ("can't obtain flags", NULL);
        }
        if (!((hints.flags & USPosition) || (hints.flags & USSize)))
        {
            TEST_FAIL ("GDK_HINT_USER_POS or GDK_HINT_USER_SIZE flags doesn't set 0x%x", hints.flags);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef GEOMETRY
    #undef CORRECT_DEFAULT_WIDTH
    #undef CORRECT_DEFAULT_HEIGHT
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: Parses a standard X Window System geometry string - see the manual page for X (type 'man X') for details on this
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "999x1000v+5+10"
 * Expected: FALSE
 * 
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: If gtk_window_parse_geometry() returns TRUE, it will also set the GDK_HINT_USER_POS and/or GDK_HINT_USER_SIZE hints indicating to the window manager that the size/position of the window was user-specified 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "999x1000v+5+10"
 * Expected: FALSE
 * 
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: If either a size or a position can be extracted from the geometry string, gtk_window_parse_geometry() returns TRUE and calls gtk_window_set_default_size() and/or gtk_window_move() to resize/move the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "999x1000v+5+10"
 * Expected: FALSE  
 */
static void test_purpose_193()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define GEOMETRY "999x1000v+5+10"
    #define CORRECT_DEFAULT_WIDTH -1
    #define CORRECT_DEFAULT_HEIGHT -1
    #define CORRECT_RESULT FALSE
    
    
    GtkWidget* widget;
    gboolean result;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    result = gtk_window_parse_geometry (GTK_WINDOW (widget), GEOMETRY);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (result != CORRECT_RESULT)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RESULT);
        return;
    }
    
    gtk_window_get_default_size (GTK_WINDOW (widget), &width, &height);
    if (width != CORRECT_DEFAULT_WIDTH)
    {
        TEST_FAIL ("default width = %d, should be %d" , 
                   width, CORRECT_DEFAULT_WIDTH);
    }
    if (height != CORRECT_DEFAULT_HEIGHT)
    {
        TEST_FAIL ("default height = %d, should be %d" , 
                   height, CORRECT_DEFAULT_HEIGHT);
    }
    
    if (result)
    {
        XSizeHints hints;
        glong junk = 1;
    
        if (!XGetWMNormalHints (GDK_WINDOW_XDISPLAY (widget->window), GDK_WINDOW_XID (widget->window), 
                                &hints, &junk))
        {
            TEST_FAIL ("can't obtain flags", NULL);
        }
        if (!((hints.flags & USPosition) || (hints.flags & USSize)))
        {
            TEST_FAIL ("GDK_HINT_USER_POS or GDK_HINT_USER_SIZE flags doesn't set 0x%x", hints.flags);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef GEOMETRY
    #undef CORRECT_DEFAULT_WIDTH
    #undef CORRECT_DEFAULT_HEIGHT
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: Parses a standard X Window System geometry string - see the manual page for X (type 'man X') for details on this
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "999x1000x5+10"
 * Expected: FALSE
 * 
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: If gtk_window_parse_geometry() returns TRUE, it will also set the GDK_HINT_USER_POS and/or GDK_HINT_USER_SIZE hints indicating to the window manager that the size/position of the window was user-specified 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "999x1000x5+10"
 * Expected: FALSE
 * 
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: If either a size or a position can be extracted from the geometry string, gtk_window_parse_geometry() returns TRUE and calls gtk_window_set_default_size() and/or gtk_window_move() to resize/move the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "999x1000x5+10"
 * Expected: FALSE  
 */
static void test_purpose_194()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define GEOMETRY "999x1000x5+10"
    #define CORRECT_DEFAULT_WIDTH -1
    #define CORRECT_DEFAULT_HEIGHT -1
    #define CORRECT_RESULT FALSE
    
    
    GtkWidget* widget;
    gboolean result;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    result = gtk_window_parse_geometry (GTK_WINDOW (widget), GEOMETRY);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (result != CORRECT_RESULT)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RESULT);
        return;
    }
    
    gtk_window_get_default_size (GTK_WINDOW (widget), &width, &height);
    if (width != CORRECT_DEFAULT_WIDTH)
    {
        TEST_FAIL ("default width = %d, should be %d" , 
                   width, CORRECT_DEFAULT_WIDTH);
    }
    if (height != CORRECT_DEFAULT_HEIGHT)
    {
        TEST_FAIL ("default height = %d, should be %d" , 
                   height, CORRECT_DEFAULT_HEIGHT);
    }
    
    if (result)
    {
        XSizeHints hints;
        glong junk = 1;
    
        if (!XGetWMNormalHints (GDK_WINDOW_XDISPLAY (widget->window), GDK_WINDOW_XID (widget->window), 
                                &hints, &junk))
        {
            TEST_FAIL ("can't obtain flags", NULL);
        }
        if (!((hints.flags & USPosition) || (hints.flags & USSize)))
        {
            TEST_FAIL ("GDK_HINT_USER_POS or GDK_HINT_USER_SIZE flags doesn't set 0x%x", hints.flags);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef GEOMETRY
    #undef CORRECT_DEFAULT_WIDTH
    #undef CORRECT_DEFAULT_HEIGHT
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: Parses a standard X Window System geometry string - see the manual page for X (type 'man X') for details on this
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "999x1000+5x10"
 * Expected: FALSE
 * 
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: If gtk_window_parse_geometry() returns TRUE, it will also set the GDK_HINT_USER_POS and/or GDK_HINT_USER_SIZE hints indicating to the window manager that the size/position of the window was user-specified 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "999x1000+5x10"
 * Expected: FALSE
 * 
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: If either a size or a position can be extracted from the geometry string, gtk_window_parse_geometry() returns TRUE and calls gtk_window_set_default_size() and/or gtk_window_move() to resize/move the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "999x1000+5x10"
 * Expected: FALSE  
 */
static void test_purpose_195()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define GEOMETRY "999x1000+5x10"
    #define CORRECT_DEFAULT_WIDTH -1
    #define CORRECT_DEFAULT_HEIGHT -1
    #define CORRECT_RESULT FALSE
    
    
    GtkWidget* widget;
    gboolean result;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    result = gtk_window_parse_geometry (GTK_WINDOW (widget), GEOMETRY);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (result != CORRECT_RESULT)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RESULT);
        return;
    }
    
    gtk_window_get_default_size (GTK_WINDOW (widget), &width, &height);
    if (width != CORRECT_DEFAULT_WIDTH)
    {
        TEST_FAIL ("default width = %d, should be %d" , 
                   width, CORRECT_DEFAULT_WIDTH);
    }
    if (height != CORRECT_DEFAULT_HEIGHT)
    {
        TEST_FAIL ("default height = %d, should be %d" , 
                   height, CORRECT_DEFAULT_HEIGHT);
    }
    
    if (result)
    {
        XSizeHints hints;
        glong junk = 1;
    
        if (!XGetWMNormalHints (GDK_WINDOW_XDISPLAY (widget->window), GDK_WINDOW_XID (widget->window), 
                                &hints, &junk))
        {
            TEST_FAIL ("can't obtain flags", NULL);
        }
        if (!((hints.flags & USPosition) || (hints.flags & USSize)))
        {
            TEST_FAIL ("GDK_HINT_USER_POS or GDK_HINT_USER_SIZE flags doesn't set 0x%x", hints.flags);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef GEOMETRY
    #undef CORRECT_DEFAULT_WIDTH
    #undef CORRECT_DEFAULT_HEIGHT
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: Parses a standard X Window System geometry string - see the manual page for X (type 'man X') for details on this
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "qwdewqr"
 * Expected: FALSE
 * 
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: If gtk_window_parse_geometry() returns TRUE, it will also set the GDK_HINT_USER_POS and/or GDK_HINT_USER_SIZE hints indicating to the window manager that the size/position of the window was user-specified 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "qwdewqr"
 * Expected: FALSE
 * 
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: If either a size or a position can be extracted from the geometry string, gtk_window_parse_geometry() returns TRUE and calls gtk_window_set_default_size() and/or gtk_window_move() to resize/move the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, "qwdewqr"
 * Expected: FALSE  
 */
static void test_purpose_196()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define GEOMETRY "qwdewqr"
    #define CORRECT_DEFAULT_WIDTH -1
    #define CORRECT_DEFAULT_HEIGHT -1
    #define CORRECT_RESULT FALSE
    
    
    GtkWidget* widget;
    gboolean result;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    result = gtk_window_parse_geometry (GTK_WINDOW (widget), GEOMETRY);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (result != CORRECT_RESULT)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RESULT);
        return;
    }
    
    gtk_window_get_default_size (GTK_WINDOW (widget), &width, &height);
    if (width != CORRECT_DEFAULT_WIDTH)
    {
        TEST_FAIL ("default width = %d, should be %d" , 
                   width, CORRECT_DEFAULT_WIDTH);
    }
    if (height != CORRECT_DEFAULT_HEIGHT)
    {
        TEST_FAIL ("default height = %d, should be %d" , 
                   height, CORRECT_DEFAULT_HEIGHT);
    }
    
    if (result)
    {
        XSizeHints hints;
        glong junk = 1;
    
        if (!XGetWMNormalHints (GDK_WINDOW_XDISPLAY (widget->window), GDK_WINDOW_XID (widget->window), 
                                &hints, &junk))
        {
            TEST_FAIL ("can't obtain flags", NULL);
        }
        if (!((hints.flags & USPosition) || (hints.flags & USSize)))
        {
            TEST_FAIL ("GDK_HINT_USER_POS or GDK_HINT_USER_SIZE flags doesn't set 0x%x", hints.flags);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef GEOMETRY
    #undef CORRECT_DEFAULT_WIDTH
    #undef CORRECT_DEFAULT_HEIGHT
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: Parses a standard X Window System geometry string - see the manual page for X (type 'man X') for details on this
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, "999x0+5+10"
 * Expected: TRUE
 * 
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: If gtk_window_parse_geometry() returns TRUE, it will also set the GDK_HINT_USER_POS and/or GDK_HINT_USER_SIZE hints indicating to the window manager that the size/position of the window was user-specified 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, "999x0+5+10"
 * Expected: TRUE
 * 
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: If either a size or a position can be extracted from the geometry string, gtk_window_parse_geometry() returns TRUE and calls gtk_window_set_default_size() and/or gtk_window_move() to resize/move the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, "999x0+5+10"
 * Expected: TRUE  
 */
static void test_purpose_197()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define GEOMETRY "999x0+5+10"
    #define CORRECT_DEFAULT_WIDTH 999
    #define CORRECT_DEFAULT_HEIGHT 1
    #define CORRECT_RESULT TRUE
    
    
    GtkWidget* widget;
    gboolean result;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    result = gtk_window_parse_geometry (GTK_WINDOW (widget), GEOMETRY);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (result != CORRECT_RESULT)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RESULT);
        return;
    }
    
    gtk_window_get_default_size (GTK_WINDOW (widget), &width, &height);
    if (width != CORRECT_DEFAULT_WIDTH)
    {
        TEST_FAIL ("default width = %d, should be %d" , 
                   width, CORRECT_DEFAULT_WIDTH);
    }
    if (height != CORRECT_DEFAULT_HEIGHT)
    {
        TEST_FAIL ("default height = %d, should be %d" , 
                   height, CORRECT_DEFAULT_HEIGHT);
    }
    
    if (result)
    {
        XSizeHints hints;
        glong junk = 1;
    
        if (!XGetWMNormalHints (GDK_WINDOW_XDISPLAY (widget->window), GDK_WINDOW_XID (widget->window), 
                                &hints, &junk))
        {
            TEST_FAIL ("can't obtain flags", NULL);
        }
        if (!((hints.flags & USPosition) || (hints.flags & USSize)))
        {
            TEST_FAIL ("GDK_HINT_USER_POS or GDK_HINT_USER_SIZE flags doesn't set 0x%x", hints.flags);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef GEOMETRY
    #undef CORRECT_DEFAULT_WIDTH
    #undef CORRECT_DEFAULT_HEIGHT
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: Parses a standard X Window System geometry string - see the manual page for X (type 'man X') for details on this
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, "rx1000+5+10"
 * Expected: FALSE
 * 
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: If gtk_window_parse_geometry() returns TRUE, it will also set the GDK_HINT_USER_POS and/or GDK_HINT_USER_SIZE hints indicating to the window manager that the size/position of the window was user-specified 
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, "rx1000+5+10"
 * Expected: FALSE
 * 
 * Name:  gtk_window_parse_geometry
 * Params: GtkWindow *window, const gchar *geometry
 * Returns: gboolean
 * Assertion: If either a size or a position can be extracted from the geometry string, gtk_window_parse_geometry() returns TRUE and calls gtk_window_set_default_size() and/or gtk_window_move() to resize/move the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, "rx1000+5+10"
 * Expected: FALSE  
 */
static void test_purpose_198()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define GEOMETRY "rx1000+5+10"
    #define CORRECT_DEFAULT_WIDTH -1
    #define CORRECT_DEFAULT_HEIGHT -1
    #define CORRECT_RESULT FALSE
    
    
    GtkWidget* widget;
    gboolean result;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    result = gtk_window_parse_geometry (GTK_WINDOW (widget), GEOMETRY);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (result != CORRECT_RESULT)
    {
        TEST_FAIL ("result = %d, should be %d", result, CORRECT_RESULT);
        return;
    }
    
    gtk_window_get_default_size (GTK_WINDOW (widget), &width, &height);
    if (width != CORRECT_DEFAULT_WIDTH)
    {
        TEST_FAIL ("default width = %d, should be %d" , 
                   width, CORRECT_DEFAULT_WIDTH);
    }
    if (height != CORRECT_DEFAULT_HEIGHT)
    {
        TEST_FAIL ("default height = %d, should be %d" , 
                   height, CORRECT_DEFAULT_HEIGHT);
    }
    
    if (result)
    {
        XSizeHints hints;
        glong junk = 1;
    
        if (!XGetWMNormalHints (GDK_WINDOW_XDISPLAY (widget->window), GDK_WINDOW_XID (widget->window), 
                                &hints, &junk))
        {
            TEST_FAIL ("can't obtain flags", NULL);
        }
        if (!((hints.flags & USPosition) || (hints.flags & USSize)))
        {
            TEST_FAIL ("GDK_HINT_USER_POS or GDK_HINT_USER_SIZE flags doesn't set 0x%x", hints.flags);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef GEOMETRY
    #undef CORRECT_DEFAULT_WIDTH
    #undef CORRECT_DEFAULT_HEIGHT
    #undef CORRECT_RESULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_reshow_with_initial_size
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Hides window, then reshows it, resetting the default size and position of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void  
 */
static void test_purpose_199()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_reshow_with_initial_size (GTK_WINDOW (widget));
    /*there is no way to check the exact size of a window due to "unexpected"
    (sometimes) behavior of different window managers */
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_reshow_with_initial_size
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Hides window, then reshows it, resetting the default size and position of the window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void  
 */
static void test_purpose_200()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    
    GtkWidget* widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_window_reshow_with_initial_size (GTK_WINDOW (widget));
    /*there is no way to check the exact size of a window due to "unexpected"
    (sometimes) behavior of different window managers */
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_get_focus
 * Params: GtkWindow *window
 * Returns: GtkWidget*
 * Assertion: Retrieves the current focused widget within the window
 * Params Values: GtkWindow *window
 * Expected: GtkWidget*
 * 
 * Name: gtk_window_get_focus
 * Params: GtkWindow *window
 * Returns: GtkWidget*
 * Assertion: Note that this is the widget that would have the focus if the toplevel window focused; if the toplevel window is not focused then GTK_WIDGET_HAS_FOCUS (widget) will not be TRUE for the widget
 * Params Values: GtkWindow *window
 * Expected: GtkWidget*  
 */
static void test_purpose_201()
{
    #define FOCUS NULL
    
    GtkWidget* widget;
    GtkWidget* focus;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    focus = FOCUS;
    if (focus)
    {
        gtk_container_add (GTK_CONTAINER (widget), focus);
    }
    
    gtk_window_set_focus (GTK_WINDOW (widget), focus);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((focus != gtk_window_get_focus (GTK_WINDOW (widget))) && GTK_WIDGET_HAS_FOCUS (focus))
    {
        TEST_FAIL ("Wrong focus widget", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef FOCUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_get_focus
 * Params: GtkWindow *window
 * Returns: GtkWidget*
 * Assertion: Retrieves the current focused widget within the window
 * Params Values: GtkWindow *window
 * Expected: GtkWidget*
 * 
 * Name: gtk_window_get_focus
 * Params: GtkWindow *window
 * Returns: GtkWidget*
 * Assertion: Note that this is the widget that would have the focus if the toplevel window focused; if the toplevel window is not focused then GTK_WIDGET_HAS_FOCUS (widget) will not be TRUE for the widget
 * Params Values: GtkWindow *window
 * Expected: GtkWidget*  
 */
static void test_purpose_202()
{
    #define FOCUS gtk_button_new_with_label ("Button")
    
    GtkWidget* widget;
    GtkWidget* focus;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    focus = FOCUS;
    if (focus)
    {
        gtk_container_add (GTK_CONTAINER (widget), focus);
    }
    
    gtk_window_set_focus (GTK_WINDOW (widget), focus);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((focus != gtk_window_get_focus (GTK_WINDOW (widget))) && GTK_WIDGET_HAS_FOCUS (focus))
    {
        TEST_FAIL ("Wrong focus widget", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef FOCUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_get_focus
 * Params: GtkWindow *window
 * Returns: GtkWidget*
 * Assertion: Retrieves the current focused widget within the window
 * Params Values: GtkWindow *window
 * Expected: GtkWidget*
 * 
 * Name: gtk_window_get_focus
 * Params: GtkWindow *window
 * Returns: GtkWidget*
 * Assertion: Note that this is the widget that would have the focus if the toplevel window focused; if the toplevel window is not focused then GTK_WIDGET_HAS_FOCUS (widget) will not be TRUE for the widget
 * Params Values: GtkWindow *window
 * Expected: GtkWidget*  
 */
static void test_purpose_203()
{
    #define FOCUS gtk_check_button_new_with_label ("Check button")
    
    GtkWidget* widget;
    GtkWidget* focus;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    focus = FOCUS;
    if (focus)
    {
        gtk_container_add (GTK_CONTAINER (widget), focus);
    }
    
    gtk_window_set_focus (GTK_WINDOW (widget), focus);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((focus != gtk_window_get_focus (GTK_WINDOW (widget))) && GTK_WIDGET_HAS_FOCUS (focus))
    {
        TEST_FAIL ("Wrong focus widget", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef FOCUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_set_focus
 * Params: GtkWindow *window, GtkWidget* focus
 * Returns: void
 * Assertion: If focus is NULL, unsets the focus widget for this window
 * Params Values: GtkWindow *window, GtkWidget* focus
 * Expected: void
 * 
 * Name: gtk_window_set_focus
 * Params: GtkWindow *window, GtkWidget* focus
 * Returns: void
 * Assertion: If focus is not the current focus widget, and is focusable, sets it as the focus widget for the window
 * Params Values: GtkWindow *window, GtkWidget* focus
 * Expected: void  
 */
static void test_purpose_204()
{
    #define FOCUS NULL
    
    GtkWidget* widget;
    GtkWidget* focus;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    focus = FOCUS;
    if (focus)
    {
        gtk_container_add (GTK_CONTAINER (widget), focus);
        if (GTK_WIDGET_CAN_FOCUS (focus))
        {
            gtk_window_set_focus (GTK_WINDOW (widget), focus);
        }
    } else {
    
        gtk_window_set_focus (GTK_WINDOW (widget), focus);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((focus != gtk_window_get_focus (GTK_WINDOW (widget))) && GTK_WIDGET_CAN_FOCUS (focus))
    {
        TEST_FAIL ("Wrong focus widget", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef FOCUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_set_focus
 * Params: GtkWindow *window, GtkWidget* focus
 * Returns: void
 * Assertion: If focus is NULL, unsets the focus widget for this window
 * Params Values: GtkWindow *window, GtkWidget* focus
 * Expected: void
 * 
 * Name: gtk_window_set_focus
 * Params: GtkWindow *window, GtkWidget* focus
 * Returns: void
 * Assertion: If focus is not the current focus widget, and is focusable, sets it as the focus widget for the window
 * Params Values: GtkWindow *window, GtkWidget* focus
 * Expected: void  
 */
static void test_purpose_205()
{
    #define FOCUS gtk_label_new ("Label")
    
    GtkWidget* widget;
    GtkWidget* focus;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    focus = FOCUS;
    if (focus)
    {
        gtk_container_add (GTK_CONTAINER (widget), focus);
        if (GTK_WIDGET_CAN_FOCUS (focus))
        {
            gtk_window_set_focus (GTK_WINDOW (widget), focus);
        }
    } else {
    
        gtk_window_set_focus (GTK_WINDOW (widget), focus);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((focus != gtk_window_get_focus (GTK_WINDOW (widget))) && GTK_WIDGET_CAN_FOCUS (focus))
    {
        TEST_FAIL ("Wrong focus widget", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef FOCUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_set_focus
 * Params: GtkWindow *window, GtkWidget* focus
 * Returns: void
 * Assertion: If focus is NULL, unsets the focus widget for this window
 * Params Values: GtkWindow *window, GtkWidget* focus
 * Expected: void
 * 
 * Name: gtk_window_set_focus
 * Params: GtkWindow *window, GtkWidget* focus
 * Returns: void
 * Assertion: If focus is not the current focus widget, and is focusable, sets it as the focus widget for the window
 * Params Values: GtkWindow *window, GtkWidget* focus
 * Expected: void  
 */
static void test_purpose_206()
{
    #define FOCUS gtk_button_new_with_label ("Button")
    
    GtkWidget* widget;
    GtkWidget* focus;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    focus = FOCUS;
    if (focus)
    {
        gtk_container_add (GTK_CONTAINER (widget), focus);
        if (GTK_WIDGET_CAN_FOCUS (focus))
        {
            gtk_window_set_focus (GTK_WINDOW (widget), focus);
        }
    } else {
    
        gtk_window_set_focus (GTK_WINDOW (widget), focus);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((focus != gtk_window_get_focus (GTK_WINDOW (widget))) && GTK_WIDGET_CAN_FOCUS (focus))
    {
        TEST_FAIL ("Wrong focus widget", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef FOCUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_set_focus
 * Params: GtkWindow *window, GtkWidget* focus
 * Returns: void
 * Assertion: If focus is NULL, unsets the focus widget for this window
 * Params Values: GtkWindow *window, GtkWidget* focus
 * Expected: void
 * 
 * Name: gtk_window_set_focus
 * Params: GtkWindow *window, GtkWidget* focus
 * Returns: void
 * Assertion: If focus is not the current focus widget, and is focusable, sets it as the focus widget for the window
 * Params Values: GtkWindow *window, GtkWidget* focus
 * Expected: void  
 */
static void test_purpose_207()
{
    #define FOCUS gtk_check_button_new_with_label ("Check button")
    
    GtkWidget* widget;
    GtkWidget* focus;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    focus = FOCUS;
    if (focus)
    {
        gtk_container_add (GTK_CONTAINER (widget), focus);
        if (GTK_WIDGET_CAN_FOCUS (focus))
        {
            gtk_window_set_focus (GTK_WINDOW (widget), focus);
        }
    } else {
    
        gtk_window_set_focus (GTK_WINDOW (widget), focus);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if ((focus != gtk_window_get_focus (GTK_WINDOW (widget))) && GTK_WIDGET_CAN_FOCUS (focus))
    {
        TEST_FAIL ("Wrong focus widget", NULL);
    }
    
    gtk_widget_destroy (widget);
    
    #undef FOCUS
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_set_default
 * Params: GtkWindow *window, GtkWidget* default_widget
 * Returns: void
 * Assertion: This function sets or unsets the default widget for a GtkWindow about
 * Params Values: GtkWindow *window, GtkWidget* default_widget
 * Expected: void
 *   
 */
static void test_purpose_208()
{
    #define DEFAULT NULL
    
    GtkWidget* widget;
    GtkWidget* default_widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    default_widget = DEFAULT;
    if (default_widget)
    {
        gtk_container_add (GTK_CONTAINER (widget), default_widget);
        if (GTK_WIDGET_CAN_DEFAULT (default_widget))
        {
            gtk_window_set_default (GTK_WINDOW (widget), default_widget);
        }
    
    } else {
    
        gtk_window_set_default (GTK_WINDOW (widget), default_widget);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (default_widget)
    {
        if (GTK_WIDGET_CAN_DEFAULT (default_widget) && !gtk_window_activate_default (GTK_WINDOW (widget)))
        {
            TEST_FAIL ("Default widget wasn't activated", NULL);
        }
    
    } else {
    
        if (gtk_window_activate_default (GTK_WINDOW (widget)))
        {
            TEST_FAIL ("Default widget cannot be activated", NULL);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef DEFAULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_set_default
 * Params: GtkWindow *window, GtkWidget* default_widget
 * Returns: void
 * Assertion: This function sets or unsets the default widget for a GtkWindow about
 * Params Values: GtkWindow *window, GtkWidget* default_widget
 * Expected: void
 *   
 */
static void test_purpose_209()
{
    #define DEFAULT gtk_label_new ("Label")
    
    GtkWidget* widget;
    GtkWidget* default_widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    default_widget = DEFAULT;
    if (default_widget)
    {
        gtk_container_add (GTK_CONTAINER (widget), default_widget);
        if (GTK_WIDGET_CAN_DEFAULT (default_widget))
        {
            gtk_window_set_default (GTK_WINDOW (widget), default_widget);
        }
    
    } else {
    
        gtk_window_set_default (GTK_WINDOW (widget), default_widget);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (default_widget)
    {
        if (GTK_WIDGET_CAN_DEFAULT (default_widget) && !gtk_window_activate_default (GTK_WINDOW (widget)))
        {
            TEST_FAIL ("Default widget wasn't activated", NULL);
        }
    
    } else {
    
        if (gtk_window_activate_default (GTK_WINDOW (widget)))
        {
            TEST_FAIL ("Default widget cannot be activated", NULL);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef DEFAULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_set_default
 * Params: GtkWindow *window, GtkWidget* default_widget
 * Returns: void
 * Assertion: This function sets or unsets the default widget for a GtkWindow about
 * Params Values: GtkWindow *window, GtkWidget* default_widget
 * Expected: void
 *   
 */
static void test_purpose_210()
{
    #define DEFAULT gtk_button_new_with_label ("Button")
    
    GtkWidget* widget;
    GtkWidget* default_widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    default_widget = DEFAULT;
    if (default_widget)
    {
        gtk_container_add (GTK_CONTAINER (widget), default_widget);
        if (GTK_WIDGET_CAN_DEFAULT (default_widget))
        {
            gtk_window_set_default (GTK_WINDOW (widget), default_widget);
        }
    
    } else {
    
        gtk_window_set_default (GTK_WINDOW (widget), default_widget);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (default_widget)
    {
        if (GTK_WIDGET_CAN_DEFAULT (default_widget) && !gtk_window_activate_default (GTK_WINDOW (widget)))
        {
            TEST_FAIL ("Default widget wasn't activated", NULL);
        }
    
    } else {
    
        if (gtk_window_activate_default (GTK_WINDOW (widget)))
        {
            TEST_FAIL ("Default widget cannot be activated", NULL);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef DEFAULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name: gtk_window_set_default
 * Params: GtkWindow *window, GtkWidget* default_widget
 * Returns: void
 * Assertion: This function sets or unsets the default widget for a GtkWindow about
 * Params Values: GtkWindow *window, GtkWidget* default_widget
 * Expected: void
 *   
 */
static void test_purpose_211()
{
    #define DEFAULT gtk_check_button_new_with_label ("Check button")
    
    GtkWidget* widget;
    GtkWidget* default_widget;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    default_widget = DEFAULT;
    if (default_widget)
    {
        gtk_container_add (GTK_CONTAINER (widget), default_widget);
        if (GTK_WIDGET_CAN_DEFAULT (default_widget))
        {
            gtk_window_set_default (GTK_WINDOW (widget), default_widget);
        }
    
    } else {
    
        gtk_window_set_default (GTK_WINDOW (widget), default_widget);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (default_widget)
    {
        if (GTK_WIDGET_CAN_DEFAULT (default_widget) && !gtk_window_activate_default (GTK_WINDOW (widget)))
        {
            TEST_FAIL ("Default widget wasn't activated", NULL);
        }
    
    } else {
    
        if (gtk_window_activate_default (GTK_WINDOW (widget)))
        {
            TEST_FAIL ("Default widget cannot be activated", NULL);
        }
    }
    
    gtk_widget_destroy (widget);
    
    #undef DEFAULT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_resize
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Resizes the window as if the user had done so, obeying geometry constraints
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, <%1>, 100
 * Expected: void
 * 
 * Name:  gtk_window_resize
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Windows may not be resized smaller than 1 by 1 pixels
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, <%1>, 100
 * Expected: void
 * 
 * Name:  gtk_window_resize
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: If gtk_window_resize() is called before showing a window for the first time, it overrides any default size set with gtk_window_set_default_size()
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, <%1>, 100
 * Expected: void  
 */
static void test_purpose_212()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define WIDTH  100
    #define HEIGHT 100
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_resize (GTK_WINDOW (widget), WIDTH, HEIGHT);
    gtk_window_get_size (GTK_WINDOW (widget), &width, &height);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (width != WIDTH) 
    {
        TEST_FAIL ("width is %d, should be %d", width, WIDTH);
    }
    
    if (height != HEIGHT) 
    {
        TEST_FAIL ("height is %d, should be %d", height, HEIGHT);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_resize
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Resizes the window as if the user had done so, obeying geometry constraints
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, <%1>, 1
 * Expected: void
 * 
 * Name:  gtk_window_resize
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Windows may not be resized smaller than 1 by 1 pixels
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, <%1>, 1
 * Expected: void
 * 
 * Name:  gtk_window_resize
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: If gtk_window_resize() is called before showing a window for the first time, it overrides any default size set with gtk_window_set_default_size()
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, <%1>, 1
 * Expected: void  
 */
static void test_purpose_213()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define WIDTH  1
    #define HEIGHT 1
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_resize (GTK_WINDOW (widget), WIDTH, HEIGHT);
    gtk_window_get_size (GTK_WINDOW (widget), &width, &height);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (width != WIDTH) 
    {
        TEST_FAIL ("width is %d, should be %d", width, WIDTH);
    }
    
    if (height != HEIGHT) 
    {
        TEST_FAIL ("height is %d, should be %d", height, HEIGHT);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_resize
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Resizes the window as if the user had done so, obeying geometry constraints
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, <%1>, 50
 * Expected: void
 * 
 * Name:  gtk_window_resize
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Windows may not be resized smaller than 1 by 1 pixels
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, <%1>, 50
 * Expected: void
 * 
 * Name:  gtk_window_resize
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: If gtk_window_resize() is called before showing a window for the first time, it overrides any default size set with gtk_window_set_default_size()
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, <%1>, 50
 * Expected: void  
 */
static void test_purpose_214()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define WIDTH  300
    #define HEIGHT 50
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_resize (GTK_WINDOW (widget), WIDTH, HEIGHT);
    gtk_window_get_size (GTK_WINDOW (widget), &width, &height);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (width != WIDTH) 
    {
        TEST_FAIL ("width is %d, should be %d", width, WIDTH);
    }
    
    if (height != HEIGHT) 
    {
        TEST_FAIL ("height is %d, should be %d", height, HEIGHT);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_resize
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Resizes the window as if the user had done so, obeying geometry constraints
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, <%1>, 200
 * Expected: void
 * 
 * Name:  gtk_window_resize
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Windows may not be resized smaller than 1 by 1 pixels
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, <%1>, 200
 * Expected: void
 * 
 * Name:  gtk_window_resize
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: If gtk_window_resize() is called before showing a window for the first time, it overrides any default size set with gtk_window_set_default_size()
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, <%1>, 200
 * Expected: void  
 */
static void test_purpose_215()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define WIDTH  200
    #define HEIGHT 200
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_resize (GTK_WINDOW (widget), WIDTH, HEIGHT);
    gtk_window_get_size (GTK_WINDOW (widget), &width, &height);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (width != WIDTH) 
    {
        TEST_FAIL ("width is %d, should be %d", width, WIDTH);
    }
    
    if (height != HEIGHT) 
    {
        TEST_FAIL ("height is %d, should be %d", height, HEIGHT);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_resize
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Resizes the window as if the user had done so, obeying geometry constraints
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, <%1>, 10
 * Expected: void
 * 
 * Name:  gtk_window_resize
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Windows may not be resized smaller than 1 by 1 pixels
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, <%1>, 10
 * Expected: void
 * 
 * Name:  gtk_window_resize
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: If gtk_window_resize() is called before showing a window for the first time, it overrides any default size set with gtk_window_set_default_size()
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, <%1>, 10
 * Expected: void  
 */
static void test_purpose_216()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define WIDTH  20
    #define HEIGHT 10
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_resize (GTK_WINDOW (widget), WIDTH, HEIGHT);
    gtk_window_get_size (GTK_WINDOW (widget), &width, &height);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (width != WIDTH) 
    {
        TEST_FAIL ("width is %d, should be %d", width, WIDTH);
    }
    
    if (height != HEIGHT) 
    {
        TEST_FAIL ("height is %d, should be %d", height, HEIGHT);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_resize
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Resizes the window as if the user had done so, obeying geometry constraints
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, <%1>, 1
 * Expected: void
 * 
 * Name:  gtk_window_resize
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: Windows may not be resized smaller than 1 by 1 pixels
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, <%1>, 1
 * Expected: void
 * 
 * Name:  gtk_window_resize
 * Params: GtkWindow *window, gint width, gint height
 * Returns: void
 * Assertion: If gtk_window_resize() is called before showing a window for the first time, it overrides any default size set with gtk_window_set_default_size()
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, <%1>, 1
 * Expected: void  
 */
static void test_purpose_217()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define WIDTH  1
    #define HEIGHT 1
    
    GtkWidget* widget;
    gint width;
    gint height;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_resize (GTK_WINDOW (widget), WIDTH, HEIGHT);
    gtk_window_get_size (GTK_WINDOW (widget), &width, &height);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    if (width != WIDTH) 
    {
        TEST_FAIL ("width is %d, should be %d", width, WIDTH);
    }
    
    if (height != HEIGHT) 
    {
        TEST_FAIL ("height is %d, should be %d", height, HEIGHT);
    }
    
    gtk_widget_destroy (widget);
    
    #undef WINDOW_TYPE 
    #undef WIDTH
    #undef HEIGHT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_icon
 * Params: GtkWindow *window, GdkPixbuf* pixbuf
 * Returns: void
 * Assertion: Sets up the icon representing a GtkWindow
 * Params Values: a newly created GtkWindow of type "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png", GdkPixbuf* pixbuf
 * Expected: void
 * 
 * Name:  gtk_window_set_icon
 * Params: GtkWindow *window, GdkPixbuf*
 * Returns: void
 * Assertion: This function is equivalent to calling gtk_window_set_icon_list() with a 1-element list
 * Params Values: a newly created GtkWindow of type "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png", GdkPixbuf*
 * Expected: void
 * 
 * Name:  gtk_window_get_icon
 * Params: GtkWindow *window
 * Returns: GdkPixbuf*
 * Assertion: Gets the value set by gtk_window_set_icon() (or if you've called gtk_window_set_icon_list(), gets the first icon in the icon list)'
 * Params Values: a newly created GtkWindow of type "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
 * Expected: GdkPixbuf*  
 */
static void test_purpose_218()
{
    #define IMAGE_FILE_NAME_REL "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
    
    GtkWidget* widget;
    GdkPixbuf* pixbuf;
    GError* error = NULL;
    GList* list = NULL;
    gchar* image_file_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    image_file_name = strdup (getenv ("TET_ROOT"));
    image_file_name = realloc (image_file_name, strlen (image_file_name) + strlen (IMAGE_FILE_NAME_REL) + 1);
    image_file_name = strcat (image_file_name, IMAGE_FILE_NAME_REL);
    
    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    pixbuf = gdk_pixbuf_new_from_file (image_file_name, &error);
    if (!pixbuf)
    {
        TEST_FAIL ("pixbuf is NULL, error is '%s'", error->message);
        return;
    }
                                                            
    gtk_window_set_icon (GTK_WINDOW (widget), pixbuf);
    if (gtk_window_get_icon (GTK_WINDOW (widget)) != pixbuf)
    {
        TEST_FAIL ("1: gtk_window_get_icon() returns wrong pixbuf", NULL);
    }
    
    list = g_list_append (list, pixbuf);
    gtk_window_set_icon_list (GTK_WINDOW (widget), list);
    g_list_free (list);
    if (gtk_window_get_icon (GTK_WINDOW (widget)) != pixbuf)
    {
        TEST_FAIL ("2: gtk_window_get_icon() returns wrong pixbuf", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    free (image_file_name);
    gtk_widget_destroy (widget);
    
    #undef IMAGE_FILE_NAME_REL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_icon_from_file
 * Params: GtkWindow *window, const gchar *filename, GError **err
 * Returns: gboolean
 * Assertion: Sets the icon for window.
 * Params Values: a newly created GtkWindow of type "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png", GdkPixbuf* pixbuf
 * Expected: void
 * 
 * Name:  gtk_window_set_icon_from_file
 * Params: GtkWindow *window, const gchar *filename, GError **err
 * Returns: gboolean
 * Assertion: This function is equivalent to calling gtk_window_set_icon() with a pixbuf created by loading the image from filename.
 * Params Values: a newly created GtkWindow of type "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png", GdkPixbuf* pixbuf
 * Expected: void  
 */
static void test_purpose_219()
{
    #define IMAGE_FILE_NAME_REL "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
    
    GtkWidget* widget;
    GdkPixbuf* pixbuf;
    GdkPixbuf* real_pixbuf;
    GError* error = NULL;
    GList* list = NULL;
    gchar* image_file_name;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    image_file_name = strdup (getenv ("TET_ROOT"));
    image_file_name = realloc (image_file_name, strlen (image_file_name) + strlen (IMAGE_FILE_NAME_REL) + 1);
    image_file_name = strcat (image_file_name, IMAGE_FILE_NAME_REL);
    
    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    pixbuf = gdk_pixbuf_new_from_file (image_file_name, &error);
    if (!pixbuf)
    {
        TEST_FAIL ("pixbuf is NULL, error is '%s'", error->message);
        return;
    }
                                                            
    res = gtk_window_set_icon_from_file (GTK_WINDOW (widget), image_file_name, &error);
    
    if (!res)
    {
        TEST_FAIL ("gtk_window_set_icon_from_file (\"%s\") FAILED", 
                   image_file_name);
    }
    
    real_pixbuf  = gtk_window_get_icon (GTK_WINDOW (widget));
    if (gdk_pixbuf_get_colorspace (real_pixbuf) 
        != gdk_pixbuf_get_colorspace (pixbuf))
    {
        TEST_FAIL ("1: gdk_pixbuf_get_colorspace (real_pixbuf) != gdk_pixbuf_get_colorspace (pixbuf)", NULL);
    }
    
    if (gdk_pixbuf_get_has_alpha (real_pixbuf) 
        != gdk_pixbuf_get_has_alpha (pixbuf))
    {
        TEST_FAIL ("1: gdk_pixbuf_get_has_alpha (real_pixbuf) != gdk_pixbuf_get_has_alpha (pixbuf)", NULL);
    }
    
    if (gdk_pixbuf_get_bits_per_sample (real_pixbuf) 
        != gdk_pixbuf_get_bits_per_sample (pixbuf))
    {
        TEST_FAIL ("1: gdk_pixbuf_get_bits_per_sample (real_pixbuf) != gdk_pixbuf_get_bits_per_sample (pixbuf)", NULL);
    }
    
    if (gdk_pixbuf_get_width (real_pixbuf) 
        != gdk_pixbuf_get_width (pixbuf))
    {
        TEST_FAIL ("1: gdk_pixbuf_get_width (real_pixbuf) != gdk_pixbuf_get_width (pixbuf)", NULL);
    }
    
    if (gdk_pixbuf_get_height (real_pixbuf) 
        != gdk_pixbuf_get_height (pixbuf))
    {
        TEST_FAIL ("1: gdk_pixbuf_get_height (real_pixbuf) != gdk_pixbuf_get_height (pixbuf)", NULL);
    }
    
    if (gdk_pixbuf_get_rowstride (real_pixbuf) 
        != gdk_pixbuf_get_rowstride (pixbuf))
    {
        TEST_FAIL ("1: gdk_pixbuf_get_rowstride (real_pixbuf) != gdk_pixbuf_get_rowstride (pixbuf)", NULL);
    }
    
    list = g_list_append (list, pixbuf);
    gtk_window_set_icon_list (GTK_WINDOW (widget), list);
    g_list_free (list);
    if (gtk_window_get_icon (GTK_WINDOW (widget)) != pixbuf)
    {
        TEST_FAIL ("2: gtk_window_get_icon() returns wrong pixbuf", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    free (image_file_name);
    gtk_widget_destroy (widget);
    
    #undef IMAGE_FILE_NAME_REL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_icon_from_file
 * Params: GtkWindow *window, const gchar *filename, GError **err
 * Returns: gboolean
 * Assertion: Warns on failure if err is NULL. 
 * Params Values: a newly created GtkWindow of type <%0%>, correct path to a pixmap file
 * Expected: void  
 */
static void test_purpose_220()
{
    GtkWidget* widget;
    GdkPixbuf* pixbuf;
    gchar* image_file_name;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    image_file_name = "wrong file name";
    
    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    res = gtk_window_set_icon_from_file (GTK_WINDOW (widget), 
                                         image_file_name, NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef IMAGE_FILE_NAME_REL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_default_icon_from_file
 * Params: const gchar *filename, GError **err
 * Returns: gboolean
 * Assertion: Sets an icon to be used as fallback for windows that haven't had gtk_window_set_icon_list() called on them from a file on disk.'
 * Params Values: a newly created GtkWindow of type "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png", GdkPixbuf* pixbuf
 * Expected: void  
 */
static void test_purpose_221()
{
    #define IMAGE_FILE_NAME_REL "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
    
    GtkWidget* widget;
    GError* error = NULL;
    gchar* image_file_name;
    gboolean res;
    GList* list = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    image_file_name = strdup (getenv ("TET_ROOT"));
    image_file_name = realloc (image_file_name, strlen (image_file_name) + strlen (IMAGE_FILE_NAME_REL) + 1);
    image_file_name = strcat (image_file_name, IMAGE_FILE_NAME_REL);
    
    res = gtk_window_set_default_icon_from_file (image_file_name, &error);
    
    if (!res)
    {
        TEST_FAIL ("gtk_window_set_default_icon_from_file (\"%s\") FAILED", 
                   image_file_name);
    }
    
    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    list = gtk_window_get_default_icon_list ();
    if (!list)
    {
        TEST_FAIL ("real_list is NULL", NULL);
    } else  if (g_list_length (list) != 1) {
        TEST_FAIL ("real_list length is %d, should be 1", g_list_length (list));
    }
    
    free (image_file_name);
    gtk_widget_destroy (widget);
    
    #undef IMAGE_FILE_NAME_REL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_default_icon_from_file
 * Params: const gchar *filename, GError **err
 * Returns: gboolean
 * Assertion: Warns on failure if err is NULL. 
 * Params Values: "wrong file name"
 * Expected: void  
 */
static void test_purpose_222()
{
    GtkWidget* widget;
    GdkPixbuf* pixbuf;
    gchar* image_file_name;
    gboolean res;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    image_file_name = "wrong file name";
    
    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    res = gtk_window_set_default_icon_from_file (image_file_name, NULL);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef IMAGE_FILE_NAME_REL
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_icon_list
 * Params: GtkWindow *window, GList*
 * Returns: void
 * Assertion: Sets up the icon representing a GtkWindow
 * Params Values: a newly created GtkWindow of type "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png", GList*
 * Expected: void
 * 
 * Name:  gtk_window_set_icon_list
 * Params: GtkWindow *window, GList*
 * Returns: void
 * Assertion: Note that transient windows (those who have been set transient for another window using gtk_window_set_transient_for()) will inherit their icon from their transient parent
 * Params Values: a newly created GtkWindow of type "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png", GList*
 * Expected: void
 * 
 * Name:  gtk_window_get_icon_list
 * Params: GtkWindow *window
 * Returns: GList*
 * Assertion: Retrieves the list of icons set by gtk_window_set_icon_list()
 * Params Values: a newly created GtkWindow of type "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
 * Expected: GList*
 * 
 * Name:  gtk_window_get_icon_list
 * Params: GtkWindow *window
 * Returns: GList*
 * Assertion: The list is copied, but the reference count on each member won't be incremented'
 * Params Values: a newly created GtkWindow of type "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
 * Expected: GList*  
 */
static void test_purpose_223()
{
    #define IMAGE_FILE_NAME_REL "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
    #define COUNT 1
    
    GtkWidget* widget;
    GtkWidget* child;
    GdkPixbuf* pixbuf;
    GError* error = NULL;
    gint i;
    GList* list = NULL;
    GList* real_list = NULL;
    gchar* image_file_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    image_file_name = strdup (getenv ("TET_ROOT"));
    image_file_name = realloc (image_file_name, strlen (image_file_name) + strlen (IMAGE_FILE_NAME_REL) + 1);
    image_file_name = strcat (image_file_name, IMAGE_FILE_NAME_REL);
    
    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    child = gtk_dialog_new ();
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    pixbuf = gdk_pixbuf_new_from_file (image_file_name, &error);
    if (!pixbuf)
    {
        TEST_FAIL ("pixbuf is NULL, error is '%s'", error->message);
        return;
    }
    
    for (i = 0; i < COUNT; i++)
    {
        list = g_list_append (list, pixbuf);
    }
    
    gtk_window_set_icon_list (GTK_WINDOW (widget), list);
    /* g_list_free (list); */
    
    real_list = gtk_window_get_icon_list (GTK_WINDOW (widget));
    if (!real_list)
    {
        TEST_FAIL ("real_list is NULL", NULL);
    } else  if (g_list_length (list) != COUNT) {
        TEST_FAIL ("gtk_window_get_icon_list() returns wrong list", NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    /*  2nd assertion cannot be tested now */
    /*
    //gtk_window_set_transient_for (GTK_WINDOW (child), GTK_WINDOW (widget));
    gtk_window_set_transient_for (GTK_WINDOW (widget), GTK_WINDOW (child));
    
    gtk_window_iconify (GTK_WINDOW (widget)); 
    gtk_window_deiconify (GTK_WINDOW (widget)); 
    
    list = gtk_window_get_icon_list (GTK_WINDOW (child));
    if (!list || (g_list_length (list) != COUNT))
    {
        TEST_FAIL ("gtk_window_get_icon_list() returns wrong list for transient widget %p, %i", list, g_list_length (list));
    }
    
    gtk_window_set_transient_for (GTK_WINDOW (child), NULL);
    g_list_free (list);
    */
    
    g_list_free (list);
    free (image_file_name);
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (child);
    
    #undef IMAGE_FILE_NAME_REL
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_icon_list
 * Params: GtkWindow *window, GList*
 * Returns: void
 * Assertion: Sets up the icon representing a GtkWindow
 * Params Values: a newly created GtkWindow of type "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png", GList*
 * Expected: void
 * 
 * Name:  gtk_window_set_icon_list
 * Params: GtkWindow *window, GList*
 * Returns: void
 * Assertion: Note that transient windows (those who have been set transient for another window using gtk_window_set_transient_for()) will inherit their icon from their transient parent
 * Params Values: a newly created GtkWindow of type "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png", GList*
 * Expected: void
 * 
 * Name:  gtk_window_get_icon_list
 * Params: GtkWindow *window
 * Returns: GList*
 * Assertion: Retrieves the list of icons set by gtk_window_set_icon_list()
 * Params Values: a newly created GtkWindow of type "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
 * Expected: GList*
 * 
 * Name:  gtk_window_get_icon_list
 * Params: GtkWindow *window
 * Returns: GList*
 * Assertion: The list is copied, but the reference count on each member won't be incremented'
 * Params Values: a newly created GtkWindow of type "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
 * Expected: GList*  
 */
static void test_purpose_224()
{
    #define IMAGE_FILE_NAME_REL "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
    #define COUNT 5
    
    GtkWidget* widget;
    GtkWidget* child;
    GdkPixbuf* pixbuf;
    GError* error = NULL;
    gint i;
    GList* list = NULL;
    GList* real_list = NULL;
    gchar* image_file_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    image_file_name = strdup (getenv ("TET_ROOT"));
    image_file_name = realloc (image_file_name, strlen (image_file_name) + strlen (IMAGE_FILE_NAME_REL) + 1);
    image_file_name = strcat (image_file_name, IMAGE_FILE_NAME_REL);
    
    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    child = gtk_dialog_new ();
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    pixbuf = gdk_pixbuf_new_from_file (image_file_name, &error);
    if (!pixbuf)
    {
        TEST_FAIL ("pixbuf is NULL, error is '%s'", error->message);
        return;
    }
    
    for (i = 0; i < COUNT; i++)
    {
        list = g_list_append (list, pixbuf);
    }
    
    gtk_window_set_icon_list (GTK_WINDOW (widget), list);
    /* g_list_free (list); */
    
    real_list = gtk_window_get_icon_list (GTK_WINDOW (widget));
    if (!real_list)
    {
        TEST_FAIL ("real_list is NULL", NULL);
    } else  if (g_list_length (list) != COUNT) {
        TEST_FAIL ("gtk_window_get_icon_list() returns wrong list", NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    /*  2nd assertion cannot be tested now */
    /*
    //gtk_window_set_transient_for (GTK_WINDOW (child), GTK_WINDOW (widget));
    gtk_window_set_transient_for (GTK_WINDOW (widget), GTK_WINDOW (child));
    
    gtk_window_iconify (GTK_WINDOW (widget)); 
    gtk_window_deiconify (GTK_WINDOW (widget)); 
    
    list = gtk_window_get_icon_list (GTK_WINDOW (child));
    if (!list || (g_list_length (list) != COUNT))
    {
        TEST_FAIL ("gtk_window_get_icon_list() returns wrong list for transient widget %p, %i", list, g_list_length (list));
    }
    
    gtk_window_set_transient_for (GTK_WINDOW (child), NULL);
    g_list_free (list);
    */
    
    g_list_free (list);
    free (image_file_name);
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (child);
    
    #undef IMAGE_FILE_NAME_REL
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_icon_list
 * Params: GtkWindow *window, GList*
 * Returns: void
 * Assertion: Sets up the icon representing a GtkWindow
 * Params Values: a newly created GtkWindow of type "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png", GList*
 * Expected: void
 * 
 * Name:  gtk_window_set_icon_list
 * Params: GtkWindow *window, GList*
 * Returns: void
 * Assertion: Note that transient windows (those who have been set transient for another window using gtk_window_set_transient_for()) will inherit their icon from their transient parent
 * Params Values: a newly created GtkWindow of type "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png", GList*
 * Expected: void
 * 
 * Name:  gtk_window_get_icon_list
 * Params: GtkWindow *window
 * Returns: GList*
 * Assertion: Retrieves the list of icons set by gtk_window_set_icon_list()
 * Params Values: a newly created GtkWindow of type "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
 * Expected: GList*
 * 
 * Name:  gtk_window_get_icon_list
 * Params: GtkWindow *window
 * Returns: GList*
 * Assertion: The list is copied, but the reference count on each member won't be incremented'
 * Params Values: a newly created GtkWindow of type "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
 * Expected: GList*  
 */
static void test_purpose_225()
{
    #define IMAGE_FILE_NAME_REL "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
    #define COUNT 49
    
    GtkWidget* widget;
    GtkWidget* child;
    GdkPixbuf* pixbuf;
    GError* error = NULL;
    gint i;
    GList* list = NULL;
    GList* real_list = NULL;
    gchar* image_file_name;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    image_file_name = strdup (getenv ("TET_ROOT"));
    image_file_name = realloc (image_file_name, strlen (image_file_name) + strlen (IMAGE_FILE_NAME_REL) + 1);
    image_file_name = strcat (image_file_name, IMAGE_FILE_NAME_REL);
    
    widget = gtk_window_new (GTK_WINDOW_TOPLEVEL);
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    child = gtk_dialog_new ();
    if (!child)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    pixbuf = gdk_pixbuf_new_from_file (image_file_name, &error);
    if (!pixbuf)
    {
        TEST_FAIL ("pixbuf is NULL, error is '%s'", error->message);
        return;
    }
    
    for (i = 0; i < COUNT; i++)
    {
        list = g_list_append (list, pixbuf);
    }
    
    gtk_window_set_icon_list (GTK_WINDOW (widget), list);
    /* g_list_free (list); */
    
    real_list = gtk_window_get_icon_list (GTK_WINDOW (widget));
    if (!real_list)
    {
        TEST_FAIL ("real_list is NULL", NULL);
    } else  if (g_list_length (list) != COUNT) {
        TEST_FAIL ("gtk_window_get_icon_list() returns wrong list", NULL);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    /*  2nd assertion cannot be tested now */
    /*
    //gtk_window_set_transient_for (GTK_WINDOW (child), GTK_WINDOW (widget));
    gtk_window_set_transient_for (GTK_WINDOW (widget), GTK_WINDOW (child));
    
    gtk_window_iconify (GTK_WINDOW (widget)); 
    gtk_window_deiconify (GTK_WINDOW (widget)); 
    
    list = gtk_window_get_icon_list (GTK_WINDOW (child));
    if (!list || (g_list_length (list) != COUNT))
    {
        TEST_FAIL ("gtk_window_get_icon_list() returns wrong list for transient widget %p, %i", list, g_list_length (list));
    }
    
    gtk_window_set_transient_for (GTK_WINDOW (child), NULL);
    g_list_free (list);
    */
    
    g_list_free (list);
    free (image_file_name);
    
    gtk_widget_destroy (widget);
    gtk_widget_destroy (child);
    
    #undef IMAGE_FILE_NAME_REL
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_default_icon_list
 * Params: GList*
 * Returns: void
 * Assertion: Sets an icon list to be used as fallback for windows that haven't had gtk_window_set_icon_list() called on them to set up a window-specific icon list'
 * Params Values: GList*
 * Expected: void
 * 
 * Name:  gtk_window_get_default_icon_list
 * Params: void
 * Returns: GList*
 * Assertion: Gets the value set by gtk_window_set_default_icon_list()
 * Params Values: void
 * Expected: GList*  
 */
static void test_purpose_226()
{
    #define IMAGE_FILE_NAME_REL "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
    #define COUNT 1
    
    GtkWidget* widget;
    GdkPixbuf* pixbuf;
    GError* error = NULL;
    gchar* image_file_name;
    gint i;
    GList* list = NULL;
    GList* real_list = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    image_file_name = strdup (getenv ("TET_ROOT"));
    image_file_name = realloc (image_file_name, strlen (image_file_name) + strlen (IMAGE_FILE_NAME_REL) + 1);
    image_file_name = strcat (image_file_name, IMAGE_FILE_NAME_REL);
    
    pixbuf = gdk_pixbuf_new_from_file (image_file_name, &error);
    if (!pixbuf)
    {
        TEST_FAIL ("pixbuf is NULL, error is '%s'", error->message);
        return;
    }
    
    for (i = 0; i < COUNT; i++)
    {
        list = g_list_append (list, pixbuf);
    }
    
    gtk_window_set_default_icon_list (list);
    
    real_list = gtk_window_get_default_icon_list ();
    if (!real_list)
    {
        TEST_FAIL ("real_list is NULL", NULL);
    } else if (g_list_length (real_list) != COUNT) {
        TEST_FAIL ("gtk_window_get_default_icon_list() returns wrong list", NULL);
    }
    g_list_free (list);
    g_list_free (real_list);
    
    #undef IMAGE_FILE_NAME_REL
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_default_icon_list
 * Params: GList*
 * Returns: void
 * Assertion: Sets an icon list to be used as fallback for windows that haven't had gtk_window_set_icon_list() called on them to set up a window-specific icon list'
 * Params Values: GList*
 * Expected: void
 * 
 * Name:  gtk_window_get_default_icon_list
 * Params: void
 * Returns: GList*
 * Assertion: Gets the value set by gtk_window_set_default_icon_list()
 * Params Values: void
 * Expected: GList*  
 */
static void test_purpose_227()
{
    #define IMAGE_FILE_NAME_REL "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
    #define COUNT 5
    
    GtkWidget* widget;
    GdkPixbuf* pixbuf;
    GError* error = NULL;
    gchar* image_file_name;
    gint i;
    GList* list = NULL;
    GList* real_list = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    image_file_name = strdup (getenv ("TET_ROOT"));
    image_file_name = realloc (image_file_name, strlen (image_file_name) + strlen (IMAGE_FILE_NAME_REL) + 1);
    image_file_name = strcat (image_file_name, IMAGE_FILE_NAME_REL);
    
    pixbuf = gdk_pixbuf_new_from_file (image_file_name, &error);
    if (!pixbuf)
    {
        TEST_FAIL ("pixbuf is NULL, error is '%s'", error->message);
        return;
    }
    
    for (i = 0; i < COUNT; i++)
    {
        list = g_list_append (list, pixbuf);
    }
    
    gtk_window_set_default_icon_list (list);
    
    real_list = gtk_window_get_default_icon_list ();
    if (!real_list)
    {
        TEST_FAIL ("real_list is NULL", NULL);
    } else if (g_list_length (real_list) != COUNT) {
        TEST_FAIL ("gtk_window_get_default_icon_list() returns wrong list", NULL);
    }
    g_list_free (list);
    g_list_free (real_list);
    
    #undef IMAGE_FILE_NAME_REL
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_default_icon_list
 * Params: GList*
 * Returns: void
 * Assertion: Sets an icon list to be used as fallback for windows that haven't had gtk_window_set_icon_list() called on them to set up a window-specific icon list'
 * Params Values: GList*
 * Expected: void
 * 
 * Name:  gtk_window_get_default_icon_list
 * Params: void
 * Returns: GList*
 * Assertion: Gets the value set by gtk_window_set_default_icon_list()
 * Params Values: void
 * Expected: GList*  
 */
static void test_purpose_228()
{
    #define IMAGE_FILE_NAME_REL "/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png"
    #define COUNT 49
    
    GtkWidget* widget;
    GdkPixbuf* pixbuf;
    GError* error = NULL;
    gchar* image_file_name;
    gint i;
    GList* list = NULL;
    GList* real_list = NULL;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    image_file_name = strdup (getenv ("TET_ROOT"));
    image_file_name = realloc (image_file_name, strlen (image_file_name) + strlen (IMAGE_FILE_NAME_REL) + 1);
    image_file_name = strcat (image_file_name, IMAGE_FILE_NAME_REL);
    
    pixbuf = gdk_pixbuf_new_from_file (image_file_name, &error);
    if (!pixbuf)
    {
        TEST_FAIL ("pixbuf is NULL, error is '%s'", error->message);
        return;
    }
    
    for (i = 0; i < COUNT; i++)
    {
        list = g_list_append (list, pixbuf);
    }
    
    gtk_window_set_default_icon_list (list);
    
    real_list = gtk_window_get_default_icon_list ();
    if (!real_list)
    {
        TEST_FAIL ("real_list is NULL", NULL);
    } else if (g_list_length (real_list) != COUNT) {
        TEST_FAIL ("gtk_window_get_default_icon_list() returns wrong list", NULL);
    }
    g_list_free (list);
    g_list_free (real_list);
    
    #undef IMAGE_FILE_NAME_REL
    #undef COUNT
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_add_mnemonic
 * Params: GtkWindow *window, guint keyval, GtkWidget *target
 * Returns: void
 * Assertion: Adds a mnemonic to this window.
 * Params Values: GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_A, gtk_button_new_with_label ("button")
 * Expected: void
 * 
 * Name:  gtk_window_remove_mnemonic
 * Params: GtkWindow *window, guint keyval, GtkWidget *target
 * Returns: void
 * Assertion: Removes a mnemonic from this window.
 * Params Values: GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_A, gtk_button_new_with_label ("button")
 * Expected: void
 * 
 * Name:  gtk_window_mnemonic_activate
 * Params: GtkWindow *window, guint keyval, GdkModifierType modifier
 * Returns: void
 * Assertion: Activates the targets associated with the mnemonic.
 * Params Values: GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_A, GDK_MOD1_MASK | GDK_BUTTON5_MASK
 * Expected: void  
 */
static void test_purpose_229()
{
    #define WINDOW_TYPE GTK_WINDOW_TOPLEVEL
    #define MNEMONIC_KEYVAL GDK_A
    #define MODIFIER_TYPE GDK_MOD1_MASK | GDK_BUTTON5_MASK
    #define TARGET gtk_button_new_with_label ("button")
    
    GtkWidget* widget;
    guint keyval;
    GtkWidget* vbox;
    GtkWidget* target;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    target = TARGET;
    
    vbox = gtk_vbox_new (FALSE, 5);
    gtk_container_add (GTK_CONTAINER (vbox), gtk_label_new ("label"));
    gtk_container_add (GTK_CONTAINER (vbox), target);
    gtk_container_add (GTK_CONTAINER (widget), vbox);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    
    g_signal_connect (G_OBJECT (target), "mnemonic_activate",
                      GTK_SIGNAL_FUNC (global_window_mnemonic_activate_handler), 
                      NULL);
    
    global_iter = 0;
    gtk_window_mnemonic_activate (GTK_WINDOW (widget), MNEMONIC_KEYVAL, MODIFIER_TYPE);
    if (global_iter != 0)
    {
        TEST_FAIL ("not added mnemonic activated: global_iter = %d, should be 0", 
                   global_iter);
    }
    
    gtk_window_add_mnemonic (GTK_WINDOW (widget), MNEMONIC_KEYVAL, target);
    
    global_iter = 0;
    gtk_window_mnemonic_activate (GTK_WINDOW (widget), MNEMONIC_KEYVAL, MODIFIER_TYPE);
    if (global_iter != 1)
    {
        TEST_FAIL ("added mnemonic not activated: global_iter = %d, should be 1", 
                   global_iter);
    }
    
    gtk_window_remove_mnemonic (GTK_WINDOW (widget), MNEMONIC_KEYVAL, target);
    
    global_iter = 0;
    gtk_window_mnemonic_activate (GTK_WINDOW (widget), MNEMONIC_KEYVAL, MODIFIER_TYPE);
    if (global_iter != 0)
    {
        TEST_FAIL ("removed  mnemonic activated: global_iter = %d, should be 0", 
                   global_iter);
    }
    
    #undef WINDOW_TYPE
    #undef MNEMONIC_KEYVAL
    #undef MODIFIER_TYPE
    #undef TARGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_add_mnemonic
 * Params: GtkWindow *window, guint keyval, GtkWidget *target
 * Returns: void
 * Assertion: Adds a mnemonic to this window.
 * Params Values: GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_A, gtk_button_new_with_label ("button")
 * Expected: void
 * 
 * Name:  gtk_window_remove_mnemonic
 * Params: GtkWindow *window, guint keyval, GtkWidget *target
 * Returns: void
 * Assertion: Removes a mnemonic from this window.
 * Params Values: GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_A, gtk_button_new_with_label ("button")
 * Expected: void
 * 
 * Name:  gtk_window_mnemonic_activate
 * Params: GtkWindow *window, guint keyval, GdkModifierType modifier
 * Returns: void
 * Assertion: Activates the targets associated with the mnemonic.
 * Params Values: GtkWindow of type GTK_WINDOW_TOPLEVEL, GDK_A, GDK_MOD1_MASK
 * Expected: void  
 */
static void test_purpose_230()
{
    #define WINDOW_TYPE GTK_WINDOW_TOPLEVEL
    #define MNEMONIC_KEYVAL GDK_A
    #define MODIFIER_TYPE GDK_MOD1_MASK
    #define TARGET gtk_button_new_with_label ("button")
    
    GtkWidget* widget;
    guint keyval;
    GtkWidget* vbox;
    GtkWidget* target;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    target = TARGET;
    
    vbox = gtk_vbox_new (FALSE, 5);
    gtk_container_add (GTK_CONTAINER (vbox), gtk_label_new ("label"));
    gtk_container_add (GTK_CONTAINER (vbox), target);
    gtk_container_add (GTK_CONTAINER (widget), vbox);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    
    g_signal_connect (G_OBJECT (target), "mnemonic_activate",
                      GTK_SIGNAL_FUNC (global_window_mnemonic_activate_handler), 
                      NULL);
    
    global_iter = 0;
    gtk_window_mnemonic_activate (GTK_WINDOW (widget), MNEMONIC_KEYVAL, MODIFIER_TYPE);
    if (global_iter != 0)
    {
        TEST_FAIL ("not added mnemonic activated: global_iter = %d, should be 0", 
                   global_iter);
    }
    
    gtk_window_add_mnemonic (GTK_WINDOW (widget), MNEMONIC_KEYVAL, target);
    
    global_iter = 0;
    gtk_window_mnemonic_activate (GTK_WINDOW (widget), MNEMONIC_KEYVAL, MODIFIER_TYPE);
    if (global_iter != 1)
    {
        TEST_FAIL ("added mnemonic not activated: global_iter = %d, should be 1", 
                   global_iter);
    }
    
    gtk_window_remove_mnemonic (GTK_WINDOW (widget), MNEMONIC_KEYVAL, target);
    
    global_iter = 0;
    gtk_window_mnemonic_activate (GTK_WINDOW (widget), MNEMONIC_KEYVAL, MODIFIER_TYPE);
    if (global_iter != 0)
    {
        TEST_FAIL ("removed  mnemonic activated: global_iter = %d, should be 0", 
                   global_iter);
    }
    
    #undef WINDOW_TYPE
    #undef MNEMONIC_KEYVAL
    #undef MODIFIER_TYPE
    #undef TARGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_add_mnemonic
 * Params: GtkWindow *window, guint keyval, GtkWidget *target
 * Returns: void
 * Assertion: Adds a mnemonic to this window.
 * Params Values: GtkWindow of type GTK_WINDOW_POPUP, GDK_A, gtk_button_new_with_label ("button")
 * Expected: void
 * 
 * Name:  gtk_window_remove_mnemonic
 * Params: GtkWindow *window, guint keyval, GtkWidget *target
 * Returns: void
 * Assertion: Removes a mnemonic from this window.
 * Params Values: GtkWindow of type GTK_WINDOW_POPUP, GDK_A, gtk_button_new_with_label ("button")
 * Expected: void
 * 
 * Name:  gtk_window_mnemonic_activate
 * Params: GtkWindow *window, guint keyval, GdkModifierType modifier
 * Returns: void
 * Assertion: Activates the targets associated with the mnemonic.
 * Params Values: GtkWindow of type GTK_WINDOW_POPUP, GDK_A, GDK_MOD1_MASK | GDK_BUTTON5_MASK
 * Expected: void  
 */
static void test_purpose_231()
{
    #define WINDOW_TYPE GTK_WINDOW_POPUP
    #define MNEMONIC_KEYVAL GDK_A
    #define MODIFIER_TYPE GDK_MOD1_MASK | GDK_BUTTON5_MASK
    #define TARGET gtk_button_new_with_label ("button")
    
    GtkWidget* widget;
    guint keyval;
    GtkWidget* vbox;
    GtkWidget* target;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    target = TARGET;
    
    vbox = gtk_vbox_new (FALSE, 5);
    gtk_container_add (GTK_CONTAINER (vbox), gtk_label_new ("label"));
    gtk_container_add (GTK_CONTAINER (vbox), target);
    gtk_container_add (GTK_CONTAINER (widget), vbox);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    
    g_signal_connect (G_OBJECT (target), "mnemonic_activate",
                      GTK_SIGNAL_FUNC (global_window_mnemonic_activate_handler), 
                      NULL);
    
    global_iter = 0;
    gtk_window_mnemonic_activate (GTK_WINDOW (widget), MNEMONIC_KEYVAL, MODIFIER_TYPE);
    if (global_iter != 0)
    {
        TEST_FAIL ("not added mnemonic activated: global_iter = %d, should be 0", 
                   global_iter);
    }
    
    gtk_window_add_mnemonic (GTK_WINDOW (widget), MNEMONIC_KEYVAL, target);
    
    global_iter = 0;
    gtk_window_mnemonic_activate (GTK_WINDOW (widget), MNEMONIC_KEYVAL, MODIFIER_TYPE);
    if (global_iter != 1)
    {
        TEST_FAIL ("added mnemonic not activated: global_iter = %d, should be 1", 
                   global_iter);
    }
    
    gtk_window_remove_mnemonic (GTK_WINDOW (widget), MNEMONIC_KEYVAL, target);
    
    global_iter = 0;
    gtk_window_mnemonic_activate (GTK_WINDOW (widget), MNEMONIC_KEYVAL, MODIFIER_TYPE);
    if (global_iter != 0)
    {
        TEST_FAIL ("removed  mnemonic activated: global_iter = %d, should be 0", 
                   global_iter);
    }
    
    #undef WINDOW_TYPE
    #undef MNEMONIC_KEYVAL
    #undef MODIFIER_TYPE
    #undef TARGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_add_mnemonic
 * Params: GtkWindow *window, guint keyval, GtkWidget *target
 * Returns: void
 * Assertion: Adds a mnemonic to this window.
 * Params Values: GtkWindow of type GTK_WINDOW_POPUP, GDK_A, gtk_button_new_with_label ("button")
 * Expected: void
 * 
 * Name:  gtk_window_remove_mnemonic
 * Params: GtkWindow *window, guint keyval, GtkWidget *target
 * Returns: void
 * Assertion: Removes a mnemonic from this window.
 * Params Values: GtkWindow of type GTK_WINDOW_POPUP, GDK_A, gtk_button_new_with_label ("button")
 * Expected: void
 * 
 * Name:  gtk_window_mnemonic_activate
 * Params: GtkWindow *window, guint keyval, GdkModifierType modifier
 * Returns: void
 * Assertion: Activates the targets associated with the mnemonic.
 * Params Values: GtkWindow of type GTK_WINDOW_POPUP, GDK_A, GDK_MOD1_MASK
 * Expected: void  
 */
static void test_purpose_232()
{
    #define WINDOW_TYPE GTK_WINDOW_POPUP
    #define MNEMONIC_KEYVAL GDK_A
    #define MODIFIER_TYPE GDK_MOD1_MASK
    #define TARGET gtk_button_new_with_label ("button")
    
    GtkWidget* widget;
    guint keyval;
    GtkWidget* vbox;
    GtkWidget* target;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    target = TARGET;
    
    vbox = gtk_vbox_new (FALSE, 5);
    gtk_container_add (GTK_CONTAINER (vbox), gtk_label_new ("label"));
    gtk_container_add (GTK_CONTAINER (vbox), target);
    gtk_container_add (GTK_CONTAINER (widget), vbox);
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    
    g_signal_connect (G_OBJECT (target), "mnemonic_activate",
                      GTK_SIGNAL_FUNC (global_window_mnemonic_activate_handler), 
                      NULL);
    
    global_iter = 0;
    gtk_window_mnemonic_activate (GTK_WINDOW (widget), MNEMONIC_KEYVAL, MODIFIER_TYPE);
    if (global_iter != 0)
    {
        TEST_FAIL ("not added mnemonic activated: global_iter = %d, should be 0", 
                   global_iter);
    }
    
    gtk_window_add_mnemonic (GTK_WINDOW (widget), MNEMONIC_KEYVAL, target);
    
    global_iter = 0;
    gtk_window_mnemonic_activate (GTK_WINDOW (widget), MNEMONIC_KEYVAL, MODIFIER_TYPE);
    if (global_iter != 1)
    {
        TEST_FAIL ("added mnemonic not activated: global_iter = %d, should be 1", 
                   global_iter);
    }
    
    gtk_window_remove_mnemonic (GTK_WINDOW (widget), MNEMONIC_KEYVAL, target);
    
    global_iter = 0;
    gtk_window_mnemonic_activate (GTK_WINDOW (widget), MNEMONIC_KEYVAL, MODIFIER_TYPE);
    if (global_iter != 0)
    {
        TEST_FAIL ("removed  mnemonic activated: global_iter = %d, should be 0", 
                   global_iter);
    }
    
    #undef WINDOW_TYPE
    #undef MNEMONIC_KEYVAL
    #undef MODIFIER_TYPE
    #undef TARGET
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_screen
 * Params: GtkWindow *window, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GdkScreen where the window is displayed; if the window is already mapped, it will be unmapped, and then remapped on the new screen.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, GdkScreen*
 * Expected: void
 * 
 * Name:  gtk_window_get_screen
 * Params: GtkWindow *window
 * Returns: GdkScreen*
 * Assertion: Returns the GdkScreen associated with window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: GdkScreen*  
 */
static void test_purpose_233()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    screen = gdk_screen_get_default ();
    gtk_window_set_screen (GTK_WINDOW (widget), screen);
    
    real_screen = gtk_window_get_screen (GTK_WINDOW (widget));
    if (!real_screen)
    {
        TEST_FAIL ("real_screen is NULL, should be not", NULL);
        return;
    }
    
    if (real_screen != screen)
    {
        TEST_FAIL ("real_screen differs from the one was set", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_screen
 * Params: GtkWindow *window, GdkScreen *screen
 * Returns: void
 * Assertion: Sets the GdkScreen where the window is displayed; if the window is already mapped, it will be unmapped, and then remapped on the new screen.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, GdkScreen*
 * Expected: void
 * 
 * Name:  gtk_window_get_screen
 * Params: GtkWindow *window
 * Returns: GdkScreen*
 * Assertion: Returns the GdkScreen associated with window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: GdkScreen*  
 */
static void test_purpose_234()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    
    GtkWidget* widget;
    GdkScreen* screen;
    GdkScreen* real_screen;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new (WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    screen = gdk_screen_get_default ();
    gtk_window_set_screen (GTK_WINDOW (widget), screen);
    
    real_screen = gtk_window_get_screen (GTK_WINDOW (widget));
    if (!real_screen)
    {
        TEST_FAIL ("real_screen is NULL, should be not", NULL);
        return;
    }
    
    if (real_screen != screen)
    {
        TEST_FAIL ("real_screen differs from the one was set", NULL);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_skip_pager_hint
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion:  This function toggles this hint.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, TRUE
 * Expected: void  
 */
static void test_purpose_235()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define SKIP_HINT TRUE
    
    GtkWidget* widget;
    gboolean real_skip_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_skip_pager_hint (GTK_WINDOW (widget), SKIP_HINT);
    
    g_object_get (GTK_OBJECT(widget), "skip-pager-hint", &real_skip_hint, NULL);
    
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  SKIP_HINT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_skip_pager_hint
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion:  This function toggles this hint.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, FALSE
 * Expected: void  
 */
static void test_purpose_236()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define SKIP_HINT FALSE
    
    GtkWidget* widget;
    gboolean real_skip_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_skip_pager_hint (GTK_WINDOW (widget), SKIP_HINT);
    
    g_object_get (GTK_OBJECT(widget), "skip-pager-hint", &real_skip_hint, NULL);
    
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  SKIP_HINT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_skip_pager_hint
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion:  This function toggles this hint.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, TRUE
 * Expected: void  
 */
static void test_purpose_237()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define SKIP_HINT TRUE
    
    GtkWidget* widget;
    gboolean real_skip_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_skip_pager_hint (GTK_WINDOW (widget), SKIP_HINT);
    
    g_object_get (GTK_OBJECT(widget), "skip-pager-hint", &real_skip_hint, NULL);
    
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  SKIP_HINT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_skip_pager_hint
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion:  This function toggles this hint.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, FALSE
 * Expected: void  
 */
static void test_purpose_238()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define SKIP_HINT FALSE
    
    GtkWidget* widget;
    gboolean real_skip_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_skip_pager_hint (GTK_WINDOW (widget), SKIP_HINT);
    
    g_object_get (GTK_OBJECT(widget), "skip-pager-hint", &real_skip_hint, NULL);
    
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  SKIP_HINT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_skip_pager_hint
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion:  Gets the value set by gtk_window_set_skip_pager_hint().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: TRUE  
 */
static void test_purpose_239()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define SKIP_HINT TRUE
    
    GtkWidget* widget;
    gboolean real_skip_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_skip_pager_hint (GTK_WINDOW (widget), SKIP_HINT);
    real_skip_hint = gtk_window_get_skip_pager_hint (GTK_WINDOW (widget));
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("1: real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    g_object_set (GTK_OBJECT(widget), "skip-pager-hint", SKIP_HINT, NULL);
    real_skip_hint = gtk_window_get_skip_pager_hint (GTK_WINDOW (widget));
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("2: real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  SKIP_HINT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_skip_pager_hint
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion:  Gets the value set by gtk_window_set_skip_pager_hint().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: FALSE  
 */
static void test_purpose_240()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define SKIP_HINT FALSE
    
    GtkWidget* widget;
    gboolean real_skip_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_skip_pager_hint (GTK_WINDOW (widget), SKIP_HINT);
    real_skip_hint = gtk_window_get_skip_pager_hint (GTK_WINDOW (widget));
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("1: real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    g_object_set (GTK_OBJECT(widget), "skip-pager-hint", SKIP_HINT, NULL);
    real_skip_hint = gtk_window_get_skip_pager_hint (GTK_WINDOW (widget));
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("2: real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  SKIP_HINT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_skip_pager_hint
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion:  Gets the value set by gtk_window_set_skip_pager_hint().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: TRUE  
 */
static void test_purpose_241()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define SKIP_HINT TRUE
    
    GtkWidget* widget;
    gboolean real_skip_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_skip_pager_hint (GTK_WINDOW (widget), SKIP_HINT);
    real_skip_hint = gtk_window_get_skip_pager_hint (GTK_WINDOW (widget));
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("1: real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    g_object_set (GTK_OBJECT(widget), "skip-pager-hint", SKIP_HINT, NULL);
    real_skip_hint = gtk_window_get_skip_pager_hint (GTK_WINDOW (widget));
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("2: real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  SKIP_HINT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_skip_pager_hint
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion:  Gets the value set by gtk_window_set_skip_pager_hint().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: FALSE  
 */
static void test_purpose_242()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define SKIP_HINT FALSE
    
    GtkWidget* widget;
    gboolean real_skip_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_skip_pager_hint (GTK_WINDOW (widget), SKIP_HINT);
    real_skip_hint = gtk_window_get_skip_pager_hint (GTK_WINDOW (widget));
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("1: real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    g_object_set (GTK_OBJECT(widget), "skip-pager-hint", SKIP_HINT, NULL);
    real_skip_hint = gtk_window_get_skip_pager_hint (GTK_WINDOW (widget));
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("2: real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  SKIP_HINT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_skip_taskbar_hint
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion:  This function toggles this hint.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, TRUE
 * Expected: void  
 */
static void test_purpose_243()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define SKIP_HINT TRUE
    
    GtkWidget* widget;
    gboolean real_skip_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_skip_taskbar_hint (GTK_WINDOW (widget), SKIP_HINT);
    
    g_object_get (GTK_OBJECT(widget), "skip-taskbar-hint", &real_skip_hint, NULL);
    
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  SKIP_HINT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_skip_taskbar_hint
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion:  This function toggles this hint.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, FALSE
 * Expected: void  
 */
static void test_purpose_244()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define SKIP_HINT FALSE
    
    GtkWidget* widget;
    gboolean real_skip_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_skip_taskbar_hint (GTK_WINDOW (widget), SKIP_HINT);
    
    g_object_get (GTK_OBJECT(widget), "skip-taskbar-hint", &real_skip_hint, NULL);
    
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  SKIP_HINT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_skip_taskbar_hint
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion:  This function toggles this hint.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, TRUE
 * Expected: void  
 */
static void test_purpose_245()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define SKIP_HINT TRUE
    
    GtkWidget* widget;
    gboolean real_skip_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_skip_taskbar_hint (GTK_WINDOW (widget), SKIP_HINT);
    
    g_object_get (GTK_OBJECT(widget), "skip-taskbar-hint", &real_skip_hint, NULL);
    
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  SKIP_HINT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_skip_taskbar_hint
 * Params: GtkWindow *window, gboolean setting
 * Returns: void
 * Assertion:  This function toggles this hint.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, FALSE
 * Expected: void  
 */
static void test_purpose_246()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define SKIP_HINT FALSE
    
    GtkWidget* widget;
    gboolean real_skip_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_skip_taskbar_hint (GTK_WINDOW (widget), SKIP_HINT);
    
    g_object_get (GTK_OBJECT(widget), "skip-taskbar-hint", &real_skip_hint, NULL);
    
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  SKIP_HINT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_skip_taskbar_hint
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion:  Gets the value set by gtk_window_set_skip_taskbar_hint().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: TRUE  
 */
static void test_purpose_247()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define SKIP_HINT TRUE
    
    GtkWidget* widget;
    gboolean real_skip_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_skip_taskbar_hint (GTK_WINDOW (widget), SKIP_HINT);
    real_skip_hint = gtk_window_get_skip_taskbar_hint (GTK_WINDOW (widget));
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("1: real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    g_object_set (GTK_OBJECT(widget), "skip-taskbar-hint", SKIP_HINT, NULL);
    real_skip_hint = gtk_window_get_skip_taskbar_hint (GTK_WINDOW (widget));
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("2: real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  SKIP_HINT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_skip_taskbar_hint
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion:  Gets the value set by gtk_window_set_skip_taskbar_hint().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: FALSE  
 */
static void test_purpose_248()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define SKIP_HINT FALSE
    
    GtkWidget* widget;
    gboolean real_skip_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_skip_taskbar_hint (GTK_WINDOW (widget), SKIP_HINT);
    real_skip_hint = gtk_window_get_skip_taskbar_hint (GTK_WINDOW (widget));
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("1: real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    g_object_set (GTK_OBJECT(widget), "skip-taskbar-hint", SKIP_HINT, NULL);
    real_skip_hint = gtk_window_get_skip_taskbar_hint (GTK_WINDOW (widget));
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("2: real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  SKIP_HINT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_skip_taskbar_hint
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion:  Gets the value set by gtk_window_set_skip_taskbar_hint().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: TRUE  
 */
static void test_purpose_249()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define SKIP_HINT TRUE
    
    GtkWidget* widget;
    gboolean real_skip_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_skip_taskbar_hint (GTK_WINDOW (widget), SKIP_HINT);
    real_skip_hint = gtk_window_get_skip_taskbar_hint (GTK_WINDOW (widget));
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("1: real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    g_object_set (GTK_OBJECT(widget), "skip-taskbar-hint", SKIP_HINT, NULL);
    real_skip_hint = gtk_window_get_skip_taskbar_hint (GTK_WINDOW (widget));
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("2: real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  SKIP_HINT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_get_skip_taskbar_hint
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion:  Gets the value set by gtk_window_set_skip_taskbar_hint().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: FALSE  
 */
static void test_purpose_250()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define SKIP_HINT FALSE
    
    GtkWidget* widget;
    gboolean real_skip_hint;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    gtk_window_set_skip_taskbar_hint (GTK_WINDOW (widget), SKIP_HINT);
    real_skip_hint = gtk_window_get_skip_taskbar_hint (GTK_WINDOW (widget));
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("1: real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    g_object_set (GTK_OBJECT(widget), "skip-taskbar-hint", SKIP_HINT, NULL);
    real_skip_hint = gtk_window_get_skip_taskbar_hint (GTK_WINDOW (widget));
    if (real_skip_hint != SKIP_HINT)
    {
        TEST_FAIL ("2: real_skip_hint is %d, should be %d", 
                   real_skip_hint, SKIP_HINT);
    }
    
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  SKIP_HINT 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_fullscreen
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Asks to place window in the fullscreen state.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void
 * 
 * Name:  gtk_window_unfullscreen
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Asks to toggle off the fullscreen state for window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: void  
 */
static void test_purpose_251()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    
    GtkWidget* widget1;
    GtkWidget* widget2;
    GdkScreen* screen;
    GdkScreen* real_screen;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_iter = 0;
    global_is_fullscreened = FALSE;
    
    widget1 = gtk_window_new (WINDOW_TYPE);
    if (!widget1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget1))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget2 = gtk_window_new (WINDOW_TYPE);
    if (!widget2)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget2))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget1);
    /******* -------------  *******/  
    gtk_window_fullscreen (GTK_WINDOW (widget1));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget2);
    /******* -------------  *******/  
    gtk_window_fullscreen (GTK_WINDOW (widget2));
    gtk_window_unfullscreen (GTK_WINDOW (widget2));
    
    gtk_widget_destroy (widget1);
    gtk_widget_destroy (widget2);
    
    #undef  WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_fullscreen
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Asks to place window in the fullscreen state.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void
 * 
 * Name:  gtk_window_unfullscreen
 * Params: GtkWindow *window
 * Returns: void
 * Assertion: Asks to toggle off the fullscreen state for window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: void  
 */
static void test_purpose_252()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    
    GtkWidget* widget1;
    GtkWidget* widget2;
    GdkScreen* screen;
    GdkScreen* real_screen;
    gint i;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    global_iter = 0;
    global_is_fullscreened = FALSE;
    
    widget1 = gtk_window_new (WINDOW_TYPE);
    if (!widget1)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget1))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    widget2 = gtk_window_new (WINDOW_TYPE);
    if (!widget2)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget2))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget1);
    /******* -------------  *******/  
    gtk_window_fullscreen (GTK_WINDOW (widget1));
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget2);
    /******* -------------  *******/  
    gtk_window_fullscreen (GTK_WINDOW (widget2));
    gtk_window_unfullscreen (GTK_WINDOW (widget2));
    
    gtk_widget_destroy (widget1);
    gtk_widget_destroy (widget2);
    
    #undef  WINDOW_TYPE 
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_resizable
 * Params: GtkWindow *window, gboolean resizable 
 * Returns: void
 * Assertion: Sets whether the user can resize a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, TRUE
 * Expected: void
 * 
 * Name:  gtk_window_set_resizable
 * Params: GtkWindow *window, gboolean resizable 
 * Returns: void
 * Assertion: Windows are user resizable by default.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, TRUE
 * Expected: void
 * 
 * Name:  gtk_window_get_resizable
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Gets the value set by gtk_window_set_resizable().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: TRUE  
 */
static void test_purpose_253()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define RESIZABLE TRUE
    
    GtkWidget* widget;
    gboolean resizable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (!gtk_window_get_resizable (GTK_WINDOW (widget)))
    {
        TEST_FAIL ("windows should be resizable by default", NULL);
    }
    
    gtk_window_set_resizable (GTK_WINDOW (widget), RESIZABLE);
    
    g_object_get (GTK_OBJECT (widget), "resizable", &resizable, NULL);
    if (resizable != RESIZABLE)
    {
        TEST_FAIL ("resizable is %d, should be %d", resizable, RESIZABLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  RESIZABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_resizable
 * Params: GtkWindow *window, gboolean resizable 
 * Returns: void
 * Assertion: Sets whether the user can resize a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, FALSE
 * Expected: void
 * 
 * Name:  gtk_window_set_resizable
 * Params: GtkWindow *window, gboolean resizable 
 * Returns: void
 * Assertion: Windows are user resizable by default.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL, FALSE
 * Expected: void
 * 
 * Name:  gtk_window_get_resizable
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Gets the value set by gtk_window_set_resizable().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_TOPLEVEL
 * Expected: FALSE  
 */
static void test_purpose_254()
{
    #define WINDOW_TYPE  GTK_WINDOW_TOPLEVEL
    #define RESIZABLE FALSE
    
    GtkWidget* widget;
    gboolean resizable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (!gtk_window_get_resizable (GTK_WINDOW (widget)))
    {
        TEST_FAIL ("windows should be resizable by default", NULL);
    }
    
    gtk_window_set_resizable (GTK_WINDOW (widget), RESIZABLE);
    
    g_object_get (GTK_OBJECT (widget), "resizable", &resizable, NULL);
    if (resizable != RESIZABLE)
    {
        TEST_FAIL ("resizable is %d, should be %d", resizable, RESIZABLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  RESIZABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_resizable
 * Params: GtkWindow *window, gboolean resizable 
 * Returns: void
 * Assertion: Sets whether the user can resize a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, TRUE
 * Expected: void
 * 
 * Name:  gtk_window_set_resizable
 * Params: GtkWindow *window, gboolean resizable 
 * Returns: void
 * Assertion: Windows are user resizable by default.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, TRUE
 * Expected: void
 * 
 * Name:  gtk_window_get_resizable
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Gets the value set by gtk_window_set_resizable().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: TRUE  
 */
static void test_purpose_255()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define RESIZABLE TRUE
    
    GtkWidget* widget;
    gboolean resizable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (!gtk_window_get_resizable (GTK_WINDOW (widget)))
    {
        TEST_FAIL ("windows should be resizable by default", NULL);
    }
    
    gtk_window_set_resizable (GTK_WINDOW (widget), RESIZABLE);
    
    g_object_get (GTK_OBJECT (widget), "resizable", &resizable, NULL);
    if (resizable != RESIZABLE)
    {
        TEST_FAIL ("resizable is %d, should be %d", resizable, RESIZABLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  RESIZABLE
    
	
    test_passed ();

    double_bug = 0;
}

/*
 * Name:  gtk_window_set_resizable
 * Params: GtkWindow *window, gboolean resizable 
 * Returns: void
 * Assertion: Sets whether the user can resize a window.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, FALSE
 * Expected: void
 * 
 * Name:  gtk_window_set_resizable
 * Params: GtkWindow *window, gboolean resizable 
 * Returns: void
 * Assertion: Windows are user resizable by default.
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP, FALSE
 * Expected: void
 * 
 * Name:  gtk_window_get_resizable
 * Params: GtkWindow *window
 * Returns: gboolean
 * Assertion: Gets the value set by gtk_window_set_resizable().
 * Params Values: a newly created GtkWindow of type GTK_WINDOW_POPUP
 * Expected: FALSE  
 */
static void test_purpose_256()
{
    #define WINDOW_TYPE  GTK_WINDOW_POPUP
    #define RESIZABLE FALSE
    
    GtkWidget* widget;
    gboolean resizable;
    

    bug_inf = NULL;
    test_passed_flag = 1;          
    all_test_purp_num++;
    fprintf (stderr, mark_symbol (all_test_purp_num));
    tet_printf("test case: %s, TP number: %d ", tet_pname, tet_thistest);

    widget = gtk_window_new(WINDOW_TYPE);
    
    if (!widget)
    {
        TEST_FAIL (get_not_created_msg (), NULL); 
        return;
    } 
    
    if (!GTK_IS_WINDOW (widget))
    {
        TEST_FAIL (get_wrong_type_msg (), NULL); 
        return;
    }
    
    if (!gtk_window_get_resizable (GTK_WINDOW (widget)))
    {
        TEST_FAIL ("windows should be resizable by default", NULL);
    }
    
    gtk_window_set_resizable (GTK_WINDOW (widget), RESIZABLE);
    
    g_object_get (GTK_OBJECT (widget), "resizable", &resizable, NULL);
    if (resizable != RESIZABLE)
    {
        TEST_FAIL ("resizable is %d, should be %d", resizable, RESIZABLE);
    }
    
    /******* VISUALISATION *******/
    TEST_VISUALIZE (widget);
    /******* -------------  *******/  
    
    gtk_widget_destroy (widget);
    
    #undef  WINDOW_TYPE 
    #undef  RESIZABLE
    
	
    test_passed ();

    double_bug = 0;
}


static 
char* get_not_created_msg (void)
{
        return "Widget is not created\n";
}

static 
char* get_wrong_type_msg (void)
{
        return "Created widget is of wrong type\n";
}


/*
 *  test_passed
 */
static void 
test_passed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    if (test_passed_flag)
    {
        test_purp_passed_num++;
    }
    tet_result (TET_PASS);
}

/*
 *  test_failed
 */
static void
test_failed (void)
{
    if (bug_inf && !double_bug)
    {
	double_bug = 1;
    }

    test_passed_flag = 0;
    tet_result (TET_FAIL);
}

/*
 * startup_func
 * open display and initialize other per test case things
 */
static void 
startup_func()
{
    int argc = 1;
    char** argv = NULL;

    argv = calloc(argc,  sizeof(char*));
    argv[0] = (char*)strdup(""); 
    gtk_init(&argc, &argv);
    fprintf (stderr, "Function tests for GtkWindow ");
}
 
/*
 * cleanup_func
 */
static void 
cleanup_func()
{

    fprintf (stderr, " %d passed", test_purp_passed_num);
    if (all_test_purp_num != test_purp_passed_num)
    {
        fprintf (stderr, " %d FAILED", all_test_purp_num - test_purp_passed_num);        
    }
    fprintf (stderr, "\n"); 
}


/* 
 *Program hooks into the tet harness 
 */
void (*tet_startup)() = startup_func;
void (*tet_cleanup)() = cleanup_func;

/*
 * TET Tests included in this file. 
 */
struct tet_testlist tet_testlist[] = {
    {test_purpose_1, 1},
    {test_purpose_2, 1},
    {test_purpose_3, 1},
    {test_purpose_4, 1},
    {test_purpose_5, 1},
    {test_purpose_6, 1},
    {test_purpose_7, 1},
    {test_purpose_8, 1},
    {test_purpose_9, 1},
    {test_purpose_10, 1},
    {test_purpose_11, 1},
    {test_purpose_12, 1},
    {test_purpose_13, 1},
    {test_purpose_14, 1},
    {test_purpose_15, 1},
    {test_purpose_16, 1},
    {test_purpose_17, 1},
    {test_purpose_18, 1},
    {test_purpose_19, 1},
    {test_purpose_20, 1},
    {test_purpose_21, 1},
    {test_purpose_22, 1},
    {test_purpose_23, 1},
    {test_purpose_24, 1},
    {test_purpose_25, 1},
    {test_purpose_26, 1},
    {test_purpose_27, 1},
    {test_purpose_28, 1},
    {test_purpose_29, 1},
    {test_purpose_30, 1},
    {test_purpose_31, 1},
    {test_purpose_32, 1},
    {test_purpose_33, 1},
    {test_purpose_34, 1},
    {test_purpose_35, 1},
    {test_purpose_36, 1},
    {test_purpose_37, 1},
    {test_purpose_38, 1},
    {test_purpose_39, 1},
    {test_purpose_40, 1},
    {test_purpose_41, 1},
    {test_purpose_42, 1},
    {test_purpose_43, 1},
    {test_purpose_44, 1},
    {test_purpose_45, 1},
    {test_purpose_46, 1},
    {test_purpose_47, 1},
    {test_purpose_48, 1},
    {test_purpose_49, 1},
    {test_purpose_50, 1},
    {test_purpose_51, 1},
    {test_purpose_52, 1},
    {test_purpose_53, 1},
    {test_purpose_54, 1},
    {test_purpose_55, 1},
    {test_purpose_56, 1},
    {test_purpose_57, 1},
    {test_purpose_58, 1},
    {test_purpose_59, 1},
    {test_purpose_60, 1},
    {test_purpose_61, 1},
    {test_purpose_62, 1},
    {test_purpose_63, 1},
    {test_purpose_64, 1},
    {test_purpose_65, 1},
    {test_purpose_66, 1},
    {test_purpose_67, 1},
    {test_purpose_68, 1},
    {test_purpose_69, 1},
    {test_purpose_70, 1},
    {test_purpose_71, 1},
    {test_purpose_72, 1},
    {test_purpose_73, 1},
    {test_purpose_74, 1},
    {test_purpose_75, 1},
    {test_purpose_76, 1},
    {test_purpose_77, 1},
    {test_purpose_78, 1},
    {test_purpose_79, 1},
    {test_purpose_80, 1},
    {test_purpose_81, 1},
    {test_purpose_82, 1},
    {test_purpose_83, 1},
    {test_purpose_84, 1},
    {test_purpose_85, 1},
    {test_purpose_86, 1},
    {test_purpose_87, 1},
    {test_purpose_88, 1},
    {test_purpose_89, 1},
    {test_purpose_90, 1},
    {test_purpose_91, 1},
    {test_purpose_92, 1},
    {test_purpose_93, 1},
    {test_purpose_94, 1},
    {test_purpose_95, 1},
    {test_purpose_96, 1},
    {test_purpose_97, 1},
    {test_purpose_98, 1},
    {test_purpose_99, 1},
    {test_purpose_100, 1},
    {test_purpose_101, 1},
    {test_purpose_102, 1},
    {test_purpose_103, 1},
    {test_purpose_104, 1},
    {test_purpose_105, 1},
    {test_purpose_106, 1},
    {test_purpose_107, 1},
    {test_purpose_108, 1},
    {test_purpose_109, 1},
    {test_purpose_110, 1},
    {test_purpose_111, 1},
    {test_purpose_112, 1},
    {test_purpose_113, 1},
    {test_purpose_114, 1},
    {test_purpose_115, 1},
    {test_purpose_116, 1},
    {test_purpose_117, 1},
    {test_purpose_118, 1},
    {test_purpose_119, 1},
    {test_purpose_120, 1},
    {test_purpose_121, 1},
    {test_purpose_122, 1},
    {test_purpose_123, 1},
    {test_purpose_124, 1},
    {test_purpose_125, 1},
    {test_purpose_126, 1},
    {test_purpose_127, 1},
    {test_purpose_128, 1},
    {test_purpose_129, 1},
    {test_purpose_130, 1},
    {test_purpose_131, 1},
    {test_purpose_132, 1},
    {test_purpose_133, 1},
    {test_purpose_134, 1},
    {test_purpose_135, 1},
    {test_purpose_136, 1},
    {test_purpose_137, 1},
    {test_purpose_138, 1},
    {test_purpose_139, 1},
    {test_purpose_140, 1},
    {test_purpose_141, 1},
    {test_purpose_142, 1},
    {test_purpose_143, 1},
    {test_purpose_144, 1},
    {test_purpose_145, 1},
    {test_purpose_146, 1},
    {test_purpose_147, 1},
    {test_purpose_148, 1},
    {test_purpose_149, 1},
    {test_purpose_150, 1},
    {test_purpose_151, 1},
    {test_purpose_152, 1},
    {test_purpose_153, 1},
    {test_purpose_154, 1},
    {test_purpose_155, 1},
    {test_purpose_156, 1},
    {test_purpose_157, 1},
    {test_purpose_158, 1},
    {test_purpose_159, 1},
    {test_purpose_160, 1},
    {test_purpose_161, 1},
    {test_purpose_162, 1},
    {test_purpose_163, 1},
    {test_purpose_164, 1},
    {test_purpose_165, 1},
    {test_purpose_166, 1},
    {test_purpose_167, 1},
    {test_purpose_168, 1},
    {test_purpose_169, 1},
    {test_purpose_170, 1},
    {test_purpose_171, 1},
    {test_purpose_172, 1},
    {test_purpose_173, 1},
    {test_purpose_174, 1},
    {test_purpose_175, 1},
    {test_purpose_176, 1},
    {test_purpose_177, 1},
    {test_purpose_178, 1},
    {test_purpose_179, 1},
    {test_purpose_180, 1},
    {test_purpose_181, 1},
    {test_purpose_182, 1},
    {test_purpose_183, 1},
    {test_purpose_184, 1},
    {test_purpose_185, 1},
    {test_purpose_186, 1},
    {test_purpose_187, 1},
    {test_purpose_188, 1},
    {test_purpose_189, 1},
    {test_purpose_190, 1},
    {test_purpose_191, 1},
    {test_purpose_192, 1},
    {test_purpose_193, 1},
    {test_purpose_194, 1},
    {test_purpose_195, 1},
    {test_purpose_196, 1},
    {test_purpose_197, 1},
    {test_purpose_198, 1},
    {test_purpose_199, 1},
    {test_purpose_200, 1},
    {test_purpose_201, 1},
    {test_purpose_202, 1},
    {test_purpose_203, 1},
    {test_purpose_204, 1},
    {test_purpose_205, 1},
    {test_purpose_206, 1},
    {test_purpose_207, 1},
    {test_purpose_208, 1},
    {test_purpose_209, 1},
    {test_purpose_210, 1},
    {test_purpose_211, 1},
    {test_purpose_212, 1},
    {test_purpose_213, 1},
    {test_purpose_214, 1},
    {test_purpose_215, 1},
    {test_purpose_216, 1},
    {test_purpose_217, 1},
    {test_purpose_218, 1},
    {test_purpose_219, 1},
    {test_purpose_220, 1},
    {test_purpose_221, 1},
    {test_purpose_222, 1},
    {test_purpose_223, 1},
    {test_purpose_224, 1},
    {test_purpose_225, 1},
    {test_purpose_226, 1},
    {test_purpose_227, 1},
    {test_purpose_228, 1},
    {test_purpose_229, 1},
    {test_purpose_230, 1},
    {test_purpose_231, 1},
    {test_purpose_232, 1},
    {test_purpose_233, 1},
    {test_purpose_234, 1},
    {test_purpose_235, 1},
    {test_purpose_236, 1},
    {test_purpose_237, 1},
    {test_purpose_238, 1},
    {test_purpose_239, 1},
    {test_purpose_240, 1},
    {test_purpose_241, 1},
    {test_purpose_242, 1},
    {test_purpose_243, 1},
    {test_purpose_244, 1},
    {test_purpose_245, 1},
    {test_purpose_246, 1},
    {test_purpose_247, 1},
    {test_purpose_248, 1},
    {test_purpose_249, 1},
    {test_purpose_250, 1},
    {test_purpose_251, 1},
    {test_purpose_252, 1},
    {test_purpose_253, 1},
    {test_purpose_254, 1},
    {test_purpose_255, 1},
    {test_purpose_256, 1},
    {NULL,0}
};
